(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    150250,       3175]*)
(*NotebookOutlinePosition[    150905,       3198]*)
(*  CellTagsIndexPosition[    150861,       3194]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Droplet Source Data Form - Diffuser with LabView and No Flare\
\>", "Title"],

Cell["Import Raw Data", "Subtitle"],

Cell[BoxData[{
    \(\(workingDir = "\<C:\\Documents and Settings\\Michael P. \
Schubmehl\\Documents\\hmc\\mth197\\Thesis Data\\good data\\\>";\)\), "\
\[IndentingNewLine]", 
    \(\(filename = "\<9-0\>";\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(rawdata = 
        Import[workingDir <> 
            filename <> "\<.txt\>", "\<Table\>"];\)\), "\[IndentingNewLine]", \

    \(\(rawdata = \(Drop[#, {4}] &\) /@ rawdata;\)\), "\[IndentingNewLine]", 
    \(Join[{{"\<Angle\>", "\<Signal\>", "\<\[PlusMinus]\>", "\<Fixed\>", "\<\
\[PlusMinus]\>"}, {"\<\>", "\<\>", "\<\>", "\<\>", "\<\>"}}, rawdata] // 
      TableForm\)}], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"Angle\"\>", "\<\"Signal\"\>", "\<\"\[PlusMinus]\"\>", \
"\<\"Fixed\"\>", "\<\"\[PlusMinus]\"\>"},
          {"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
          {"3.`", "0.107`", "0.012`", "2.152`", "0.088`"},
          {"4.`", "0.106`", "0.009`", "2.274`", "0.072`"},
          {"5.`", "0.081`", "0.005`", "2.07`", "0.095`"},
          {"6.`", "0.063`", "0.004`", "2.048`", "0.072`"},
          {"7.`", "0.05`", "0.004`", "1.939`", "0.132`"},
          {"8.`", "0.062`", "0.003`", "2.608`", "0.078`"},
          {"9.`", "0.051`", "0.004`", "2.245`", "0.089`"},
          {"10.`", "0.04`", "0.002`", "2.696`", "0.123`"},
          {"12.`", "0.031`", "0.001`", "3.142`", "0.141`"},
          {"14.`", "0.022`", "0.001`", "3.547`", "0.071`"},
          {"16.`", "0.017`", "0.001`", "3.504`", "0.275`"},
          {"18.`", "0.012`", "0.001`", "4.371`", "0.101`"},
          {"20.`", "0.008`", "0.001`", "4.098`", "0.163`"},
          {"25.`", "0.004`", "0.001`", "4.155`", "0.166`"},
          {"9.`", "0.08`", "0.004`", "4.807`", "0.245`"},
          {"8.`", "0.125`", "0.004`", "5.389`", "0.195`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(rawdata = Drop[rawdata, {6, 7}];\)\), "\[IndentingNewLine]", 
    \(\(rawdata = Sort[rawdata, #1[\([1]\)] < #2[\([1]\)] &];\)\)}], "Input"],

Cell[CellGroupData[{

Cell["Process Raw Data", "Subtitle"],

Cell[BoxData[{
    \(<< Graphics`MultipleListPlot`\  (*\ 
      Load\ this\ first\ so\ ErrorBar\ doesn' t\ get\ shadowed\ *) \), "\n", 
    \(\(normFactor = 
        1\/\((rawdata[\([1, 2]\)]\/rawdata[\([1, 4]\)])\);\)\ \ \ \ \ \ \ \ \ \
\ \ \ \ \  (*Allow\ normalization\ by\ first\ point*) \), "\n", 
    \(\(finaldata = 
        Table[{rawdata[\([i, 1]\)], 
            normFactor*rawdata[\([i, 2]\)]\/rawdata[\([i, 4]\)], 
            normFactor*
              Abs[rawdata[\([i, 2]\)]\/rawdata[\([i, 4]\)]] \@\(rawdata[\([i, \
3]\)]\^2\/rawdata[\([i, 2]\)]\^2 + rawdata[\([i, 5]\)]\^2\/rawdata[\([i, \
4]\)]\^2\)}, {i, 1, Length[rawdata]}];\)\), "\n", 
    \(\(finaldataerror = 
        Table[{{finaldata[\([i, 1]\)], finaldata[\([i, 2]\)]}, 
            ErrorBar[finaldata[\([i, 3]\)]]}, {i, 1, 
            Length[finaldata]}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell["Plot Adjusted Data", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"MultipleListPlot", "[", 
          RowBox[{"finaldataerror", ",", 
            StyleBox[\(SymbolShape \[Rule] PlotSymbol[Box]\),
              FontColor->GrayLevel[0.666667]], 
            StyleBox[",",
              FontColor->GrayLevel[0.666667]], 
            StyleBox[\(Frame \[Rule] True\),
              FontColor->GrayLevel[0.666667]], 
            StyleBox[",",
              FontColor->GrayLevel[0.666667]], 
            
            StyleBox[\(FrameLabel \[Rule] {StyleForm[
                    TraditionalForm["\<Angle (\[Degree])\>"], 
                    FontSize \[Rule] 14], 
                  StyleForm[
                    TraditionalForm["\<Intensity (arbitrary units)\>"], 
                    FontSize \[Rule] 14]}\),
              FontColor->GrayLevel[0.666667]], 
            StyleBox[",",
              FontColor->GrayLevel[0.666667]], 
            
            StyleBox[\(PlotLabel \[Rule] 
                StyleForm[TraditionalForm["\<Intensity vs. Angle\>"], 
                  FontSize \[Rule] 20]\),
              FontColor->GrayLevel[0.666667]], 
            StyleBox[",",
              FontColor->GrayLevel[0.666667]], 
            StyleBox[\(PlotRange -> All\),
              FontColor->GrayLevel[0.666667]], ",", \(Axes \[Rule] False\)}], 
          "]"}], ";"}], " "}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.106061 0.04329 0.00701203 0.532716 [
[.11039 -0.0125 -3 -9 ]
[.11039 -0.0125 3 0 ]
[.32684 -0.0125 -6 -9 ]
[.32684 -0.0125 6 0 ]
[.54329 -0.0125 -6 -9 ]
[.54329 -0.0125 6 0 ]
[.75974 -0.0125 -6 -9 ]
[.75974 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -39.6875 -23.9375 ]
[.5 -0.0125 39.6875 -9 ]
[-0.0125 .00701 -6 -4.5 ]
[-0.0125 .00701 0 4.5 ]
[-0.0125 .11356 -18 -4.5 ]
[-0.0125 .11356 0 4.5 ]
[-0.0125 .2201 -18 -4.5 ]
[-0.0125 .2201 0 4.5 ]
[-0.0125 .32664 -18 -4.5 ]
[-0.0125 .32664 0 4.5 ]
[-0.0125 .43318 -18 -4.5 ]
[-0.0125 .43318 0 4.5 ]
[-0.0125 .53973 -6 -4.5 ]
[-0.0125 .53973 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -31.625 -115.063 ]
[-0.01875 .30902 -18 115.063 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -116 0 ]
[.5 .63053 116 18.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11039 0 m
.11039 .00625 L
s
[(5)] .11039 -0.0125 0 1 Mshowa
.32684 0 m
.32684 .00625 L
s
[(10)] .32684 -0.0125 0 1 Mshowa
.54329 0 m
.54329 .00625 L
s
[(15)] .54329 -0.0125 0 1 Mshowa
.75974 0 m
.75974 .00625 L
s
[(20)] .75974 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(25)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.15368 0 m
.15368 .00375 L
s
.19697 0 m
.19697 .00375 L
s
.24026 0 m
.24026 .00375 L
s
.28355 0 m
.28355 .00375 L
s
.37013 0 m
.37013 .00375 L
s
.41342 0 m
.41342 .00375 L
s
.45671 0 m
.45671 .00375 L
s
.5 0 m
.5 .00375 L
s
.58658 0 m
.58658 .00375 L
s
.62987 0 m
.62987 .00375 L
s
.67316 0 m
.67316 .00375 L
s
.71645 0 m
.71645 .00375 L
s
.80303 0 m
.80303 .00375 L
s
.84632 0 m
.84632 .00375 L
s
.88961 0 m
.88961 .00375 L
s
.9329 0 m
.9329 .00375 L
s
.0671 0 m
.0671 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -100.688 -27.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22.9375 translate 1 -1 scale
63.000 15.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Angle) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
113.250 15.188 moveto
(H) show
121.625 15.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\260) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
130.000 15.188 moveto
(L) show
138.375 15.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .00701 m
.00625 .00701 L
s
[(0)] -0.0125 .00701 1 0 Mshowa
0 .11356 m
.00625 .11356 L
s
[(0.2)] -0.0125 .11356 1 0 Mshowa
0 .2201 m
.00625 .2201 L
s
[(0.4)] -0.0125 .2201 1 0 Mshowa
0 .32664 m
.00625 .32664 L
s
[(0.6)] -0.0125 .32664 1 0 Mshowa
0 .43318 m
.00625 .43318 L
s
[(0.8)] -0.0125 .43318 1 0 Mshowa
0 .53973 m
.00625 .53973 L
s
[(1)] -0.0125 .53973 1 0 Mshowa
.125 Mabswid
0 .03365 m
.00375 .03365 L
s
0 .06028 m
.00375 .06028 L
s
0 .08692 m
.00375 .08692 L
s
0 .14019 m
.00375 .14019 L
s
0 .16683 m
.00375 .16683 L
s
0 .19346 m
.00375 .19346 L
s
0 .24673 m
.00375 .24673 L
s
0 .27337 m
.00375 .27337 L
s
0 .30001 m
.00375 .30001 L
s
0 .35328 m
.00375 .35328 L
s
0 .37991 m
.00375 .37991 L
s
0 .40655 m
.00375 .40655 L
s
0 .45982 m
.00375 .45982 L
s
0 .48646 m
.00375 .48646 L
s
0 .51309 m
.00375 .51309 L
s
0 .56636 m
.00375 .56636 L
s
0 .593 m
.00375 .593 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -200.875 -10.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
176.063 10.8125 translate
90 rotate
-176.063 -10.8125 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.625 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Intensity) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
146.750 13.875 moveto
(H) show
155.125 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(arbitrary) show
238.875 13.875 moveto
(units) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
280.750 13.875 moveto
(L) show
289.125 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .61178 m
.11039 .61803 L
s
.32684 .61178 m
.32684 .61803 L
s
.54329 .61178 m
.54329 .61803 L
s
.75974 .61178 m
.75974 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.15368 .61428 m
.15368 .61803 L
s
.19697 .61428 m
.19697 .61803 L
s
.24026 .61428 m
.24026 .61803 L
s
.28355 .61428 m
.28355 .61803 L
s
.37013 .61428 m
.37013 .61803 L
s
.41342 .61428 m
.41342 .61803 L
s
.45671 .61428 m
.45671 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.58658 .61428 m
.58658 .61803 L
s
.62987 .61428 m
.62987 .61803 L
s
.67316 .61428 m
.67316 .61803 L
s
.71645 .61428 m
.71645 .61803 L
s
.80303 .61428 m
.80303 .61803 L
s
.84632 .61428 m
.84632 .61803 L
s
.88961 .61428 m
.88961 .61803 L
s
.9329 .61428 m
.9329 .61803 L
s
.0671 .61428 m
.0671 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00701 m
1 .00701 L
s
.99375 .11356 m
1 .11356 L
s
.99375 .2201 m
1 .2201 L
s
.99375 .32664 m
1 .32664 L
s
.99375 .43318 m
1 .43318 L
s
.99375 .53973 m
1 .53973 L
s
.125 Mabswid
.99625 .03365 m
1 .03365 L
s
.99625 .06028 m
1 .06028 L
s
.99625 .08692 m
1 .08692 L
s
.99625 .14019 m
1 .14019 L
s
.99625 .16683 m
1 .16683 L
s
.99625 .19346 m
1 .19346 L
s
.99625 .24673 m
1 .24673 L
s
.99625 .27337 m
1 .27337 L
s
.99625 .30001 m
1 .30001 L
s
.99625 .35328 m
1 .35328 L
s
.99625 .37991 m
1 .37991 L
s
.99625 .40655 m
1 .40655 L
s
.99625 .45982 m
1 .45982 L
s
.99625 .48646 m
1 .48646 L
s
.99625 .51309 m
1 .51309 L
s
.99625 .56636 m
1 .56636 L
s
.99625 .593 m
1 .593 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -177 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26.4375 translate 1 -1 scale
63.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Intensity) show
183.000 17.750 moveto
(vs) show
207.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
231.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Angle) show
291.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.02381 .60332 m
.02381 .47614 L
s
.02381 .60332 1.5 0 Mabsadd m
.02381 .60332 -1.5 0 Mabsadd L s
.02381 .47614 1.5 0 Mabsadd m
.02381 .47614 -1.5 0 Mabsadd L s
.0671 .55169 m
.0671 .46118 L
s
.0671 .55169 1.5 0 Mabsadd m
.0671 .55169 -1.5 0 Mabsadd L s
.0671 .46118 1.5 0 Mabsadd m
.0671 .46118 -1.5 0 Mabsadd L s
.11039 .45851 m
.11039 .39401 L
s
.11039 .45851 1.5 0 Mabsadd m
.11039 .45851 -1.5 0 Mabsadd L s
.11039 .39401 1.5 0 Mabsadd m
.11039 .39401 -1.5 0 Mabsadd L s
.15368 .36051 m
.15368 .31268 L
s
.15368 .36051 1.5 0 Mabsadd m
.15368 .36051 -1.5 0 Mabsadd L s
.15368 .31268 1.5 0 Mabsadd m
.15368 .31268 -1.5 0 Mabsadd L s
.19697 .31231 m
.19697 .25427 L
s
.19697 .31231 1.5 0 Mabsadd m
.19697 .31231 -1.5 0 Mabsadd L s
.19697 .25427 1.5 0 Mabsadd m
.19697 .25427 -1.5 0 Mabsadd L s
.24026 .26753 m
.24026 .24352 L
s
.24026 .26753 1.5 0 Mabsadd m
.24026 .26753 -1.5 0 Mabsadd L s
.24026 .24352 1.5 0 Mabsadd m
.24026 .24352 -1.5 0 Mabsadd L s
.28355 .19805 m
.28355 .17259 L
s
.28355 .19805 1.5 0 Mabsadd m
.28355 .19805 -1.5 0 Mabsadd L s
.28355 .17259 1.5 0 Mabsadd m
.28355 .17259 -1.5 0 Mabsadd L s
.32684 .17673 m
.32684 .15521 L
s
.32684 .17673 1.5 0 Mabsadd m
.32684 .17673 -1.5 0 Mabsadd L s
.32684 .15521 1.5 0 Mabsadd m
.32684 .15521 -1.5 0 Mabsadd L s
.41342 .11856 m
.41342 .10688 L
s
.41342 .11856 1.5 0 Mabsadd m
.41342 .11856 -1.5 0 Mabsadd L s
.41342 .10688 1.5 0 Mabsadd m
.41342 .10688 -1.5 0 Mabsadd L s
.5 .07677 m
.5 .07016 L
s
.5 .07677 1.5 0 Mabsadd m
.5 .07677 -1.5 0 Mabsadd L s
.5 .07016 1.5 0 Mabsadd m
.5 .07016 -1.5 0 Mabsadd L s
.58658 .06409 m
.58658 .05389 L
s
.58658 .06409 1.5 0 Mabsadd m
.58658 .06409 -1.5 0 Mabsadd L s
.58658 .05389 1.5 0 Mabsadd m
.58658 .05389 -1.5 0 Mabsadd L s
.67316 .03897 m
.67316 .03388 L
s
.67316 .03897 1.5 0 Mabsadd m
.67316 .03897 -1.5 0 Mabsadd L s
.67316 .03388 1.5 0 Mabsadd m
.67316 .03388 -1.5 0 Mabsadd L s
.75974 .03067 m
.75974 .02518 L
s
.75974 .03067 1.5 0 Mabsadd m
.75974 .03067 -1.5 0 Mabsadd L s
.75974 .02518 1.5 0 Mabsadd m
.75974 .02518 -1.5 0 Mabsadd L s
.97619 .01994 m
.97619 .01472 L
s
.97619 .01994 1.5 0 Mabsadd m
.97619 .01994 -1.5 0 Mabsadd L s
.97619 .01472 1.5 0 Mabsadd m
.97619 .01472 -1.5 0 Mabsadd L s
.0001 w
.02381 .53973 -2.5 2.5 Mabsadd m
.02381 .53973 2.5 2.5 Mabsadd L
.02381 .53973 2.5 -2.5 Mabsadd L
.02381 .53973 -2.5 -2.5 Mabsadd L
.02381 .53973 -2.5 2.5 Mabsadd L closepath F
.0671 .50644 -2.5 2.5 Mabsadd m
.0671 .50644 2.5 2.5 Mabsadd L
.0671 .50644 2.5 -2.5 Mabsadd L
.0671 .50644 -2.5 -2.5 Mabsadd L
.0671 .50644 -2.5 2.5 Mabsadd L closepath F
.11039 .42626 -2.5 2.5 Mabsadd m
.11039 .42626 2.5 2.5 Mabsadd L
.11039 .42626 2.5 -2.5 Mabsadd L
.11039 .42626 -2.5 -2.5 Mabsadd L
.11039 .42626 -2.5 2.5 Mabsadd L closepath F
.15368 .33659 -2.5 2.5 Mabsadd m
.15368 .33659 2.5 2.5 Mabsadd L
.15368 .33659 2.5 -2.5 Mabsadd L
.15368 .33659 -2.5 -2.5 Mabsadd L
.15368 .33659 -2.5 2.5 Mabsadd L closepath F
.19697 .28329 -2.5 2.5 Mabsadd m
.19697 .28329 2.5 2.5 Mabsadd L
.19697 .28329 2.5 -2.5 Mabsadd L
.19697 .28329 -2.5 -2.5 Mabsadd L
.19697 .28329 -2.5 2.5 Mabsadd L closepath F
.24026 .25553 -2.5 2.5 Mabsadd m
.24026 .25553 2.5 2.5 Mabsadd L
.24026 .25553 2.5 -2.5 Mabsadd L
.24026 .25553 -2.5 -2.5 Mabsadd L
.24026 .25553 -2.5 2.5 Mabsadd L closepath F
.28355 .18532 -2.5 2.5 Mabsadd m
.28355 .18532 2.5 2.5 Mabsadd L
.28355 .18532 2.5 -2.5 Mabsadd L
.28355 .18532 -2.5 -2.5 Mabsadd L
.28355 .18532 -2.5 2.5 Mabsadd L closepath F
.32684 .16597 -2.5 2.5 Mabsadd m
.32684 .16597 2.5 2.5 Mabsadd L
.32684 .16597 2.5 -2.5 Mabsadd L
.32684 .16597 -2.5 -2.5 Mabsadd L
.32684 .16597 -2.5 2.5 Mabsadd L closepath F
.41342 .11272 -2.5 2.5 Mabsadd m
.41342 .11272 2.5 2.5 Mabsadd L
.41342 .11272 2.5 -2.5 Mabsadd L
.41342 .11272 -2.5 -2.5 Mabsadd L
.41342 .11272 -2.5 2.5 Mabsadd L closepath F
.5 .07347 -2.5 2.5 Mabsadd m
.5 .07347 2.5 2.5 Mabsadd L
.5 .07347 2.5 -2.5 Mabsadd L
.5 .07347 -2.5 -2.5 Mabsadd L
.5 .07347 -2.5 2.5 Mabsadd L closepath F
.58658 .05899 -2.5 2.5 Mabsadd m
.58658 .05899 2.5 2.5 Mabsadd L
.58658 .05899 2.5 -2.5 Mabsadd L
.58658 .05899 -2.5 -2.5 Mabsadd L
.58658 .05899 -2.5 2.5 Mabsadd L closepath F
.67316 .03643 -2.5 2.5 Mabsadd m
.67316 .03643 2.5 2.5 Mabsadd L
.67316 .03643 2.5 -2.5 Mabsadd L
.67316 .03643 -2.5 -2.5 Mabsadd L
.67316 .03643 -2.5 2.5 Mabsadd L closepath F
.75974 .02793 -2.5 2.5 Mabsadd m
.75974 .02793 2.5 2.5 Mabsadd L
.75974 .02793 2.5 -2.5 Mabsadd L
.75974 .02793 -2.5 -2.5 Mabsadd L
.75974 .02793 -2.5 2.5 Mabsadd L closepath F
.97619 .01733 -2.5 2.5 Mabsadd m
.97619 .01733 2.5 2.5 Mabsadd L
.97619 .01733 2.5 -2.5 Mabsadd L
.97619 .01733 -2.5 -2.5 Mabsadd L
.97619 .01733 -2.5 2.5 Mabsadd L closepath F
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{535.063, 330.688},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008G0001BR000`400?l00000o`00003oo`3ooooo
0?oooaT0oooo003o0?ooool0oooo6@3oool00?l0oooo303oool400000280oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`3G0?ooo`00o`3oool@0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3F0?ooo`00o`3oool@0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3F0?ooo`00n@3oool3
00000080oooo0`0000001@3oool00000000000000000oooo00<000000P3oool3000000040?ooo`00
0000oooo0?ooo`L000000P3oool5000000l0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`3E0?ooo`00nP3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0`3oool010000000oooo0?ooo`0000030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3E0?ooo`00
n`3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3E0?ooo`00n`3oool010000000oooo
0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool6000000l0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`3E0?ooo`00n`3oool010000000oooo0?ooo`0000040?oo
o`8000000P3oool010000000oooo0?ooo`0000030?ooo`8000001@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0=D0oooo003l0?ooo`800000103oool2000000030?ooo`0000000000
00@0oooo0`0000000`3oool00000000000040?ooo`030000003oool0oooo00<0oooo1000000@0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0e@3oool00?`0oooo0P00000G0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool00`3oool2000000H0oooo00<000000?ooo`3o
ool0eP3oool00?/0oooo0`00000G0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0=H0oooo003o0?oooaD0oooo
0P00000K0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0=L0oooo003o0?ooocL0oooo0P00003O0?ooo`00o`3ooooo0?oooaT0oooo001_
0?ooo`800000F`3oool500000080oooo0P00001H0?ooo`D000000P3oool2000005P0oooo10000003
0?ooo`800000E`3oool4000000<0oooo0P00000P0?ooo`00KP3oool010000000oooo0?ooo`00001L
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`1G0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool00000EP3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
01l0oooo001a0?ooo`030000003oool0oooo05X0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool00000E`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo01d0oooo001_0?ooo`800000G@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`020?ooo`800000FP3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`020?ooo`800000803oool006l0oooo00<000000?ooo`3oool0G03oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo05L0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00001F0?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool07`3oool006l0oooo0`00001K0?ooo`80
0000103oool2000005T0oooo0P0000040?ooo`<00000F03oool2000000@0oooo0P00001H0?ooo`80
0000103oool3000001l0oooo003o0?ooool0oooo6@3oool00?l0ooooo`3ooolI0?ooo`00o`3ooooo
0?oooaT0oooo003o0?ooool0oooo6@3oool00?l0ooooo`3ooolI0?ooo`00o`3ooooo0?oooaT0oooo
003o0?ooool0oooo6@3oool003l0ooooo`000031000001P0oooo000e0?ooo`800000203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0F0?ooo`00=03oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
01H0oooo000d0?ooo`040000003oool0oooo000000L0oooo1000000]0?ooo`030000003oool0oooo
05h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
05d0oooo00<000000?ooo`3oool01@3oool4000001P0oooo000d0?ooo`040000003oool0oooo0000
00L0oooo00<000000?ooo`3oool0o`3ooonm0?ooo`030000003oool0oooo01H0oooo000d0?ooo`04
0000003oool0oooo000000L0oooo00<000000?ooo`3oool0o`3ooonm0?ooo`030000003oool0oooo
01H0oooo000e0?ooo`800000203oool00`000000oooo0?ooo`3o0?oookd0oooo00<000000?ooo`3o
ool05P3oool003l0oooo00<000000?ooo`3oool0o`3ooon`0?ooo`D00000203oool00`000000oooo
0?ooo`0F0?ooo`00?`3oool00`000000oooo0?ooo`3o0?oook00oooo1@0000080?ooo`030000003o
ool0oooo01H0oooo000o0?ooo`030000003oool0oooo0?l0oooo/03oool5000000P0oooo00<00000
0?ooo`3oool05P3oool003l0oooo00<000000?ooo`3oool0o`3ooon`0?ooo`D00000203oool00`00
0000oooo0?ooo`0F0?ooo`00?`3oool00`000000oooo0?ooo`3o0?ooodl0oooo1@00001L0?ooo`D0
0000203oool00`000000oooo0?ooo`0F0?ooo`00?`3oool00`000000oooo0?ooo`3o0?ooodl0oooo
1@00001Y0?ooo`030000003oool0oooo01H0oooo000o0?ooo`030000003oool0oooo0?l0ooooC`3o
ool5000006T0oooo00<000000?ooo`3oool05P3oool003l0oooo00<000000?ooo`3oool0o`3ooom?
0?ooo`D00000J@3oool00`000000oooo0?ooo`0F0?ooo`00?`3oool300000?l0oooo:03oool50000
0280oooo1@00001W0?ooo`<00000603oool003l0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`D0
0000T03oool00`000000oooo0?ooo`0F0?ooo`00?`3oool00`000000oooo0?ooo`3o0?ooobP0oooo
1@00002@0?ooo`030000003oool0oooo01H0oooo000o0?ooo`030000003oool0oooo0?l0oooo:03o
ool500000900oooo00<000000?ooo`3oool05P3oool003l0oooo00<000000?ooo`3oool0o`3ooolX
0?ooo`D00000T03oool00`000000oooo0?ooo`0F0?ooo`00?`3oool00`000000oooo0?ooo`3o0?oo
okd0oooo00<000000?ooo`3oool05P3oool003l0oooo00<000000?ooo`3oool0o`3ooonm0?ooo`03
0000003oool0oooo01H0oooo000o0?ooo`030000003oool0oooo0?l0oooo_@3oool00`000000oooo
0?ooo`0F0?ooo`00?`3oool00`000000oooo0?ooo`3o0?oookd0oooo00<000000?ooo`3oool05P3o
ool003l0oooo00<000000?ooo`3oool0o`3oool30?ooo`@00000]P3oool00`000000oooo0?ooo`0F
0?ooo`00?`3oool00`000000oooo0?ooo`3o0?ooo`80oooo1@00002f0?ooo`030000003oool0oooo
01H0oooo000o0?ooo`030000003oool0oooo0?l0oooo0P3oool500000;H0oooo00<000000?ooo`3o
ool05P3oool003l0oooo0`00003o0?ooo`80oooo1@00002d0?ooo`<00000603oool001T0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0oooo0P3o
ool500000;H0oooo00<000000?ooo`3oool05P3oool001T0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0oooo0P3oool500000;H0oooo00<00000
0?ooo`3oool05P3oool001T0oooo2000000N0?ooo`030000003oool0oooo0?l0oooo_@3oool00`00
0000oooo0?ooo`0F0?ooo`006@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0o`3ooonm0?ooo`030000003oool0oooo01H0oooo000I0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`3J0?ooo`D00000
g@3oool00`000000oooo0?ooo`0F0?ooo`00?`3oool00`000000oooo0?ooo`3J0?ooo`D00000g@3o
ool00`000000oooo0?ooo`0F0?ooo`00?`3oool00`000000oooo0?ooo`3J0?ooo`D00000g@3oool0
0`000000oooo0?ooo`0F0?ooo`006`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0fP3oool500000=d0oooo00<000000?ooo`3oool05P3oool001/0
oooo1P00000N0?ooo`030000003oool0oooo0=X0oooo1@00003M0?ooo`030000003oool0oooo01H0
oooo000K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`3o0?oookd0oooo00<000000?ooo`3oool05P3oool001/0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`3o0?oookd0oooo00<000000?ooo`3oool05P3oool001/0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`<00000o`3ooonk0?ooo`<00000603oool0
01`0oooo1@00000N0?ooo`030000003oool0oooo0?l0oooo_@3oool00`000000oooo0?ooo`0F0?oo
o`00803oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0oooo_@3oool00`000000
oooo0?ooo`0F0?ooo`00?`3oool00`000000oooo0?ooo`3o0?oookd0oooo00<000000?ooo`3oool0
5P3oool001/0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o0?oookd0oooo00<0
00000?ooo`3oool05P3oool001T0oooo1`00000O0?ooo`030000003oool0oooo0?l0oooo_@3oool0
0`000000oooo0?ooo`0F0?ooo`006`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0o`3ooonm0?ooo`030000003oool0oooo01H0oooo000K0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`3o0?oookd0
oooo00<000000?ooo`3oool05P3oool001/0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo0?l0oooo_@3oool00`000000oooo0?ooo`0F0?ooo`006`3o
ool01@000000oooo0?ooo`3oool0000001l0oooo00<000000?ooo`3oool0]03oool400000?l0oooo
1@3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool2000000@0oooo0P0000030?ooo`@000001`3o
ool00`000000oooo0?ooo`2c0?ooo`D00000o`3oool50?ooo`030000003oool0oooo01H0oooo000X
0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`2c0?ooo`D00000o`3oool50?ooo`030000003oool0oooo01H0oooo000L0?ooo`@00000203oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo00L0oooo1000002b0?ooo`D00000o`3o
ool20?ooo`@00000603oool001/0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`05
0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`2c0?ooo`D00000o`3oool50?ooo`030000003oool0oooo01H0oooo000K0?ooo`030000003oool0
00000080oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000000L0oooo00<000000?ooo`3oool0/`3oool500000?l0oooo1@3oool00`000000oooo
0?ooo`0F0?ooo`006`3oool00`000000oooo000000020?ooo`030000003oool0oooo00H0oooo0P00
000:0?ooo`800000203oool00`000000oooo0?ooo`3o0?oookd0oooo00<000000?ooo`3oool05P3o
ool001/0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo0?l0oooo_@3oool00`000000oooo0?ooo`0F0?ooo`00703oool200000080oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`3o0?oookd0oooo00<000000?ooo`3oool05P3oool003l0
oooo00<000000?ooo`3oool0o`3ooonm0?ooo`030000003oool0oooo01H0oooo000o0?ooo`030000
003oool0oooo0?l0oooo_@3oool00`000000oooo0?ooo`0F0?ooo`006`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0o`3ooonm0?ooo`030000003o
ool0oooo01H0oooo000K0?ooo`H000007P3oool00`000000oooo0?ooo`3o0?oookd0oooo00<00000
0?ooo`3oool05P3oool001/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo0?l0oooo_@3oool00`000000oooo0?ooo`0F0?ooo`006`3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0oooo_@3oool00`000000oooo0?ooo`0F0?ooo`00
6`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo0`00003o0?oook/0oooo
0`00000H0?ooo`00703oool5000001h0oooo00<000000?ooo`3oool0o`3ooonm0?ooo`030000003o
ool0oooo01H0oooo000P0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0o`3ooonm
0?ooo`030000003oool0oooo01H0oooo000o0?ooo`030000003oool0oooo0?l0oooo_@3oool00`00
0000oooo0?ooo`0F0?ooo`00703oool00`000000oooo0?ooo`02000001h0oooo00<000000?ooo`3o
ool0o`3ooonm0?ooo`030000003oool0oooo01H0oooo000K0?ooo`050000003oool000000?ooo`00
00007`3oool00`000000oooo0?ooo`3o0?oookd0oooo00<000000?ooo`3oool05P3oool001/0oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0oooo
_@3oool00`000000oooo0?ooo`0F0?ooo`006`3oool00`000000oooo000000020?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0SP3oool400000?l0oooo:`3oool00`000000oooo0?oo
o`0F0?ooo`006`3oool00`000000oooo000000020?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`3o0?ooob/0oooo00<000000?ooo`3oool05P3oool0
01/0oooo0P0000000`3oool000000000000O0?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool0o`3oool[0?ooo`030000003oool0oooo01H0oooo000o0?ooo`030000003oool0oooo08d0
oooo1@00003o0?ooob/0oooo00<000000?ooo`3oool05P3oool003l0oooo00<000000?ooo`3oool0
S@3oool500000?l0oooo:`3oool00`000000oooo0?ooo`0F0?ooo`00803oool00`000000oooo0?oo
o`0L0?ooo`<00000S@3oool500000?l0oooo:@3oool3000001P0oooo000K0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2=0?ooo`D00000o`3oool[
0?ooo`030000003oool0oooo01H0oooo000K0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`1j0?ooo`@000003`3oool500000?l0oooo:`3oool00`00
0000oooo0?ooo`0F0?ooo`006@3oool00`000000oooo00000005000001h0oooo00<000000?ooo`3o
ool0O03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0oooo:`3oool00`000000
oooo0?ooo`0F0?ooo`00803oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo07`0oooo
00<000000?ooo`3oool03`3oool400000?l0oooo:`3oool00`000000oooo0?ooo`0F0?ooo`00803o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0o`3o
ooln0?ooo`030000003oool0oooo01H0oooo000P0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0O03oool00`000000oooo0?ooo`3o0?oooch0oooo00<000000?ooo`3oool05P3oool0
03l0oooo00<000000?ooo`3oool0N@3oool500000?l0oooo?`3oool00`000000oooo0?ooo`0F0?oo
o`006`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo07T0oooo1@00003o0?ooocl0
oooo00<000000?ooo`3oool05P3oool001T0oooo1`00000O0?ooo`030000003oool0oooo07T0oooo
1@00003o0?ooocl0oooo00<000000?ooo`3oool05P3oool001/0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo07T0oooo1@00003o0?ooocl0oooo00<0
00000?ooo`3oool05P3oool001/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo07T0oooo1@00003o0?ooocl0oooo00<000000?ooo`3oool05P3oool0
01/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`<00000O03oool00`00
0000oooo0?ooo`3o0?oooc`0oooo0`00000H0?ooo`006`3oool01@000000oooo0?ooo`3oool00000
01l0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`3o0?oooch0oooo00<000000?oo
o`3oool05P3oool003l0oooo00<000000?ooo`3oool0NP3oool400000?l0oooo?`3oool00`000000
oooo0?ooo`0F0?ooo`00?`3oool00`000000oooo0?ooo`3o0?oookd0oooo00<000000?ooo`3oool0
5P3oool001/0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o0?oookd0oooo00<0
00000?ooo`3oool05P3oool001/0oooo0`0000050?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0o`3ooonm0?ooo`030000003oool0oooo01H0oooo000K0?ooo`030000003oool0oooo
008000000P3oool2000001/0oooo00<000000?ooo`3oool0o`3ooonm0?ooo`030000003oool0oooo
01H0oooo000P0?ooo`80000000<0oooo0000003oool06P3oool00`000000oooo0?ooo`3o0?oookd0
oooo00<000000?ooo`3oool05P3oool001/0oooo00<000000?ooo`3oool00P00000O0?ooo`030000
003oool0oooo0?l0oooo_@3oool00`000000oooo0?ooo`0F0?ooo`006`3oool300000240oooo00<0
00000?ooo`3oool0o`3ooonm0?ooo`030000003oool0oooo01H0oooo000K0?ooo`030000003oool0
oooo00/0oooo0P0000040?ooo`8000001@3oool3000000H0oooo00<000000?ooo`3oool0o`3ooonm
0?ooo`030000003oool0oooo01H0oooo000X0?ooo`040000003oool0oooo000000/0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oookd0oooo00<000000?ooo`3oool05P3oool0
02P0oooo00@000000?ooo`3oool00000203oool5000000H0oooo1000003o0?oookT0oooo1000000H
0?ooo`00:03oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000L0oooo00<0
00000?ooo`3oool0o`3ooonm0?ooo`030000003oool0oooo01H0oooo000X0?ooo`040000003oool0
oooo000000T0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`3o0?oookd0oooo00<0
00000?ooo`3oool05P3oool002T0oooo0P00000;0?ooo`8000001`3oool00`000000oooo0?ooo`3o
0?oookd0oooo00<000000?ooo`3oool05P3oool003l0oooo00<000000?ooo`3oool0o`3ooonm0?oo
o`030000003oool0oooo01H0oooo000o0?ooo`030000003oool0oooo0?l0oooo_@3oool00`000000
oooo0?ooo`0F0?ooo`00?`3oool00`000000oooo0?ooo`3o0?oookd0oooo00<000000?ooo`3oool0
5P3oool003l0oooo00<000000?ooo`3oool0o`3ooonm0?ooo`030000003oool0oooo01H0oooo000o
0?ooo`030000003oool0oooo0?l0oooo_@3oool00`000000oooo0?ooo`0F0?ooo`00?`3oool00`00
0000oooo0?ooo`3o0?oookd0oooo00<000000?ooo`3oool05P3oool003l0oooo00<000000?ooo`3o
ool0I`3oool400000?l0ooooDP3oool00`000000oooo0?ooo`0F0?ooo`00?`3oool00`000000oooo
0?ooo`1X0?ooo`030000003oool0oooo0?l0ooooDP3oool00`000000oooo0?ooo`0F0?ooo`00?`3o
ool3000006P0oooo00<000000?ooo`3oool0o`3ooom@0?ooo`<00000603oool003l0oooo00<00000
0?ooo`3oool0J03oool00`000000oooo0?ooo`3o0?oooe80oooo00<000000?ooo`3oool05P3oool0
03l0oooo00<000000?ooo`3oool0IP3oool500000?l0ooooDP3oool00`000000oooo0?ooo`0F0?oo
o`006`3oool6000001h0oooo00<000000?ooo`3oool0E03oool4000000h0oooo1@00003o0?oooe80
oooo00<000000?ooo`3oool05P3oool001T0oooo0P0000060?ooo`800000703oool00`000000oooo
0?ooo`1E0?ooo`030000003oool0oooo00h0oooo1@00003o0?oooe80oooo00<000000?ooo`3oool0
5P3oool001P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool03P3oool500000?l0ooooDP3oool00`000000oooo0?oo
o`0F0?ooo`00?`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00h0oooo1@00003o
0?oooe80oooo00<000000?ooo`3oool05P3oool003l0oooo00<000000?ooo`3oool0E@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooDP3oool00`000000oooo0?ooo`0F0?oo
o`00703oool010000000oooo00000000000O0?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`3o0?oooe80oooo00<000000?ooo`3oool05P3oool001/0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05D0
oooo00<000000?ooo`3oool03`3oool400000?l0ooooDP3oool00`000000oooo0?ooo`0F0?ooo`00
6`3oool00`000000oooo000000020?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
E@3oool00`000000oooo0?ooo`3o0?ooofD0oooo00<000000?ooo`3oool05P3oool001/0oooo00<0
00000?ooo`0000000P3oool00`000000oooo0?ooo`0L0?ooo`<00000E@3oool00`000000oooo0?oo
o`3o0?ooof<0oooo0`00000H0?ooo`006`3oool01@000000oooo0000003oool0000001l0oooo00<0
00000?ooo`3oool0E@3oool00`000000oooo0?ooo`3o0?ooofD0oooo00<000000?ooo`3oool05P3o
ool001`0oooo1@00000N0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0o`3ooomU
0?ooo`030000003oool0oooo01H0oooo000P0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0D`3oool500000?l0ooooI@3oool00`000000oooo0?ooo`0F0?ooo`00?`3oool00`000000
oooo0?ooo`1C0?ooo`D00000o`3ooomU0?ooo`030000003oool0oooo01H0oooo000K0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1C0?ooo`D00000
o`3ooomU0?ooo`030000003oool0oooo01H0oooo000K0?ooo`H000007P3oool00`000000oooo0?oo
o`1C0?ooo`D00000o`3ooomU0?ooo`030000003oool0oooo01H0oooo000L0?ooo`050000003oool0
oooo0?ooo`0000007P3oool00`000000oooo0?ooo`1C0?ooo`D00000o`3ooomU0?ooo`030000003o
ool0oooo01H0oooo000K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0?l0ooooI@3oool00`000000oooo0?ooo`0F
0?ooo`006`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`3o0?ooofD0oooo00<000000?ooo`3oool05P3oool001/0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0?l0
ooooI@3oool00`000000oooo0?ooo`0F0?ooo`00?`3oool00`000000oooo0?ooo`1E0?ooo`030000
003oool0oooo0?l0ooooI@3oool00`000000oooo0?ooo`0F0?ooo`00603oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo01`0oooo0`00001E0?ooo`030000003oool0oooo0?l0ooooH`3o
ool3000001P0oooo000H0?ooo`T000007P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0
oooo0?l0ooooI@3oool00`000000oooo0?ooo`0F0?ooo`00703oool010000000oooo0?ooo`00000O
0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0o`3ooomU0?ooo`030000003oool0
oooo01H0oooo000K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo0?l0ooooI@3oool00`000000oooo0?ooo`0F0?oo
o`006`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0E@3oool00`000000oooo0?ooo`3o0?ooofD0oooo00<000000?ooo`3oool05P3oool001/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0o`3ooomU0?ooo`030000003oool0oooo01H0oooo000L0?ooo`@000007`3o
ool00`000000oooo0?ooo`100?ooo`@00000403oool400000?l0ooooI@3oool00`000000oooo0?oo
o`0F0?ooo`00?`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0?l0ooooN03oool0
0`000000oooo0?ooo`0F0?ooo`00?`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
0?l0ooooN03oool00`000000oooo0?ooo`0F0?ooo`00803oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool0o`3ooomh0?ooo`030000003oool0oooo01H0
oooo000K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool2000000@0oooo
0P0000030?ooo`<00000203oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0?l0oooo
N03oool00`000000oooo0?ooo`0F0?ooo`006`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00D0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000070?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool0o`3ooomh0?ooo`030000003oool0oooo01H0
oooo000I0?ooo`030000003oool0000000D000001`3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000L0oooo100000110?ooo`030000003oool0oooo0?l0ooooM@3oool40000
01P0oooo000P0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000203oool30000
00P0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`3o0?ooogP0oooo00<000000?oo
o`3oool05P3oool00200oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`3o0?oo
ogP0oooo00<000000?ooo`3oool05P3oool00200oooo00<000000?ooo`3oool01P3oool2000000X0
oooo0`0000070?ooo`030000003oool0oooo03l0oooo1@00003o0?ooogT0oooo00<000000?ooo`3o
ool05P3oool003l0oooo00<000000?ooo`3oool0?`3oool500000?l0ooooN@3oool00`000000oooo
0?ooo`0F0?ooo`006`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03l0oooo1@00
003o0?ooogT0oooo00<000000?ooo`3oool05P3oool001T0oooo1`00000O0?ooo`030000003oool0
oooo03l0oooo1@00003o0?ooogT0oooo00<000000?ooo`3oool05P3oool001/0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo03l0oooo1@00003o0?oo
ogT0oooo00<000000?ooo`3oool05P3oool001/0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0o`3ooomh0?ooo`03
0000003oool0oooo01H0oooo000K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0?l0ooooN03oool00`000000oooo
0?ooo`0F0?ooo`006`3oool01@000000oooo0?ooo`3oool0000001l0oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`3o0?ooogP0oooo00<000000?ooo`3oool05P3oool003l0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`3o0?ooogP0oooo00<000000?ooo`3oool05P3o
ool003l0oooo0`0000120?ooo`030000003oool0oooo0?l0ooooMP3oool3000001P0oooo000K0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`120?oo
o`030000003oool0oooo0?l0ooooN03oool00`000000oooo0?ooo`0F0?ooo`006`3oool6000001h0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`3o0?ooogP0oooo00<000000?ooo`3o
ool05P3oool001`0oooo00D000000?ooo`3oool0oooo0000000N0?ooo`030000003oool0oooo0400
oooo1000003o0?ooogT0oooo00<000000?ooo`3oool05P3oool001/0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0oooo_@3oool00`000000oooo
0?ooo`0F0?ooo`006`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0o`3ooonm0?ooo`030000003oool0oooo01H0oooo000K0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool0o`3ooonm0?ooo`030000003oool0oooo01H0oooo000o0?oo
o`030000003oool0oooo0?l0oooo_@3oool00`000000oooo0?ooo`0F0?ooo`00?`3oool00`000000
oooo0?ooo`3o0?oookd0oooo00<000000?ooo`3oool05P3oool001`0oooo00@000000?ooo`000000
00007`3oool00`000000oooo0?ooo`3o0?oookd0oooo00<000000?ooo`3oool05P3oool001/0oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0oooo
_@3oool00`000000oooo0?ooo`0F0?ooo`006`3oool00`000000oooo000000020?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0o`3ooonm0?ooo`030000003oool0oooo01H0oooo000K
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0703oool300000?l0oooo^`3oool3
000001P0oooo000K0?ooo`050000003oool000000?ooo`0000007`3oool00`000000oooo0?ooo`3o
0?oookd0oooo00<000000?ooo`3oool05P3oool001`0oooo1@00000N0?ooo`030000003oool0oooo
0?l0oooo_@3oool00`000000oooo0?ooo`0F0?ooo`00803oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo0?l0oooo_@3oool00`000000oooo0?ooo`0F0?ooo`00?`3oool00`000000oooo
0?ooo`3o0?oookd0oooo00<000000?ooo`3oool05P3oool001/0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0oooo_@3oool00`000000oooo0?oo
o`0F0?ooo`006`3oool6000001h0oooo00<000000?ooo`3oool0;@3oool400000?l0ooooS03oool0
0`000000oooo0?ooo`0F0?ooo`00703oool01@000000oooo0?ooo`3oool0000001h0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`3o0?oooh`0oooo00<000000?ooo`3oool05P3oool0
01/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool0o`3ooon<0?ooo`030000003oool0oooo01H0oooo000K0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo0?l0ooooS03oool00`000000oooo0?ooo`0F0?ooo`006`3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0o`3ooon<0?ooo`030000
003oool0oooo01H0oooo000o0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0o`3o
oon<0?ooo`030000003oool0oooo01H0oooo000o0?ooo`<00000;P3oool00`000000oooo0?ooo`3o
0?ooohX0oooo0`00000H0?ooo`006`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool0o`3ooon<0?ooo`030000003oool0oooo01H0oooo000K0?ooo`<0
00001@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool0o`3ooon<0?ooo`030000003oool0oooo01H0oooo000K0?ooo`030000003oool0oooo00800000
0P3oool2000001/0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3o0?oooh`0oooo
00<000000?ooo`3oool05P3oool00200oooo0P0000000`3oool000000?ooo`0J0?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool0o`3ooon<0?ooo`030000003oool0oooo01H0oooo000K
0?ooo`030000003oool0oooo008000007`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo0?l0ooooS03oool00`000000oooo0?ooo`0F0?ooo`006`3oool300000240oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`3o0?oooh`0oooo00<000000?ooo`3oool05P3oool001/0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0/0?ooo`D00000o`3ooon<0?ooo`03
0000003oool0oooo01H0oooo000o0?ooo`030000003oool0oooo02`0oooo1@00003o0?oooh`0oooo
00<000000?ooo`3oool05P3oool003l0oooo00<000000?ooo`3oool0;03oool500000?l0ooooS03o
ool00`000000oooo0?ooo`0F0?ooo`00:@3oool2000000@0oooo0P0000040?ooo`800000203oool0
0`000000oooo0?ooo`0/0?ooo`D00000o`3ooon<0?ooo`030000003oool0oooo01H0oooo000X0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?oo
o`0/0?ooo`D00000o`3ooon<0?ooo`030000003oool0oooo01H0oooo000X0?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000001`3oool4000002d0oooo00<000000?ooo`3oool0
o`3ooon90?ooo`@00000603oool002P0oooo00@000000?ooo`3oool000002@3oool2000000P0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3o0?oooh`0oooo00<000000?ooo`3oool0
5P3oool002P0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000070?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool0o`3ooon<0?ooo`030000003oool0oooo01H0
oooo000Y0?ooo`8000002P3oool2000000P0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`3o0?oooh`0oooo00<000000?ooo`3oool05P3oool003l0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`3o0?oooh`0oooo00<000000?ooo`3oool05P3oool003l0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`3o0?oooh`0oooo00<000000?ooo`3oool05P3oool0
03l0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3o0?oooh`0oooo00<000000?oo
o`3oool05P3oool003l0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3o0?oooh`0
oooo00<000000?ooo`3oool05P3oool003l0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`3o0?oooh`0oooo00<000000?ooo`3oool05P3oool001/0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0?l0ooooS03oool00`000000oooo0?oo
o`0F0?ooo`006`3oool5000001l0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`3o
0?oooh`0oooo00<000000?ooo`3oool05P3oool00200oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0]0?ooo`@00000o`3ooon<0?ooo`030000003oool0oooo01H0oooo000P0?ooo`03
0000003oool0oooo01`0oooo0`00000J0?ooo`@00000o`3ooonM0?ooo`<00000603oool001/0oooo
00D000000?ooo`3oool0oooo0000000O0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0o`3ooonO0?ooo`030000003oool0oooo01H0oooo000K0?ooo`H000007P3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo0?l0ooooW`3oool00`000000oooo0?ooo`0F0?ooo`00803o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0o`3o
oonO0?ooo`030000003oool0oooo01H0oooo000o0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0o`3ooonO0?ooo`030000003oool0oooo01H0oooo000K0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
0?l0ooooW`3oool00`000000oooo0?ooo`0F0?ooo`006`3oool6000001h0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`3o0?oooil0oooo00<000000?ooo`3oool05P3oool001/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo
1000000A0?ooo`030000003oool0oooo0?l0ooooW`3oool00`000000oooo0?ooo`0F0?ooo`006`3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`3o0?oooil0oooo00<000000?ooo`3oool05P3oool001/0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`3o0?oooil0oooo00<000000?ooo`3oool05P3oool0
01`0oooo1@00000N0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`3o0?oooil0oooo00<000000?ooo`3oool05P3oool00200oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0o`3ooonO0?ooo`030000003oool0oooo01H0oooo000o0?ooo`<00000203oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooW@3oool3000001P0oooo000P0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0?l0ooooW`3oool00`000000oooo0?ooo`0F0?ooo`006`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo0?l0ooooW`3oool00`000000oooo0?ooo`0F0?ooo`006`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooW`3oool00`000000oooo0?ooo`0F0?oo
o`006@3oool00`000000oooo00000005000001h0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooW`3oool00`000000oooo0?ooo`0F0?ooo`00
803oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`3o0?oooil0oooo00<000000?ooo`3oool05P3oool00200oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0o`3ooonO0?ooo`030000003oool0oooo01H0oooo000P0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`D00000o`3ooonO
0?ooo`030000003oool0oooo01H0oooo000o0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool03P3oool500000?l0ooooW`3oool00`000000oooo0?ooo`0F0?ooo`006`3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03P3oool500000?l0
ooooW`3oool00`000000oooo0?ooo`0F0?ooo`006@3oool7000001l0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0>0?ooo`D00000o`3ooonO0?ooo`030000003oool0oooo01H0oooo
000K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00h0oooo1@00003o0?oooil0oooo00<000000?ooo`3oool05P3o
ool001/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`<00000203oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooW@3oool3000001P0oooo000K0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0o`3ooonO0?ooo`030000003oool0oooo
01H0oooo000K0?ooo`050000003oool0oooo0?ooo`0000007`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0o`3ooonO0?ooo`030000003oool0oooo
01H0oooo000o0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`3o0?oooil0oooo00<000000?ooo`3oool05P3oool003l0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooW`3oool00`000000oooo
0?ooo`0F0?ooo`00703oool00`000000oooo0?ooo`02000001h0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooW`3oool00`000000oooo0?oo
o`0F0?ooo`006`3oool01@000000oooo0000003oool0000001l0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooW`3oool00`000000oooo0?oo
o`0F0?ooo`006`3oool00`000000oooo000000020?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooW`3oool0
0`000000oooo0?ooo`0F0?ooo`006`3oool00`000000oooo000000020?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0?l0ooooW`3oool00`000000oooo0?ooo`0F0?ooo`006`3oool00`000000oooo000000020?ooo`03
0000003oool0oooo0140oooo1@0000060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`3o0?oooil0oooo00<000000?ooo`3oool05P3oool001/0oooo
0P0000000`3oool000000000000F0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1@3oool500000140oooo00<000000?ooo`3oool0o`3ooonO0?ooo`030000003oool0oooo01H0oooo
000f0?ooo`030000003oool0oooo00H0oooo100000040?ooo`D000004@3oool00`000000oooo0?oo
o`3o0?oooi`0oooo1000000H0?ooo`00=P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo1@00000A0?ooo`030000003oool0oooo0?l0ooooW`3oool00`000000oooo0?ooo`0F
0?ooo`00=P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo1@00000A0?oo
o`030000003oool0oooo0?l0ooooW`3oool00`000000oooo0?ooo`0F0?ooo`00=@3oool2000000P0
oooo00<000000?ooo`3oool01@3oool500000140oooo00<000000?ooo`3oool0o`3ooonO0?ooo`03
0000003oool0oooo01H0oooo000H0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
o`3ooonO0?ooo`030000003oool0oooo01H0oooo000I0?ooo`8000001P3oool2000001`0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooW`3o
ool00`000000oooo0?ooo`0F0?ooo`006`3oool6000001h0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0?0?ooo`@00000o`3ooonO0?ooo`030000003oool0oooo01H0oooo000o0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooonb0?ooo`030000003oool0oooo
01H0oooo000o0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooonb0?ooo`03
0000003oool0oooo01H0oooo000o0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
o`3ooonb0?ooo`030000003oool0oooo01H0oooo000o0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0o`3ooonb0?ooo`030000003oool0oooo01H0oooo000o0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0o`3ooonb0?ooo`030000003oool0oooo01H0oooo000o0?oo
o`<00000203oool00`000000oooo0?ooo`3o0?oook00oooo0`00000H0?ooo`00?`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo/P3oool00`000000oooo0?ooo`0F0?ooo`00
?`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo/P3oool00`000000oooo
0?ooo`0F0?ooo`00?`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo/P3o
ool00`000000oooo0?ooo`0F0?ooo`00?`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0?l0oooo/P3oool00`000000oooo0?ooo`0F0?ooo`00?`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0?l0oooo/P3oool00`000000oooo0?ooo`0F0?ooo`00?`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo/P3oool00`000000oooo0?ooo`0F0?ooo`00
?`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo/P3oool00`000000oooo
0?ooo`0F0?ooo`00?`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo/P3o
ool00`000000oooo0?ooo`0F0?ooo`00?`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0?l0oooo/P3oool00`000000oooo0?ooo`0F0?ooo`00?`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0?l0oooo/P3oool00`000000oooo0?ooo`0F0?ooo`00?`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo/P3oool00`000000oooo0?ooo`0F0?ooo`00
?`3oool3000000P0oooo00<000000?ooo`3oool0o`3ooon`0?ooo`<00000603oool003l0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?oook80oooo00<000000?ooo`3oool05P3o
ool003l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?oook80oooo00<00000
0?ooo`3oool05P3oool003l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?oo
ok80oooo00<000000?ooo`3oool05P3oool003l0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`3o0?oook80oooo00<000000?ooo`3oool05P3oool003l0oooo00<000000?ooo`3oool0
1P3oool400000?l0oooo/`3oool00`000000oooo0?ooo`0F0?ooo`00?`3oool00`000000oooo0?oo
o`3o0?oookd0oooo00<000000?ooo`3oool05P3oool003l0oooo00<000000?ooo`3oool0o`3ooonm
0?ooo`030000003oool0oooo01H0oooo000o0?ooo`030000003oool0oooo0?l0oooo_@3oool00`00
0000oooo0?ooo`0F0?ooo`00?`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo05d0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0F0?ooo`00?`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0F0?ooo`00?`3ooooo00000<400000603oool00?l0ooooo`3ooolI0?ooo`00o`3ooooo0?oo
oaT0oooo003o0?ooool0oooo6@3oool00?l0ooooo`3ooolI0?ooo`00o`3ooooo0?oooaT0oooo003o
0?ooool0oooo6@3oool00?l0ooooo`3ooolI0?ooo`00o`3oool>0?ooo`D00000G@3oool400000:@0
oooo003o0?oooa40oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`2Q0?ooo`00o`3o
oolB0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0X03oool00?l0oooo4P3oool0
0`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0:00oooo002^0?ooo`L000001@3oool30000
00<0oooo0`0000060?ooo`@000001`3oool5000000D0oooo0`0000030?ooo`<000000`3oool00`00
0000oooo00000003000000D0oooo2@0000070?ooo`@00000203oool2000001H0oooo0P0000070?oo
o`030000003oool0000000<00000203oool300000140oooo100000040?ooo`@000000P3oool30000
00<0oooo0`0000050?ooo`<0000000<0oooo0000003oool0103oool9000000D0oooo1@00002:0?oo
o`00/@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`80
0000103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00P3oool2000000H0oooo0P00000F0?ooo`8000001`3oool2000000@0oooo00<000000?ooo`3o
ool01@3oool300000180oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool20000
00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
08L0oooo002a0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool010000000
oooo0?ooo`00000D0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`<000004`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo08h0oooo002a0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000503oool0
10000000oooo0?ooo`00000=0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`2>0?ooo`00/@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`P000001@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0K0?ooo`P000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00D0oooo200000290?ooo`00/@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo1@0000090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`040?ooo`D000007`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0Q`3oool00;40oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo08L0oooo002a0?ooo`030000003oool0oooo00L0oooo
0P0000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool2000000L0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000001h0oooo
00@000000?ooo`3oool000001`3oool2000000<0oooo00<000000?ooo`3oool0103oool010000000
oooo0?ooo`3oool2000000T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo08P0oooo002a0?ooo`030000003oool0oooo00H0oooo0P000000103oool0
00000000000000060?ooo`P000001P3oool4000000H0oooo0P000000103oool00000000000000007
0?ooo`D0000000<0oooo0000003oool00`3oool4000000P0oooo200000020?ooo`@00000103oool4
000000`0oooo100000040?ooo`@000000`3oool5000000030?ooo`000000oooo01d0oooo00@00000
0?ooo`3oool000001P3oool2000000040?ooo`0000000000000000P0oooo0`0000000`3oool00000
000000080?ooo`030000003oool0oooo00L0oooo1000002;0?ooo`00/@3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0D@3oool010000000oooo0?oo
o`00000R0?ooo`030000003oool0oooo09H0oooo002a0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0>@3oool00`000000oooo0?ooo`1B0?ooo`8000008`3oool00`000000oooo0?oo
o`2F0?ooo`00[P3oool7000001<0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo04l0oooo1@00000S0?ooo`030000003oool0oooo09H0oooo003i0?oo
o`030000003oool0oooo07l0oooo1000002H0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 534.063}, {329.688, 0}} -> {-0.836429, -0.137202, \
0.0517003, 0.00420132}}]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Export Data Table", "Section"],

Cell[BoxData[
    \(\(Export[workingDir <> "\<fits\\\>" <> filename <> "\<.txt\>", 
        finaldata, "\<Table\>"];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Import and Plot Results of Fit", "Section"],

Cell[BoxData[{
    \(\(bestfit = 
        Import[workingDir <> "\<fits\\\>" <> 
            filename <> "\<-output.txt\>", "\<Table\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(bestfit = Take[bestfit, \(-Length[finaldata]\)];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"MultipleListPlot", "[", 
        RowBox[{"finaldataerror", ",", "bestfit", ",", 
          StyleBox[\(SymbolShape \[Rule] {PlotSymbol[Box], None}\),
            FontColor->GrayLevel[0.666667]], 
          StyleBox[",",
            FontColor->GrayLevel[0.666667]], 
          StyleBox[\(Frame \[Rule] True\),
            FontColor->GrayLevel[0.666667]], 
          StyleBox[",",
            FontColor->GrayLevel[0.666667]], 
          
          StyleBox[\(FrameLabel \[Rule] {StyleForm[
                  TraditionalForm["\<Angle (\[Degree])\>"], 
                  FontSize \[Rule] 14], 
                StyleForm[TraditionalForm["\<Intensity (arbitrary units)\>"], 
                  FontSize \[Rule] 14]}\),
            FontColor->GrayLevel[0.666667]], 
          StyleBox[",",
            FontColor->GrayLevel[0.666667]], 
          
          StyleBox[\(PlotLabel \[Rule] 
              StyleForm[
                TraditionalForm["\<Intensity vs. Angle: Data and Theory\>"], 
                FontSize \[Rule] 20]\),
            FontColor->GrayLevel[0.666667]], 
          StyleBox[",",
            FontColor->GrayLevel[0.666667]], 
          StyleBox[\(PlotJoined \[Rule] {False, True}\),
            FontColor->GrayLevel[0.666667]]}], "]"}], ";"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0380952 0.0147151 0.537823 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -39.6875 -23.9375 ]
[.5 -0.0125 39.6875 -9 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .12228 -18 -4.5 ]
[-0.0125 .12228 0 4.5 ]
[-0.0125 .22984 -18 -4.5 ]
[-0.0125 .22984 0 4.5 ]
[-0.0125 .33741 -18 -4.5 ]
[-0.0125 .33741 0 4.5 ]
[-0.0125 .44497 -18 -4.5 ]
[-0.0125 .44497 0 4.5 ]
[-0.0125 .55254 -6 -4.5 ]
[-0.0125 .55254 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -31.625 -115.063 ]
[-0.01875 .30902 -18 115.063 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -218 0 ]
[.5 .63053 218 18.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(5)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(10)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(15)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(20)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(25)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.0619 0 m
.0619 .00375 L
s
.1 0 m
.1 .00375 L
s
.1381 0 m
.1381 .00375 L
s
.17619 0 m
.17619 .00375 L
s
.25238 0 m
.25238 .00375 L
s
.29048 0 m
.29048 .00375 L
s
.32857 0 m
.32857 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.44286 0 m
.44286 .00375 L
s
.48095 0 m
.48095 .00375 L
s
.51905 0 m
.51905 .00375 L
s
.55714 0 m
.55714 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.67143 0 m
.67143 .00375 L
s
.70952 0 m
.70952 .00375 L
s
.74762 0 m
.74762 .00375 L
s
.82381 0 m
.82381 .00375 L
s
.8619 0 m
.8619 .00375 L
s
.9 0 m
.9 .00375 L
s
.9381 0 m
.9381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -100.688 -27.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22.9375 translate 1 -1 scale
63.000 15.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Angle) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
113.250 15.188 moveto
(H) show
121.625 15.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\260) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
130.000 15.188 moveto
(L) show
138.375 15.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .12228 m
.00625 .12228 L
s
[(0.2)] -0.0125 .12228 1 0 Mshowa
0 .22984 m
.00625 .22984 L
s
[(0.4)] -0.0125 .22984 1 0 Mshowa
0 .33741 m
.00625 .33741 L
s
[(0.6)] -0.0125 .33741 1 0 Mshowa
0 .44497 m
.00625 .44497 L
s
[(0.8)] -0.0125 .44497 1 0 Mshowa
0 .55254 m
.00625 .55254 L
s
[(1)] -0.0125 .55254 1 0 Mshowa
.125 Mabswid
0 .04161 m
.00375 .04161 L
s
0 .0685 m
.00375 .0685 L
s
0 .09539 m
.00375 .09539 L
s
0 .14917 m
.00375 .14917 L
s
0 .17606 m
.00375 .17606 L
s
0 .20295 m
.00375 .20295 L
s
0 .25674 m
.00375 .25674 L
s
0 .28363 m
.00375 .28363 L
s
0 .31052 m
.00375 .31052 L
s
0 .3643 m
.00375 .3643 L
s
0 .39119 m
.00375 .39119 L
s
0 .41808 m
.00375 .41808 L
s
0 .47186 m
.00375 .47186 L
s
0 .49876 m
.00375 .49876 L
s
0 .52565 m
.00375 .52565 L
s
0 .57943 m
.00375 .57943 L
s
0 .60632 m
.00375 .60632 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -200.875 -10.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
176.063 10.8125 translate
90 rotate
-176.063 -10.8125 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.625 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Intensity) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
146.750 13.875 moveto
(H) show
155.125 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(arbitrary) show
238.875 13.875 moveto
(units) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
280.750 13.875 moveto
(L) show
289.125 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.0619 .61428 m
.0619 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.1381 .61428 m
.1381 .61803 L
s
.17619 .61428 m
.17619 .61803 L
s
.25238 .61428 m
.25238 .61803 L
s
.29048 .61428 m
.29048 .61803 L
s
.32857 .61428 m
.32857 .61803 L
s
.36667 .61428 m
.36667 .61803 L
s
.44286 .61428 m
.44286 .61803 L
s
.48095 .61428 m
.48095 .61803 L
s
.51905 .61428 m
.51905 .61803 L
s
.55714 .61428 m
.55714 .61803 L
s
.63333 .61428 m
.63333 .61803 L
s
.67143 .61428 m
.67143 .61803 L
s
.70952 .61428 m
.70952 .61803 L
s
.74762 .61428 m
.74762 .61803 L
s
.82381 .61428 m
.82381 .61803 L
s
.8619 .61428 m
.8619 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.9381 .61428 m
.9381 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .12228 m
1 .12228 L
s
.99375 .22984 m
1 .22984 L
s
.99375 .33741 m
1 .33741 L
s
.99375 .44497 m
1 .44497 L
s
.99375 .55254 m
1 .55254 L
s
.125 Mabswid
.99625 .04161 m
1 .04161 L
s
.99625 .0685 m
1 .0685 L
s
.99625 .09539 m
1 .09539 L
s
.99625 .14917 m
1 .14917 L
s
.99625 .17606 m
1 .17606 L
s
.99625 .20295 m
1 .20295 L
s
.99625 .25674 m
1 .25674 L
s
.99625 .28363 m
1 .28363 L
s
.99625 .31052 m
1 .31052 L
s
.99625 .3643 m
1 .3643 L
s
.99625 .39119 m
1 .39119 L
s
.99625 .41808 m
1 .41808 L
s
.99625 .47186 m
1 .47186 L
s
.99625 .49876 m
1 .49876 L
s
.99625 .52565 m
1 .52565 L
s
.99625 .57943 m
1 .57943 L
s
.99625 .60632 m
1 .60632 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -279 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26.4375 translate 1 -1 scale
63.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Intensity) show
183.000 17.750 moveto
(vs) show
207.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
231.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Angle) show
291.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
315.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Data) show
375.000 17.750 moveto
(and) show
423.000 17.750 moveto
(Theory) show
495.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.1381 .60332 m
.1381 .50176 L
s
.1381 .60332 1.5 0 Mabsadd m
.1381 .60332 -1.5 0 Mabsadd L s
.1381 .50176 1.5 0 Mabsadd m
.1381 .50176 -1.5 0 Mabsadd L s
.17619 .43963 m
.17619 .34474 L
s
.17619 .43963 1.5 0 Mabsadd m
.17619 .43963 -1.5 0 Mabsadd L s
.17619 .34474 1.5 0 Mabsadd m
.17619 .34474 -1.5 0 Mabsadd L s
.21429 .35206 m
.21429 .20496 L
s
.21429 .35206 1.5 0 Mabsadd m
.21429 .35206 -1.5 0 Mabsadd L s
.21429 .20496 1.5 0 Mabsadd m
.21429 .20496 -1.5 0 Mabsadd L s
.25238 .25877 m
.25238 .22561 L
s
.25238 .25877 1.5 0 Mabsadd m
.25238 .25877 -1.5 0 Mabsadd L s
.25238 .22561 1.5 0 Mabsadd m
.25238 .22561 -1.5 0 Mabsadd L s
.29048 .19977 m
.29048 .16978 L
s
.29048 .19977 1.5 0 Mabsadd m
.29048 .19977 -1.5 0 Mabsadd L s
.29048 .16978 1.5 0 Mabsadd m
.29048 .16978 -1.5 0 Mabsadd L s
.32857 .16561 m
.32857 .12812 L
s
.32857 .16561 1.5 0 Mabsadd m
.32857 .16561 -1.5 0 Mabsadd L s
.32857 .12812 1.5 0 Mabsadd m
.32857 .12812 -1.5 0 Mabsadd L s
.36667 .13541 m
.36667 .11643 L
s
.36667 .13541 1.5 0 Mabsadd m
.36667 .13541 -1.5 0 Mabsadd L s
.36667 .11643 1.5 0 Mabsadd m
.36667 .11643 -1.5 0 Mabsadd L s
.40476 .10706 m
.40476 .08504 L
s
.40476 .10706 1.5 0 Mabsadd m
.40476 .10706 -1.5 0 Mabsadd L s
.40476 .08504 1.5 0 Mabsadd m
.40476 .08504 -1.5 0 Mabsadd L s
.48095 .07088 m
.48095 .05506 L
s
.48095 .07088 1.5 0 Mabsadd m
.48095 .07088 -1.5 0 Mabsadd L s
.48095 .05506 1.5 0 Mabsadd m
.48095 .05506 -1.5 0 Mabsadd L s
.55714 .05477 m
.55714 .0471 L
s
.55714 .05477 1.5 0 Mabsadd m
.55714 .05477 -1.5 0 Mabsadd L s
.55714 .0471 1.5 0 Mabsadd m
.55714 .0471 -1.5 0 Mabsadd L s
.63333 .04351 m
.63333 .03773 L
s
.63333 .04351 1.5 0 Mabsadd m
.63333 .04351 -1.5 0 Mabsadd L s
.63333 .03773 1.5 0 Mabsadd m
.63333 .03773 -1.5 0 Mabsadd L s
.70952 .03325 m
.70952 .02892 L
s
.70952 .03325 1.5 0 Mabsadd m
.70952 .03325 -1.5 0 Mabsadd L s
.70952 .02892 1.5 0 Mabsadd m
.70952 .02892 -1.5 0 Mabsadd L s
.78571 .0302 m
.78571 .02494 L
s
.78571 .0302 1.5 0 Mabsadd m
.78571 .0302 -1.5 0 Mabsadd L s
.78571 .02494 1.5 0 Mabsadd m
.78571 .02494 -1.5 0 Mabsadd L s
.97619 .02388 m
.97619 .01923 L
s
.97619 .02388 1.5 0 Mabsadd m
.97619 .02388 -1.5 0 Mabsadd L s
.97619 .01923 1.5 0 Mabsadd m
.97619 .01923 -1.5 0 Mabsadd L s
.0001 w
.1381 .55254 -2.5 2.5 Mabsadd m
.1381 .55254 2.5 2.5 Mabsadd L
.1381 .55254 2.5 -2.5 Mabsadd L
.1381 .55254 -2.5 -2.5 Mabsadd L
.1381 .55254 -2.5 2.5 Mabsadd L closepath F
.17619 .39219 -2.5 2.5 Mabsadd m
.17619 .39219 2.5 2.5 Mabsadd L
.17619 .39219 2.5 -2.5 Mabsadd L
.17619 .39219 -2.5 -2.5 Mabsadd L
.17619 .39219 -2.5 2.5 Mabsadd L closepath F
.21429 .27851 -2.5 2.5 Mabsadd m
.21429 .27851 2.5 2.5 Mabsadd L
.21429 .27851 2.5 -2.5 Mabsadd L
.21429 .27851 -2.5 -2.5 Mabsadd L
.21429 .27851 -2.5 2.5 Mabsadd L closepath F
.25238 .24219 -2.5 2.5 Mabsadd m
.25238 .24219 2.5 2.5 Mabsadd L
.25238 .24219 2.5 -2.5 Mabsadd L
.25238 .24219 -2.5 -2.5 Mabsadd L
.25238 .24219 -2.5 2.5 Mabsadd L closepath F
.29048 .18478 -2.5 2.5 Mabsadd m
.29048 .18478 2.5 2.5 Mabsadd L
.29048 .18478 2.5 -2.5 Mabsadd L
.29048 .18478 -2.5 -2.5 Mabsadd L
.29048 .18478 -2.5 2.5 Mabsadd L closepath F
.32857 .14687 -2.5 2.5 Mabsadd m
.32857 .14687 2.5 2.5 Mabsadd L
.32857 .14687 2.5 -2.5 Mabsadd L
.32857 .14687 -2.5 -2.5 Mabsadd L
.32857 .14687 -2.5 2.5 Mabsadd L closepath F
.36667 .12592 -2.5 2.5 Mabsadd m
.36667 .12592 2.5 2.5 Mabsadd L
.36667 .12592 2.5 -2.5 Mabsadd L
.36667 .12592 -2.5 -2.5 Mabsadd L
.36667 .12592 -2.5 2.5 Mabsadd L closepath F
.40476 .09605 -2.5 2.5 Mabsadd m
.40476 .09605 2.5 2.5 Mabsadd L
.40476 .09605 2.5 -2.5 Mabsadd L
.40476 .09605 -2.5 -2.5 Mabsadd L
.40476 .09605 -2.5 2.5 Mabsadd L closepath F
.48095 .06297 -2.5 2.5 Mabsadd m
.48095 .06297 2.5 2.5 Mabsadd L
.48095 .06297 2.5 -2.5 Mabsadd L
.48095 .06297 -2.5 -2.5 Mabsadd L
.48095 .06297 -2.5 2.5 Mabsadd L closepath F
.55714 .05093 -2.5 2.5 Mabsadd m
.55714 .05093 2.5 2.5 Mabsadd L
.55714 .05093 2.5 -2.5 Mabsadd L
.55714 .05093 -2.5 -2.5 Mabsadd L
.55714 .05093 -2.5 2.5 Mabsadd L closepath F
.63333 .04062 -2.5 2.5 Mabsadd m
.63333 .04062 2.5 2.5 Mabsadd L
.63333 .04062 2.5 -2.5 Mabsadd L
.63333 .04062 -2.5 -2.5 Mabsadd L
.63333 .04062 -2.5 2.5 Mabsadd L closepath F
.70952 .03109 -2.5 2.5 Mabsadd m
.70952 .03109 2.5 2.5 Mabsadd L
.70952 .03109 2.5 -2.5 Mabsadd L
.70952 .03109 -2.5 -2.5 Mabsadd L
.70952 .03109 -2.5 2.5 Mabsadd L closepath F
.78571 .02757 -2.5 2.5 Mabsadd m
.78571 .02757 2.5 2.5 Mabsadd L
.78571 .02757 2.5 -2.5 Mabsadd L
.78571 .02757 -2.5 -2.5 Mabsadd L
.78571 .02757 -2.5 2.5 Mabsadd L closepath F
.97619 .02156 -2.5 2.5 Mabsadd m
.97619 .02156 2.5 2.5 Mabsadd L
.97619 .02156 2.5 -2.5 Mabsadd L
.97619 .02156 -2.5 -2.5 Mabsadd L
.97619 .02156 -2.5 2.5 Mabsadd L closepath F
.001 w
[ .5 3 ] 0 Mabsdash
.1381 .47723 m
.17619 .40467 L
.21429 .32884 L
.25238 .25738 L
.29048 .1956 L
.32857 .14616 L
.36667 .10924 L
.40476 .08335 L
.48095 .05507 L
.55714 .04345 L
.63333 .03783 L
.70952 .03419 L
.78571 .03146 L
.97619 .02693 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{756, 467},
  ImageMargins->{{35, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;d0001db000`400?l00000o`00003oo`3ooooo
0?ooooH0oooo003o0?ooool0oooomP3oool00?l0ooooO03oool400000280oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`3o0?ooodD0oooo003o0?oooh00oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooA03oool00?l0ooooP03o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3o
oom40?ooo`00o`3ooomZ0?ooo`<000000P3oool3000000050?ooo`00000000000000003oool00`00
00020?ooo`<0000000@0oooo0000003oool0oooo1`0000020?ooo`D000003`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0?l0oooo@`3oool00?l0ooooJ`3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`80
00001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`3o0?oood<0oooo003o0?ooof`0oooo100000040?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0o`3ooom30?ooo`00o`3ooom/0?ooo`040000003oool0oooo000000@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`H000003`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0?l0oooo@`3oool00?l0ooooK03oool010000000oooo0?ooo`0000040?oo
o`8000000P3oool010000000oooo0?ooo`0000030?ooo`8000001@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0?l0oooo@`3oool00?l0ooooK@3oool2000000@0oooo0P0000000`3o
ool00000000000040?ooo`<0000000<0oooo000000000000103oool00`000000oooo0?ooo`030?oo
o`@00000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0oooo@`3oool00?l0
ooooK@3oool2000001L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`80
00001@3oool00`000000oooo0?ooo`3o0?oood@0oooo003o0?ooof`0oooo0`00000G0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0?l0ooooA03oool00?l0ooooQ@3oool2000001/0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0?l0ooooA@3oool00?l0oooo
Z03oool200000?l0ooooC03oool00?l0ooooo`3oooof0?ooo`00E03oool2000007`0oooo0P00001g
0?ooo`D000000P3oool2000007D0oooo1@0000020?ooo`800000M03oool4000000<0oooo0P00001e
0?ooo`@000000`3oool2000002L0oooo001C0?ooo`040000003oool0oooo000007X0oooo00@00000
0?ooo`3oool00000N03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
M03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0L@3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo000007@0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`00000V0?ooo`00D`3oool010000000oooo0?ooo`00001m0?ooo`030000003oool0
oooo07H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo07@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000M@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02@0oooo
001C0?ooo`040000003oool0oooo000007/0oooo0P00001i0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0080oooo0P00001f0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
0080oooo0P00000W0?ooo`00D`3oool010000000oooo0?ooo`00001k0?ooo`030000003oool0oooo
07P0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo07@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`1c0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000M03oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02H0
oooo001D0?ooo`800000O03oool3000007L0oooo0P0000040?ooo`800000MP3oool2000000@0oooo
0`00001d0?ooo`800000103oool2000007H0oooo0P0000040?ooo`<000009P3oool00?l0ooooo`3o
ooof0?ooo`00o`3ooooo0?ooooH0oooo003o0?ooool0oooomP3oool00?l0ooooo`3oooof0?ooo`00
o`3ooooo0?ooooH0oooo003o0?ooool0oooomP3oool00?l0ooooo`3oooof0?ooo`00o`3ooooo0?oo
ooH0oooo003o0?ooool0oooomP3oool00?l0ooooo`3oooof0?ooo`00o`3ooooo0?ooooH0oooo0016
0?ooool00000o`00002E000001/0oooo00160?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01T0oooo00160?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo01T0oooo00160?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
N`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0
NP3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
6@3oool004H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1k0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`1j0?ooo`030000003o
ool0oooo07/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0I0?ooo`00AP3oool0
0`000000oooo0?ooo`3o0?ooool0ooooT@3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`00
0000oooo0?ooo`3o0?ooool0ooooT@3oool00`000000oooo0?ooo`0I0?ooo`00>@3oool2000000/0
oooo00<000000?ooo`3oool0o`3ooooo0?oooi40oooo00<000000?ooo`3oool06@3oool003P0oooo
00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`3o0?ooool0ooooT@3oool00`000000
oooo0?ooo`0I0?ooo`00>03oool010000000oooo0?ooo`00000:0?ooo`D00000o`3ooooo0?oooh/0
oooo1@00000K0?ooo`00>03oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0?l0
ooooo`3ooonA0?ooo`030000003oool0oooo01T0oooo000h0?ooo`040000003oool0oooo000000X0
oooo00<000000?ooo`3oool0o`3ooooo0?oooi40oooo00<000000?ooo`3oool06@3oool003T0oooo
0P00000;0?ooo`030000003oool0oooo0?l0ooooo`3ooomo0?ooo`D000003@3oool00`000000oooo
0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`3o0?ooool0ooooO`3oool5000000d0oooo00<0
00000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0o`3ooooo0?ooogl0oooo1@00000=
0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003oool0oooo0?l0ooooo`3ooomo0?oo
o`D000003@3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`3o0?ooool0
oooo0P3oool5000007P0oooo1@00000=0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000
003oool0oooo0?l0ooooo`3oool20?ooo`D00000N@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo01T0oooo00160?ooo`030000003oool0oooo0?l0ooooo`3oool20?ooo`D00000C`3o
ool2000000030?ooo`00000000000080oooo00<000000?ooo`3oool00P0000020?ooo`030000003o
ool0oooo008000000P3oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool00P00
00020?ooo`030000003oool0oooo008000004`3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool0
0`000000oooo0?ooo`3o0?ooolh0oooo1@00000^0?ooo`D000009@3oool200000080oooo00<00000
0?ooo`3oool00P0000020?ooo`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`02
00000080oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo008000000P3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003oool0oooo
0?l0oooocP3oool5000002h0oooo1@0000020?ooo`8000000P3oool00`000000oooo0?ooo`020000
0080oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo008000000P3oool00`00
0000oooo0?ooo`0200000080oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0I0?oo
o`00AP3oool00`000000oooo0?ooo`3o0?ooolh0oooo1@00000F0?ooo`030000003oool0oooo0080
00000P3oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool00P0000020?ooo`04
0000003oool0oooo000008h0oooo00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3o
ool0o`3oooo=0?ooo`H0000000@0oooo0000003oool0oooo0P0000020?ooo`030000003oool0oooo
008000000P3oool00`000000oooo0?ooo`0200000:T0oooo00<000000?ooo`3oool06@3oool004H0
oooo00<000000?ooo`3oool0o`3ooonh0?ooo`030000003oool0oooo008000000P3oool00`000000
oooo0?ooo`0200000080oooo00<000000?ooo`3oool00P0000030?ooo`D00000_@3oool00`000000
oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`3o0?oooj<0oooo00<000000?ooo`3oool0
0P0000020?ooo`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`0200000=X0oooo
00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0o`3ooonE0?ooo`030000003o
ool0oooo008000000P3oool500000>l0oooo00<000000?ooo`3oool06@3oool004H0oooo00<00000
0?ooo`3oool0o`3ooon70?ooo`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`02
000000T0oooo1@00003_0?ooo`030000003oool0oooo01T0oooo00160?ooo`<00000o`3ooomi0?oo
o`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`02000001L0oooo1@00003]0?oo
o`<000006`3oool004H0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`8000000P3oool00`000000
oooo0?ooo`02000002D0oooo1@00003_0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000
003oool0oooo0?l0ooooI`3oool200000080oooo00<000000?ooo`3oool0;P3oool500000>l0oooo
00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0o`3ooomP0?ooo`8000000P3o
ool00`000000oooo0?ooo`3o0?ooobX0oooo00<000000?ooo`3oool06@3oool004H0oooo00<00000
0?ooo`3oool0o`3ooomI0?ooo`8000000P3oool00`000000oooo0?ooo`0;0?ooo`@00000o`3ooolR
0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003oool0oooo0?l0ooooD`3oool00`00
0000oooo0?ooo`0200000180oooo1@00003o0?ooob80oooo00<000000?ooo`3oool06@3oool004H0
oooo00<000000?ooo`3oool0o`3ooom<0?ooo`030000003oool0oooo008000006@3oool500000?l0
oooo8P3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`3o0?ooodD0oooo
00<000000?ooo`3oool00P00000P0?ooo`D00000o`3ooolR0?ooo`030000003oool0oooo01T0oooo
00160?ooo`030000003oool0oooo0?l0oooo?P3oool00`000000oooo0?ooo`02000002L0oooo1@00
003o0?ooob80oooo00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0o`3oooli
0?ooo`@00000;@3oool500000?l0oooo8P3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`00
0000oooo0?ooo`3o0?ooocL0oooo0P0000000`3oool000000?ooo`3o0?oooeD0oooo00<000000?oo
o`3oool06@3oool004H0oooo00<000000?ooo`3oool0o`3ooold0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0o`3ooomD0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000
003oool0oooo0?l0oooo<@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo
E03oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`3o0?oooc00oooo00<0
00000?ooo`3oool01@3oool500000?l0ooooE03oool00`000000oooo0?ooo`0I0?ooo`00AP3oool0
0`000000oooo0?ooo`3o0?ooobd0oooo0P0000090?ooo`D00000o`3ooomD0?ooo`030000003oool0
oooo01T0oooo00160?ooo`030000003oool0oooo0?l0oooo:P3oool00`000000oooo0?ooo`0;0?oo
o`D00000o`3ooomD0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003oool0oooo0?l0
oooo9`3oool00`000000oooo0?ooo`0>0?ooo`D00000o`3ooomD0?ooo`030000003oool0oooo01T0
oooo00160?ooo`030000003oool0oooo0?l0oooo903oool00`000000oooo0?ooo`0A0?ooo`D00000
o`3ooomD0?ooo`030000003oool0oooo01T0oooo00160?ooo`<00000o`3ooolS0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0o`3ooomB0?ooo`<000006`3oool004H0oooo00<00000
0?ooo`3oool0o`3ooolP0?ooo`8000005`3oool400000?l0ooooE03oool00`000000oooo0?ooo`0I
0?ooo`00AP3oool00`000000oooo0?ooo`3o0?oooad0oooo00<000000?ooo`3oool0o`3oooma0?oo
o`030000003oool0oooo01T0oooo00160?ooo`030000003oool0oooo0?l0oooo6P3oool00`000000
oooo0?ooo`3o0?ooog@0oooo00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0
o`3ooolF0?ooo`800000o`3ooomi0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003o
ool0oooo0?l0oooo4`3oool00`000000oooo0?ooo`3o0?ooog/0oooo00<000000?ooo`3oool06@3o
ool004H0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`030000003oool0oooo0?l0ooooN`3oool0
0`000000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?oo
o`3oool0o`3ooomn0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003oool0oooo0?l0
oooo303oool200000?l0ooooP`3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo
0?ooo`3o0?ooo`T0oooo0P00003o0?ooohH0oooo00<000000?ooo`3oool06@3oool004H0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooi40oooo00<000000?ooo`3oool06@3oool004H0oooo00<00000
0?ooo`3oool0o`3oool60?ooo`D00000o`3ooon60?ooo`030000003oool0oooo01T0oooo00160?oo
o`030000003oool0oooo0?l0oooo203oool00`000000oooo0?ooo`3o0?ooohH0oooo00<000000?oo
o`3oool06@3oool004H0oooo00<000000?ooo`3oool0o`3oool30?ooo`8000000`3oool00`000000
oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0
o`3oool80?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0I0?ooo`00AP3o
ool00`000000oooo0?ooo`3o0?ooo`8000001P3oool00`000000oooo0?ooo`3o0?ooohH0oooo00<0
00000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0o`3oool60?ooo`D00000o`3ooon6
0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003oool0oooo0?`0oooo0P0000070?oo
o`D00000o`3ooon60?ooo`030000003oool0oooo01T0oooo00160?ooo`<00000o`3oool60?ooo`D0
0000o`3ooon40?ooo`<000006`3oool004H0oooo00<000000?ooo`3oool0nP3oool00`000000oooo
0?ooo`080?ooo`D00000o`3ooon60?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003o
ool0oooo0?l0oooo1P3oool500000?l0ooooQP3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool0
0`000000oooo0?ooo`3g0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooon6
0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003oool0oooo0?l0oooo203oool00`00
0000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3o
ool0m03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooQP3oool00`000000
oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`3o0?ooo`P0oooo00<000000?ooo`3oool0
o`3ooon60?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003oool0oooo0?40oooo00<0
00000?ooo`3oool04P3oool400000?l0ooooQP3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool0
0`000000oooo0?ooo`3^0?ooo`030000003oool0oooo0?l0ooooW`3oool00`000000oooo0?ooo`0I
0?ooo`00AP3oool00`000000oooo0?ooo`3^0?ooo`030000003oool0oooo0?l0ooooW`3oool00`00
0000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`3o0?ooool0ooooT@3oool00`000000
oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`3[0?ooo`800000o`3ooonS0?ooo`030000
003oool0oooo01T0oooo00160?ooo`030000003oool0oooo0?l0ooooo`3ooonA0?ooo`030000003o
ool0oooo01T0oooo00160?ooo`030000003oool0oooo0>T0oooo00@000000?ooo`3oool0oooo1000
003o0?oooil0oooo00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0j@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0ooooW`3oool00`000000oooo0?ooo`0I
0?ooo`00;@3oool2000000@0oooo0P0000030?ooo`@000002P3oool00`000000oooo0?ooo`3^0?oo
o`030000003oool0oooo0?l0ooooW`3oool00`000000oooo0?ooo`0I0?ooo`00;03oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0iP3oool20000
00H0oooo00<000000?ooo`3oool0o`3ooonO0?ooo`030000003oool0oooo01T0oooo000/0?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`3oool02P3oool500000>`0oooo00<000000?oo
o`3oool0o`3ooonK0?ooo`D000006`3oool002`0oooo00@000000?ooo`3oool000002P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0>@0oooo00<000000?ooo`3oool01@3oool50000
0?l0ooooW`3oool00`000000oooo0?ooo`0I0?ooo`00;03oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0i03oool00`000000oooo0?ooo`05
0?ooo`D00000o`3ooonO0?ooo`030000003oool0oooo01T0oooo000]0?ooo`8000002P3oool20000
00/0oooo00<000000?ooo`3oool0k03oool500000?l0ooooW`3oool00`000000oooo0?ooo`0I0?oo
o`00AP3oool00`000000oooo0?ooo`3C0?ooo`@000002P3oool2000000T0oooo1@00003o0?oooil0
oooo00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0e@3oool00`000000oooo
0?ooo`0D0?ooo`D00000o`3ooonO0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003o
ool0oooo0=D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0?l0ooooW`3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`3E
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3ooonO0?ooo`030000003oool0
oooo01T0oooo00160?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0ooooW`3oool00`000000oooo0?ooo`0I0?oo
o`00AP3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool03P3oool400000?l0ooooW`3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo
0?ooo`3E0?ooo`030000003oool0oooo0?l0oooo^03oool00`000000oooo0?ooo`0I0?ooo`00AP3o
ool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3o
oonc0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003oool0oooo0=D0oooo00<00000
0?ooo`3oool0o`3ooonh0?ooo`030000003oool0oooo01T0oooo000K0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3E0?ooo`040000003oool0oooo
00000?l0oooo]`3oool00`000000oooo0?ooo`0I0?ooo`006`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0e@3oool00`000000oooo0000003o0?oo
okP0oooo00<000000?ooo`3oool06@3oool001/0oooo2000000S0?ooo`030000003oool0oooo0=80
oooo1@00003o0?oookT0oooo00<000000?ooo`3oool06@3oool001/0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0=80oooo1@00003o0?oookT0oooo
00<000000?ooo`3oool06@3oool001/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0=80oooo1@00003o0?oookT0oooo00<000000?ooo`3oool06@3o
ool004H0oooo0`00003B0?ooo`D00000o`3ooong0?ooo`<000006`3oool004H0oooo00<000000?oo
o`3oool0dP3oool500000?l0oooo^@3oool00`000000oooo0?ooo`0I0?ooo`007@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0e@3oool00`000000
oooo0?ooo`3o0?oookP0oooo00<000000?ooo`3oool06@3oool001d0oooo1P00000S0?ooo`030000
003oool0oooo0=40oooo00D000000?ooo`3oool0oooo0000003o0?oookX0oooo00<000000?ooo`3o
ool06@3oool001d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0=40oooo00D000000?ooo`3oool0oooo0000003o0?oookX0oooo00<000000?ooo`3o
ool06@3oool001d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3E0?ooo`030000
003oool0oooo0?l0oooo^03oool00`000000oooo0?ooo`0I0?ooo`007@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0cP3oool2000000D0oooo00<0
00000?ooo`3oool0o`3ooonh0?ooo`030000003oool0oooo01T0oooo000N0?ooo`D000008`3oool0
0`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0?l0oooo^03oool00`000000oooo0?ooo`0I
0?ooo`008P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0=D0oooo00<000000?oo
o`3oool0o`3ooonh0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003oool0oooo0<`0
oooo0P0000070?ooo`030000003oool0oooo0?l0oooo^03oool00`000000oooo0?ooo`0I0?ooo`00
7@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0
o`3ooonh0?ooo`030000003oool0oooo01T0oooo000K0?ooo`L00000903oool00`000000oooo0?oo
o`3C0?ooo`@00000o`3oooni0?ooo`030000003oool0oooo01T0oooo000M0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0
oooo0?l0oooo``3oool00`000000oooo0?ooo`0I0?ooo`007@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0o`3ooooo0?oooi40oooo00<000000?oo
o`3oool06@3oool001d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo0;X0oooo1000000:0?ooo`030000003oool0oooo0?l0ooooa@3oool00`000000
oooo0?ooo`0I0?ooo`007@3oool01@000000oooo0?ooo`3oool0000002@0oooo00<000000?ooo`3o
ool0_03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0ooooa@3oool00`000000
oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo0?l0oooo
d@3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`2l0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0o`3oooo70?ooo`030000003oool0oooo01T0oooo000N
0?ooo`@00000903oool300000;`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o
0?ooolD0oooo0`00000K0?ooo`007@3oool00`000000oooo000000020?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`3o0?ooom40oooo00<000000?oo
o`3oool06@3oool001d0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo0;`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooolT0
oooo00<000000?ooo`3oool06@3oool001d0oooo00<000000?ooo`0000000P3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool0o`3ooooA0?ooo`030000
003oool0oooo01T0oooo000M0?ooo`030000003oool000000080oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`2i0?ooo`D00000o`3ooooB0?ooo`030000003oool0oooo01T0oooo000N
0?ooo`8000000P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;T0oooo1@000004
0?ooo`030000003oool0oooo0?l0oooob`3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`00
0000oooo0?ooo`2i0?ooo`D00000o`3ooooB0?ooo`030000003oool0oooo01T0oooo00160?ooo`03
0000003oool0oooo0;T0oooo1@0000020?ooo`030000003oool0oooo0?l0ooooc@3oool00`000000
oooo0?ooo`0I0?ooo`007@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0^@3oool5000000030?ooo`000000oooo0?l0ooooc`3oool00`000000oooo
0?ooo`0I0?ooo`007@3oool6000002<0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?oo
o`3o0?ooom40oooo00<000000?ooo`3oool06@3oool001d0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`000000o`3ooooA
0?ooo`030000003oool0oooo01T0oooo000M0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0_03oool200000?l0oooodP3oool00`000000oooo0?ooo`0I0?ooo`007@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0_03oool00`000000
oooo0?ooo`3o0?ooom40oooo00<000000?ooo`3oool06@3oool001h0oooo1@00000S0?ooo`030000
003oool0oooo0;/0oooo0P00003o0?ooom<0oooo00<000000?ooo`3oool06@3oool00280oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo0?l0ooood@3o
ool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`2j0?ooo`@00000o`3ooooB
0?ooo`030000003oool0oooo01T0oooo000N0?ooo`030000003oool0oooo008000008`3oool00`00
0000oooo0?ooo`2i0?ooo`800000o`3ooooE0?ooo`030000003oool0oooo01T0oooo000M0?ooo`05
0000003oool000000?ooo`000000903oool300000?l0ooooo`3ooon?0?ooo`<000006`3oool001d0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0
ooooo`3ooonA0?ooo`030000003oool0oooo01T0oooo000M0?ooo`030000003oool000000080oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`280?ooo`@00000;03oool00`000000oooo
0?ooo`3o0?ooomD0oooo00<000000?ooo`3oool06@3oool001d0oooo00<000000?ooo`0000000P3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0o`3o
oooo0?ooo`@0oooo00<000000?ooo`3oool06@3oool001d0oooo0P0000000`3oool000000000000T
0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`@0oooo00<00000
0?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo0?l0ooooe`3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`000000
oooo0?ooo`2:0?ooo`030000003oool0oooo0?l0ooooo`3oool40?ooo`030000003oool0oooo01T0
oooo000R0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0RP3oool00`000000oooo
0?ooo`3o0?ooool0oooo103oool00`000000oooo0?ooo`0I0?ooo`007@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo0?l0oooof@3oool00`000000oooo0?ooo`0I0?ooo`007@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0RP3oool0
0`000000oooo0?ooo`3o0?ooool0oooo103oool00`000000oooo0?ooo`0I0?ooo`006`3oool00`00
0000oooo00000005000002<0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`3o0?oo
ool0oooo103oool00`000000oooo0?ooo`0I0?ooo`008P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo08X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3o0?ooom/0
oooo00<000000?ooo`3oool06@3oool00280oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`2:0?ooo`030000003oool0oooo0?l0ooooo`3oool40?ooo`030000003oool0oooo01T0oooo
000R0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`3o0?ooool0oooo103oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`2:
0?ooo`030000003oool0oooo02<0oooo0P00003o0?ooomh0oooo00<000000?ooo`3oool06@3oool0
01d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo
01@0oooo1000003o0?ooon/0oooo00<000000?ooo`3oool06@3oool001/0oooo1`00000;0?ooo`80
0000103oool2000000D0oooo0`0000090?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`3o0?ooonX0oooo00<000000?ooo`3oool06@3oool001d0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000/0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0203oool200000?l0ooooh03oool00`000000oooo0?ooo`0I0?ooo`00
7@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0
0000203oool5000000T0oooo1@0000280?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0o`3ooooV0?ooo`D000006`3oool001d0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000002P3oool00`00
0000oooo0?ooo`2:0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3ooooZ0?oo
o`030000003oool0oooo01T0oooo000M0?ooo`050000003oool0oooo0?ooo`0000002P3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool0RP3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooooP
0?ooo`030000003oool0oooo01T0oooo000]0?ooo`8000002`3oool2000000X0oooo00<000000?oo
o`3oool0RP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0oooojP3oool00`00
0000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0o`3ooooZ0?ooo`030000003oool0oooo01T0oooo000M0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooooR0?ooo`030000003oool0oooo01T0oooo
000M0?ooo`<000001@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo08X0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`3o0?ooonX0oooo00<000000?ooo`3oool06@3o
ool001d0oooo00<000000?ooo`3oool00P0000020?ooo`800000803oool00`000000oooo0?ooo`2:
0?ooo`030000003oool0oooo01<0oooo1@00003o0?ooon/0oooo00<000000?ooo`3oool06@3oool0
0280oooo0P0000000`3oool000000?ooo`0O0?ooo`030000003oool0oooo08X0oooo00<000000?oo
o`3oool04`3oool5000000@0oooo00<000000?ooo`3oool0o`3ooooT0?ooo`030000003oool0oooo
01T0oooo000M0?ooo`030000003oool0oooo00800000903oool00`000000oooo0?ooo`2:0?ooo`03
0000003oool0oooo01<0oooo1@00003o0?ooon/0oooo00<000000?ooo`3oool06@3oool001d0oooo
0`00000V0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool04`3oool500000?l0oooo
j`3oool00`000000oooo0?ooo`0I0?ooo`007@3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo08X0oooo00<000000?ooo`3oool04`3oool500000080oooo00<000000?ooo`3oool0o`3o
oooV0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003oool0oooo08X0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`3o0?ooonX0oooo00<000000?ooo`3oool06@3oool0
04H0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
0?l0oooojP3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`2:0?ooo`03
0000003oool0oooo01H0oooo00@000000?ooo`0000000000o`3ooooY0?ooo`030000003oool0oooo
01T0oooo00160?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`3o0?ooonX0oooo00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0
RP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0oooojP3oool00`000000oooo
0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo01H0oooo0P00
003o0?ooon/0oooo00<000000?ooo`3oool06@3oool004H0oooo0`00002:0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0o`3ooooX0?ooo`<000006`3oool004H0oooo00<000000?oo
o`3oool0RP3oool00`000000oooo0?ooo`0D0?ooo`@00000o`3oooo[0?ooo`030000003oool0oooo
01T0oooo00160?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`3o0?ooon/0oooo00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0
RP3oool00`000000oooo0?ooo`3o0?ooool0oooo103oool00`000000oooo0?ooo`0I0?ooo`00AP3o
ool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?l0ooooo`3oool40?ooo`030000003o
ool0oooo01T0oooo00160?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`3o0?ooond0oooo00<000000?ooo`3oool06@3oool004H0oooo00<000000?oo
o`3oool0RP3oool00`000000oooo0?ooo`3o0?ooool0oooo103oool00`000000oooo0?ooo`0I0?oo
o`00AP3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?l0ooooo`3oool40?ooo`03
0000003oool0oooo01T0oooo00160?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0
4@3oool200000?l0ooool03oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?oo
o`2:0?ooo`030000003oool0oooo0?l0ooooo`3oool40?ooo`030000003oool0oooo01T0oooo000M
0?ooo`H000008`3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?l0ooooo`3oool4
0?ooo`030000003oool0oooo01T0oooo000K0?ooo`8000001P3oool200000240oooo00<000000?oo
o`3oool0RP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooool03oool00`00
0000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0
ooool03oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`270?ooo`D00000
o`3ooooo0?ooo`D0oooo00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0Q`3o
ool5000000l0oooo00<000000?ooo`3oool0o`3oooob0?ooo`030000003oool0oooo01T0oooo000N
0?ooo`040000003oool00000000002@0oooo00<000000?ooo`3oool0Q`3oool5000000l0oooo00<0
00000?ooo`3oool0o`3oooob0?ooo`030000003oool0oooo01T0oooo000M0?ooo`030000003oool0
00000080oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`270?ooo`D00000o`3ooooo
0?ooo`D0oooo00<000000?ooo`3oool06@3oool001d0oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo08L0oooo1@00000>0?ooo`030000003oool0oooo
0?l0ooool`3oool00`000000oooo0?ooo`0I0?ooo`007@3oool00`000000oooo000000020?ooo`03
0000003oool0oooo0240oooo0`00002:0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0o`3oooob0?ooo`<000006`3oool001d0oooo00D000000?ooo`000000oooo0000000T0?ooo`03
0000003oool0oooo08X0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`@0oooo00<000000?ooo`3o
ool06@3oool001h0oooo1@00000S0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`3o0?ooooD0oooo00<000000?ooo`3oool06@3oool00280oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0o`3ooooe0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003oool0
oooo08X0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`@0oooo00<000000?ooo`3oool06@3oool0
01d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
08X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooooL0oooo00<000000?oo
o`3oool06@3oool001d0oooo1P00000S0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`3o0?ooooL0oooo00<000000?ooo`3oool06@3oool001h0oooo
00D000000?ooo`3oool0oooo0000000S0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooo`@0oooo00<000000?ooo`3oool06@3oool001d0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0
o`3ooooo0?ooo`@0oooo00<000000?ooo`3oool06@3oool001d0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`3o0?ooooP0oooo00<000000?ooo`3oool06@3oool001d0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?l0ooooo`3oool4
0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003oool0oooo08X0oooo00<000000?oo
o`3oool0o`3ooooo0?ooo`@0oooo00<000000?ooo`3oool06@3oool001X0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`3o0?ooooX0oooo00<000000?ooo`3oool06@3oool001X0oooo
2@00000S0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`@0oooo
00<000000?ooo`3oool06@3oool001h0oooo00@000000?ooo`3oool00000903oool00`000000oooo
0?ooo`2:0?ooo`030000003oool0oooo0?l0ooooo`3oool40?ooo`030000003oool0oooo01T0oooo
000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`2:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooool0?ooo`030000003o
ool0oooo01T0oooo000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?l0ooooo`3oool40?ooo`030000003oool0
oooo01T0oooo000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool30000
08X0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`80oooo0`00000K0?ooo`007P3oool4000002@0
oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0
ooooo@3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`2:0?ooo`030000
003oool0oooo0?l0ooooo`3oool40?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003o
ool0oooo08X0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`@0oooo00<000000?ooo`3oool06@3o
ool00280oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`2:0?ooo`050000003oool0
oooo0?ooo`000000o`3ooooo0?ooo`80oooo00<000000?ooo`3oool06@3oool001d0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo08X0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooo`@0oooo00<000000?ooo`3oool06@3oool001d0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo08X0oooo00<000000?oo
o`3oool0o`3ooooo0?ooo`@0oooo00<000000?ooo`3oool06@3oool001/0oooo00<000000?ooo`00
00001@00000S0?ooo`030000003oool0oooo08X0oooo00@000000?ooo`0000000000o`3ooooo0?oo
o`<0oooo00<000000?ooo`3oool06@3oool00280oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`2:0?ooo`030000003oool0oooo0?l0ooooo`3oool40?ooo`030000003oool0oooo01T0
oooo000R0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0RP3oool00`000000oooo
0?ooo`3o0?ooool0oooo103oool00`000000oooo0?ooo`0I0?ooo`008P3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo08X0oooo0P00003o0?ooool0oooo1@3oool00`000000oooo0?oo
o`0I0?ooo`00AP3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0?l0ooooo`3oool4
0?ooo`030000003oool0oooo01T0oooo000M0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0RP3oool00`000000oooo0?ooo`3o0?ooool0oooo103oool00`000000oooo0?ooo`0I0?oo
o`006`3oool7000002@0oooo00<000000?ooo`3oool0R@3oool200000?l0ooooo`3oool60?ooo`03
0000003oool0oooo01T0oooo000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`290?ooo`800000o`3ooooo0?ooo`H0oooo00<000000?ooo`3oool0
6@3oool001d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo08X0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`@0oooo00<000000?ooo`3oool06@3o
ool001d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`800000103oool2
000000<0oooo0`00000;0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`000000o`3ooooo
0?ooo`H0oooo00<000000?ooo`3oool06@3oool001d0oooo00D000000?ooo`3oool0oooo0000000:
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000002P3oool00`000000oooo
0?ooo`270?ooo`040000003oool0oooo00000?l0ooooo`3oool60?ooo`030000003oool0oooo01T0
oooo000/0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000002P3oool50000
08P0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`D000006`3oool002`0oooo00@000000?ooo`3o
ool00000203oool3000000/0oooo00<000000?ooo`3oool0QP3oool01@000000oooo0?ooo`3oool0
00000?l0ooooo`3oool60?ooo`030000003oool0oooo01T0oooo000M0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0QP3oool01@000000oooo0?ooo`3oool000000?l0ooooo`3o
ool60?ooo`030000003oool0oooo01T0oooo000M0?ooo`H000002P3oool2000000X0oooo0`00000:
0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`@0oooo00<00000
0?ooo`3oool06@3oool001h0oooo00D000000?ooo`3oool0oooo0000000S0?ooo`030000003oool0
oooo08X0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`@0oooo00<000000?ooo`3oool06@3oool0
01d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
06l0oooo1000000A0?ooo`800000103oool00`000000oooo0?ooo`3o0?ooool0oooo103oool00`00
0000oooo0?ooo`0I0?ooo`007@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0
ooooo`3oool40?ooo`030000003oool0oooo01T0oooo000M0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0oooo
o`3oool40?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooo`3o
ool40?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003oool0oooo0740oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`3o0?ooool0oooo103oool00`000000oooo0?ooo`0I
0?ooo`007P3oool010000000oooo00000000000T0?ooo`030000003oool0oooo0740oooo00<00000
0?ooo`3oool0503oool400000?l0ooooo`3oool50?ooo`030000003oool0oooo01T0oooo000M0?oo
o`030000003oool000000080oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1a0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`d0oooo00<000000?oo
o`3oool06@3oool001d0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo0740oooo00<000000?ooo`3oool0o`3ooooo0?oooad0oooo00<000000?ooo`3o
ool06@3oool001d0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0740oooo00<000000?ooo`3oool0o`3ooooo0?oooad0oooo00<000000?ooo`3oool0
6@3oool001d0oooo00D000000?ooo`000000oooo0000000T0?ooo`030000003oool0oooo0740oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooool0oooo3P3oool00`000000oooo
0?ooo`0I0?ooo`007P3oool5000002<0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?oo
o`3o0?ooool0oooo7@3oool00`000000oooo0?ooo`0I0?ooo`008P3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0o`3ooooo0?oooad0oooo00<00000
0?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo0?l0ooooo`3oool@0?ooo`030000003oool0oooo01T0oooo000M0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool300000740oooo00<000000?ooo`3o
ool0o`3ooooo0?oooa/0oooo0`00000K0?ooo`007@3oool6000002<0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`3o0?ooool0oooo7@3oool00`000000oooo0?ooo`0I0?ooo`007P3o
ool01@000000oooo0?ooo`3oool0000002<0oooo00<000000?ooo`3oool0L@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0?l0ooooo`3ooolA0?ooo`030000003oool0oooo01T0oooo
000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`1a0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooooo0?oooa80oooo00<0
00000?ooo`3oool06@3oool001d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0o`3ooooo0?oooad0oooo00<00000
0?ooo`3oool06@3oool001d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1a0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooooo0?oooa<0oooo00<000000?oo
o`3oool06@3oool004H0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0?l0ooooo`3ooolC0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000
003oool0oooo0740oooo00<000000?ooo`3oool0o`3ooooo0?oooad0oooo00<000000?ooo`3oool0
6@3oool001d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1a0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0o`3ooooo0?oooa@0oooo00<000000?ooo`3oool06@3o
ool001d0oooo0`0000050?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0L@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooo`3ooolE0?ooo`030000003oool0
oooo01T0oooo000M0?ooo`030000003oool0oooo008000000P3oool200000200oooo00<000000?oo
o`3oool0L@3oool00`000000oooo0?ooo`3o0?ooool0oooo7@3oool00`000000oooo0?ooo`0I0?oo
o`008P3oool2000000030?ooo`000000oooo01l0oooo00<000000?ooo`3oool0L@3oool00`000000
oooo0?ooo`3o0?ooool0oooo7@3oool00`000000oooo0?ooo`0I0?ooo`007@3oool00`000000oooo
0?ooo`02000002@0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0?l0ooooo`3ooolF0?ooo`030000003oool0oooo01T0oooo000M0?ooo`<000009P3o
ool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0ooooo`3ooolM0?ooo`030000003o
ool0oooo01T0oooo000M0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0L@3oool0
0`000000oooo0?ooo`3o0?ooool0oooo7@3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`00
0000oooo0?ooo`1a0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooooo0?oo
oaP0oooo00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0L@3oool00`000000
oooo0?ooo`3o0?ooool0oooo7@3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool3000006h0oooo
1@00003o0?ooool0oooo703oool3000001/0oooo00160?ooo`030000003oool0oooo06h0oooo1@00
00020?ooo`030000003oool0oooo0?l0ooooo`3ooolI0?ooo`030000003oool0oooo01T0oooo0016
0?ooo`030000003oool0oooo06h0oooo1@00003o0?ooool0oooo7P3oool00`000000oooo0?ooo`0I
0?ooo`00AP3oool00`000000oooo0?ooo`1^0?ooo`D00000o`3ooooo0?oooah0oooo00<000000?oo
o`3oool06@3oool004H0oooo00<000000?ooo`3oool0KP3oool600000?l0ooooo`3ooolM0?ooo`03
0000003oool0oooo01T0oooo00160?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0
o`3ooooo0?oooad0oooo00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0L@3o
ool00`000000oooo0?ooo`3o0?ooool0oooo7@3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool0
0`000000oooo0?ooo`1a0?ooo`800000o`3ooooo0?oooah0oooo00<000000?ooo`3oool06@3oool0
04H0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`3o0?ooool0oooo7@3oool00`00
0000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0?l0
ooooo`3ooolM0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003oool0oooo0700oooo
0P00003o0?ooool0oooo7`3oool00`000000oooo0?ooo`0I0?ooo`007@3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo0700oooo0P00003o0?ooool0oooo7`3oool00`000000oooo0?oo
o`0I0?ooo`007@3oool5000002@0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`3o
0?ooool0oooo7@3oool00`000000oooo0?ooo`0I0?ooo`008P3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo06h0oooo00@000000?ooo`3oool00000o`3ooooo0?oooal0oooo00<00000
0?ooo`3oool06@3oool00280oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1^0?oo
o`040000003oool0oooo00000?l0ooooo`3ooolO0?ooo`030000003oool0oooo01T0oooo000M0?oo
o`050000003oool0oooo0?ooo`000000903oool00`000000oooo0?ooo`1a0?ooo`030000003oool0
oooo0?l0ooooo`3ooolM0?ooo`030000003oool0oooo01T0oooo000M0?ooo`H000008`3oool00`00
0000oooo0?ooo`1]0?ooo`050000003oool0oooo0?ooo`000000o`3ooooo0?oooal0oooo00<00000
0?ooo`3oool06@3oool00280oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1]0?oo
o`050000003oool0oooo0?ooo`000000o`3ooooo0?oooal0oooo00<000000?ooo`3oool06@3oool0
04H0oooo0`00001a0?ooo`030000003oool0oooo0?l0ooooo`3ooolK0?ooo`<000006`3oool001d0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo06/0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooool0oooo7@3oool00`000000
oooo0?ooo`0I0?ooo`007@3oool6000002<0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0?l0ooooo`3ooolM0?ooo`030000003oool0oooo01T0oooo
000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`1a0?ooo`030000003oool0oooo0?l0ooooo`3ooolM0?ooo`030000003oool0oooo01T0oooo000M
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`3o
0?ooool0oooo7@3oool00`000000oooo0?ooo`0I0?ooo`007@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0J@3oool2000000H0oooo00<000000?oo
o`3oool0o`3ooooo0?oooad0oooo00<000000?ooo`3oool06@3oool001h0oooo1@00000S0?ooo`03
0000003oool0oooo0740oooo00<000000?ooo`3oool0o`3ooooo0?oooad0oooo00<000000?ooo`3o
ool06@3oool00280oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1a0?ooo`030000
003oool0oooo0?l0ooooo`3ooolM0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003o
ool0oooo06P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooool0oooo7@3o
ool00`000000oooo0?ooo`0I0?ooo`008P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo0740oooo00<000000?ooo`3oool0o`3ooooo0?oooad0oooo00<000000?ooo`3oool06@3oool0
01d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
0740oooo00<000000?ooo`3oool0o`3ooooo0?oooad0oooo00<000000?ooo`3oool06@3oool001d0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo06H0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooool0oooo7@3oool00`000000
oooo0?ooo`0I0?ooo`006`3oool00`000000oooo00000005000002<0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`3o0?ooool0oooo7@3oool00`000000oooo0?ooo`0I0?ooo`008P3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0o`3o
oooo0?oooad0oooo00<000000?ooo`3oool06@3oool00280oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00L0oooo1000003o0?ooool0oooo7P3oool0
0`000000oooo0?ooo`0I0?ooo`008P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
0?l0ooooo`3ooonA0?ooo`030000003oool0oooo01T0oooo000]0?ooo`800000103oool2000000@0
oooo0P00000;0?ooo`030000003oool0oooo0?l0ooooo`3ooonA0?ooo`030000003oool0oooo01T0
oooo000M0?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000:0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ob/0oooo00<000000?ooo`3oool06@3oool001/0oooo1`00000:0?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool000002P3oool500000?l0ooooo`3ooon;0?ooo`D000006`3oool0
01d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo
000000T0oooo0P00000;0?ooo`030000003oool0oooo0?l0ooooo`3ooonA0?ooo`030000003oool0
oooo01T0oooo000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0H@3o
ool00`000000oooo0?ooo`3o0?ooool0oooo;@3oool00`000000oooo0?ooo`0I0?ooo`007@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo0P00000:0?ooo`8000002`3oool0
0`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0?l0ooooo`3oool]0?ooo`030000003oool0
oooo01T0oooo000M0?ooo`050000003oool0oooo0?ooo`000000903oool00`000000oooo0?ooo`3o
0?ooool0ooooT@3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`1P0?oo
o`030000003oool0oooo0?l0ooooo`3oool^0?ooo`030000003oool0oooo01T0oooo00160?ooo`03
0000003oool0oooo0600oooo00<000000?ooo`3oool0o`3ooooo0?ooobh0oooo00<000000?ooo`3o
ool06@3oool001h0oooo00<000000?ooo`3oool00P00000S0?ooo`030000003oool0oooo0?l0oooo
o`3ooonA0?ooo`030000003oool0oooo01T0oooo000M0?ooo`050000003oool000000?ooo`000000
903oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0?l0ooooo`3oool`0?ooo`030000
003oool0oooo01T0oooo000M0?ooo`030000003oool000000080oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0?l0ooooo`3oool`0?ooo`030000003o
ool0oooo01T0oooo000M0?ooo`030000003oool000000080oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`3o0?ooool0ooooT@3oool00`000000oooo0?ooo`0I0?ooo`007@3oool00`00
0000oooo000000020?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`3o0?ooool0oooo<@3oool00`000000oooo0?ooo`0I0?ooo`007@3oool200000003
0?ooo`000000000002@0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`3o0?ooool0
oooo<P3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`3o0?ooool0oooo
T@3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`1K0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolc0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003oool0
oooo05/0oooo00<000000?ooo`3oool0o`3ooooo0?oooc<0oooo00<000000?ooo`3oool06@3oool0
04H0oooo00<000000?ooo`3oool0o`3ooooo0?oooi40oooo00<000000?ooo`3oool06@3oool001X0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0?l0
ooooo`3ooonA0?ooo`030000003oool0oooo01T0oooo000K0?ooo`8000001P3oool200000240oooo
0`00001I0?ooo`030000003oool0oooo0?l0ooooo`3ooolc0?ooo`<000006`3oool001d0oooo1P00
000S0?ooo`030000003oool0oooo0?l0ooooo`3ooonA0?ooo`030000003oool0oooo01T0oooo0016
0?ooo`030000003oool0oooo0?l0ooooo`3ooonA0?ooo`030000003oool0oooo01T0oooo00160?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool0o`3ooooo0?ooocH0oooo00<000000?oo
o`3oool06@3oool004H0oooo00<000000?ooo`3oool0o`3ooooo0?oooi40oooo00<000000?ooo`3o
ool06@3oool004H0oooo00<000000?ooo`3oool0o`3ooooo0?oooi40oooo00<000000?ooo`3oool0
6@3oool004H0oooo00<000000?ooo`3oool0o`3ooooo0?oooi40oooo00<000000?ooo`3oool06@3o
ool004H0oooo00<000000?ooo`3oool0o`3ooooo0?oooi40oooo00<000000?ooo`3oool06@3oool0
04H0oooo00<000000?ooo`3oool0o`3ooooo0?oooi40oooo00<000000?ooo`3oool06@3oool004H0
oooo00<000000?ooo`3oool0o`3ooooo0?oooi40oooo00<000000?ooo`3oool06@3oool004H0oooo
00<000000?ooo`3oool0o`3ooooo0?oooi40oooo00<000000?ooo`3oool06@3oool004H0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooi40oooo00<000000?ooo`3oool06@3oool004H0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooi40oooo00<000000?ooo`3oool06@3oool004H0oooo00<000000?oo
o`3oool0o`3ooooo0?oooi40oooo00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooi40oooo00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0
o`3ooooo0?oooi40oooo00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0o`3o
oooo0?oooi40oooo00<000000?ooo`3oool06@3oool004H0oooo0`00003o0?ooool0ooooS`3oool3
000001/0oooo00160?ooo`030000003oool0oooo0?l0ooooo`3ooonA0?ooo`030000003oool0oooo
01T0oooo00160?ooo`030000003oool0oooo05H0oooo1000003o0?ooool0oooo=`3oool00`000000
oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0?l0oooo
o`3ooolf0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooocH0oooo00<000000?ooo`3oool06@3oool004H0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`3o0?ooool0oooo=P3oool00`000000oooo0?ooo`0I
0?ooo`00AP3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0?l0ooooo`3ooolf0?oo
o`030000003oool0oooo01T0oooo00160?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooocH0oooo00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`3o0?ooool0oooo=P3oool00`000000oooo0?ooo`0I0?ooo`00AP3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0?l0ooooo`3ooolf0?ooo`030000003o
ool0oooo01T0oooo00160?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooocH0oooo00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`3o0?ooool0oooo=P3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo0?l0ooooo`3ooolf0?ooo`030000003oool0oooo01T0
oooo00160?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0o`3ooooo0?ooocH0oooo
00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`3o0?ooool0oooo=P3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo0?l0ooooo`3ooolf0?ooo`030000003oool0oooo01T0oooo00160?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool0o`3ooooo0?ooocH0oooo00<000000?oo
o`3oool06@3oool004H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3o0?ooool0
oooo=P3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool3000005P0oooo00<000000?ooo`3oool0
o`3ooooo0?oooc@0oooo0`00000K0?ooo`00AP3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolf0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0o`3ooooo0?ooocH0oooo00<000000?ooo`3oool06@3oool0
04H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3o0?ooool0oooo=P3oool00`00
0000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0?l0
ooooo`3ooolf0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooocH0oooo00<000000?ooo`3oool06@3oool004H0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`3o0?ooool0oooo=P3oool00`000000oooo0?oo
o`0I0?ooo`00AP3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0?l0ooooo`3ooolf
0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooocH0oooo00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`3o0?ooool0oooo=P3oool00`000000oooo0?ooo`0I0?ooo`00
AP3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0?l0ooooo`3ooolf0?ooo`030000
003oool0oooo01T0oooo00160?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0o`3o
oooo0?ooocH0oooo00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`3o0?ooool0oooo=P3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo0?l0ooooo`3ooolf0?ooo`030000003oool0oooo
01T0oooo00160?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0o`3ooooo0?ooocH0
oooo00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`3o0?ooool0oooo=P3oool00`000000oooo0?ooo`0I0?ooo`00>03oool5000000T0oooo00<0
00000?ooo`3oool0E@3oool500000?l0ooooo`3ooolg0?ooo`030000003oool0oooo01T0oooo000j
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0E@3oool500000?l0ooooo`3ooolg
0?ooo`030000003oool0oooo01T0oooo000j0?ooo`030000003oool0oooo00T0oooo1@00001C0?oo
o`D00000o`3ooooo0?oooc<0oooo1@00000K0?ooo`00>P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo05D0oooo1@00003o0?ooool0oooo=`3oool00`000000oooo0?ooo`0I0?ooo`00
>P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo05D0oooo1@00003o0?ooool0oooo
=`3oool00`000000oooo0?ooo`0I0?ooo`00>@3oool2000000/0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`3o0?ooool0oooo=P3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0?l0ooooo`3ooolf0?ooo`030000003oool0
oooo01T0oooo00160?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ocH0oooo00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`3o0?ooool0oooo=P3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo0?l0ooooo`3ooolf0?ooo`030000003oool0oooo01T0oooo
00160?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0o`3ooooo0?ooocH0oooo00<0
00000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3o
0?ooool0oooo=P3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo0?l0ooooo`3ooolf0?ooo`030000003oool0oooo01T0oooo00160?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0o`3ooooo0?ooocH0oooo00<000000?ooo`3o
ool06@3oool004H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3o0?ooool0oooo
=P3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo0?l0ooooo`3ooolf0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0o`3ooooo0?ooocH0oooo00<000000?ooo`3oool06@3oool0
04H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3o0?ooool0oooo=P3oool00`00
0000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0?l0
ooooo`3ooolf0?ooo`030000003oool0oooo01T0oooo00160?ooo`<00000F03oool00`000000oooo
0?ooo`3o0?ooool0oooo=03oool3000001/0oooo00160?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooocH0oooo00<000000?ooo`3oool06@3oool004H0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`3o0?ooool0oooo=P3oool00`000000oooo0?ooo`0I
0?ooo`00AP3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0?l0ooooo`3ooolf0?oo
o`030000003oool0oooo01T0oooo00160?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0o`3ooooo0?ooocH0oooo00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`3o0?ooool0oooo=P3oool00`000000oooo0?ooo`0I0?ooo`00AP3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0?l0ooooo`3ooolf0?ooo`030000003o
ool0oooo01T0oooo00160?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0o`3ooooo
0?ooocH0oooo00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`3o0?ooool0oooo=P3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo0?l0ooooo`3ooolf0?ooo`030000003oool0oooo01T0
oooo00160?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0o`3ooooo0?ooocH0oooo
00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`3o0?ooool0oooo=P3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo0?l0ooooo`3ooolf0?ooo`030000003oool0oooo01T0oooo00160?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool0o`3ooooo0?ooocH0oooo00<000000?oo
o`3oool06@3oool004H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3o0?ooool0
oooo=P3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo0?l0ooooo`3ooolf0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003o
ool0oooo05H0oooo1000003o0?ooool0oooo=`3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool0
0`000000oooo0?ooo`3o0?ooool0ooooT@3oool00`000000oooo0?ooo`0I0?ooo`00AP3oool30000
0?l0ooooo`3ooon?0?ooo`<000006`3oool004H0oooo00<000000?ooo`3oool0o`3ooooo0?oooi40
oooo00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0o`3ooooo0?oooi40oooo
00<000000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0o`3ooooo0?oooi40oooo00<0
00000?ooo`3oool06@3oool004H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1k
0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`1j
0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0I
0?ooo`00AP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0I0?ooo`00AP3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0I0?ooo`00
AP3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0I0?ooo`00AP3ooooo00000?l00000U@00000K0?ooo`00o`3ooooo
0?ooooH0oooo003o0?ooool0oooomP3oool00?l0ooooo`3oooof0?ooo`00o`3ooooo0?ooooH0oooo
003o0?ooool0oooomP3oool00?l0ooooo`3oooof0?ooo`00o`3ooooo0?ooooH0oooo003o0?ooool0
oooomP3oool00?l0ooooo`3oooof0?ooo`00o`3ooolI0?ooo`D00000G@3oool400000=h0oooo1@00
002C0?ooo`00o`3ooolL0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0gP3oool0
0`000000oooo0?ooo`2B0?ooo`00o`3ooolM0?ooo`030000003oool0oooo0600oooo00<000000?oo
o`3oool0gP3oool00`000000oooo0?ooo`2A0?ooo`00o`3ooolM0?ooo`030000003oool0oooo0600
oooo00<000000?ooo`3oool0gP3oool00`000000oooo0?ooo`2A0?ooo`00^@3oool7000000D0oooo
0`0000030?ooo`<000001P3oool4000000L0oooo1@0000050?ooo`<000000`3oool3000000<0oooo
00<000000?ooo`0000000`0000050?ooo`T000001`3oool4000000P0oooo0P00000F0?ooo`800000
1`3oool00`000000oooo00000003000000P0oooo0`00000A0?ooo`@00000103oool400000080oooo
0`0000030?ooo`<000001@3oool3000000030?ooo`000000oooo00@0oooo2@0000050?ooo`D00000
1`3oool3000001<0oooo1`0000060?ooo`D0000000<0oooo0000000000001P3oool4000000H0oooo
1@0000000`3oool000000000000@0?ooo`D0000000<0oooo0000000000000`3oool3000000<0oooo
0`0000040?ooo`@000000P3oool200000100oooo1@0000060?ooo`<000000`3oool3000000D0oooo
1@0000070?ooo`D000001P3oool6000000P0oooo0P00002B0?ooo`00_03oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`800000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool2000000H0oooo0P00
000F0?ooo`8000001`3oool2000000@0oooo00<000000?ooo`3oool01@3oool300000180oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`3oool2000000T0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo0`00000D0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`800000
1P3oool00`000000oooo0?ooo`020?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`800000
403oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool3000001<0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00;`0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000001@0oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo0`00000C0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool3000001@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`090?ooo`040000003oool0oooo00000940oooo002l0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00T0oooo00@000000?ooo`3oool00000503oool010000000oooo0?ooo`00000=0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02@3oool010000000oooo0?ooo`00002A0?ooo`00_03oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`070?ooo`P000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0K0?ooo`P000001@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00D0oooo2000000M0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool6000000H0oooo00<000000?ooo`3oool02@3oool600000180oooo
1P0000050?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000070?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo200000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0SP3oool00;`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`D00000
2@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
103oool5000001l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000L0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2>0?ooo`00_03oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool3000001@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`030?ooo`800000203oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo08h0oooo002l0?ooo`030000003oool0oooo00L0oooo0P0000030?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo0P0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool2000000L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000001h0oooo00@000000?ooo`3oool0
00001`3oool2000000<0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool20000
00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00D0oooo0`00000D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo0`00000C0?ooo`030000003oool0oooo00L0oooo0P0000030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo000000030?ooo`050000003oool0oooo
0?ooo`0000001P3oool00`000000oooo0?ooo`2=0?ooo`00_03oool00`000000oooo0?ooo`060?oo
o`80000000@0oooo00000000000000001P3oool8000000H0oooo100000060?ooo`80000000@0oooo
00000000000000001`3oool5000000030?ooo`000000oooo00<0oooo100000080?ooo`P000000P3o
ool4000000@0oooo1000000<0?ooo`@00000103oool4000000<0oooo1@0000000`3oool000000?oo
o`0M0?ooo`040000003oool0oooo000000H0oooo0P000000103oool000000000000000080?ooo`<0
000000<0oooo000000000000203oool00`000000oooo0?ooo`070?ooo`@00000203oool3000001@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`D000001@3oool8000000H0
oooo1@00000C0?ooo`D000001@3oool2000000040?ooo`0000000000000000L0oooo100000020?oo
o`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`0000000P0000080?ooo`@00000203oool5000000H0oooo0P000002
0?ooo`<000000P3oool4000000@0oooo1000002=0?ooo`00_03oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0D@3oool010000000oooo0?ooo`00000R
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`330?ooo`00_03oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0DP3oool2
000002<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0<<0oooo002i
0?ooo`L000004`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0C`3oool5000002<0oooo00<000000?ooo`3oool0:@3oool7000001<0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`T000001@3oool00`000000oooo0?ooo`33
0?ooo`00o`3oool50?ooo`030000003oool0oooo07l0oooo100000250?ooo`800000703oool20000
0<D0oooo0000\
\>"],
  ImageRangeCache->{{{0, 755}, {466, 0}} -> {-3.41548, -0.118169, 0.0398459, \
0.00282237}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 967}},
WindowSize->{943, 758},
WindowMargins->{{Automatic, 38}, {Automatic, 36}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 86, 2, 150, "Title"],
Cell[1828, 55, 35, 0, 64, "Subtitle"],
Cell[1866, 57, 220, 4, 50, "Input"],

Cell[CellGroupData[{
Cell[2111, 65, 404, 8, 70, "Input"],
Cell[2518, 75, 1334, 26, 311, "Output"]
}, Open  ]],
Cell[3867, 104, 162, 2, 50, "Input"],

Cell[CellGroupData[{
Cell[4054, 110, 36, 0, 64, "Subtitle"],
Cell[4093, 112, 849, 16, 201, "Input"],

Cell[CellGroupData[{
Cell[4967, 132, 37, 0, 53, "Section"],

Cell[CellGroupData[{
Cell[5029, 136, 1371, 32, 110, "Input"],
Cell[6403, 170, 57557, 1282, 339, 14006, 740, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[63975, 1455, 26, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[64038, 1460, 36, 0, 53, "Section"],
Cell[64077, 1462, 131, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[64245, 1469, 49, 0, 53, "Section"],
Cell[64297, 1471, 240, 5, 50, "Input"],

Cell[CellGroupData[{
Cell[64562, 1480, 1306, 30, 110, "Input"],
Cell[65871, 1512, 84327, 1657, 476, 14986, 796, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

