(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    159791,       3929]*)
(*NotebookOutlinePosition[    160467,       3953]*)
(*  CellTagsIndexPosition[    160423,       3949]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Droplet Source Data Form", "Title"],

Cell[CellGroupData[{

Cell["Collect Raw Data", "Section"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"rawdata", "=", 
          RowBox[{"(", GridBox[{
                {"\"\<Angle (\[Degree])\>\"", "\"\<Signal (mV)\>\"", 
                  "\"\<\[PlusMinus]\>\"", 
                  "\"\<Pick-Off (V)\>\"", \(Gain\ \((mV\ nA)\)\)},
                {"\[Placeholder]", "\[Placeholder]", "\[Placeholder]", 
                  "\[Placeholder]", "\[Placeholder]"},
                {"\[Placeholder]", "\[Placeholder]", "\[Placeholder]", 
                  "\[Placeholder]", "\[Placeholder]"},
                {"\[Placeholder]", "\[Placeholder]", "\[Placeholder]", 
                  "\[Placeholder]", "\[Placeholder]"},
                {"\[Placeholder]", "\[Placeholder]", "\[Placeholder]", 
                  "\[Placeholder]", "\[Placeholder]"},
                {"\[Placeholder]", "\[Placeholder]", "\[Placeholder]", 
                  "\[Placeholder]", "\[Placeholder]"},
                {"\[Placeholder]", "\[Placeholder]", "\[Placeholder]", 
                  "\[Placeholder]", "\[Placeholder]"},
                {"\[Placeholder]", "\[Placeholder]", "\[Placeholder]", 
                  "\[Placeholder]", "\[Placeholder]"},
                {"\[Placeholder]", "\[Placeholder]", "\[Placeholder]", 
                  "\[Placeholder]", "\[Placeholder]"}
                }], ")"}]}], ";"}], 
      "       ", \( (*\ Ctrl - Enter\ for\ more\ rows; \ 
        rows\ of\ boxes\ will\ be\ discarded\ *) \)}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"blankdata", "=", 
        RowBox[{"(", GridBox[{
              {"\"\<Angle (\[Degree])\>\"", "\"\<Signal (mV)\>\"", 
                "\"\<\[PlusMinus]\>\"", 
                "\"\<Pick-Off (V)\>\"", \(Gain\ \((mV\ nA)\)\)},
              {"\[Placeholder]", "\[Placeholder]", "\[Placeholder]", 
                "\[Placeholder]", "\[Placeholder]"},
              {"\[Placeholder]", "\[Placeholder]", "\[Placeholder]", 
                "\[Placeholder]", "\[Placeholder]"},
              {"\[Placeholder]", "\[Placeholder]", "\[Placeholder]", 
                "\[Placeholder]", "\[Placeholder]"},
              {"\[Placeholder]", "\[Placeholder]", "\[Placeholder]", 
                "\[Placeholder]", "\[Placeholder]"},
              {"\[Placeholder]", "\[Placeholder]", "\[Placeholder]", 
                "\[Placeholder]", "\[Placeholder]"},
              {"\[Placeholder]", "\[Placeholder]", "\[Placeholder]", 
                "\[Placeholder]", "\[Placeholder]"},
              {"\[Placeholder]", "\[Placeholder]", "\[Placeholder]", 
                "\[Placeholder]", "\[Placeholder]"},
              {"\[Placeholder]", "\[Placeholder]", "\[Placeholder]", 
                "\[Placeholder]", "\[Placeholder]"},
              {"\[Placeholder]", "\[Placeholder]", "\[Placeholder]", 
                "\[Placeholder]", "\[Placeholder]"}
              }], ")"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Process Raw Data", "Section"],

Cell[BoxData[
    \( (*\ Note\ that, \ since\ we\ are\ dividing\ signal\ by\ pick - off, \ 
      there\ is\ no\ need\ to\ worry\ about\ the\ difference\ in\ units\ \((V\
\ vs\ mV)\)\ *) \)], "Input"],

Cell[BoxData[
    \(\(\(<<\)\(Graphics`MultipleListPlot`\)\(\ \)\( (*\ 
        Load\ this\ first\ so\ ErrorBar\ doesn' 
          t\ get\ shadowed\ *) \)\)\)], "Input"],

Cell[BoxData[{
    \(\(rawdata = Select[rawdata, NumberQ[#1[\([1]\)]] &];\)\  (*\ 
      Get\ rid\ of\ non - numerical\ colunms\ *) \), "\[IndentingNewLine]", 
    \(newdata = \({#1[\([1]\)], N[\(#1[\([2]\)]*#1[\([5]\)]\)\/#1[\([4]\)]], 
            N[\(#1[\([3]\)]*#1[\([5]\)]\)\/#1[\([4]\)]]} &\) /@ 
        rawdata; \  (*\ 
      Divide\ through\ by\ pick\ off\ and\ multiply\ by\ gain\ \
*) \[IndentingNewLine]blankdata = 
      Select[blankdata, NumberQ[#1[\([1]\)]] &];\), "\[IndentingNewLine]", 
    \(\(newblank = \({#1[\([1]\)], 
              N[\(#1[\([2]\)]*#1[\([5]\)]\)\/#1[\([4]\)]], 
              N[\(#1[\([3]\)]*#1[\([5]\)]\)\/#1[\([4]\)]]} &\) /@ 
          blankdata;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(finaldata = 
        Table[{If[newdata[\([i, 1]\)] \[Equal] newblank[\([i, 1]\)], 
              newdata[\([i, 1]\)], "\<Error\>"], 
            newdata[\([i, 2]\)] - 
              newblank[\([i, 
                  2]\)], \@\(newdata[\([i, 3]\)]\^2 + newblank[\([i, 3]\)]\^2\
\)}, {i, 1, 
            Min[Length[newdata], 
              Length[newblank]]}];\)\), "\[IndentingNewLine]", 
    \(\(finaldataerror = 
        Table[{{If[newdata[\([i, 1]\)] \[Equal] newblank[\([i, 1]\)], 
                newdata[\([i, 1]\)], "\<Error\>"], 
              newdata[\([i, 2]\)] - newblank[\([i, 2]\)]}, 
            ErrorBar[\@\(newdata[\([i, 3]\)]\^2 + newblank[\([i, \
3]\)]\^2\)]}, {i, 1, Min[Length[newdata], Length[newblank]]}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot Adjusted Data", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"MultipleListPlot", "[", 
          RowBox[{"finaldataerror", ",", 
            StyleBox[\(SymbolShape \[Rule] PlotSymbol[Box]\),
              FontColor->GrayLevel[0.666667]], 
            StyleBox[",",
              FontColor->GrayLevel[0.666667]], 
            StyleBox[\(Frame \[Rule] True\),
              FontColor->GrayLevel[0.666667]], 
            StyleBox[",",
              FontColor->GrayLevel[0.666667]], 
            
            StyleBox[\(FrameLabel \[Rule] {StyleForm[
                    TraditionalForm["\<Angle (\[Degree])\>"], 
                    FontSize \[Rule] 14], 
                  StyleForm[
                    TraditionalForm["\<Intensity (arbitrary units)\>"], 
                    FontSize \[Rule] 14]}\),
              FontColor->GrayLevel[0.666667]], 
            StyleBox[",",
              FontColor->GrayLevel[0.666667]], 
            
            StyleBox[\(PlotLabel \[Rule] 
                StyleForm[TraditionalForm["\<Intensity vs. Angle\>"], 
                  FontSize \[Rule] 20]\),
              FontColor->GrayLevel[0.666667]]}], "]"}], ";"}], 
      " ", \( (*\ Mostly\ just\ plotting\ options\ *) \), 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214286 0.238095 0.0147151 0.0222073 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -39.6875 -23.9375 ]
[.5 -0.0125 39.6875 -9 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .12575 -6 -4.5 ]
[-0.0125 .12575 0 4.5 ]
[-0.0125 .23679 -12 -4.5 ]
[-0.0125 .23679 0 4.5 ]
[-0.0125 .34782 -12 -4.5 ]
[-0.0125 .34782 0 4.5 ]
[-0.0125 .45886 -12 -4.5 ]
[-0.0125 .45886 0 4.5 ]
[-0.0125 .5699 -12 -4.5 ]
[-0.0125 .5699 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -25.625 -115.063 ]
[-0.01875 .30902 -12 115.063 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -116 0 ]
[.5 .63053 116 18.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(1)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(2)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(3)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(4)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(5)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -100.688 -27.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22.9375 translate 1 -1 scale
63.000 15.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Angle) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
113.250 15.188 moveto
(H) show
121.625 15.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\260) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
130.000 15.188 moveto
(L) show
138.375 15.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .12575 m
.00625 .12575 L
s
[(5)] -0.0125 .12575 1 0 Mshowa
0 .23679 m
.00625 .23679 L
s
[(10)] -0.0125 .23679 1 0 Mshowa
0 .34782 m
.00625 .34782 L
s
[(15)] -0.0125 .34782 1 0 Mshowa
0 .45886 m
.00625 .45886 L
s
[(20)] -0.0125 .45886 1 0 Mshowa
0 .5699 m
.00625 .5699 L
s
[(25)] -0.0125 .5699 1 0 Mshowa
.125 Mabswid
0 .03692 m
.00375 .03692 L
s
0 .05913 m
.00375 .05913 L
s
0 .08134 m
.00375 .08134 L
s
0 .10354 m
.00375 .10354 L
s
0 .14796 m
.00375 .14796 L
s
0 .17017 m
.00375 .17017 L
s
0 .19237 m
.00375 .19237 L
s
0 .21458 m
.00375 .21458 L
s
0 .259 m
.00375 .259 L
s
0 .2812 m
.00375 .2812 L
s
0 .30341 m
.00375 .30341 L
s
0 .32562 m
.00375 .32562 L
s
0 .37003 m
.00375 .37003 L
s
0 .39224 m
.00375 .39224 L
s
0 .41445 m
.00375 .41445 L
s
0 .43665 m
.00375 .43665 L
s
0 .48107 m
.00375 .48107 L
s
0 .50328 m
.00375 .50328 L
s
0 .52548 m
.00375 .52548 L
s
0 .54769 m
.00375 .54769 L
s
0 .5921 m
.00375 .5921 L
s
0 .61431 m
.00375 .61431 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -194.875 -10.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
176.063 10.8125 translate
90 rotate
-176.063 -10.8125 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.625 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Intensity) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
146.750 13.875 moveto
(H) show
155.125 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(arbitrary) show
238.875 13.875 moveto
(units) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
280.750 13.875 moveto
(L) show
289.125 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .12575 m
1 .12575 L
s
.99375 .23679 m
1 .23679 L
s
.99375 .34782 m
1 .34782 L
s
.99375 .45886 m
1 .45886 L
s
.99375 .5699 m
1 .5699 L
s
.125 Mabswid
.99625 .03692 m
1 .03692 L
s
.99625 .05913 m
1 .05913 L
s
.99625 .08134 m
1 .08134 L
s
.99625 .10354 m
1 .10354 L
s
.99625 .14796 m
1 .14796 L
s
.99625 .17017 m
1 .17017 L
s
.99625 .19237 m
1 .19237 L
s
.99625 .21458 m
1 .21458 L
s
.99625 .259 m
1 .259 L
s
.99625 .2812 m
1 .2812 L
s
.99625 .30341 m
1 .30341 L
s
.99625 .32562 m
1 .32562 L
s
.99625 .37003 m
1 .37003 L
s
.99625 .39224 m
1 .39224 L
s
.99625 .41445 m
1 .41445 L
s
.99625 .43665 m
1 .43665 L
s
.99625 .48107 m
1 .48107 L
s
.99625 .50328 m
1 .50328 L
s
.99625 .52548 m
1 .52548 L
s
.99625 .54769 m
1 .54769 L
s
.99625 .5921 m
1 .5921 L
s
.99625 .61431 m
1 .61431 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -177 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26.4375 translate 1 -1 scale
63.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Intensity) show
183.000 17.750 moveto
(vs) show
207.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
231.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Angle) show
291.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.02381 .60332 m
.02381 .59901 L
s
.02381 .60332 1.5 0 Mabsadd m
.02381 .60332 -1.5 0 Mabsadd L s
.02381 .59901 1.5 0 Mabsadd m
.02381 .59901 -1.5 0 Mabsadd L s
.2619 .03617 m
.2619 .03176 L
s
.2619 .03617 1.5 0 Mabsadd m
.2619 .03617 -1.5 0 Mabsadd L s
.2619 .03176 1.5 0 Mabsadd m
.2619 .03176 -1.5 0 Mabsadd L s
.5 .0238 m
.5 .02158 L
s
.5 .0238 1.5 0 Mabsadd m
.5 .0238 -1.5 0 Mabsadd L s
.5 .02158 1.5 0 Mabsadd m
.5 .02158 -1.5 0 Mabsadd L s
.7381 .02598 m
.7381 .02353 L
s
.7381 .02598 1.5 0 Mabsadd m
.7381 .02598 -1.5 0 Mabsadd L s
.7381 .02353 1.5 0 Mabsadd m
.7381 .02353 -1.5 0 Mabsadd L s
.97619 .01899 m
.97619 .01764 L
s
.97619 .01899 1.5 0 Mabsadd m
.97619 .01899 -1.5 0 Mabsadd L s
.97619 .01764 1.5 0 Mabsadd m
.97619 .01764 -1.5 0 Mabsadd L s
.0001 w
.02381 .60116 -2.5 2.5 Mabsadd m
.02381 .60116 2.5 2.5 Mabsadd L
.02381 .60116 2.5 -2.5 Mabsadd L
.02381 .60116 -2.5 -2.5 Mabsadd L
.02381 .60116 -2.5 2.5 Mabsadd L closepath F
.2619 .03396 -2.5 2.5 Mabsadd m
.2619 .03396 2.5 2.5 Mabsadd L
.2619 .03396 2.5 -2.5 Mabsadd L
.2619 .03396 -2.5 -2.5 Mabsadd L
.2619 .03396 -2.5 2.5 Mabsadd L closepath F
.5 .02269 -2.5 2.5 Mabsadd m
.5 .02269 2.5 2.5 Mabsadd L
.5 .02269 2.5 -2.5 Mabsadd L
.5 .02269 -2.5 -2.5 Mabsadd L
.5 .02269 -2.5 2.5 Mabsadd L closepath F
.7381 .02476 -2.5 2.5 Mabsadd m
.7381 .02476 2.5 2.5 Mabsadd L
.7381 .02476 2.5 -2.5 Mabsadd L
.7381 .02476 -2.5 -2.5 Mabsadd L
.7381 .02476 -2.5 2.5 Mabsadd L closepath F
.97619 .01832 -2.5 2.5 Mabsadd m
.97619 .01832 2.5 2.5 Mabsadd L
.97619 .01832 2.5 -2.5 Mabsadd L
.97619 .01832 -2.5 -2.5 Mabsadd L
.97619 .01832 -2.5 2.5 Mabsadd L closepath F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{525.25, 324.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008=0001A1P00`40o`000?l0003oooooooooool?
oooo003oooooooooo`ooool00?ooool4oooo100002;oool00`000?ooooooo`09oooo00<0003ooooo
ool0eOooo`00ooooo`Soool00`000?ooooooo`0Noooo00<0003oooooool02oooo`030000oooooooo
0=Coool00?ooool8oooo00<0003oooooool07_ooo`030000oooooooo00_oool00`000?ooooooo`3D
oooo003aoooo0`0000;oool3000000Goool000000000003oool00`0000;oool3000000Coool0003o
ooooool700000_ooo`D0000?oooo00<0003oooooool03Oooo`030000oooooooo0=?oool00?;oool0
0`000?ooooooo`02oooo00D0003oooooooooool000000oooo`040000oooooooo00000oooo`800005
oooo00<0003oooooool00_ooo`030000oooooooo01;oool00`000?ooooooo`0=oooo00<0003ooooo
ool0doooo`00loooo`@00004oooo00D0003oooooooooool000000_ooo`030000oooooooo00;oool0
0`000?ooooooo`03oooo00<0003oooooool00_ooo`030000oooooooo01;oool00`000?ooooooo`0=
oooo00<0003oooooool0doooo`00loooo`040000oooooooo00001?ooo`050000oooooooooooo0000
00;oool00`000?ooooooo`02oooo00<0003oooooool00oooo`030000oooooooo00;oool600003ooo
o`030000oooooooo00goool00`000?ooooooo`3Coooo003coooo00@0003oooooool00004oooo0P00
00;oool010000?ooooooo`0000?oool200001Oooo`030000oooooooo00;oool00`000?ooooooo`02
oooo00<0003oooooool03Oooo`030000oooooooo00goool00`000?ooooooo`3Coooo003doooo0P00
00Coool2000000?oool0000000001?ooo`<000000oooo`0000000004oooo00<0003oooooool00ooo
o`@0000@oooo00<0003oooooool03Oooo`030000oooooooo0=?oool00?Coool200005oooo`030000
oooooooo01Soool00`000?ooooooo`03oooo0P0000Koool00`000?ooooooo`3Doooo003coooo0`00
01Ooool00`000?ooooooo`0Hoooo00<0003oooooool00_ooo`040000oooooooo00001Oooo`030000
oooooooo0=Coool00?ooool=oooo0P0001_oool01@000?ooooooooooo`000002oooo00<0003ooooo
ool00_ooo`030000oooooooo0=Goool00?ooool_oooo0P000=goool00?oooooooooo3oooo`00A?oo
o`D0001Soooo100006Goool20000J?ooo`<0001Toooo0P0002Goool004Koool00`000?ooooooo`1S
oooo00<0003oooooool0IOooo`040000oooooooo0000J?ooo`030000oooooooo06;oool010000?oo
ooooo`0002Coool004Koool00`000?ooooooo`1Toooo00<0003oooooool0I_ooo`030000oooooooo
06Coool50000I_ooo`030000oooooooo02;oool004Koool00`000?ooooooo`1Uoooo00<0003ooooo
ool0I_ooo`030000oooooooo06?oool010000?ooooooo`0006Goool200009Oooo`00A_ooo`030000
oooooooo06?oool010000?ooooooo`0006Coool010000?ooooooo`0006Koool00`000?ooo`00001U
oooo00<0003oooooool09?ooo`00AOooo`80001Voooo0P0006Koool20000J?ooo`80001Uoooo0`00
02Coool00?oooooooooo3oooo`00ooooooooool?oooo003oooooooooo`ooool00?oooooooooo3ooo
o`00ooooooooool?oooo003oooooooooo`ooool00?oooooooooo3oooo`00??ooool0002g00006ooo
o`00??ooo`030000oooooooo00Ooool00`000?ooooooo`0Boooo00<0003oooooool04_ooo`030000
oooooooo01;oool00`000?ooooooo`0Boooo00<0003oooooool04Oooo`030000oooooooo01;oool0
0`000?ooooooo`0Boooo00<0003oooooool04_ooo`030000oooooooo01;oool00`000?ooooooo`0A
oooo00<0003oooooool04_ooo`030000oooooooo01;oool00`000?ooooooo`0Boooo00<0003ooooo
ool04_ooo`030000oooooooo01;oool00`000?ooooooo`0Aoooo00<0003oooooool04_ooo`030000
oooooooo01;oool00`000?ooooooo`0Boooo00<0003oooooool04_ooo`030000oooooooo00Ooool0
0`000?ooooooo`0Ioooo000loooo00<0003oooooool01oooo`030000oooooooo01;oool00`000?oo
ooooo`0Boooo00<0003oooooool04_ooo`030000oooooooo01;oool00`000?ooooooo`0Aoooo00<0
003oooooool04_ooo`030000oooooooo01;oool00`000?ooooooo`0Boooo00<0003oooooool04_oo
o`030000oooooooo017oool00`000?ooooooo`0Boooo00<0003oooooool04_ooo`030000oooooooo
01;oool00`000?ooooooo`0Boooo00<0003oooooool04_ooo`030000oooooooo017oool00`000?oo
ooooo`0Boooo00<0003oooooool04_ooo`030000oooooooo01;oool00`000?ooooooo`0Boooo00<0
003oooooool01oooo`030000oooooooo01Woool003coool00`000?ooooooo`07oooo00<0003ooooo
ool0IOooo`030000oooooooo06Goool00`000?ooooooo`1Voooo00<0003oooooool0IOooo`030000
oooooooo00Ooool00`000?ooooooo`0Ioooo000loooo00<0003oooooool0oooook?oool00`000?oo
ooooo`0Ioooo000boooo0P0000Soool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool0
037oool010000?ooooooo`0000Ooool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool0
037oool010000?ooooooo`0000Ooool40000ooooojGoool500001Oooo`@0000Koooo000aoooo00@0
003oooooool00007oooo00<0003oooooool0ooooojKoool500002?ooo`030000oooooooo01Woool0
037oool010000?ooooooo`0000Ooool00`000?ooooooo`3Eoooo1@000<_oool500002?ooo`030000
oooooooo01Woool003;oool200002?ooo`030000oooooooo0=Goool50000Hoooo`D0001Soooo1@00
00Soool00`000?ooooooo`0Ioooo000loooo00<0003oooooool0eOooo`D0001Soooo1@0006?oool5
00002?ooo`030000oooooooo01Woool003coool00`000?ooooooo`3Eoooo1@0006?oool50000L?oo
o`030000oooooooo01Woool003coool00`000?ooooooo`3Eoooo1@0006?oool50000L?ooo`030000
oooooooo01Woool003coool00`000?ooooooo`1]oooo1@000<_oool50000L?ooo`030000oooooooo
01Woool003coool00`000?ooooooo`1]oooo1@000?oooom1oooo00<0003oooooool06Oooo`00??oo
o`80001^oooo1@000?oooom0oooo0P0001_oool003coool00`000?ooooooo`1]oooo1@000?oooom1
oooo00<0003oooooool06Oooo`00??ooo`030000oooooooo06goool50000oooood7oool00`000?oo
ooooo`0Ioooo000loooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000loooo00<0
003oooooool0oooook?oool00`000?ooooooo`0Ioooo000loooo00<0003oooooool0oooook?oool0
0`000?ooooooo`0Ioooo000loooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000l
oooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000loooo00<0003oooooool0oooo
ok?oool00`000?ooooooo`0Ioooo000Loooo00<0003oooooool01?ooo`030000oooooooo01Koool0
0`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool001coool00`000?ooooooo`04oooo00<0
003oooooool05_ooo`80003ooooo/oooo`80000Koooo000Loooo200001Soool00`000?ooooooo`3o
oooo/oooo`030000oooooooo01Woool001coool00`000?ooooooo`04oooo00<0003oooooool05_oo
o`030000oooooooo0?ooooncoooo00<0003oooooool06Oooo`007?ooo`030000oooooooo00Coool0
0`000?ooooooo`0Foooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000loooo00<0
003oooooool0oooook?oool00`000?ooooooo`0Ioooo000loooo00<0003oooooool0oooook?oool0
0`000?ooooooo`0Ioooo000Noooo00<0003oooooool00_ooo`030000oooooooo01Koool00`000?oo
ooooo`3ooooo/oooo`030000oooooooo01Woool001koool600006?ooo`030000oooooooo0?oooonc
oooo00<0003oooooool06Oooo`007_ooo`030000oooooooo00;oool00`000?ooooooo`0Foooo00<0
003oooooool0oooook?oool00`000?ooooooo`0Ioooo000Noooo00<0003oooooool06oooo`030000
oooooooo0?ooooncoooo00<0003oooooool06Oooo`007_ooo`030000oooooooo00;oool00`000?oo
ooooo`0Foooo0P000?ooooncoooo0P0001_oool001ooool500006?ooo`030000oooooooo0?oooonc
oooo00<0003oooooool06Oooo`008oooo`030000oooooooo01Koool00`000?ooooooo`3ooooo/ooo
o`030000oooooooo01Woool003coool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool0
01koool00`000?ooooooo`0Koooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000L
oooo1`0001Woool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool001koool00`000?oo
ooooo`02oooo00<0003oooooool05_ooo`030000oooooooo0?ooooncoooo00<0003oooooool06Ooo
o`007_ooo`030000oooooooo00;oool00`000?ooooooo`0Foooo00<0003oooooool0oooook?oool0
0`000?ooooooo`0Ioooo000Noooo00<0003oooooool00_ooo`030000oooooooo01Koool00`000?oo
ooooo`3ooooo/oooo`030000oooooooo01Woool001koool01@000?ooooooooooo`00000Ioooo00<0
003oooooool0oooook?oool00`000?ooooooo`0Ioooo000loooo0P000?ooooncoooo0P0001_oool0
03coool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool001ooool400006Oooo`030000
oooooooo0?ooooncoooo00<0003oooooool06Oooo`007_ooo`030000oooo000000;oool00`000?oo
ooooo`0Foooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000Noooo00<0003oool0
00000_ooo`030000oooooooo01Koool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool0
01koool00`000?ooo`000002oooo00<0003oooooool05_ooo`030000oooooooo0?ooooncoooo00<0
003oooooool06Oooo`007_ooo`030000oooo000000;oool00`000?ooooooo`0Foooo00<0003ooooo
ool0oooook?oool00`000?ooooooo`0Ioooo000Ooooo0P0000;oool00`000?ooooooo`0<oooo0P00
00Soool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool0037oool010000?ooooooo`00
00Ooool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool003Coool00`000?ooooooo`05
oooo10000?oooon_oooo100001_oool001koool00`000?ooooooo`02oooo00<0003oooooool03?oo
o`800008oooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000Noooo1P0000koool0
0`000?ooooooo`07oooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000Noooo00<0
003oooooool00_ooo`030000oooooooo00coool300001oooo`030000oooooooo0?ooooncoooo00<0
003oooooool06Oooo`007_ooo`030000oooooooo01_oool00`000?ooooooo`3ooooo/oooo`030000
oooooooo01Woool001koool00`000?ooooooo`02oooo00<0003oooooool05_ooo`030000oooooooo
0?ooooncoooo00<0003oooooool06Oooo`007oooo`D0000Hoooo00<0003oooooool0oooook?oool0
0`000?ooooooo`0Ioooo000Soooo00<0003oooooool05_ooo`030000oooooooo0?ooooncoooo00<0
003oooooool06Oooo`00??ooo`030000oooooooo0?ooooncoooo00<0003oooooool06Oooo`007ooo
o`030000oooooooo0080000Hoooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000N
oooo00D0003oool0003oool000006Oooo`80003ooooo/oooo`80000Koooo000Noooo00<0003oool0
00000_ooo`030000oooooooo01Koool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool0
01koool00`000?ooo`000002oooo00<0003oooooool05_ooo`030000oooooooo0?ooooncoooo00<0
003oooooool06Oooo`007_ooo`030000oooo000000;oool00`000?ooooooo`0Foooo00<0003ooooo
ool0oooook?oool00`000?ooooooo`0Ioooo000Noooo0P000003oooo0000000001Woool00`000?oo
ooooo`3ooooo/oooo`030000oooooooo01Woool003coool00`000?ooooooo`3ooooo/oooo`030000
oooooooo01Woool003coool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool002?oool0
0`000?ooooooo`0Foooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000Noooo00<0
003oooooool00_ooo`030000oooooooo01Koool00`000?ooooooo`3ooooo/oooo`030000oooooooo
01Woool001koool00`000?ooooooo`02oooo00<0003oooooool05_ooo`030000oooooooo0?oooonc
oooo00<0003oooooool06Oooo`007?ooo`030000oooo000000D0000Hoooo0P000?ooooncoooo0P00
01_oool002?oool00`000?ooooooo`0Foooo00<0003oooooool0oooook?oool00`000?ooooooo`0I
oooo000Soooo00<0003oooooool05_ooo`030000oooooooo0?ooooncoooo00<0003oooooool06Ooo
o`008oooo`030000oooooooo01Koool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool0
03coool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool001koool00`000?ooooooo`0K
oooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000Loooo1`0001Woool00`000?oo
ooooo`3ooooo/oooo`030000oooooooo01Woool001koool00`000?ooooooo`02oooo00<0003ooooo
ool05_ooo`030000oooooooo0?ooooncoooo00<0003oooooool06Oooo`007_ooo`030000oooooooo
00;oool00`000?ooooooo`0Foooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000N
oooo00<0003oooooool00_ooo`030000oooooooo01Koool20000oooook?oool200006oooo`007_oo
o`050000oooooooooooo000001Woool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool0
03coool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool003coool00`000?ooooooo`3o
oooo/oooo`030000oooooooo01Woool001koool00`000?ooooooo`0Koooo00<0003oooooool0oooo
ok?oool00`000?ooooooo`0Ioooo000Noooo0`0000Goool00`000?ooooooo`0Coooo00<0003ooooo
ool0oooook?oool00`000?ooooooo`0Ioooo000Noooo00<0003oooooool00P0000;oool200005Ooo
o`030000oooooooo0?ooooncoooo00<0003oooooool06Oooo`008oooo`8000000oooo`000?ooo`0D
oooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000Noooo00<0003oooooool00P00
01Woool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool001koool300006oooo`030000
oooooooo0?ooooncoooo00<0003oooooool06Oooo`007_ooo`030000oooooooo01_oool20000oooo
ok?oool200006oooo`00??ooo`030000oooooooo0?ooooncoooo00<0003oooooool06Oooo`00??oo
o`030000oooooooo0?ooooncoooo00<0003oooooool06Oooo`00??ooo`030000oooooooo0?oooonc
oooo00<0003oooooool06Oooo`00??ooo`030000oooooooo0?ooooncoooo00<0003oooooool06Ooo
o`00??ooo`030000oooooooo0?ooooncoooo00<0003oooooool06Oooo`00??ooo`030000oooooooo
0?ooooncoooo00<0003oooooool06Oooo`00??ooo`030000oooooooo0?ooooncoooo00<0003ooooo
ool06Oooo`00:oooo`D00002oooo0P0000Soool00`000?ooooooo`3ooooo/oooo`030000oooooooo
01Woool002goool01@000?ooooooooooo`000002oooo00<0003oooooool01Oooo`030000oooooooo
0?ooooncoooo00<0003oooooool06Oooo`00;Oooo`050000oooooooooooo000000;oool00`000?oo
ooooo`05oooo10000?oooon_oooo100001_oool002goool01@000?ooooooooooo`000002oooo00<0
003oooooool01Oooo`030000oooooooo0?ooooncoooo00<0003oooooool06Oooo`00;Oooo`050000
oooooooooooo000000;oool00`000?ooooooo`05oooo00<0003oooooool0oooook?oool00`000?oo
ooooo`0Ioooo000/oooo0P0000Coool200002?ooo`030000oooooooo0?ooooncoooo00<0003ooooo
ool06Oooo`00??ooo`030000oooooooo0?ooooncoooo00<0003oooooool06Oooo`00??ooo`030000
oooooooo0?ooooncoooo00<0003oooooool06Oooo`00??ooo`030000oooooooo0?ooooncoooo00<0
003oooooool06Oooo`007_ooo`H0000Hoooo00<0003oooooool0oooook?oool00`000?ooooooo`0I
oooo000Loooo0P0000Koool200005_ooo`030000oooooooo0?ooooncoooo00<0003oooooool06Ooo
o`006oooo`030000oooooooo00Soool00`000?ooooooo`0Coooo00<0003oooooool0oooook?oool0
0`000?ooooooo`0Ioooo000loooo0P000?ooooncoooo0P0001_oool003coool00`000?ooooooo`3o
oooo/oooo`030000oooooooo01Woool003coool00`000?ooooooo`3ooooo/oooo`030000oooooooo
01Woool001ooool010000?ooo`00000001Woool00`000?ooooooo`3ooooo/oooo`030000oooooooo
01Woool001koool00`000?ooo`000002oooo00<0003oooooool05_ooo`030000oooooooo0?oooonc
oooo00<0003oooooool06Oooo`007_ooo`030000oooo000000;oool00`000?ooooooo`0Foooo00<0
003oooooool0oooook?oool00`000?ooooooo`0Ioooo000Noooo00<0003oool000000_ooo`030000
oooooooo01Koool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool001koool01@000?oo
o`000?ooo`00000Ioooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000Ooooo1@00
01Soool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool002?oool00`000?ooooooo`0F
oooo0P000?ooooncoooo0P0001_oool003coool00`000?ooooooo`3ooooo/oooo`030000oooooooo
01Woool001koool00`000?ooooooo`02oooo00<0003oooooool05_ooo`030000oooooooo0?oooonc
oooo00<0003oooooool06Oooo`007_ooo`H0000Hoooo00<0003oooooool0oooook?oool00`000?oo
ooooo`0Ioooo000Ooooo00D0003oooooooooool000006?ooo`030000oooooooo0?ooooncoooo00<0
003oooooool06Oooo`007_ooo`030000oooooooo00;oool00`000?ooooooo`0Foooo00<0003ooooo
ool0oooook?oool00`000?ooooooo`0Ioooo000Noooo00<0003oooooool00_ooo`030000oooooooo
01Koool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool001koool00`000?ooooooo`0K
oooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000loooo00<0003oooooool0oooo
ok?oool00`000?ooooooo`0Ioooo000Koooo00<0003oooooool01Oooo`030000oooooooo01Koool0
0`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool001_oool900006?ooo`80003ooooo/ooo
o`80000Koooo000Ooooo00@0003oooooool0000Ioooo00<0003oooooool0oooook?oool00`000?oo
ooooo`0Ioooo000Noooo00<0003oooooool00_ooo`030000oooooooo01Koool00`000?ooooooo`3o
oooo/oooo`030000oooooooo01Woool001koool00`000?ooooooo`02oooo00<0003oooooool05_oo
o`030000oooooooo0?ooooncoooo00<0003oooooool06Oooo`007_ooo`030000oooooooo00;oool0
0`000?ooooooo`0Foooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000Ooooo1000
01Woool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool003coool00`000?ooooooo`3o
oooo/oooo`030000oooooooo01Woool003coool00`000?ooooooo`3ooooo/oooo`030000oooooooo
01Woool002?oool00`000?ooooooo`0Foooo00<0003oooooool0oooook?oool00`000?ooooooo`0I
oooo000Noooo00<0003oooooool00_ooo`030000oooooooo01Koool00`000?ooooooo`3ooooo/ooo
o`030000oooooooo01Woool001koool00`000?ooooooo`02oooo00<0003oooooool05_ooo`80003o
oooo/oooo`80000Koooo000Loooo00<0003oool000001@0001Soool00`000?ooooooo`3ooooo/ooo
o`030000oooooooo01Woool002?oool00`000?ooooooo`0Foooo00<0003oooooool0oooook?oool0
0`000?ooooooo`0Ioooo000Soooo00<0003oooooool05_ooo`030000oooooooo0?ooooncoooo00<0
003oooooool06Oooo`008oooo`030000oooooooo01Koool00`000?ooooooo`3ooooo/oooo`030000
oooooooo01Woool003coool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool001koool0
0`000?ooooooo`0Koooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000Loooo1`00
00Soool500000_ooo`800008oooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000N
oooo00<0003oooooool00_ooo`030000oooooooo00Ooool01@000?ooooooooooo`000002oooo00<0
003oooooool01Oooo`030000oooooooo0?ooooncoooo00<0003oooooool06Oooo`007_ooo`030000
oooooooo00;oool00`000?ooooooo`07oooo00<0003oooooool01?ooo`030000oooooooo00Goool4
0000ooooojooool400006oooo`007_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0
003oooooool00_ooo`800008oooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000N
oooo00D0003oooooooooool000002_ooo`030000oooooooo00;oool00`000?ooooooo`07oooo00<0
003oooooool0oooook?oool00`000?ooooooo`0Ioooo000/oooo0P0000Coool300001oooo`030000
oooooooo0?ooooncoooo00<0003oooooool06Oooo`00??ooo`030000oooooooo0?ooooncoooo00<0
003oooooool06Oooo`007_ooo`030000oooooooo00;oool00`000?ooooooo`0Foooo00<0003ooooo
ool0oooook?oool00`000?ooooooo`0Ioooo000Noooo1P0001Soool00`000?ooooooo`3ooooo/ooo
o`030000oooooooo01Woool001ooool01@000?ooooooooooo`00000Hoooo00<0003oooooool0oooo
ok?oool00`000?ooooooo`0Ioooo000Noooo00<0003oooooool00_ooo`030000oooooooo01Koool0
0`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool001koool00`000?ooooooo`02oooo00<0
003oooooool05_ooo`030000oooooooo0?ooooncoooo00<0003oooooool06Oooo`007_ooo`030000
oooooooo01_oool20000oooook?oool200006oooo`00??ooo`030000oooooooo0?ooooncoooo00<0
003oooooool06Oooo`00??ooo`030000oooooooo0?ooooncoooo00<0003oooooool06Oooo`007ooo
o`040000oooo000000006Oooo`030000oooooooo0?ooooncoooo00<0003oooooool06Oooo`007_oo
o`030000oooo000000;oool00`000?ooooooo`0Foooo00<0003oooooool0oooook?oool00`000?oo
ooooo`0Ioooo000Noooo00<0003oool000000_ooo`030000oooooooo01Koool00`000?ooooooo`3o
oooo/oooo`030000oooooooo01Woool001koool00`000?ooo`000002oooo00<0003oooooool05_oo
o`030000oooooooo0?ooooncoooo00<0003oooooool06Oooo`007_ooo`050000oooo0000oooo0000
01Woool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool001ooool500006?ooo`030000
oooooooo0?ooooncoooo00<0003oooooool06Oooo`008oooo`030000oooooooo01Koool00`000?oo
ooooo`3ooooo/oooo`030000oooooooo01Woool003coool20000oooook?oool200006oooo`007_oo
o`030000oooooooo00;oool00`000?ooooooo`0Foooo00<0003oooooool0oooook?oool00`000?oo
ooooo`0Ioooo000Noooo1P0001Soool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool0
01ooool01@000?ooooooooooo`00000Hoooo00<0003oooooool0oooook?oool00`000?ooooooo`0I
oooo000Noooo00<0003oooooool00_ooo`030000oooooooo01Koool00`000?ooooooo`3ooooo/ooo
o`030000oooooooo01Woool001koool00`000?ooooooo`02oooo00<0003oooooool05_ooo`030000
oooooooo0?ooooncoooo00<0003oooooool06Oooo`007_ooo`030000oooooooo01_oool00`000?oo
ooooo`3ooooo/oooo`030000oooooooo01Woool003coool00`000?ooooooo`3ooooo/oooo`030000
oooooooo01Woool003coool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool001koool0
0`000?ooooooo`0Koooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000Noooo0`00
00Goool00`000?ooooooo`0Coooo0P000?ooooncoooo0P0001_oool001koool00`000?ooooooo`02
00000_ooo`80000Eoooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000Soooo0P00
0003oooo0000oooo01Coool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool001koool0
0`000?ooooooo`0200006Oooo`030000oooooooo0?ooooncoooo00<0003oooooool06Oooo`007_oo
o`<0000Koooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000Noooo00<0003ooooo
ool06oooo`030000oooooooo0?ooooncoooo00<0003oooooool06Oooo`00??ooo`030000oooooooo
0?ooooncoooo00<0003oooooool06Oooo`00??ooo`030000oooooooo0?ooooncoooo00<0003ooooo
ool06Oooo`00??ooo`030000oooooooo0?ooooncoooo00<0003oooooool06Oooo`00??ooo`80003o
oooo/oooo`80000Koooo000loooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000l
oooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000loooo00<0003oooooool0oooo
ok?oool00`000?ooooooo`0Ioooo000loooo00<0003oooooool0oooook?oool00`000?ooooooo`0I
oooo000loooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000loooo00<0003ooooo
ool0oooook?oool00`000?ooooooo`0Ioooo000loooo00<0003oooooool0oooook?oool00`000?oo
ooooo`0Ioooo000[oooo100000?oool200002?ooo`030000oooooooo0?ooooncoooo00<0003ooooo
ool06Oooo`007_ooo`030000oooooooo00[oool00`000?ooooooo`03oooo00@0003oooooool00007
oooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000Noooo1@0000Woool00`000?oo
ooooo`02oooo00@0003oooooool00007oooo10000?oooon_oooo100001_oool002?oool00`000?oo
ooooo`07oooo00D0003oooooooooool000000_ooo`030000oooooooo00Goool00`000?ooooooo`3o
oooo/oooo`030000oooooooo01Woool002?oool00`000?ooooooo`05oooo00@0003oooooool00002
oooo00@0003oooooool00007oooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000N
oooo00D0003oooooooooool000002Oooo`800004oooo0P0000Soool00`000?ooooooo`3ooooo/ooo
o`030000oooooooo01Woool001koool600006?ooo`030000oooooooo0?ooooncoooo00<0003ooooo
ool06Oooo`008oooo`030000oooooooo01Koool00`000?ooooooo`3ooooo/oooo`030000oooooooo
01Woool003coool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool001koool00`000?oo
ooooo`02oooo00<0003oooooool05_ooo`030000oooooooo0?ooooncoooo00<0003oooooool06Ooo
o`007_ooo`H0000Hoooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000Noooo00<0
003oooooool00_ooo`030000oooooooo01Koool00`000?ooooooo`3ooooo/oooo`030000oooooooo
01Woool001koool00`000?ooooooo`0Koooo0P000?ooooncoooo0P0001_oool001koool00`000?oo
ooooo`02oooo00<0003oooooool05_ooo`030000oooooooo0?ooooncoooo00<0003oooooool06Ooo
o`007oooo`D0000Hoooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000Soooo00<0
003oooooool05_ooo`030000oooooooo0?ooooncoooo00<0003oooooool06Oooo`00??ooo`030000
oooooooo0?ooooncoooo00<0003oooooool06Oooo`008oooo`030000oooooooo01Koool00`000?oo
ooooo`3ooooo/oooo`030000oooooooo01Woool001koool00`000?ooooooo`02oooo00<0003ooooo
ool05_ooo`030000oooooooo0?ooooncoooo00<0003oooooool06Oooo`007_ooo`030000oooooooo
00;oool00`000?ooooooo`0Foooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000L
oooo00<0003oool000001@0001Soool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool0
02?oool00`000?ooooooo`0Foooo0P000?ooooncoooo0P0001_oool002?oool00`000?ooooooo`0F
oooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000Soooo00<0003oooooool05_oo
o`030000oooooooo0?ooooncoooo00<0003oooooool06Oooo`00??ooo`030000oooooooo0?oooonc
oooo00<0003oooooool06Oooo`007_ooo`030000oooooooo01_oool00`000?ooooooo`3ooooo/ooo
o`030000oooooooo01Woool001coool700006Oooo`030000oooooooo0?ooooncoooo00<0003ooooo
ool06Oooo`007_ooo`030000oooooooo00;oool00`000?ooooooo`0Foooo00<0003oooooool0oooo
ok?oool00`000?ooooooo`0Ioooo000Noooo00<0003oooooool00_ooo`030000oooooooo01Koool0
0`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool001koool00`000?ooooooo`02oooo00<0
003oooooool05_ooo`030000oooooooo0?ooooncoooo00<0003oooooool06Oooo`007_ooo`050000
oooooooooooo000001Woool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool003coool2
0000oooook?oool200006oooo`00??ooo`030000oooooooo0?ooooncoooo00<0003oooooool06Ooo
o`007oooo`030000oooooooo0080000Hoooo00<0003oooooool0oooook?oool00`000?ooooooo`0I
oooo000Noooo00D0003oool0003oool000006Oooo`030000oooooooo0?ooooncoooo00<0003ooooo
ool06Oooo`007_ooo`030000oooo000000;oool00`000?ooooooo`0Foooo00<0003oooooool0oooo
ok?oool00`000?ooooooo`0Ioooo000Noooo00<0003oool000000_ooo`030000oooooooo01Koool0
0`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool001koool00`000?ooo`000002oooo00<0
003oooooool05_ooo`030000oooooooo0?ooooncoooo00<0003oooooool06Oooo`007_ooo`800000
0oooo`000000000Ioooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000loooo00<0
003oooooool0oooook?oool00`000?ooooooo`0Ioooo000loooo00<0003oooooool0oooook?oool0
0`000?ooooooo`0Ioooo000loooo0P000?ooooncoooo0P0001_oool003coool00`000?ooooooo`3o
oooo/oooo`030000oooooooo01Woool001_oool00`000?ooooooo`08oooo00<0003oooooool04ooo
o`030000oooooooo0?ooooncoooo00<0003oooooool06Oooo`007?ooo`800006oooo0P0001Koool0
0`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool001koool600006?ooo`030000oooooooo
0?ooooncoooo00<0003oooooool06Oooo`00??ooo`030000oooooooo0?ooooncoooo00<0003ooooo
ool06Oooo`00??ooo`030000oooooooo0?ooooncoooo00<0003oooooool06Oooo`00??ooo`030000
oooooooo0?ooooncoooo00<0003oooooool06Oooo`00:oooo`@00003oooo0P0000Soool00`000?oo
ooooo`3ooooo/oooo`030000oooooooo01Woool002_oool00`000?ooooooo`03oooo00@0003ooooo
ool00007oooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000/oooo00<0003ooooo
ool01Oooo`030000oooooooo00Goool40000ooooojooool400006oooo`00;Oooo`030000oooooooo
00;oool200002?ooo`030000oooooooo0?ooooncoooo00<0003oooooool06Oooo`00:oooo`040000
oooooooo00000oooo`030000oooooooo00Ooool00`000?ooooooo`3ooooo/oooo`030000oooooooo
01Woool002coool200001?ooo`<00007oooo00<0003oooooool0oooook?oool00`000?ooooooo`0I
oooo000loooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000loooo00<0003ooooo
ool0oooook?oool00`000?ooooooo`0Ioooo000loooo00<0003oooooool0oooook?oool00`000?oo
ooooo`0Ioooo000loooo00<0003oooooool0oooook?oool00`000?ooooooo`0Ioooo000loooo00<0
003oooooool0oooook?oool00`000?ooooooo`0Ioooo000loooo0P000?ooooncoooo0P0001_oool0
03coool00`000?ooooooo`3ooooo/oooo`030000oooooooo01Woool003coool00`000?ooooooo`3o
oooo/oooo`030000oooooooo01Woool003coool00`000?ooooooo`05oooo1@000?oooonYoooo00<0
003oooooool06Oooo`00??ooo`030000oooooooo00Goool50000ooooojWoool00`000?ooooooo`0I
oooo000loooo00<0003oooooool01Oooo`D0003oooooZOooo`030000oooooooo01Woool003coool0
0`000?ooooooo`05oooo1@000?oooonYoooo00<0003oooooool06Oooo`00??ooo`030000oooooooo
00Goool50000ooooojWoool00`000?ooooooo`0Ioooo000loooo00<0003oooooool0oooook?oool0
0`000?ooooooo`0Ioooo000loooo00<0003oooooool01oooo`030000oooooooo06Goool00`000?oo
ooooo`1Uoooo00<0003oooooool0I_ooo`030000oooooooo06Goool00`000?ooooooo`07oooo00<0
003oooooool06Oooo`00??ooo`800008oooo00<0003oooooool04_ooo`030000oooooooo01;oool0
0`000?ooooooo`0Boooo00<0003oooooool04_ooo`030000oooooooo017oool00`000?ooooooo`0B
oooo00<0003oooooool04_ooo`030000oooooooo01;oool00`000?ooooooo`0Boooo00<0003ooooo
ool04Oooo`030000oooooooo01;oool00`000?ooooooo`0Boooo00<0003oooooool04_ooo`030000
oooooooo01;oool00`000?ooooooo`0Boooo00<0003oooooool04Oooo`030000oooooooo01;oool0
0`000?ooooooo`0Boooo00<0003oooooool04_ooo`030000oooooooo01;oool00`000?ooooooo`06
oooo0P0001_oool003coool00`000?ooooooo`07oooo00<0003oooooool04_ooo`030000oooooooo
01;oool00`000?ooooooo`0Boooo00<0003oooooool04_ooo`030000oooooooo017oool00`000?oo
ooooo`0Boooo00<0003oooooool04_ooo`030000oooooooo01;oool00`000?ooooooo`0Boooo00<0
003oooooool04Oooo`030000oooooooo01;oool00`000?ooooooo`0Boooo00<0003oooooool04_oo
o`030000oooooooo01;oool00`000?ooooooo`0Boooo00<0003oooooool04Oooo`030000oooooooo
01;oool00`000?ooooooo`0Boooo00<0003oooooool04_ooo`030000oooooooo01;oool00`000?oo
ooooo`07oooo00<0003oooooool06Oooo`00??ooool0002g00006oooo`00ooooooooool?oooo003o
ooooooooo`ooool00?oooooooooo3oooo`00ooooooooool?oooo003oooooooooo`ooool00?oooooo
oooo3oooo`00ooooo`Koool50000GOooo`@0002Roooo003ooooo2Oooo`030000oooooooo063oool0
0`000?ooooooo`2Ooooo003ooooo2_ooo`030000oooooooo063oool00`000?ooooooo`2Noooo003o
oooo2_ooo`030000oooooooo063oool00`000?ooooooo`2Noooo002Voooo1`0000Goool300000ooo
o`<00006oooo100000Ooool500001Oooo`<00003oooo0`0000?oool00`000?ooo`00000300001Ooo
o`T00007oooo100000Soool200005_ooo`800007oooo00<0003oool000000`0000Soool300004Ooo
o`@00004oooo100000;oool300000oooo`<00005oooo0`000003oooo0000oooo00Coool900001Ooo
o`D00028oooo002Yoooo00<0003oooooool01oooo`030000oooooooo00?oool00`000?ooooooo`04
oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool00oooo`030000oooooooo00?oool0
0`000?ooooooo`03oooo00<0003oooooool00_ooo`800004oooo00<0003oooooool01_ooo`030000
oooooooo00Soool00`000?ooooooo`02oooo0P0000Koool200005_ooo`800007oooo0P0000Coool0
0`000?ooooooo`05oooo0`0001;oool00`000?ooooooo`06oooo00<0003oooooool00_ooo`030000
oooooooo00?oool00`000?ooooooo`03oooo00@0003oooooooooool200002Oooo`030000oooooooo
00Koool00`000?ooooooo`03oooo00<0003oooooool0QOooo`00ZOooo`030000oooooooo00Ooool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00Ooool00`000?ooooooo`0:
oooo00<0003oooooool00oooo`030000oooooooo00;oool00`000?ooooooo`04oooo00<0003ooooo
ool01Oooo`030000oooooooo00Soool00`000?ooooooo`09oooo00@0003oooooool0000Doooo00@0
003oooooool00006oooo00<0003oooooool01?ooo`030000oooooooo00Coool300004oooo`030000
oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00;oool0
0`000?ooooooo`03oooo00<0003oooooool01oooo`030000oooooooo00Goool00`000?ooooooo`2<
oooo002Yoooo00<0003oooooool01oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0
003oooooool01oooo`030000oooooooo00[oool00`000?ooooooo`03oooo00<0003oooooool02Ooo
o`030000oooooooo00Goool00`000?ooooooo`08oooo00<0003oooooool02Oooo`040000oooooooo
00005?ooo`040000oooooooo00003Oooo`030000oooooooo01[oool00`000?ooooooo`04oooo00<0
003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`02oooo00<0003oooooool00ooo
o`030000oooooooo00Ooool00`000?ooooooo`05oooo00<0003oooooool0S?ooo`00ZOooo`030000
oooooooo00Ooool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00Ooool8
00001Oooo`030000oooooooo00?oool00`000?ooooooo`08oooo00<0003oooooool01_ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool00_ooo`030000oooooooo013oool0
0`000?ooooooo`02oooo00<0003oooooool02Oooo`030000oooooooo01_oool800001Oooo`030000
oooooooo00?oool00`000?ooooooo`02oooo00<0003oooooool00oooo`030000oooooooo00Ooool0
0`000?ooooooo`05oooo200008Ooool00:Woool00`000?ooooooo`07oooo00<0003oooooool00ooo
o`030000oooooooo00Coool00`000?ooooooo`07oooo00<0003oooooool01?ooo`030000oooooooo
00?oool00`000?ooooooo`03oooo00<0003oooooool00oooo`D00009oooo00<0003oooooool02?oo
o`030000oooooooo00Soool00`000?ooooooo`02oooo00<0003oooooool04?ooo`030000oooooooo
00;oool00`000?ooooooo`04oooo1@0001ooool00`000?ooooooo`02oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`02oooo00<0003oooooool00oooo`030000oooooooo
00Ooool00`000?ooooooo`05oooo00<0003oooooool01?ooo`030000oooooooo08Goool00:Woool0
0`000?ooooooo`07oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`07
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003ooooo
ool00_ooo`030000oooooooo00Coool00`000?ooooooo`05oooo00<0003oooooool02?ooo`030000
oooooooo00Ooool00`000?ooooooo`03oooo00<0003oooooool04?ooo`030000oooooooo00;oool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo01_oool00`000?ooooooo`02
oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`02oooo00<0003ooooo
ool00oooo`030000oooooooo00Ooool00`000?ooooooo`05oooo00<0003oooooool01?ooo`030000
oooooooo08Goool00:Woool00`000?ooooooo`07oooo0P0000?oool00`000?ooooooo`05oooo00<0
003oooooool02?ooo`030000oooooooo00;oool00`000?ooooooo`04oooo0P0000?oool00`000?oo
ooooo`03oooo00<0003oooooool00oooo`800007oooo00<0003oooooool02?ooo`030000oooooooo
00Ooool00`000?ooooooo`04oooo00<0003oooooool03_ooo`030000oooooooo00Coool00`000?oo
ooooo`02oooo00<0003oooooool00oooo`80000Noooo00@0003oooooool00007oooo0P0000?oool0
0`000?ooooooo`04oooo00@0003oooooooooool200002Oooo`030000oooooooo00Koool00`000?oo
ooooo`02oooo00<0003oooooool0Q_ooo`00ZOooo`030000oooooooo00Koool2000000Coool00000
00000006oooo200000Koool400001_ooo`8000001?ooo`000000000000Ooool5000000?oool0003o
ool00oooo`@00008oooo200000;oool400001?ooo`@0000<oooo100000Coool400000oooo`D00000
0oooo`000?ooo`0Moooo00@0003oooooool00006oooo0P000004oooo0000000000002?ooo`<00000
0oooo`0000000008oooo00<0003oooooool01oooo`@00029oooo002Yoooo00<0003oooooool05?oo
o`030000oooooooo03Woool00`000?ooooooo`1Aoooo00@0003oooooool0000Roooo00<0003ooooo
ool0U?ooo`00ZOooo`030000oooooooo01Coool00`000?ooooooo`0ioooo00<0003oooooool0D_oo
o`80000Soooo00<0003oooooool0U?ooo`00Y_ooo`L0000Coooo00<0003oooooool0;_ooo`030000
oooooooo00Soool00`000?ooooooo`1?oooo1@0002?oool00`000?ooooooo`2Doooo003aoooo00<0
003oooooool0Ooooo`@0002Foooo0000\
\>"],
  ImageRangeCache->{{{0, 524.25}, {323.625, 0}} -> {0.321091, -3.69013, \
0.00960269, 0.102955}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Export Data Table", "Section"],

Cell[BoxData[{
    \(\(filename = "\<data.txt\>";\)\), "\n", 
    \(\(Export["\<c:\\documents\\mschubmehl\\\>" <> filename, 
        finaldata, "\<Table\>"];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Import and Plot Results of Fit", "Section"],

Cell[BoxData[
    \(\(bestfit = 
        Rest[Import["\<c:\\documents\\mschubmehl\\bestfit.txt\>", \
"\<Table\>"]];\)\)], "Input"],

Cell[BoxData[
    \(\(chidist = 
        Import["\<c:\\documents\\mschubmehl\\chidist.txt\>", \
"\<Table\>"];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"MultipleListPlot", "[", 
        RowBox[{"finaldataerror", ",", "bestfit", ",", 
          StyleBox[\(SymbolShape \[Rule] {PlotSymbol[Box], None}\),
            FontColor->GrayLevel[0.666667]], 
          StyleBox[",",
            FontColor->GrayLevel[0.666667]], 
          StyleBox[\(Frame \[Rule] True\),
            FontColor->GrayLevel[0.666667]], 
          StyleBox[",",
            FontColor->GrayLevel[0.666667]], 
          
          StyleBox[\(FrameLabel \[Rule] {StyleForm[
                  TraditionalForm["\<Angle (\[Degree])\>"], 
                  FontSize \[Rule] 14], 
                StyleForm[TraditionalForm["\<Intensity (arbitrary units)\>"], 
                  FontSize \[Rule] 14]}\),
            FontColor->GrayLevel[0.666667]], 
          StyleBox[",",
            FontColor->GrayLevel[0.666667]], 
          
          StyleBox[\(PlotLabel \[Rule] 
              StyleForm[
                TraditionalForm["\<Intensity vs. Angle: Data and Theory\>"], 
                FontSize \[Rule] 20]\),
            FontColor->GrayLevel[0.666667]], 
          StyleBox[",",
            FontColor->GrayLevel[0.666667]], 
          StyleBox[\(PlotJoined \[Rule] {False, True}\),
            FontColor->GrayLevel[0.666667]]}], "]"}], ";"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0136054 0.0147151 0.000369517 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.15986 -0.0125 -6 -9 ]
[.15986 -0.0125 6 0 ]
[.29592 -0.0125 -6 -9 ]
[.29592 -0.0125 6 0 ]
[.43197 -0.0125 -6 -9 ]
[.43197 -0.0125 6 0 ]
[.56803 -0.0125 -6 -9 ]
[.56803 -0.0125 6 0 ]
[.70408 -0.0125 -6 -9 ]
[.70408 -0.0125 6 0 ]
[.84014 -0.0125 -6 -9 ]
[.84014 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -39.6875 -23.9375 ]
[.5 -0.0125 39.6875 -9 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10709 -18 -4.5 ]
[-0.0125 .10709 0 4.5 ]
[-0.0125 .19947 -18 -4.5 ]
[-0.0125 .19947 0 4.5 ]
[-0.0125 .29185 -18 -4.5 ]
[-0.0125 .29185 0 4.5 ]
[-0.0125 .38423 -24 -4.5 ]
[-0.0125 .38423 0 4.5 ]
[-0.0125 .47661 -24 -4.5 ]
[-0.0125 .47661 0 4.5 ]
[-0.0125 .56899 -24 -4.5 ]
[-0.0125 .56899 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -37.625 -115.063 ]
[-0.01875 .30902 -24 115.063 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -218 0 ]
[.5 .63053 218 18.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.15986 0 m
.15986 .00625 L
s
[(10)] .15986 -0.0125 0 1 Mshowa
.29592 0 m
.29592 .00625 L
s
[(20)] .29592 -0.0125 0 1 Mshowa
.43197 0 m
.43197 .00625 L
s
[(30)] .43197 -0.0125 0 1 Mshowa
.56803 0 m
.56803 .00625 L
s
[(40)] .56803 -0.0125 0 1 Mshowa
.70408 0 m
.70408 .00625 L
s
[(50)] .70408 -0.0125 0 1 Mshowa
.84014 0 m
.84014 .00625 L
s
[(60)] .84014 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(70)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05102 0 m
.05102 .00375 L
s
.07823 0 m
.07823 .00375 L
s
.10544 0 m
.10544 .00375 L
s
.13265 0 m
.13265 .00375 L
s
.18707 0 m
.18707 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2415 0 m
.2415 .00375 L
s
.26871 0 m
.26871 .00375 L
s
.32313 0 m
.32313 .00375 L
s
.35034 0 m
.35034 .00375 L
s
.37755 0 m
.37755 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45918 0 m
.45918 .00375 L
s
.48639 0 m
.48639 .00375 L
s
.51361 0 m
.51361 .00375 L
s
.54082 0 m
.54082 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62245 0 m
.62245 .00375 L
s
.64966 0 m
.64966 .00375 L
s
.67687 0 m
.67687 .00375 L
s
.73129 0 m
.73129 .00375 L
s
.7585 0 m
.7585 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.81293 0 m
.81293 .00375 L
s
.86735 0 m
.86735 .00375 L
s
.89456 0 m
.89456 .00375 L
s
.92177 0 m
.92177 .00375 L
s
.94898 0 m
.94898 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -100.688 -27.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22.9375 translate 1 -1 scale
63.000 15.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Angle) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
113.250 15.188 moveto
(H) show
121.625 15.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\260) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
130.000 15.188 moveto
(L) show
138.375 15.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10709 m
.00625 .10709 L
s
[(250)] -0.0125 .10709 1 0 Mshowa
0 .19947 m
.00625 .19947 L
s
[(500)] -0.0125 .19947 1 0 Mshowa
0 .29185 m
.00625 .29185 L
s
[(750)] -0.0125 .29185 1 0 Mshowa
0 .38423 m
.00625 .38423 L
s
[(1000)] -0.0125 .38423 1 0 Mshowa
0 .47661 m
.00625 .47661 L
s
[(1250)] -0.0125 .47661 1 0 Mshowa
0 .56899 m
.00625 .56899 L
s
[(1500)] -0.0125 .56899 1 0 Mshowa
.125 Mabswid
0 .03319 m
.00375 .03319 L
s
0 .05167 m
.00375 .05167 L
s
0 .07014 m
.00375 .07014 L
s
0 .08862 m
.00375 .08862 L
s
0 .12557 m
.00375 .12557 L
s
0 .14405 m
.00375 .14405 L
s
0 .16252 m
.00375 .16252 L
s
0 .181 m
.00375 .181 L
s
0 .21795 m
.00375 .21795 L
s
0 .23643 m
.00375 .23643 L
s
0 .2549 m
.00375 .2549 L
s
0 .27338 m
.00375 .27338 L
s
0 .31033 m
.00375 .31033 L
s
0 .3288 m
.00375 .3288 L
s
0 .34728 m
.00375 .34728 L
s
0 .36576 m
.00375 .36576 L
s
0 .40271 m
.00375 .40271 L
s
0 .42118 m
.00375 .42118 L
s
0 .43966 m
.00375 .43966 L
s
0 .45814 m
.00375 .45814 L
s
0 .49509 m
.00375 .49509 L
s
0 .51356 m
.00375 .51356 L
s
0 .53204 m
.00375 .53204 L
s
0 .55051 m
.00375 .55051 L
s
0 .58747 m
.00375 .58747 L
s
0 .60594 m
.00375 .60594 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -206.875 -10.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
176.063 10.8125 translate
90 rotate
-176.063 -10.8125 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.625 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Intensity) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
146.750 13.875 moveto
(H) show
155.125 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(arbitrary) show
238.875 13.875 moveto
(units) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
280.750 13.875 moveto
(L) show
289.125 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.15986 .61178 m
.15986 .61803 L
s
.29592 .61178 m
.29592 .61803 L
s
.43197 .61178 m
.43197 .61803 L
s
.56803 .61178 m
.56803 .61803 L
s
.70408 .61178 m
.70408 .61803 L
s
.84014 .61178 m
.84014 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05102 .61428 m
.05102 .61803 L
s
.07823 .61428 m
.07823 .61803 L
s
.10544 .61428 m
.10544 .61803 L
s
.13265 .61428 m
.13265 .61803 L
s
.18707 .61428 m
.18707 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2415 .61428 m
.2415 .61803 L
s
.26871 .61428 m
.26871 .61803 L
s
.32313 .61428 m
.32313 .61803 L
s
.35034 .61428 m
.35034 .61803 L
s
.37755 .61428 m
.37755 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45918 .61428 m
.45918 .61803 L
s
.48639 .61428 m
.48639 .61803 L
s
.51361 .61428 m
.51361 .61803 L
s
.54082 .61428 m
.54082 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62245 .61428 m
.62245 .61803 L
s
.64966 .61428 m
.64966 .61803 L
s
.67687 .61428 m
.67687 .61803 L
s
.73129 .61428 m
.73129 .61803 L
s
.7585 .61428 m
.7585 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.81293 .61428 m
.81293 .61803 L
s
.86735 .61428 m
.86735 .61803 L
s
.89456 .61428 m
.89456 .61803 L
s
.92177 .61428 m
.92177 .61803 L
s
.94898 .61428 m
.94898 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10709 m
1 .10709 L
s
.99375 .19947 m
1 .19947 L
s
.99375 .29185 m
1 .29185 L
s
.99375 .38423 m
1 .38423 L
s
.99375 .47661 m
1 .47661 L
s
.99375 .56899 m
1 .56899 L
s
.125 Mabswid
.99625 .03319 m
1 .03319 L
s
.99625 .05167 m
1 .05167 L
s
.99625 .07014 m
1 .07014 L
s
.99625 .08862 m
1 .08862 L
s
.99625 .12557 m
1 .12557 L
s
.99625 .14405 m
1 .14405 L
s
.99625 .16252 m
1 .16252 L
s
.99625 .181 m
1 .181 L
s
.99625 .21795 m
1 .21795 L
s
.99625 .23643 m
1 .23643 L
s
.99625 .2549 m
1 .2549 L
s
.99625 .27338 m
1 .27338 L
s
.99625 .31033 m
1 .31033 L
s
.99625 .3288 m
1 .3288 L
s
.99625 .34728 m
1 .34728 L
s
.99625 .36576 m
1 .36576 L
s
.99625 .40271 m
1 .40271 L
s
.99625 .42118 m
1 .42118 L
s
.99625 .43966 m
1 .43966 L
s
.99625 .45814 m
1 .45814 L
s
.99625 .49509 m
1 .49509 L
s
.99625 .51356 m
1 .51356 L
s
.99625 .53204 m
1 .53204 L
s
.99625 .55051 m
1 .55051 L
s
.99625 .58747 m
1 .58747 L
s
.99625 .60594 m
1 .60594 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -279 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26.4375 translate 1 -1 scale
63.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Intensity) show
183.000 17.750 moveto
(vs) show
207.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
231.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Angle) show
291.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
315.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Data) show
375.000 17.750 moveto
(and) show
423.000 17.750 moveto
(Theory) show
495.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.07823 .58163 m
.07823 .55276 L
s
.07823 .58163 1.5 0 Mabsadd m
.07823 .58163 -1.5 0 Mabsadd L s
.07823 .55276 1.5 0 Mabsadd m
.07823 .55276 -1.5 0 Mabsadd L s
.10544 .59025 m
.10544 .56133 L
s
.10544 .59025 1.5 0 Mabsadd m
.10544 .59025 -1.5 0 Mabsadd L s
.10544 .56133 1.5 0 Mabsadd m
.10544 .56133 -1.5 0 Mabsadd L s
.13265 .57103 m
.13265 .54162 L
s
.13265 .57103 1.5 0 Mabsadd m
.13265 .57103 -1.5 0 Mabsadd L s
.13265 .54162 1.5 0 Mabsadd m
.13265 .54162 -1.5 0 Mabsadd L s
.15986 .57733 m
.15986 .54817 L
s
.15986 .57733 1.5 0 Mabsadd m
.15986 .57733 -1.5 0 Mabsadd L s
.15986 .54817 1.5 0 Mabsadd m
.15986 .54817 -1.5 0 Mabsadd L s
.18707 .58186 m
.18707 .55254 L
s
.18707 .58186 1.5 0 Mabsadd m
.18707 .58186 -1.5 0 Mabsadd L s
.18707 .55254 1.5 0 Mabsadd m
.18707 .55254 -1.5 0 Mabsadd L s
.21429 .57175 m
.21429 .54238 L
s
.21429 .57175 1.5 0 Mabsadd m
.21429 .57175 -1.5 0 Mabsadd L s
.21429 .54238 1.5 0 Mabsadd m
.21429 .54238 -1.5 0 Mabsadd L s
.2415 .54134 m
.2415 .51261 L
s
.2415 .54134 1.5 0 Mabsadd m
.2415 .54134 -1.5 0 Mabsadd L s
.2415 .51261 1.5 0 Mabsadd m
.2415 .51261 -1.5 0 Mabsadd L s
.26871 .53885 m
.26871 .50996 L
s
.26871 .53885 1.5 0 Mabsadd m
.26871 .53885 -1.5 0 Mabsadd L s
.26871 .50996 1.5 0 Mabsadd m
.26871 .50996 -1.5 0 Mabsadd L s
.29592 .52186 m
.29592 .49276 L
s
.29592 .52186 1.5 0 Mabsadd m
.29592 .52186 -1.5 0 Mabsadd L s
.29592 .49276 1.5 0 Mabsadd m
.29592 .49276 -1.5 0 Mabsadd L s
.32313 .5003 m
.32313 .48548 L
s
.32313 .5003 1.5 0 Mabsadd m
.32313 .5003 -1.5 0 Mabsadd L s
.32313 .48548 1.5 0 Mabsadd m
.32313 .48548 -1.5 0 Mabsadd L s
.35034 .48218 m
.35034 .46729 L
s
.35034 .48218 1.5 0 Mabsadd m
.35034 .48218 -1.5 0 Mabsadd L s
.35034 .46729 1.5 0 Mabsadd m
.35034 .46729 -1.5 0 Mabsadd L s
.37755 .4644 m
.37755 .44942 L
s
.37755 .4644 1.5 0 Mabsadd m
.37755 .4644 -1.5 0 Mabsadd L s
.37755 .44942 1.5 0 Mabsadd m
.37755 .44942 -1.5 0 Mabsadd L s
.40476 .43759 m
.40476 .42258 L
s
.40476 .43759 1.5 0 Mabsadd m
.40476 .43759 -1.5 0 Mabsadd L s
.40476 .42258 1.5 0 Mabsadd m
.40476 .42258 -1.5 0 Mabsadd L s
.43197 .4085 m
.43197 .39304 L
s
.43197 .4085 1.5 0 Mabsadd m
.43197 .4085 -1.5 0 Mabsadd L s
.43197 .39304 1.5 0 Mabsadd m
.43197 .39304 -1.5 0 Mabsadd L s
.45918 .36882 m
.45918 .35329 L
s
.45918 .36882 1.5 0 Mabsadd m
.45918 .36882 -1.5 0 Mabsadd L s
.45918 .35329 1.5 0 Mabsadd m
.45918 .35329 -1.5 0 Mabsadd L s
.48639 .33327 m
.48639 .31772 L
s
.48639 .33327 1.5 0 Mabsadd m
.48639 .33327 -1.5 0 Mabsadd L s
.48639 .31772 1.5 0 Mabsadd m
.48639 .31772 -1.5 0 Mabsadd L s
.51361 .30052 m
.51361 .28478 L
s
.51361 .30052 1.5 0 Mabsadd m
.51361 .30052 -1.5 0 Mabsadd L s
.51361 .28478 1.5 0 Mabsadd m
.51361 .28478 -1.5 0 Mabsadd L s
.54082 .26945 m
.54082 .2537 L
s
.54082 .26945 1.5 0 Mabsadd m
.54082 .26945 -1.5 0 Mabsadd L s
.54082 .2537 1.5 0 Mabsadd m
.54082 .2537 -1.5 0 Mabsadd L s
.0001 w
.07823 .56719 -2.5 2.5 Mabsadd m
.07823 .56719 2.5 2.5 Mabsadd L
.07823 .56719 2.5 -2.5 Mabsadd L
.07823 .56719 -2.5 -2.5 Mabsadd L
.07823 .56719 -2.5 2.5 Mabsadd L closepath F
.10544 .57579 -2.5 2.5 Mabsadd m
.10544 .57579 2.5 2.5 Mabsadd L
.10544 .57579 2.5 -2.5 Mabsadd L
.10544 .57579 -2.5 -2.5 Mabsadd L
.10544 .57579 -2.5 2.5 Mabsadd L closepath F
.13265 .55632 -2.5 2.5 Mabsadd m
.13265 .55632 2.5 2.5 Mabsadd L
.13265 .55632 2.5 -2.5 Mabsadd L
.13265 .55632 -2.5 -2.5 Mabsadd L
.13265 .55632 -2.5 2.5 Mabsadd L closepath F
.15986 .56275 -2.5 2.5 Mabsadd m
.15986 .56275 2.5 2.5 Mabsadd L
.15986 .56275 2.5 -2.5 Mabsadd L
.15986 .56275 -2.5 -2.5 Mabsadd L
.15986 .56275 -2.5 2.5 Mabsadd L closepath F
.18707 .5672 -2.5 2.5 Mabsadd m
.18707 .5672 2.5 2.5 Mabsadd L
.18707 .5672 2.5 -2.5 Mabsadd L
.18707 .5672 -2.5 -2.5 Mabsadd L
.18707 .5672 -2.5 2.5 Mabsadd L closepath F
.21429 .55706 -2.5 2.5 Mabsadd m
.21429 .55706 2.5 2.5 Mabsadd L
.21429 .55706 2.5 -2.5 Mabsadd L
.21429 .55706 -2.5 -2.5 Mabsadd L
.21429 .55706 -2.5 2.5 Mabsadd L closepath F
.2415 .52697 -2.5 2.5 Mabsadd m
.2415 .52697 2.5 2.5 Mabsadd L
.2415 .52697 2.5 -2.5 Mabsadd L
.2415 .52697 -2.5 -2.5 Mabsadd L
.2415 .52697 -2.5 2.5 Mabsadd L closepath F
.26871 .52441 -2.5 2.5 Mabsadd m
.26871 .52441 2.5 2.5 Mabsadd L
.26871 .52441 2.5 -2.5 Mabsadd L
.26871 .52441 -2.5 -2.5 Mabsadd L
.26871 .52441 -2.5 2.5 Mabsadd L closepath F
.29592 .50731 -2.5 2.5 Mabsadd m
.29592 .50731 2.5 2.5 Mabsadd L
.29592 .50731 2.5 -2.5 Mabsadd L
.29592 .50731 -2.5 -2.5 Mabsadd L
.29592 .50731 -2.5 2.5 Mabsadd L closepath F
.32313 .49289 -2.5 2.5 Mabsadd m
.32313 .49289 2.5 2.5 Mabsadd L
.32313 .49289 2.5 -2.5 Mabsadd L
.32313 .49289 -2.5 -2.5 Mabsadd L
.32313 .49289 -2.5 2.5 Mabsadd L closepath F
.35034 .47474 -2.5 2.5 Mabsadd m
.35034 .47474 2.5 2.5 Mabsadd L
.35034 .47474 2.5 -2.5 Mabsadd L
.35034 .47474 -2.5 -2.5 Mabsadd L
.35034 .47474 -2.5 2.5 Mabsadd L closepath F
.37755 .45691 -2.5 2.5 Mabsadd m
.37755 .45691 2.5 2.5 Mabsadd L
.37755 .45691 2.5 -2.5 Mabsadd L
.37755 .45691 -2.5 -2.5 Mabsadd L
.37755 .45691 -2.5 2.5 Mabsadd L closepath F
.40476 .43009 -2.5 2.5 Mabsadd m
.40476 .43009 2.5 2.5 Mabsadd L
.40476 .43009 2.5 -2.5 Mabsadd L
.40476 .43009 -2.5 -2.5 Mabsadd L
.40476 .43009 -2.5 2.5 Mabsadd L closepath F
.43197 .40077 -2.5 2.5 Mabsadd m
.43197 .40077 2.5 2.5 Mabsadd L
.43197 .40077 2.5 -2.5 Mabsadd L
.43197 .40077 -2.5 -2.5 Mabsadd L
.43197 .40077 -2.5 2.5 Mabsadd L closepath F
.45918 .36106 -2.5 2.5 Mabsadd m
.45918 .36106 2.5 2.5 Mabsadd L
.45918 .36106 2.5 -2.5 Mabsadd L
.45918 .36106 -2.5 -2.5 Mabsadd L
.45918 .36106 -2.5 2.5 Mabsadd L closepath F
.48639 .3255 -2.5 2.5 Mabsadd m
.48639 .3255 2.5 2.5 Mabsadd L
.48639 .3255 2.5 -2.5 Mabsadd L
.48639 .3255 -2.5 -2.5 Mabsadd L
.48639 .3255 -2.5 2.5 Mabsadd L closepath F
.51361 .29265 -2.5 2.5 Mabsadd m
.51361 .29265 2.5 2.5 Mabsadd L
.51361 .29265 2.5 -2.5 Mabsadd L
.51361 .29265 -2.5 -2.5 Mabsadd L
.51361 .29265 -2.5 2.5 Mabsadd L closepath F
.54082 .26157 -2.5 2.5 Mabsadd m
.54082 .26157 2.5 2.5 Mabsadd L
.54082 .26157 2.5 -2.5 Mabsadd L
.54082 .26157 -2.5 -2.5 Mabsadd L
.54082 .26157 -2.5 2.5 Mabsadd L closepath F
.001 w
[ .5 3 ] 0 Mabsdash
.03741 .60332 m
.05102 .60319 L
.06463 .60298 L
.07823 .60208 L
.09184 .60049 L
.10544 .59823 L
.11905 .59527 L
.13265 .59165 L
.14626 .58736 L
.15986 .58242 L
.17347 .57684 L
.18707 .57065 L
.20068 .56385 L
.21429 .55648 L
.22789 .54857 L
.2415 .54012 L
.2551 .53324 L
.26871 .5239 L
.28231 .51412 L
.29592 .50392 L
.30952 .49336 L
.32313 .48245 L
.33673 .47125 L
.35034 .45977 L
.36395 .45033 L
.37755 .43842 L
.39116 .42635 L
.40476 .41414 L
.41837 .39973 L
.43197 .38742 L
.44558 .37716 L
.45918 .36479 L
.47279 .35248 L
.48639 .34023 L
.5 .32624 L
.51361 .31428 L
.52721 .30419 L
.54082 .29249 L
.55442 .26837 L
.56803 .24553 L
.58163 .23402 L
.59524 .21324 L
.60884 .20556 L
.62245 .19673 L
.63605 .17855 L
.64966 .17068 L
.66327 .15324 L
.67687 .14634 L
.69048 .14066 L
.70408 .12676 L
Mistroke
.71769 .12092 L
.73129 .1153 L
.7449 .10277 L
.7585 .09798 L
.77211 .0941 L
.78571 .08968 L
.79932 .08045 L
.81293 .0767 L
.82653 .07312 L
.84014 .06914 L
.85374 .062 L
.86735 .05967 L
.88095 .05696 L
.89456 .05438 L
.90816 .05192 L
.92177 .04634 L
.93537 .04433 L
.94898 .04279 L
.96259 .04095 L
.97619 .03919 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{545.938, 337.438},
  ImageMargins->{{75, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008Q0001DAP00`40o`000?l0003ooooooooooolS
oooo003oooooooooob?oool00?oooolDoooo100002?oool00`000?ooooooo`08oooo00<0003ooooo
ool0fOooo`00oooooaSoool00`000?ooooooo`0Ooooo00<0003oooooool02_ooo`030000oooooooo
0=Soool00?oooolHoooo00<0003oooooool07oooo`030000oooooooo00[oool00`000?ooooooo`3H
oooo003ooooo0_ooo`<00002oooo0`000005oooo000000000000oooo00<00002oooo0`000004oooo
0000oooooooo1`0000;oool500004?ooo`030000oooooooo00coool00`000?ooooooo`3Goooo003o
oooo0oooo`030000oooooooo00;oool01@000?ooooooooooo`000003oooo00@0003oooooool00003
oooo0P0000Goool00`000?ooooooo`02oooo00<0003oooooool04oooo`030000oooooooo00coool0
0`000?ooooooo`3Goooo003ooooo1?ooo`@00004oooo00D0003oooooooooool000000_ooo`030000
oooooooo00;oool00`000?ooooooo`03oooo00<0003oooooool00_ooo`030000oooooooo01?oool0
0`000?ooooooo`0<oooo00<0003oooooool0eoooo`00ooooo`Coool010000?ooooooo`0000Coool0
1@000?ooooooooooo`000002oooo00<0003oooooool00_ooo`030000oooooooo00?oool00`000?oo
ooooo`02oooo1P00013oool00`000?ooooooo`0<oooo00<0003oooooool0eoooo`00ooooo`Coool0
10000?ooooooo`0000Coool200000_ooo`040000oooooooo00000oooo`800005oooo00<0003ooooo
ool00_ooo`030000oooooooo00;oool00`000?ooooooo`0>oooo00<0003oooooool03?ooo`030000
oooooooo0=Ooool00?ooool5oooo0P0000Coool2000000?oool0000000001?ooo`<000000oooo`00
00000004oooo00<0003oooooool00oooo`@0000Aoooo00<0003oooooool03?ooo`030000oooooooo
0=Ooool00?ooool5oooo0P0001Ooool00`000?ooooooo`0Ioooo00<0003oooooool00oooo`800005
oooo00<0003oooooool0f?ooo`00ooooo`Coool300005oooo`030000oooooooo01Woool00`000?oo
ooooo`02oooo00@0003oooooool00004oooo00<0003oooooool0f?ooo`00oooooagoool200007?oo
o`050000oooooooooooo000000;oool01@000?ooooooooooo`00003Koooo003ooooo@?ooo`80003P
oooo003oooooooooob?oool004coool20000>?ooo`D00002oooo0P0003Koool400000oooo`80000f
oooo0P0000Coool20000=oooo`<00002oooo0P0003Koool200001?ooo`80000foooo0`0000Coool2
0000=oooo`030000oooooooo00;oool200007?ooo`00Boooo`040000oooooooo0000>Oooo`050000
oooooooooooo000000;oool00`000?ooooooo`0coooo00<0003oooooool00oooo`040000oooooooo
0000=?ooo`040000oooooooo00000_ooo`040000oooooooo0000=oooo`040000oooooooo00000_oo
o`030000oooooooo03;oool010000?ooooooo`0000;oool010000?ooooooo`0003Goool010000?oo
ooooo`0000;oool010000?ooooooo`0003Koool01@000?ooooooooooo`000002oooo00<0003ooooo
ool06Oooo`00Boooo`040000oooooooo0000>Oooo`050000oooooooooooo000000;oool00`000?oo
ooooo`0doooo00<0003oooooool00_ooo`040000oooooooo0000=_ooo`050000oooooooooooo0000
00;oool00`000?ooooooo`0boooo1@000005oooo0000oooooooo000003Ooool010000?ooooooo`00
00;oool00`000?ooooooo`0coooo00@0003oooooool00002oooo00@0003oooooool0000foooo00D0
003oooooooooool000000_ooo`030000oooooooo01Woool004_oool010000?ooooooo`0003Woool0
1@000?ooooooooooo`000002oooo00<0003oooooool0=Oooo`050000oooooooooooo000000;oool0
0`000?ooooooo`0eoooo00@0003oooooool00002oooo00<0003oooooool0<_ooo`040000oooooooo
00000_ooo`040000oooooooo0000=Oooo`800003oooo00@0003oooooool0000eoooo0`0000?oool0
10000?ooooooo`0003Ooool010000?ooooooo`0000;oool00`000?ooooooo`0Ioooo001;oooo00@0
003oooooool0000ioooo00D0003oooooooooool000000_ooo`030000oooooooo03?oool010000?oo
ooooo`0000;oool010000?ooooooo`0003Coool010000?ooooooo`0000;oool010000?ooooooo`00
03Goool00`000?ooo`000002oooo00@0003oooooool0000eoooo00<0003oooooool00_ooo`040000
oooooooo0000=_ooo`030000oooooooo00;oool010000?ooooooo`0003Coool010000?ooooooo`00
00;oool010000?ooooooo`0001_oool004coool20000>Oooo`800004oooo0P0003Ooool200001?oo
o`80000foooo0P0000Coool20000=oooo`800003oooo0P0003Koool300000oooo`80000goooo0`00
00?oool20000=Oooo`@00003oooo0P0001coool00?oooooooooo8oooo`00oooooooooolSoooo003o
ooooooooob?oool00?oooooooooo8oooo`00oooooooooolSoooo003oooooooooob?oool00?oooooo
oooo8oooo`00oooooooooolSoooo0012ooooo`000<`0000Doooo0012oooo00<0003oooooool02?oo
o`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo
00Woool00`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?oo
ooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0
003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02_oo
o`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo
00[oool00`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0
003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02_oo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo
00Woool00`000?ooooooo`0:oooo00<0003oooooool02?ooo`030000oooooooo01;oool004;oool0
0`000?ooooooo`08oooo00<0003oooooool0>oooo`030000oooooooo03coool00`000?ooooooo`0k
oooo00<0003oooooool0>oooo`030000oooooooo03_oool00`000?ooooooo`0loooo00<0003ooooo
ool0>oooo`030000oooooooo00Soool00`000?ooooooo`0Boooo0012oooo00<0003oooooool02?oo
o`030000oooooooo03_oool00`000?ooooooo`0loooo00<0003oooooool0>oooo`030000oooooooo
03_oool00`000?ooooooo`0koooo00<0003oooooool0??ooo`030000oooooooo03_oool00`000?oo
ooooo`08oooo00<0003oooooool04_ooo`00>Oooo`800007oooo00<0003oooooool0ooooolSoool0
0`000?ooooooo`0Boooo000hoooo00@0003oooooool00006oooo00<0003oooooool0ooooolSoool0
0`000?ooooooo`0Boooo000hoooo00@0003oooooool00006oooo10000?ooooo4oooo100001Coool0
03Soool010000?ooooooo`0000Koool00`000?ooooooo`3ooooob?ooo`030000oooooooo01;oool0
03Soool010000?ooooooo`0000Koool00`000?ooooooo`3ooooob?ooo`030000oooooooo01;oool0
03Woool200001oooo`030000oooooooo0?ooooo8oooo00<0003oooooool04_ooo`00@_ooo`030000
oooooooo0?ooooo8oooo00<0003oooooool04_ooo`00@_ooo`030000oooooooo0?ooooo8oooo00<0
003oooooool04_ooo`00@_ooo`030000oooooooo0?ooooo8oooo00<0003oooooool04_ooo`00@_oo
o`030000oooooooo0?ooooo8oooo00<0003oooooool04_ooo`00@_ooo`030000oooooooo0?ooooo8
oooo00<0003oooooool04_ooo`00@_ooo`<0003oooooa_ooo`<0000Doooo0012oooo00<0003ooooo
ool0ooooolSoool00`000?ooooooo`0Boooo0012oooo00<0003oooooool0ooooolSoool00`000?oo
ooooo`0Boooo0012oooo00<0003oooooool0oooookSoool2000000?oool0000000002oooo`030000
oooooooo01;oool004;oool00`000?ooooooo`3ooooo/Oooo`800002oooo00<0003oooooool04?oo
o`030000oooooooo01;oool004;oool00`000?ooooooo`3oooooYoooo`030000oooooooo00800002
oooo00<0003oooooool05oooo`030000oooooooo01;oool004;oool00`000?ooooooo`3oooooXooo
o`800002oooo00<0003oooooool07_ooo`030000oooooooo01;oool004;oool00`000?ooooooo`3o
ooooX?ooo`030000oooooooo02Goool00`000?ooooooo`0Boooo0012oooo0`000?oooonPoooo00<0
003oooooool08oooo`<0000Doooo0012oooo00<0003oooooool0oooooiWoool200000_ooo`030000
oooooooo02Soool00`000?ooooooo`0Boooo0012oooo00<0003oooooool0oooooi?oool010000?oo
ooooo`00037oool00`000?ooooooo`0Boooo0012oooo00<0003oooooool0ooooohooool010000?oo
ooooo`0003Goool00`000?ooooooo`0Boooo0012oooo00<0003oooooool0ooooohWoool010000?oo
ooooo`0003_oool00`000?ooooooo`0Boooo0012oooo00<0003oooooool0ooooohGoool010000?oo
ooooo`0003ooool00`000?ooooooo`0Boooo0012oooo00<0003oooooool0ooooolSoool00`000?oo
ooooo`0Boooo0012oooo00<0003oooooool0oooooh;oool00`000?ooooooo`13oooo00<0003ooooo
ool04_ooo`005_ooo`030000oooooooo00Coool00`000?ooooooo`0Roooo00<0003oooooool0oooo
ogkoool20000B?ooo`030000oooooooo01;oool001Koool00`000?ooooooo`04oooo00<0003ooooo
ool08_ooo`<0003oooooNoooo`800019oooo0`0001Coool001Koool800009?ooo`030000oooooooo
0?oooomhoooo00<0003oooooool0COooo`030000oooooooo01;oool001Koool00`000?ooooooo`04
oooo00<0003oooooool08_ooo`030000oooooooo0?oooomdoooo0P0005;oool00`000?ooooooo`0B
oooo000Foooo00<0003oooooool01?ooo`030000oooooooo02;oool00`000?ooooooo`3oooooLOoo
o`030000oooooooo05Coool00`000?ooooooo`0Boooo0012oooo00<0003oooooool0ooooofkoool0
0`000?ooooooo`1Goooo00<0003oooooool04_ooo`00@_ooo`030000oooooooo0?oooom[oooo00<0
003oooooool0F_ooo`030000oooooooo01;oool001Soool00`000?ooooooo`02oooo00<0003ooooo
ool08_ooo`030000oooooooo0?oooomZoooo00<0003oooooool0Foooo`030000oooooooo01;oool0
01Soool600009?ooo`030000oooooooo0?oooomXoooo00<0003oooooool0GOooo`030000oooooooo
01;oool001Soool00`000?ooooooo`02oooo00<0003oooooool08_ooo`<0003oooooa_ooo`<0000D
oooo000Hoooo00<0003oooooool09oooo`030000oooooooo0?oooomToooo0P0006;oool00`000?oo
ooooo`0Boooo000Hoooo00<0003oooooool00_ooo`030000oooooooo02;oool00`000?ooooooo`3o
ooooHOooo`80001Uoooo00<0003oooooool04_ooo`006Oooo`D0000Toooo00<0003oooooool0oooo
oekoool00`000?ooooooo`1Woooo00<0003oooooool04_ooo`007Oooo`030000oooooooo02;oool0
0`000?ooooooo`3oooooF_ooo`80001/oooo00<0003oooooool04_ooo`00@_ooo`030000oooooooo
0?oooomGoooo0P0006ooool00`000?ooooooo`0Boooo000Hoooo00<0003oooooool09oooo`030000
oooooooo0?oooomDoooo00<0003oooooool0LOooo`030000oooooooo01;oool001Koool700003ooo
o`@00003oooo0P0000Coool200001oooo`030000oooooooo0?ooooo8oooo00<0003oooooool04_oo
o`006?ooo`030000oooooooo00;oool00`000?ooooooo`0<oooo00<0003oooooool00oooo`040000
oooooooo00000_ooo`040000oooooooo00001_ooo`030000oooooooo0?oooomAoooo00<0003ooooo
ool0M?ooo`030000oooooooo01;oool001Soool00`000?ooooooo`02oooo00<0003oooooool03Ooo
o`030000oooooooo00Goool010000?ooooooo`0000;oool00`000?ooooooo`04oooo10000?oooom@
oooo00<0003oooooool0LOooo`@0000Doooo000Hoooo00<0003oooooool00_ooo`030000oooooooo
00koool00`000?ooooooo`02oooo0P0000?oool010000?ooooooo`0000Koool00`000?ooooooo`3o
oooob?ooo`030000oooooooo01;oool001Soool01@000?ooooooooooo`00000?oooo00@0003ooooo
ool00003oooo00<0003oooooool00_ooo`040000oooooooo00001_ooo`030000oooooooo0?oooom>
oooo0P0007Soool00`000?ooooooo`0Boooo000]oooo0P0000Coool300000oooo`800007oooo00<0
003oooooool0ooooolSoool00`000?ooooooo`0Boooo0012oooo00<0003oooooool0ooooodcoool0
0`000?ooooooo`1ioooo00<0003oooooool04_ooo`006Oooo`@0000Uoooo00<0003oooooool0oooo
odSoool20000O_ooo`030000oooooooo01;oool001Soool00`000?ooo`000002oooo00<0003ooooo
ool08_ooo`030000oooooooo0?oooom6oooo00<0003oooooool0Ooooo`030000oooooooo01;oool0
01Soool00`000?ooo`000002oooo00<0003oooooool08_ooo`030000oooooooo0?oooom5oooo00<0
003oooooool0P?ooo`030000oooooooo01;oool001Soool00`000?ooo`000002oooo00<0003ooooo
ool08_ooo`<0003ooooo@_ooo`030000oooooooo087oool300005?ooo`006?ooo`030000oooo0000
00;oool00`000?ooooooo`0Roooo00<0003oooooool0ooooolSoool00`000?ooooooo`0Boooo000I
oooo0P0000;oool00`000?ooooooo`0Roooo00<0003oooooool0ooooolSoool00`000?ooooooo`0B
oooo0012oooo00<0003oooooool0ooooockoool00`000?ooooooo`27oooo00<0003oooooool04_oo
o`00@_ooo`030000oooooooo0?ooooo8oooo00<0003oooooool04_ooo`006?ooo`030000oooooooo
00;oool00`000?ooooooo`0Roooo00<0003oooooool0oooooccoool00`000?ooooooo`29oooo00<0
003oooooool04_ooo`006?ooo`H0000Toooo00<0003oooooool0oooooccoool00`000?ooooooo`29
oooo00<0003oooooool04_ooo`006?ooo`030000oooooooo00;oool00`000?ooooooo`0Roooo00<0
003oooooool0ooooocWoool00`000?ooooooo`2<oooo00<0003oooooool04_ooo`006?ooo`030000
oooooooo02Ooool00`000?ooooooo`3ooooo>Oooo`030000oooooooo08coool00`000?ooooooo`0B
oooo000Hoooo00<0003oooooool00_ooo`030000oooooooo02;oool30000ooooocKoool00`000?oo
ooooo`2=oooo0`0001Coool001Woool500009?ooo`030000oooooooo0?oooolboooo0P0009Coool0
0`000?ooooooo`0Boooo000Moooo00<0003oooooool08_ooo`030000oooooooo0?ooooo8oooo00<0
003oooooool04_ooo`00@_ooo`030000oooooooo0?ooool_oooo0P0009Ooool00`000?ooooooo`0B
oooo000Ioooo00<0003oooooool00P0002Coool00`000?ooooooo`3ooooob?ooo`030000oooooooo
01;oool001Soool01@000?ooo`000?ooo`00000Uoooo00<0003oooooool0ooooobgoool00`000?oo
ooooo`2Hoooo00<0003oooooool04_ooo`006?ooo`030000oooo000000;oool00`000?ooooooo`0R
oooo00<0003oooooool0ooooolSoool00`000?ooooooo`0Boooo000Hoooo00<0003oool000000_oo
o`030000oooooooo02;oool00`000?ooooooo`3ooooob?ooo`030000oooooooo01;oool001Soool0
0`000?ooo`000002oooo00<0003oooooool08_ooo`<0003ooooo:_ooo`80002Joooo0`0001Coool0
01Soool2000000?oool0000000009Oooo`030000oooooooo0?ooooo8oooo00<0003oooooool04_oo
o`00@_ooo`030000oooooooo0?oooolYoooo00<0003oooooool0W?ooo`030000oooooooo01;oool0
04;oool00`000?ooooooo`3ooooo:?ooo`030000oooooooo09goool00`000?ooooooo`0Boooo000M
oooo00<0003oooooool08_ooo`030000oooooooo0?ooooo8oooo00<0003oooooool04_ooo`006?oo
o`030000oooooooo00;oool00`000?ooooooo`0Roooo00<0003oooooool0ooooobKoool00`000?oo
ooooo`2Ooooo00<0003oooooool04_ooo`006?ooo`030000oooooooo00;oool00`000?ooooooo`0R
oooo00<0003oooooool0ooooob?oool00`000?ooooooo`2Roooo00<0003oooooool04_ooo`005_oo
o`030000oooo000000D0000Toooo00<0003oooooool0ooooob?oool00`000?ooooooo`2Roooo00<0
003oooooool04_ooo`007Oooo`030000oooooooo02;oool30000ooooob3oool00`000?ooooooo`2S
oooo0`0001Coool001goool00`000?ooooooo`0Roooo00<0003oooooool0ooooob3oool00`000?oo
ooooo`2Uoooo00<0003oooooool04_ooo`007Oooo`030000oooooooo02;oool00`000?ooooooo`3o
oooob?ooo`030000oooooooo01;oool004;oool00`000?ooooooo`3ooooo7_ooo`030000oooooooo
0:Ooool00`000?ooooooo`0Boooo000Hoooo00<0003oooooool09oooo`030000oooooooo0?oooolN
oooo00<0003oooooool0Yoooo`030000oooooooo01;oool001Koool700009Oooo`030000oooooooo
0?ooooo8oooo00<0003oooooool04_ooo`006?ooo`030000oooooooo00;oool00`000?ooooooo`0R
oooo00<0003oooooool0oooooacoool00`000?ooooooo`2Yoooo00<0003oooooool04_ooo`006?oo
o`030000oooooooo00;oool00`000?ooooooo`0=oooo0P0000Coool200001?ooo`800007oooo00<0
003oooooool0oooooacoool00`000?ooooooo`2Yoooo00<0003oooooool04_ooo`006?ooo`030000
oooooooo00;oool00`000?ooooooo`0<oooo00@0003oooooool00002oooo00@0003oooooool00002
oooo00@0003oooooool00006oooo00<0003oooooool0ooooolSoool00`000?ooooooo`0Boooo000H
oooo00D0003oooooooooool000004_ooo`040000oooooooo00000_ooo`040000oooooooo00000_oo
o`030000oooooooo00Coool40000oooooaSoool20000Z_ooo`@0000Doooo000]oooo0P0000?oool0
10000?ooooooo`0000;oool010000?ooooooo`0000Koool00`000?ooooooo`3ooooo5oooo`030000
oooooooo0:koool00`000?ooooooo`0Boooo000]oooo00<0003oooooool00_ooo`040000oooooooo
00000_ooo`040000oooooooo00001_ooo`030000oooooooo0?oooolFoooo00<0003oooooool0[ooo
o`030000oooooooo01;oool001Soool00`000?ooooooo`0Boooo0`0000?oool200001?ooo`800007
oooo00<0003oooooool0oooooaCoool00`000?ooooooo`2aoooo00<0003oooooool04_ooo`006?oo
o`<00005oooo00<0003oooooool07oooo`030000oooooooo0?oooolCoooo00<0003oooooool0/_oo
o`030000oooooooo01;oool001Soool00`000?ooooooo`0200000_ooo`80000Qoooo00<0003ooooo
ool0oooooa3oool20000]_ooo`030000oooooooo01;oool001goool2000000?oool0003oool08?oo
o`030000oooooooo0?ooooo8oooo00<0003oooooool04_ooo`006?ooo`030000oooooooo0080000U
oooo00<0003oooooool0ooooo`koool00`000?ooooooo`2goooo00<0003oooooool04_ooo`006?oo
o`<0000Woooo0`000?ooooo6oooo0`0001Coool001Soool00`000?ooooooo`0Woooo00<0003ooooo
ool0ooooolSoool00`000?ooooooo`0Boooo0012oooo00<0003oooooool0ooooo`coool00`000?oo
ooooo`2ioooo00<0003oooooool04_ooo`00@_ooo`030000oooooooo0?ooooo8oooo00<0003ooooo
ool04_ooo`00@_ooo`030000oooooooo0?ooooo8oooo00<0003oooooool04_ooo`00@_ooo`030000
oooooooo0?ooool:oooo00<0003oooooool0^oooo`030000oooooooo01;oool004;oool00`000?oo
ooooo`3ooooob?ooo`030000oooooooo01;oool004;oool00`000?ooooooo`3ooooob?ooo`030000
oooooooo01;oool004;oool00`000?ooooooo`3ooooo2?ooo`030000oooooooo0;goool00`000?oo
ooooo`0Boooo0012oooo0`000?ooooo6oooo0`0001Coool004;oool00`000?ooooooo`3ooooo1Ooo
o`800031oooo00<0003oooooool04_ooo`00@_ooo`030000oooooooo0?ooooo8oooo00<0003ooooo
ool04_ooo`00@_ooo`030000oooooooo0?ooool3oooo00<0003oooooool0`_ooo`030000oooooooo
01;oool004;oool00`000?ooooooo`3ooooo0oooo`030000oooooooo0<;oool00`000?ooooooo`0B
oooo0012oooo00<0003oooooool0ooooolSoool00`000?ooooooo`0Boooo0012oooo00<0003ooooo
ool0ooooo`7oool00`000?ooooooo`34oooo00<0003oooooool04_ooo`00@_ooo`030000oooooooo
0?ooool1oooo00<0003oooooool0a?ooo`030000oooooooo01;oool004;oool30000loooo`@0003>
oooo0`0001Coool001Soool600009?ooo`030000oooooooo0?Goool00`000?ooooooo`06oooo00<0
003oooooool0a_ooo`030000oooooooo01;oool001Koool200001_ooo`80000Roooo00<0003ooooo
ool0l_ooo`D00007oooo00<0003oooooool0a_ooo`030000oooooooo01;oool001Goool00`000?oo
ooooo`08oooo00<0003oooooool07oooo`030000oooooooo0?;oool50000d?ooo`030000oooooooo
01;oool004;oool00`000?ooooooo`3boooo1@0000Goool00`000?ooooooo`38oooo00<0003ooooo
ool04_ooo`00@_ooo`030000oooooooo0?;oool500001Oooo`030000oooooooo0<Soool00`000?oo
ooooo`0Boooo000Ioooo00@0003oool00000000Uoooo00<0003oooooool0l_ooo`D0003@oooo00<0
003oooooool04_ooo`006?ooo`030000oooo000000;oool00`000?ooooooo`0Roooo00<0003ooooo
ool0loooo`@00004oooo00<0003oooooool0bOooo`030000oooooooo01;oool001Soool00`000?oo
o`000002oooo00<0003oooooool08_ooo`030000oooooooo0?[oool00`000?ooooooo`3:oooo00<0
003oooooool04_ooo`006?ooo`030000oooo000000;oool00`000?ooooooo`0Roooo0`000?ooooo6
oooo0`0001Coool001Soool01@000?ooo`000?ooo`00000Uoooo00<0003oooooool0nOooo`030000
oooooooo0<_oool00`000?ooooooo`0Boooo000Ioooo1@0002Coool00`000?ooooooo`3ioooo00<0
003oooooool0boooo`030000oooooooo01;oool001goool00`000?ooooooo`0Roooo00<0003ooooo
ool0ooooolSoool00`000?ooooooo`0Boooo0012oooo00<0003oooooool0moooo`030000oooooooo
0<goool00`000?ooooooo`0Boooo000Hoooo00<0003oooooool00_ooo`030000oooooooo02;oool0
0`000?ooooooo`3Woooo100000coool00`000?ooooooo`3=oooo00<0003oooooool04_ooo`006?oo
o`H0000@oooo00<0003oooooool00_ooo`800004oooo0P0000Ooool00`000?ooooooo`3Xoooo00<0
003oooooool0g?ooo`030000oooooooo01;oool001Woool01@000?ooooooooooo`00000@oooo00D0
003oooooooooool000000_ooo`040000oooooooo00000_ooo`030000oooooooo00Coool00`000?oo
ooooo`3Voooo1@0000[oool00`000?ooooooo`3?oooo00<0003oooooool04_ooo`006?ooo`030000
oooooooo00;oool00`000?ooooooo`0>oooo00<0003oooooool01?ooo`040000oooooooo00000_oo
o`030000oooooooo00Coool40000iOooo`D0000:oooo00<0003oooooool0c?ooo`@0000Doooo000H
oooo00<0003oooooool00_ooo`030000oooooooo00ooool010000?ooooooooooo`800003oooo00@0
003oooooool00006oooo00<0003oooooool0i_ooo`D0003Loooo00<0003oooooool04_ooo`006?oo
o`030000oooooooo017oool010000?ooooooo`0000?oool00`000?ooooooo`02oooo00@0003ooooo
ool00006oooo00<0003oooooool0i_ooo`D00008oooo00<0003oooooool0dOooo`030000oooooooo
01;oool002coool400000oooo`<00003oooo0P0000Ooool00`000?ooooooo`3Voooo1@000=coool0
0`000?ooooooo`0Boooo000Eoooo00<0003oooooool01Oooo`030000oooooooo02;oool00`000?oo
ooooo`3Woooo100000Goool00`000?ooooooo`3Doooo00<0003oooooool04_ooo`005Oooo`T0000T
oooo00<0003oooooool0ooooolSoool00`000?ooooooo`0Boooo000Ioooo00@0003oooooool0000U
oooo00<0003oooooool0k_ooo`030000oooooooo0=Koool00`000?ooooooo`0Boooo000Hoooo00<0
003oooooool00_ooo`030000oooooooo02;oool00`000?ooooooo`3]oooo00<0003oooooool0eooo
o`030000oooooooo01;oool001Soool00`000?ooooooo`02oooo00<0003oooooool08_ooo`030000
oooooooo0>_oool00`000?ooooooo`3Ioooo00<0003oooooool04_ooo`006?ooo`030000oooooooo
00;oool00`000?ooooooo`0Roooo0`000>[oool00`000?ooooooo`3Hoooo0`0001Coool001Woool4
00009Oooo`030000oooooooo0?ooooo8oooo00<0003oooooool04_ooo`00@_ooo`030000oooooooo
0>Soool00`000?ooooooo`3Loooo00<0003oooooool04_ooo`00@_ooo`030000oooooooo0=[oool4
0000jOooo`030000oooooooo01;oool001goool00`000?ooooooo`0Roooo00<0003oooooool0g?oo
o`030000oooooooo00Koool00`000?ooooooo`3Ooooo00<0003oooooool04_ooo`006?ooo`030000
oooooooo00;oool00`000?ooooooo`0Roooo00<0003oooooool0fOooo`D0003Yoooo00<0003ooooo
ool04_ooo`006?ooo`030000oooooooo00;oool00`000?ooooooo`0Roooo00<0003oooooool0fOoo
o`D00005oooo00<0003oooooool0hOooo`030000oooooooo01;oool001Koool00`000?ooo`000005
00009?ooo`030000oooooooo0=Woool500001?ooo`030000oooooooo0>;oool00`000?ooooooo`0B
oooo000Moooo00<0003oooooool08_ooo`<0003Ioooo1@000>Ooool300005?ooo`007Oooo`030000
oooooooo02;oool00`000?ooooooo`3Ioooo1@0000;oool00`000?ooooooo`3Toooo00<0003ooooo
ool04_ooo`007Oooo`030000oooooooo02;oool00`000?ooooooo`3Joooo10000>Woool00`000?oo
ooooo`0Boooo0012oooo00<0003oooooool0g_ooo`030000oooooooo0>Koool00`000?ooooooo`0B
oooo000Hoooo00<0003oooooool09oooo`030000oooooooo0?ooooo8oooo00<0003oooooool04_oo
o`005_ooo`L0000Uoooo00<0003oooooool0ooooolSoool00`000?ooooooo`0Boooo000Hoooo00<0
003oooooool00_ooo`030000oooooooo02;oool00`000?ooooooo`3Koooo00<0003oooooool0jOoo
o`030000oooooooo01;oool001Soool00`000?ooooooo`02oooo00<0003oooooool08_ooo`030000
oooooooo0?ooooo8oooo00<0003oooooool04_ooo`006?ooo`030000oooooooo00;oool00`000?oo
ooooo`0Roooo00<0003oooooool0f?ooo`80003]oooo00<0003oooooool04_ooo`006?ooo`050000
oooooooooooo000002Goool30000ooooolKoool300005?ooo`00@_ooo`030000oooooooo0=Koool0
0`000?ooooooo`3^oooo00<0003oooooool04_ooo`00@_ooo`030000oooooooo0<koool400001?oo
o`030000oooooooo0>koool00`000?ooooooo`0Boooo000Hoooo00<0003oooooool00_ooo`030000
oooooooo02;oool00`000?ooooooo`3?oooo00<0003oooooool0mOooo`030000oooooooo01;oool0
01Soool600009?ooo`030000oooooooo0<goool5000000?oool000000000l_ooo`030000oooooooo
01;oool001Woool01@000?ooooooooooo`00000Toooo00<0003oooooool0cOooo`D0003eoooo00<0
003oooooool04_ooo`006?ooo`030000oooooooo00;oool00`000?ooooooo`0Roooo00<0003ooooo
ool0cOooo`D0003eoooo00<0003oooooool04_ooo`006?ooo`030000oooooooo00;oool00`000?oo
ooooo`0Roooo00<0003oooooool0cOooo`D0003eoooo00<0003oooooool04_ooo`006?ooo`030000
oooooooo02Ooool30000cOooo`D0003coooo0`0001Coool004;oool00`000?ooooooo`3>oooo1000
0?Goool00`000?ooooooo`0Boooo0012oooo00<0003oooooool0ooooolSoool00`000?ooooooo`0B
oooo000Ioooo00@0003oool00000000Uoooo00<0003oooooool0boooo`80003joooo00<0003ooooo
ool04_ooo`006?ooo`030000oooo000000;oool00`000?ooooooo`0Roooo00<0003oooooool0oooo
olSoool00`000?ooooooo`0Boooo000Hoooo00<0003oool000000_ooo`030000oooooooo02;oool0
0`000?ooooooo`39oooo00<0003oooooool0noooo`030000oooooooo01;oool001Soool00`000?oo
o`000002oooo00<0003oooooool01_ooo`D00002oooo0P0000Coool200001?ooo`800007oooo00<0
003oooooool0ooooolSoool00`000?ooooooo`0Boooo000Hoooo00D0003oool0003oool000002ooo
o`050000oooooooooooo000000;oool010000?ooooooo`0000;oool010000?ooooooo`0000;oool0
0`000?ooooooo`04oooo00<0003oooooool0a_ooo`030000oooooooo0?koool00`000?ooooooo`0B
oooo000Ioooo1@0000[oool01@000?ooooooooooo`000002oooo00@0003oooooool00002oooo00@0
003oooooool00002oooo00<0003oooooool01?ooo`@0003oooooa?ooo`@0000Doooo000Moooo00<0
003oooooool02?ooo`050000oooooooooooo000000;oool010000?ooooooo`0000;oool010000?oo
ooooo`0000;oool00`000?ooooooo`04oooo00<0003oooooool0a?ooo`030000oooooooo0?ooool1
oooo00<0003oooooool04_ooo`00:?ooo`050000oooooooooooo000000;oool010000?ooooooo`00
00;oool010000?ooooooo`0000;oool00`000?ooooooo`04oooo00<0003oooooool0`oooo`030000
oooooooo0?ooool2oooo00<0003oooooool04_ooo`006?ooo`030000oooooooo00;oool00`000?oo
ooooo`07oooo0P0000Coool200001?ooo`800004oooo0P0000Ooool00`000?ooooooo`3ooooob?oo
o`030000oooooooo01;oool001Soool600009?ooo`030000oooooooo0<7oool40000ooooo`?oool0
0`000?ooooooo`0Boooo000Ioooo00D0003oooooooooool000009?ooo`030000oooooooo0<?oool0
0`000?ooooooo`3ooooo0_ooo`030000oooooooo01;oool001Soool00`000?ooooooo`02oooo00<0
003oooooool08_ooo`030000oooooooo0;koool00`000?ooo`0000040000ooooo`?oool00`000?oo
ooooo`0Boooo000Hoooo00<0003oooooool00_ooo`030000oooooooo02;oool00`000?ooooooo`30
oooo1@000?ooool3oooo00<0003oooooool04_ooo`006?ooo`030000oooooooo02Ooool00`000?oo
ooooo`2loooo00@0003oooooooooool50000ooooo`?oool00`000?ooooooo`0Boooo0012oooo0`00
0;coool010000?ooooooooooo`D0003ooooo0Oooo`<0000Doooo0012oooo00<0003oooooool0`?oo
o`D0003ooooo0oooo`030000oooooooo01;oool001Soool00`000?ooooooo`0Woooo00<0003ooooo
ool0^Oooo`800008oooo00<0003oooooool0ooooo`;oool00`000?ooooooo`0Boooo000Hoooo0`00
00Goool00`000?ooooooo`0Ooooo00<0003oooooool0`Oooo`@0003ooooo0oooo`030000oooooooo
01;oool001Soool00`000?ooooooo`0200000_ooo`80000Qoooo00<0003oooooool0]oooo`030000
oooooooo0?ooool>oooo00<0003oooooool04_ooo`007Oooo`8000000oooo`000?ooo`0Poooo00<0
003oooooool0]oooo`030000oooooooo0?ooool>oooo00<0003oooooool04_ooo`006?ooo`030000
oooooooo0080000Uoooo00<0003oooooool0ooooolSoool00`000?ooooooo`0Boooo000Hoooo0`00
02Ooool00`000?ooooooo`2doooo0P000?oooolBoooo00<0003oooooool04_ooo`006?ooo`030000
oooooooo02Ooool30000ooooolKoool300005?ooo`00@_ooo`030000oooooooo0;;oool00`000?oo
ooooo`040000ooooo`ooool00`000?ooooooo`0Boooo0012oooo00<0003oooooool0]_ooo`030000
oooooooo0?ooool?oooo00<0003oooooool04_ooo`00@_ooo`030000oooooooo0:ooool00`000?oo
ooooo`02oooo1@000?ooool?oooo00<0003oooooool04_ooo`00@_ooo`030000oooooooo0:ooool0
0`000?ooooooo`02oooo1@000?ooool?oooo00<0003oooooool04_ooo`00@_ooo`030000oooooooo
0;Coool50000ooooo`ooool00`000?ooooooo`0Boooo0012oooo00<0003oooooool0[?ooo`800006
oooo1@000?ooool?oooo00<0003oooooool04_ooo`00@_ooo`030000oooooooo0;Coool50000oooo
o`ooool00`000?ooooooo`0Boooo0012oooo00<0003oooooool0Z_ooo`030000oooooooo00Soool4
0000ooooo`ooool00`000?ooooooo`0Boooo0012oooo0`000?ooooo6oooo0`0001Coool004;oool0
0`000?ooooooo`2Woooo00<0003oooooool0oooooakoool00`000?ooooooo`0Boooo0012oooo00<0
003oooooool0Yoooo`030000oooooooo0?oooolNoooo00<0003oooooool04_ooo`00@_ooo`030000
oooooooo0?ooooo8oooo00<0003oooooool04_ooo`00@_ooo`030000oooooooo0:Coool200000ooo
o`@0003ooooo6oooo`030000oooooooo01;oool001Soool00`000?ooooooo`0Woooo00<0003ooooo
ool0Z_ooo`030000oooooooo0?oooolKoooo00<0003oooooool04_ooo`006?ooo`D0000Uoooo00<0
003oooooool0X_ooo`030000oooooooo00?oool50000oooooa_oool00`000?ooooooo`0Boooo000M
oooo00<0003oooooool08_ooo`030000oooooooo0:Soool50000oooooa_oool00`000?ooooooo`0B
oooo000Moooo00<0003oooooool08_ooo`<0002Ooooo00<0003oooooool01_ooo`D0003ooooo6Ooo
o`<0000Doooo000Hoooo00D0003oooooooooool000009Oooo`030000oooooooo0:Soool50000oooo
oa_oool00`000?ooooooo`0Boooo000Hoooo1P0002Coool00`000?ooooooo`2Loooo00<0003ooooo
ool02Oooo`D0003ooooo6oooo`030000oooooooo01;oool001goool00`000?ooooooo`0Roooo00<0
003oooooool0ZOooo`@0003ooooo6oooo`030000oooooooo01;oool004;oool00`000?ooooooo`2J
oooo00<0003oool000000`000?oooolXoooo00<0003oooooool04_ooo`006?ooo`030000oooooooo
00;oool00`000?ooooooo`0Roooo00<0003oooooool0VOooo`030000oooooooo00;oool00`000?oo
ooooo`3ooooo9oooo`030000oooooooo01;oool001Soool600009?ooo`030000oooooooo09Ooool0
10000?ooooooooooo`D0003ooooo:?ooo`030000oooooooo01;oool001Soool00`000?ooooooo`02
oooo00<0003oooooool01_ooo`D000000oooo`000000000200000oooo`800004oooo0P0000Ooool0
0`000?ooooooo`2Goooo00@0003oooooooooool50000ooooobSoool00`000?ooooooo`0Boooo000H
oooo00<0003oooooool03Oooo`050000oooooooooooo000000Goool010000?ooooooo`0000;oool0
10000?ooooooo`0000Koool00`000?ooooooo`2Koooo1@000?oooolXoooo00<0003oooooool04_oo
o`006?ooo`030000oooooooo00;oool00`000?ooooooo`08oooo00<0003oooooool00_ooo`030000
oooooooo00Goool010000?ooooooo`0000;oool00`000?ooooooo`04oooo100009?oool00`000?oo
ooooo`04oooo1@000?oooolUoooo100001Coool001Woool500002_ooo`030000oooooooo00?oool0
0`000?ooooooo`02oooo0P0000?oool010000?ooooooo`0000Koool00`000?ooooooo`2Koooo1@00
0?oooolXoooo00<0003oooooool04_ooo`007Oooo`030000oooooooo00Soool01@000?oooooooooo
o`000002oooo00D0003oooooooooool000001?ooo`040000oooooooo00001_ooo`030000oooooooo
097oool200002Oooo`@0003ooooo:?ooo`030000oooooooo01;oool002Ooool200001?ooo`800004
oooo0`0000?oool200001oooo`030000oooooooo0?ooooo8oooo00<0003oooooool04_ooo`007Ooo
o`030000oooooooo02;oool00`000?ooooooo`2?oooo1@000?ooooldoooo00<0003oooooool04_oo
o`006?ooo`030000oooooooo00;oool00`000?ooooooo`0Roooo00<0003oooooool0TOooo`030000
oooooooo0?ooooldoooo00<0003oooooool04_ooo`006?ooo`030000oooooooo00;oool00`000?oo
ooooo`0Roooo00<0003oooooool0S?ooo`030000oooooooo00D0003ooooo=?ooo`030000oooooooo
01;oool001Koool00`000?ooo`00000500009?ooo`030000oooooooo08?oool400001Oooo`030000
oooooooo00D0003ooooo=?ooo`030000oooooooo01;oool001goool00`000?ooooooo`0Roooo0`00
08Goool01@000?ooooooooooo`000005oooo1@000?oooolboooo0`0001Coool001goool00`000?oo
ooooo`0Roooo00<0003oooooool0QOooo`050000oooooooooooo000000Goool50000ooooocCoool0
0`000?ooooooo`0Boooo000Moooo00<0003oooooool08_ooo`030000oooooooo08Goool00`000?oo
ooooo`07oooo1@000?ooooldoooo00<0003oooooool04_ooo`00@_ooo`030000oooooooo08Goool3
00002?ooo`@0003ooooo=?ooo`030000oooooooo01;oool001Soool00`000?ooooooo`0Woooo00<0
003oooooool0P_ooo`D0003ooooo@Oooo`030000oooooooo01;oool001Koool700009Oooo`030000
oooooooo08;oool50000oooood7oool00`000?ooooooo`0Boooo000Hoooo00<0003oooooool00_oo
o`030000oooooooo02;oool00`000?ooooooo`22oooo1@000?oooom1oooo00<0003oooooool04_oo
o`006?ooo`030000oooooooo00;oool00`000?ooooooo`0Roooo00<0003oooooool0Moooo`@00006
oooo1P000?oooom1oooo00<0003oooooool04_ooo`006?ooo`030000oooooooo00;oool00`000?oo
ooooo`0Roooo00<0003oooooool0J_ooo`@0000:oooo00<0003oooooool01oooo`D0003ooooo@Ooo
o`030000oooooooo01;oool001Soool01@000?ooooooooooo`00000Uoooo0`0006coool00`000?oo
ooooo`09oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`3ooooo?_oo
o`<0000Doooo0012oooo00<0003oooooool0K?ooo`030000oooooooo00Woool00`000?ooooooo`0:
oooo00<0003oooooool0oooood3oool00`000?ooooooo`0Boooo0012oooo00<0003oooooool0K?oo
o`030000oooooooo00Woool010000?ooooooo`0000Woool00`000?ooooooo`3ooooo@?ooo`030000
oooooooo01;oool001Woool00`000?ooooooo`0200009?ooo`030000oooooooo06coool00`000?oo
ooooo`07oooo1@0000Soool40000oooood7oool00`000?ooooooo`0Boooo000Hoooo00D0003oool0
003oool000009Oooo`030000oooooooo06Woool500002?ooo`D0003oooooCOooo`030000oooooooo
01;oool001Soool00`000?ooo`000002oooo00<0003oooooool08_ooo`030000oooooooo06Woool5
00002?ooo`D0003oooooCOooo`030000oooooooo01;oool001Soool00`000?ooo`000002oooo00<0
003oooooool08_ooo`030000oooooooo06Woool500001oooo`H0003oooooCOooo`030000oooooooo
01;oool001Soool00`000?ooo`000002oooo00<0003oooooool08_ooo`030000oooooooo06Woool5
00002?ooo`D0003oooooCOooo`030000oooooooo01;oool001Soool2000000?oool0000000009Ooo
o`<0001Yoooo1@0000Coool200001?ooo`030000oooooooo0?oooom;oooo0`0001Coool004;oool0
0`000?ooooooo`1/oooo00<0003oooooool02Oooo`030000oooooooo0?oooom=oooo00<0003ooooo
ool04_ooo`00@_ooo`030000oooooooo06coool00`000?ooooooo`0200001oooo`030000oooooooo
0?oooom=oooo00<0003oooooool04_ooo`00@_ooo`030000oooooooo06coool200002Oooo`@0003o
ooooCOooo`030000oooooooo01;oool004;oool00`000?ooooooo`0ioooo100002goool40000oooo
oe[oool00`000?ooooooo`0Boooo000Eoooo00<0003oooooool02?ooo`030000oooooooo01ooool0
0`000?ooooooo`0joooo00<0003oooooool08Oooo`@00007oooo0P000?oooomMoooo00<0003ooooo
ool04_ooo`005_ooo`800006oooo0P0002;oool00`000?ooooooo`0joooo00<0003oooooool08_oo
o`030000oooooooo0?oooomVoooo00<0003oooooool04_ooo`006?ooo`H0000Toooo00<0003ooooo
ool0>_ooo`030000oooooooo00Soool400005_ooo`030000oooooooo00Coool20000ooooof3oool0
0`000?ooooooo`0Boooo0012oooo0`0003[oool00`000?ooooooo`09oooo00<0003oooooool05_oo
o`030000oooooooo0?oooomToooo0`0001Coool004;oool00`000?ooooooo`0Poooo100001Koool0
0`000?ooooooo`09oooo00<0003oooooool02?ooo`@0000:oooo00@0003oooooooooool20000oooo
of?oool00`000?ooooooo`0Boooo0012oooo00<0003oooooool08Oooo`030000oooooooo01Coool5
00002Oooo`030000oooooooo00[oool00`000?ooooooo`07oooo1@000?oooomVoooo00<0003ooooo
ool04_ooo`00@_ooo`030000oooooooo027oool00`000?ooooooo`0Doooo1@0000Woool00`000?oo
ooooo`0:oooo00<0003oooooool01oooo`D0003oooooI_ooo`030000oooooooo01;oool004;oool0
0`000?ooooooo`0Qoooo00<0003oooooool05?ooo`D00009oooo00<0003oooooool02_ooo`030000
oooooooo00Ooool50000ooooofKoool00`000?ooooooo`0Boooo0012oooo00<0003oooooool08Ooo
o`030000oooooooo00Soool400002?ooo`D00007oooo1@0000[oool00`000?ooooooo`07oooo1@00
0?oooomVoooo00<0003oooooool04_ooo`00@_ooo`030000oooooooo027oool00`000?ooooooo`0:
oooo00<0003oooooool01oooo`D00007oooo1@0000[oool00`000?ooooooo`04oooo0P000003oooo
0000000000<0003oooooI_ooo`030000oooooooo01;oool002Koool500000_ooo`800004oooo0P00
00Coool200001oooo`030000oooooooo01ooool500002_ooo`030000oooooooo00Woool00`000?oo
ooooo`07oooo1@0000Ooool500000_ooo`030000oooooooo00Goool00`000?ooooooo`3oooooI_oo
o`030000oooooooo01;oool002Soool01@000?ooooooooooo`000002oooo00@0003oooooool00002
oooo00@0003oooooool00002oooo00<0003oooooool01?ooo`030000oooooooo01ooool500002_oo
o`030000oooooooo00Woool00`000?ooooooo`07oooo1@0000Ooool500000_ooo`030000oooooooo
00Goool00`000?ooooooo`3oooooI_ooo`030000oooooooo01;oool002Soool00`000?ooooooo`04
oooo00@0003oooooool00002oooo00@0003oooooool00002oooo00<0003oooooool01?ooo`@0000N
oooo1@0000[oool00`000?ooooooo`09oooo00<0003oooooool01oooo`D00007oooo1@0000[oool0
0`000?ooooooo`3oooooHoooo`@0000Doooo000Xoooo00<0003oooooool00_ooo`800003oooo00@0
003oooooool00002oooo00@0003oooooool00006oooo00<0003oooooool07oooo`D0000:oooo00<0
003oooooool02?ooo`@00009oooo00<0003oooooool01oooo`D00009oooo10000?oooomVoooo00<0
003oooooool04_ooo`00:?ooo`030000oooooooo00;oool00`000?ooooooo`02oooo00@0003ooooo
ool00002oooo00@0003oooooool00006oooo00<0003oooooool07oooo`D00007oooo1@0001Koool0
0`000?ooooooo`07oooo1@000?oooomcoooo00<0003oooooool04_ooo`009oooo`800004oooo0`00
00?oool200001?ooo`800007oooo00<0003oooooool08Oooo`030000oooooooo00Ooool500005_oo
o`030000oooooooo00Coool200001?ooo`030000oooooooo0?oooomboooo00<0003oooooool04_oo
o`00@_ooo`030000oooooooo027oool00`000?ooooooo`07oooo1@0001Goool400000_ooo`030000
oooooooo00Goool00`000?ooooooo`3oooooL_ooo`030000oooooooo01;oool004;oool00`000?oo
ooooo`0Qoooo00<0003oooooool01oooo`D0000Joooo00<0003oooooool01_ooo`030000oooooooo
0?oooomboooo00<0003oooooool04_ooo`00@_ooo`030000oooooooo023oool400001oooo`D0000G
oooo00<0003oooooool01oooo`@0003oooooLoooo`030000oooooooo01;oool004;oool00`000?oo
ooooo`0^oooo00<0003oooooool04oooo`030000oooooooo0?oooon1oooo00<0003oooooool04_oo
o`00@_ooo`<0000^oooo00<0003oooooool03oooo`80003oooooQ?ooo`<0000Doooo0012oooo00<0
003oooooool0;_ooo`030000oooooooo00coool20000ooooohWoool00`000?ooooooo`0Boooo0012
oooo00<0003oooooool0;?ooo`@0000:oooo00<0003oooooool0oooooh_oool00`000?ooooooo`0B
oooo0012oooo00<0003oooooool0=_ooo`80003oooooT?ooo`030000oooooooo01;oool004;oool0
0`000?ooooooo`0coooo00<0003oooooool0oooooi;oool00`000?ooooooo`0Boooo0012oooo00<0
003oooooool0;Oooo`040000oooooooo0000oooooiOoool00`000?ooooooo`0Boooo0012oooo00<0
003oooooool0:Oooo`040000oooooooo0000oooooi_oool00`000?ooooooo`0Boooo0012oooo00<0
003oooooool06oooo`030000oooooooo00800002oooo00<0003oooooool00P000?oooonQoooo00<0
003oooooool04_ooo`00@_ooo`030000oooooooo013oool200000_ooo`030000oooooooo0080003o
oooo[oooo`030000oooooooo01;oool004;oool30000ooooolKoool300005?ooo`00@_ooo`030000
oooooooo0?ooooo8oooo00<0003oooooool04_ooo`00@_ooo`030000oooooooo00Soool00`000?oo
ooooo`0koooo00<0003oooooool0??ooo`030000oooooooo03_oool00`000?ooooooo`0koooo00<0
003oooooool0>oooo`030000oooooooo03coool00`000?ooooooo`0koooo00<0003oooooool02?oo
o`030000oooooooo01;oool004;oool00`000?ooooooo`08oooo00<0003oooooool0>oooo`030000
oooooooo03coool00`000?ooooooo`0koooo00<0003oooooool0>oooo`030000oooooooo03_oool0
0`000?ooooooo`0loooo00<0003oooooool0>oooo`030000oooooooo00Soool00`000?ooooooo`0B
oooo0012oooo00<0003oooooool02?ooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0
003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02_oo
o`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo
00[oool00`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?oo
ooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0
003oooooool02Oooo`030000oooooooo00[oool00`000?ooooooo`09oooo00<0003oooooool02_oo
o`030000oooooooo00Woool00`000?ooooooo`09oooo00<0003oooooool02_ooo`030000oooooooo
00Woool00`000?ooooooo`0:oooo00<0003oooooool02Oooo`030000oooooooo00[oool00`000?oo
ooooo`09oooo00<0003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`09oooo00<0
003oooooool02_ooo`030000oooooooo00Woool00`000?ooooooo`0:oooo00<0003oooooool02?oo
o`030000oooooooo01;oool004;ooooo0000c00001Coool00?oooooooooo8oooo`00oooooooooolS
oooo003oooooooooob?oool00?oooooooooo8oooo`00oooooooooolSoooo003oooooooooob?oool0
0?oooooooooo8oooo`00/?ooo`D0001Moooo10000=koool50000:?ooo`00/oooo`030000oooooooo
063oool00`000?ooooooo`3Noooo00<0003oooooool09oooo`00]?ooo`030000oooooooo063oool0
0`000?ooooooo`3Noooo00<0003oooooool09_ooo`00]?ooo`030000oooooooo063oool00`000?oo
ooooo`3Noooo00<0003oooooool09_ooo`00DOooo`L00005oooo0`0000?oool300001_ooo`@00007
oooo1@0000Goool300000oooo`<00003oooo00<0003oool000000`0000Goool900001oooo`@00008
oooo0P0001Koool200001oooo`030000oooo000000<00008oooo0`00017oool400001?ooo`@00002
oooo0`0000?oool300001Oooo`<000000oooo`000?ooo`04oooo2@0000Goool500001oooo`<0000C
oooo1`0000Koool5000000?oool0000000001_ooo`@00006oooo1@000003oooo00000000013oool5
000000?oool0000000000oooo`<00003oooo0`0000Coool400000_ooo`80000@oooo1@0000Koool3
00000oooo`<00005oooo1@0000Ooool500001_ooo`H00008oooo0P0002Ooool005Coool00`000?oo
ooooo`07oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`02oooo0P00
00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?oo
ooooo`02oooo0P0000Coool00`000?ooooooo`06oooo00<0003oooooool02?ooo`030000oooooooo
00;oool200001_ooo`80000Foooo0P0000Ooool200001?ooo`030000oooooooo00Goool300004_oo
o`030000oooooooo00Koool00`000?ooooooo`02oooo00<0003oooooool00oooo`030000oooooooo
00?oool010000?ooooooooooo`800009oooo00<0003oooooool01_ooo`030000oooooooo00?oool0
0`000?ooooooo`04oooo0`0001Coool00`000?ooooooo`03oooo00<0003oooooool00_ooo`030000
oooooooo00?oool200001_ooo`030000oooooooo00;oool200000oooo`030000oooooooo00?oool2
00004?ooo`030000oooooooo00?oool200001Oooo`030000oooooooo00?oool00`000?ooooooo`02
oooo00<0003oooooool00_ooo`<0000Coooo00<0003oooooool01oooo`030000oooooooo00?oool0
0`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`03
oooo00<0003oooooool01?ooo`030000oooooooo00[oool200009oooo`00E?ooo`030000oooooooo
00Ooool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00Ooool00`000?oo
ooooo`0:oooo00<0003oooooool00oooo`030000oooooooo00;oool00`000?ooooooo`04oooo00<0
003oooooool01Oooo`030000oooooooo00Soool00`000?ooooooo`09oooo00@0003oooooool0000D
oooo00@0003oooooool00006oooo00<0003oooooool01?ooo`030000oooooooo00Coool300004ooo
o`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000oooooooo
00;oool00`000?ooooooo`03oooo00<0003oooooool01oooo`030000oooooooo00Goool00`000?oo
ooooo`0;oooo0`0001Coool00`000?ooooooo`03oooo00<0003oooooool00_ooo`030000oooooooo
00Coool00`000?ooooooo`04oooo00<0003oooooool01oooo`030000oooooooo00Coool00`000?oo
ooooo`0>oooo00<0003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00D0
003oooooooooool000001oooo`030000oooooooo017oool00`000?ooooooo`07oooo00<0003ooooo
ool00oooo`030000oooooooo00;oool00`000?ooooooo`09oooo00<0003oooooool01Oooo`030000
oooooooo00?oool00`000?ooooooo`09oooo00@0003oooooool0000Voooo001Doooo00<0003ooooo
ool01oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool01oooo`030000
oooooooo00[oool00`000?ooooooo`03oooo00<0003oooooool02Oooo`030000oooooooo00Goool0
0`000?ooooooo`08oooo00<0003oooooool02Oooo`040000oooooooo00005?ooo`040000oooooooo
00003Oooo`030000oooooooo01[oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000
oooooooo00?oool00`000?ooooooo`02oooo00<0003oooooool00oooo`030000oooooooo00Ooool0
0`000?ooooooo`05oooo00<0003oooooool08_ooo`030000oooooooo00Coool00`000?ooooooo`02
oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`08oooo00<0003ooooo
ool00oooo`030000oooooooo00ooool00`000?ooooooo`03oooo00<0003oooooool00oooo`030000
oooooooo00?oool01@000?ooooooooooo`000007oooo00<0003oooooool04Oooo`030000oooooooo
00Ooool00`000?ooooooo`03oooo00<0003oooooool00_ooo`030000oooooooo00Woool00`000?oo
ooooo`05oooo00<0003oooooool00oooo`030000oooooooo00Woool010000?ooooooo`0002Koool0
05Coool00`000?ooooooo`07oooo00<0003oooooool00oooo`030000oooooooo00Coool00`000?oo
ooooo`07oooo200000Goool00`000?ooooooo`03oooo00<0003oooooool02?ooo`030000oooooooo
00Koool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00;oool00`000?oo
ooooo`0@oooo00<0003oooooool00_ooo`030000oooooooo00Woool00`000?ooooooo`0Koooo2000
00Goool00`000?ooooooo`03oooo00<0003oooooool00_ooo`030000oooooooo00?oool00`000?oo
ooooo`07oooo00<0003oooooool01Oooo`P0000Moooo00<0003oooooool01?ooo`030000oooooooo
00?oool600001_ooo`030000oooooooo00Woool600004_ooo`H00005oooo00<0003oooooool00ooo
o`050000oooooooooooo000000Ooool00`000?ooooooo`0Aoooo00<0003oooooool01oooo`030000
oooooooo00?oool00`000?ooooooo`02oooo200000Coool00`000?ooooooo`05oooo00<0003ooooo
ool00oooo`030000oooooooo00Soool00`000?ooooooo`02oooo00<0003oooooool08oooo`00E?oo
o`030000oooooooo00Ooool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo
00Ooool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo00?oool00`000?oo
ooooo`03oooo1@0000Woool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00;oool00`000?ooooooo`0@oooo00<0003oooooool00_ooo`030000oooooooo00Coool500007ooo
o`030000oooooooo00;oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo
00;oool00`000?ooooooo`03oooo00<0003oooooool01oooo`030000oooooooo00Goool00`000?oo
ooooo`04oooo00<0003oooooool06oooo`030000oooooooo00Coool00`000?ooooooo`08oooo00<0
003oooooool01?ooo`030000oooooooo00koool00`000?ooooooo`0Eoooo00<0003oooooool00ooo
o`030000oooooooo00?oool01@000?ooooooooooo`000007oooo00<0003oooooool04Oooo`030000
oooooooo00Ooool00`000?ooooooo`03oooo00<0003oooooool00_ooo`030000oooooooo00Coool0
0`000?ooooooo`02oooo00<0003oooooool01Oooo`030000oooooooo00?oool00`000?ooooooo`08
oooo00<0003oooooool00_ooo`030000oooooooo02?oool005Coool00`000?ooooooo`07oooo00<0
003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`07oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool00_ooo`030000oooooooo
00Coool00`000?ooooooo`05oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?oo
ooooo`03oooo00<0003oooooool04?ooo`030000oooooooo00;oool00`000?ooooooo`03oooo00<0
003oooooool01?ooo`030000oooooooo01_oool00`000?ooooooo`02oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`02oooo00<0003oooooool00oooo`030000oooooooo
00Ooool00`000?ooooooo`05oooo00<0003oooooool01?ooo`030000oooooooo00Coool300005?oo
o`030000oooooooo00Coool00`000?ooooooo`08oooo00<0003oooooool01?ooo`030000oooooooo
00koool00`000?ooooooo`0Eoooo00<0003oooooool00oooo`030000oooooooo00?oool01@000?oo
ooooooooo`000007oooo00<0003oooooool04Oooo`030000oooooooo00Ooool00`000?ooooooo`03
oooo00<0003oooooool00_ooo`030000oooooooo00Coool00`000?ooooooo`02oooo00<0003ooooo
ool01Oooo`030000oooooooo00?oool200002?ooo`030000oooooooo00?oool00`000?ooooooo`0S
oooo001Doooo00<0003oooooool01oooo`800003oooo00<0003oooooool01Oooo`030000oooooooo
00Soool00`000?ooooooo`02oooo00<0003oooooool01?ooo`800003oooo00<0003oooooool00ooo
o`030000oooooooo00?oool200001oooo`030000oooooooo00Soool00`000?ooooooo`07oooo00<0
003oooooool01?ooo`030000oooooooo00koool00`000?ooooooo`04oooo00<0003oooooool00_oo
o`030000oooooooo00?oool200007_ooo`040000oooooooo00001oooo`800003oooo00<0003ooooo
ool01?ooo`040000oooooooooooo0P0000Woool00`000?ooooooo`06oooo00<0003oooooool00_oo
o`030000oooooooo00Goool300005?ooo`030000oooooooo00Coool00`000?ooooooo`02oooo00<0
003oooooool00oooo`030000oooooooo00Coool00`000?ooooooo`08oooo00<0003oooooool00ooo
o`030000oooooooo00ooool00`000?ooooooo`03oooo00<0003oooooool00oooo`800003oooo00<0
003oooooool00oooo`030000oooooooo00;oool300004oooo`030000oooooooo00Ooool200000ooo
o`030000oooooooo00Coool00`000?ooooooo`02oooo00<0003oooooool01?ooo`030000oooooooo
00?oool00`000?ooooooo`04oooo00<0003oool000000oooo`050000oooooooooooo000000Koool0
0`000?ooooooo`0Roooo001Doooo00<0003oooooool01_ooo`8000001?ooo`000000000000Koool8
00001_ooo`@00006oooo0P000004oooo0000000000001oooo`D000000oooo`000?ooo`03oooo1000
00Soool800000_ooo`@00004oooo100000coool400001?ooo`@00003oooo1@000003oooo0000oooo
01goool010000?ooooooo`0000Koool2000000Coool0000000000008oooo0`000003oooo00000000
00Soool00`000?ooooooo`07oooo100000Soool300005?ooo`030000oooooooo00Coool00`000?oo
ooooo`03oooo1@0000Goool800001_ooo`D0000Coooo1@0000Goool2000000Coool0000000000007
oooo100000;oool00`000?ooooooo`0=oooo00D0003oooooooooool000000oooo`030000oooooooo
00?oool00`000?ooo`00000200002?ooo`@00008oooo1@0000Koool200000_ooo`<00002oooo1000
00Coool400008_ooo`00E?ooo`030000oooooooo01Coool00`000?ooooooo`0ioooo00<0003ooooo
ool0DOooo`040000oooooooo00008_ooo`030000oooooooo02[oool00`000?ooooooo`03oooo00<0
003oooooool04?ooo`030000oooooooo03koool00`000?ooooooo`0=oooo00D0003oooooooooool0
00000oooo`030000oooooooo00?oool00`000?ooooooo`1Hoooo001Doooo00<0003oooooool05?oo
o`030000oooooooo03Woool00`000?ooooooo`1Boooo0P0002?oool00`000?ooooooo`0Zoooo00<0
003oooooool00oooo`030000oooooooo013oool00`000?ooooooo`0noooo00<0003oooooool03Ooo
o`050000oooooooooooo000000?oool00`000?ooooooo`03oooo00<0003oooooool0F?ooo`00DOoo
o`L0000Coooo00<0003oooooool0;_ooo`030000oooooooo00Soool00`000?ooooooo`1?oooo1@00
02?oool00`000?ooooooo`0Yoooo1`0001?oool00`000?ooooooo`0noooo00<0003oooooool03Ooo
o`T00005oooo00<0003oooooool0F?ooo`00W?ooo`030000oooooooo07ooool40000QOooo`80000L
oooo0P0005[oool00001\
\>"],
  ImageRangeCache->{{{0, 544.938}, {336.438, 0}} -> {-12.4952, -215.317, \
0.160725, 5.91782}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"ListPlot", "[", 
        RowBox[{"chidist", ",", 
          StyleBox[\(PlotJoined \[Rule] True\),
            FontColor->GrayLevel[0.666667]], 
          StyleBox[",",
            FontColor->GrayLevel[0.666667]], 
          StyleBox[\(Frame \[Rule] True\),
            FontColor->GrayLevel[0.666667]], 
          StyleBox[",",
            FontColor->GrayLevel[0.666667]], 
          
          StyleBox[\(FrameLabel \[Rule] {StyleForm[
                  TraditionalForm["\<Size Parameter\>"], 
                  FontSize \[Rule] 14], 
                StyleForm[TraditionalForm[\*"\"\<\!\(\[Chi]\^2\)\>\""], 
                  FontSize \[Rule] 14]}\),
            FontColor->GrayLevel[0.666667]], 
          StyleBox[",",
            FontColor->GrayLevel[0.666667]], 
          
          StyleBox[\(PlotLabel \[Rule] 
              StyleForm[TraditionalForm["\<Chi-squared vs Size Parameter\>"], 
                FontSize \[Rule] 20]\),
            FontColor->GrayLevel[0.666667]]}], "]"}], ";"}]], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{1939, Inherited}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 0.000516469 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -60.625 -22.625 ]
[.5 -0.0125 60.625 -9 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11801 -18 -4.5 ]
[-0.0125 .11801 0 4.5 ]
[-0.0125 .2213 -18 -4.5 ]
[-0.0125 .2213 0 4.5 ]
[-0.0125 .3246 -18 -4.5 ]
[-0.0125 .3246 0 4.5 ]
[-0.0125 .42789 -18 -4.5 ]
[-0.0125 .42789 0 4.5 ]
[-0.0125 .53118 -24 -4.5 ]
[-0.0125 .53118 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -40.375 -9.53125 ]
[-0.01875 .30902 -24 9.53125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -176 0 ]
[.5 .63053 176 18.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -121.625 -26.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.625 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Size) show
104.875 13.875 moveto
(Parameter) show
180.250 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11801 m
.00625 .11801 L
s
[(200)] -0.0125 .11801 1 0 Mshowa
0 .2213 m
.00625 .2213 L
s
[(400)] -0.0125 .2213 1 0 Mshowa
0 .3246 m
.00625 .3246 L
s
[(600)] -0.0125 .3246 1 0 Mshowa
0 .42789 m
.00625 .42789 L
s
[(800)] -0.0125 .42789 1 0 Mshowa
0 .53118 m
.00625 .53118 L
s
[(1000)] -0.0125 .53118 1 0 Mshowa
.125 Mabswid
0 .04054 m
.00375 .04054 L
s
0 .06636 m
.00375 .06636 L
s
0 .09219 m
.00375 .09219 L
s
0 .14383 m
.00375 .14383 L
s
0 .16966 m
.00375 .16966 L
s
0 .19548 m
.00375 .19548 L
s
0 .24713 m
.00375 .24713 L
s
0 .27295 m
.00375 .27295 L
s
0 .29877 m
.00375 .29877 L
s
0 .35042 m
.00375 .35042 L
s
0 .37624 m
.00375 .37624 L
s
0 .40207 m
.00375 .40207 L
s
0 .45371 m
.00375 .45371 L
s
0 .47954 m
.00375 .47954 L
s
0 .50536 m
.00375 .50536 L
s
0 .55701 m
.00375 .55701 L
s
0 .58283 m
.00375 .58283 L
s
0 .60865 m
.00375 .60865 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -102.719 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
70.5313 12.1875 translate
90 rotate
-70.5313 -12.1875 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 16.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
71.563 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.938 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
78.063 16.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 14.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11801 m
1 .11801 L
s
.99375 .2213 m
1 .2213 L
s
.99375 .3246 m
1 .3246 L
s
.99375 .42789 m
1 .42789 L
s
.99375 .53118 m
1 .53118 L
s
.125 Mabswid
.99625 .04054 m
1 .04054 L
s
.99625 .06636 m
1 .06636 L
s
.99625 .09219 m
1 .09219 L
s
.99625 .14383 m
1 .14383 L
s
.99625 .16966 m
1 .16966 L
s
.99625 .19548 m
1 .19548 L
s
.99625 .24713 m
1 .24713 L
s
.99625 .27295 m
1 .27295 L
s
.99625 .29877 m
1 .29877 L
s
.99625 .35042 m
1 .35042 L
s
.99625 .37624 m
1 .37624 L
s
.99625 .40207 m
1 .40207 L
s
.99625 .45371 m
1 .45371 L
s
.99625 .47954 m
1 .47954 L
s
.99625 .50536 m
1 .50536 L
s
.99625 .55701 m
1 .55701 L
s
.99625 .58283 m
1 .58283 L
s
.99625 .60865 m
1 .60865 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -237 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26.4375 translate 1 -1 scale
63.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Chi) show
99.000 17.750 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
111.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(squared) show
207.000 17.750 moveto
(vs) show
243.000 17.750 moveto
(Size) show
303.000 17.750 moveto
(Parameter) show
411.000 17.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.04286 .03592 m
.0619 .03581 L
.08095 .03523 L
.1 .03437 L
.11905 .03333 L
.1381 .03214 L
.15714 .03083 L
.17619 .02942 L
.19524 .02789 L
.21429 .02602 L
.23333 .02355 L
.25238 .02073 L
.27143 .01834 L
.29048 .01687 L
.30952 .01617 L
.32857 .01617 L
.34762 .01731 L
.36667 .01999 L
.38571 .02382 L
.40476 .02863 L
.42381 .03536 L
.44286 .0448 L
.4619 .05619 L
.48095 .06819 L
.5 .08198 L
.51905 .09992 L
.5381 .12161 L
.55714 .14318 L
.57619 .16431 L
.59524 .18997 L
.61429 .22273 L
.63333 .25663 L
.65238 .28477 L
.67143 .31246 L
.69048 .34737 L
.70952 .38838 L
.72857 .42173 L
.74762 .44661 L
.76667 .4715 L
.78571 .50302 L
.80476 .53207 L
.82381 .55048 L
.84286 .56347 L
.8619 .57768 L
.88095 .59222 L
.9 .59529 L
.91905 .59357 L
.9381 .59531 L
.95714 .60332 L
.97619 .58935 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{551.75, 341},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008W0001EAP00`40o`000?l0003ooooooooooolY
oooo003oooooooooobWoool00?oooooooooo:Oooo`00oooooooooolYoooo003oooooooooobWoool0
0?;oool00`000?ooo`00000200000oooo`L00002oooo1@0000?oool500003?ooo`@00005oooo0`00
0004oooo00000000oooo1@0000Coool3000000?oool0000000000`000005oooo00000000oooo0000
00;oool500001?ooo`<00004oooo1@0000;oool50000a_ooo`00l_ooo`800003oooo00<0003ooooo
ool00oooo`030000oooooooo00?oool01@000?ooooooooooo`000002oooo00<0003oooooool04?oo
o`030000oooooooo00Coool010000?ooooooooooo`800003oooo00<0003oooooool01?ooo`040000
oooooooooooo0P0000;oool010000?ooooooo`0000;oool00`000?ooo`000008oooo00D0003ooooo
ooooool000000_ooo`030000oooooooo00Koool00`000?ooooooo`37oooo003goooo00<0003ooooo
ool00oooo`030000oooooooo00Coool00`000?ooooooo`03oooo00<0003oooooool04?ooo`030000
oooooooo00Coool00`000?ooooooo`02oooo00D0003oooooooooool000001_ooo`030000oooooooo
00;oool010000?ooooooo`0000;oool01P000?ooooooo`000?ooo`0000Soool00`000?ooooooo`04
oooo00<0003oooooool01_ooo`030000oooooooo0<Ooool00?Ooool00`000?ooooooo`03oooo00<0
003oooooool01Oooo`030000oooooooo00;oool600003Oooo`@00004oooo1@0000?oool00`000?oo
ooooo`05oooo1@0000;oool010000?ooooooo`0000;oool00`000?ooo`00000500000oooo`030000
oooooooo00Coool600000oooo`030000oooooooo0<Ooool00??oool400001_ooo`030000oooooooo
00?oool010000?ooooooo`0000?oool00`000?ooooooo`02oooo00<0003oooooool02oooo`050000
oooooooooooo000000;oool00`000?ooooooo`02oooo00@0003oooooooooool200001Oooo`030000
oooooooo00;oool00`000?ooooooo`02000000Ooool00000003oool0003oool000001?ooo`050000
oooooooooooo000000Koool00`000?ooooooo`02oooo00@0003oooooooooool20000b?ooo`00l_oo
o`030000oooooooo00Koool300001Oooo`D00003oooo100000koool01@000?ooooooooooo`000003
oooo100000?oool2000000Coool0000000000003oooo100000;oool2000000Goool0003oooooool0
00000oooo`@00003oooo1P0000?oool400000oooo`8000001?ooo`00000000000<Goool00?;oool0
10000?ooooooooooo`80000Uoooo00D0003oooooooooool00000:oooo`030000oooooooo0=Ooool0
0??oool3000000?oool0003oool01?ooo`030000oooooooo01coool50000;?ooo`030000oooooooo
0=Ooool00?oooooooooo:Oooo`00oooooooooolYoooo001=oooo0P0005Koool40000E_ooo`<0001D
oooo0`0005Koool20000Doooo`D00002oooo0P0001[oool004coool010000?ooooooo`0005Goool0
0`000?ooooooo`1Hoooo00<0003oooooool0Doooo`040000oooooooo0000E?ooo`040000oooooooo
0000E?ooo`050000oooooooooooo000000;oool00`000?ooooooo`0Goooo001<oooo00@0003ooooo
ool0001Foooo00<0003oooooool0E?ooo`D0001Doooo00@0003oooooool0001Doooo00@0003ooooo
ool0001Doooo00D0003oooooooooool000000_ooo`030000oooooooo01Ooool004coool010000?oo
ooooo`0005Ooool00`000?ooooooo`1Coooo00@0003oooooool0001Eoooo0`0005Koool20000EOoo
o`050000oooooooooooo000000;oool00`000?ooooooo`0Goooo001<oooo00@0003oooooool0001E
oooo00@0003oooooool0001Eoooo00<0003oool00000E_ooo`030000oooooooo05Coool010000?oo
ooooo`0005Coool01@000?ooooooooooo`000002oooo00<0003oooooool05oooo`00COooo`80001G
oooo0P0005Ooool20000E_ooo`<0001Eoooo0P0005Coool200001?ooo`80000Joooo003ooooooooo
obWoool00?oooooooooo:Oooo`00oooooooooolYoooo003oooooooooobWoool00?oooooooooo:Ooo
o`00oooooooooolYoooo003oooooooooobWoool00?oooooooooo:Oooo`00@oooool0003C00004_oo
o`00@oooo`030000oooooooo00Soool00`000?ooooooo`0Coooo00<0003oooooool04oooo`030000
oooooooo01?oool00`000?ooooooo`0Doooo00<0003oooooool04oooo`030000oooooooo01?oool0
0`000?ooooooo`0Coooo00<0003oooooool04oooo`030000oooooooo01?oool00`000?ooooooo`0C
oooo00<0003oooooool04oooo`030000oooooooo01Coool00`000?ooooooo`0Coooo00<0003ooooo
ool04oooo`030000oooooooo01?oool00`000?ooooooo`0Coooo00<0003oooooool04oooo`030000
oooooooo01?oool00`000?ooooooo`0Doooo00<0003oooooool04oooo`030000oooooooo00Soool0
0`000?ooooooo`0@oooo0013oooo00<0003oooooool02?ooo`030000oooooooo01?oool00`000?oo
ooooo`0Coooo00<0003oooooool04oooo`030000oooooooo01Coool00`000?ooooooo`0Coooo00<0
003oooooool04oooo`030000oooooooo01?oool00`000?ooooooo`0Coooo00<0003oooooool04ooo
o`030000oooooooo01?oool00`000?ooooooo`0Coooo00<0003oooooool05?ooo`030000oooooooo
01?oool00`000?ooooooo`0Coooo00<0003oooooool04oooo`030000oooooooo01?oool00`000?oo
ooooo`0Coooo00<0003oooooool04oooo`030000oooooooo01Coool00`000?ooooooo`0Coooo00<0
003oooooool02?ooo`030000oooooooo013oool004?oool00`000?ooooooo`08oooo00<0003ooooo
ool0E_ooo`030000oooooooo05Goool00`000?ooooooo`1Foooo00<0003oooooool0EOooo`030000
oooooooo05Koool00`000?ooooooo`08oooo00<0003oooooool04?ooo`00@oooo`030000oooooooo
0?ooooo?oooo00<0003oooooool04?ooo`00>Oooo`800008oooo00<0003oooooool0ooooolooool0
0`000?ooooooo`0@oooo000hoooo00@0003oooooool00007oooo00<0003oooooool0ooooolooool0
0`000?ooooooo`0@oooo000hoooo00@0003oooooool00007oooo100008SooolB0000oooooc7oool4
00004_ooo`00>?ooo`040000oooooooo00001oooo`030000oooooooo07Woool@00004_ooo`P0003o
oooo;?ooo`030000oooooooo013oool003Soool010000?ooooooo`0000Ooool00`000?ooooooo`1e
oooo100002[oool70000ooooobGoool00`000?ooooooo`0@oooo000ioooo0P0000Soool00`000?oo
ooooo`1^oooo1`0003Goool40000ooooob7oool00`000?ooooooo`0@oooo0013oooo00<0003ooooo
ool0I_ooo`P00010oooo1@000?oooolLoooo00<0003oooooool04?ooo`00@oooo`030000oooooooo
05goool90000COooo`@0003ooooo6?ooo`030000oooooooo013oool004?oool00`000?ooooooo`1D
oooo2@0005[oool40000oooooaCoool00`000?ooooooo`0@oooo0013oooo00<0003oooooool0@_oo
oa80001Woooo0`000?oooolAoooo00<0003oooooool04?ooo`00@oooo`030000oooooooo033ooolB
0000O?ooo`<0003ooooo3_ooo`030000oooooooo013oool004?oool00`000?ooooooo`0Ooooo4@00
097oool20000ooooo`coool00`000?ooooooo`0@oooo0013oooo00<0003oooooool04Oooo`h0002T
oooo0P000?ooool:oooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0<Goool20000oooo
o`Soool00`000?ooooooo`0@oooo0013oooo0`000<Ooool20000ooooo`Coool300004_ooo`00@ooo
o`030000oooooooo0<Woool20000ooooo`Coool00`000?ooooooo`0@oooo0013oooo00<0003ooooo
ool0boooo`030000oooooooo0?ooool1oooo00<0003oooooool04?ooo`00@oooo`030000oooooooo
0<coool20000ooooo`7oool00`000?ooooooo`0@oooo0013oooo00<0003oooooool0c_ooo`80003n
oooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0=3oool20000o?ooo`030000oooooooo
013oool004?oool00`000?ooooooo`3Boooo0P000?[oool00`000?ooooooo`0@oooo0013oooo00<0
003oooooool0e?ooo`030000oooooooo0?Ooool00`000?ooooooo`0@oooo0013oooo00<0003ooooo
ool0eOooo`80003goooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0=Ooool00`000?oo
ooooo`3doooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0=Soool20000m?ooo`030000
oooooooo013oool004?oool00`000?ooooooo`3Joooo00<0003oooooool0lOooo`030000oooooooo
013oool004?oool30000foooo`80003_oooo0`0001;oool004?oool00`000?ooooooo`3Moooo00<0
003oooooool0k_ooo`030000oooooooo013oool004?oool00`000?ooooooo`3Noooo00<0003ooooo
ool0kOooo`030000oooooooo013oool004?oool00`000?ooooooo`3Ooooo0P000>goool00`000?oo
ooooo`0@oooo0013oooo00<0003oooooool0hOooo`030000oooooooo0>[oool00`000?ooooooo`0@
oooo0013oooo00<0003oooooool0h_ooo`030000oooooooo0>Woool00`000?ooooooo`0@oooo0013
oooo00<0003oooooool0hoooo`80003Yoooo00<0003oooooool04?ooo`00@oooo`030000oooooooo
0>Goool00`000?ooooooo`3Voooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0>Koool0
0`000?ooooooo`3Uoooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0>Ooool00`000?oo
ooooo`3Toooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0>Soool00`000?ooooooo`3S
oooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0>Woool20000hoooo`030000oooooooo
013oool004?oool30000joooo`030000oooooooo0=koool300004_ooo`00@oooo`030000oooooooo
0>coool00`000?ooooooo`3Ooooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0>goool0
0`000?ooooooo`3Noooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0>koool00`000?oo
ooooo`3Moooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0>ooool00`000?ooooooo`3L
oooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0?3oool00`000?ooooooo`3Koooo00<0
003oooooool04?ooo`00@oooo`030000oooooooo0?7oool00`000?ooooooo`3Joooo00<0003ooooo
ool04?ooo`00@oooo`030000oooooooo0?;oool00`000?ooooooo`3Ioooo00<0003oooooool04?oo
o`00@oooo`030000oooooooo0??oool00`000?ooooooo`3Hoooo00<0003oooooool04?ooo`00@ooo
o`030000oooooooo0??oool00`000?ooooooo`3Hoooo00<0003oooooool04?ooo`00;?ooo`@00003
oooo0P0000Coool200002?ooo`030000oooooooo0?Coool00`000?ooooooo`3Goooo00<0003ooooo
ool04?ooo`00;?ooo`030000oooooooo00?oool010000?ooooooo`0000;oool010000?ooooooo`00
00Ooool00`000?ooooooo`3eoooo00<0003oooooool0e_ooo`030000oooooooo013oool002goool0
0`000?ooooooo`02oooo00@0003oooooool00002oooo00@0003oooooool00007oooo10000?Goool0
0`000?ooooooo`3Boooo100001;oool002koool01@000?ooooooooooo`000002oooo00@0003ooooo
ool00002oooo00<0003oooooool01Oooo`030000oooooooo0?Ooool00`000?ooooooo`3Doooo00<0
003oooooool04?ooo`00;?ooo`040000oooooooo00000_ooo`040000oooooooo00000_ooo`040000
oooooooo00001oooo`030000oooooooo0?Soool00`000?ooooooo`3Coooo00<0003oooooool04?oo
o`00;Oooo`800004oooo0P0000Coool200002?ooo`030000oooooooo0?Woool00`000?ooooooo`3B
oooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0?[oool00`000?ooooooo`3Aoooo00<0
003oooooool04?ooo`00@oooo`030000oooooooo0?_oool00`000?ooooooo`3@oooo00<0003ooooo
ool04?ooo`00@oooo`030000oooooooo0?coool00`000?ooooooo`3?oooo00<0003oooooool04?oo
o`00@oooo`030000oooooooo0?coool00`000?ooooooo`3?oooo00<0003oooooool04?ooo`00@ooo
o`030000oooooooo0?goool00`000?ooooooo`3>oooo00<0003oooooool04?ooo`00@oooo`030000
oooooooo0?koool00`000?ooooooo`3=oooo00<0003oooooool04?ooo`00@oooo`030000oooooooo
0?ooool00`000?ooooooo`3<oooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0?ooool1
oooo00<0003oooooool0boooo`030000oooooooo013oool004?oool30000ooooo`;oool00`000?oo
ooooo`38oooo0`0001;oool004?oool00`000?ooooooo`3ooooo0oooo`030000oooooooo0<Woool0
0`000?ooooooo`0@oooo0013oooo00<0003oooooool0ooooo`Coool00`000?ooooooo`38oooo00<0
003oooooool04?ooo`00@oooo`030000oooooooo0?ooool5oooo00<0003oooooool0aoooo`030000
oooooooo013oool004?oool00`000?ooooooo`3ooooo1_ooo`030000oooooooo0<Koool00`000?oo
ooooo`0@oooo0013oooo00<0003oooooool0ooooo`Koool00`000?ooooooo`36oooo00<0003ooooo
ool04?ooo`00@oooo`030000oooooooo0?ooool7oooo00<0003oooooool0aOooo`030000oooooooo
013oool004?oool00`000?ooooooo`3ooooo2?ooo`030000oooooooo0<Coool00`000?ooooooo`0@
oooo0013oooo00<0003oooooool0ooooo`Woool00`000?ooooooo`33oooo00<0003oooooool04?oo
o`00@oooo`030000oooooooo0?ooool:oooo00<0003oooooool0`_ooo`030000oooooooo013oool0
04?oool00`000?ooooooo`3ooooo2oooo`030000oooooooo0<7oool00`000?ooooooo`0@oooo0013
oooo00<0003oooooool0ooooo`coool00`000?ooooooo`30oooo00<0003oooooool04?ooo`00@ooo
o`<0003ooooo3?ooo`030000oooooooo0;koool300004_ooo`00@oooo`030000oooooooo0?ooool=
oooo00<0003oooooool0_oooo`030000oooooooo013oool004?oool00`000?ooooooo`3ooooo3_oo
o`030000oooooooo0;koool00`000?ooooooo`0@oooo0013oooo00<0003oooooool0ooooo`ooool0
0`000?ooooooo`2moooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0?ooool?oooo00<0
003oooooool0_Oooo`030000oooooooo013oool004?oool00`000?ooooooo`3ooooo4?ooo`030000
oooooooo0;coool00`000?ooooooo`0@oooo0013oooo00<0003oooooool0oooooa7oool00`000?oo
ooooo`2koooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0?oooolBoooo00<0003ooooo
ool0^_ooo`030000oooooooo013oool004?oool00`000?ooooooo`3ooooo4_ooo`030000oooooooo
0;[oool00`000?ooooooo`0@oooo0013oooo00<0003oooooool0oooooa?oool00`000?ooooooo`2i
oooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0?oooolDoooo00<0003oooooool0^?oo
o`030000oooooooo013oool004?oool00`000?ooooooo`3ooooo5?ooo`030000oooooooo0;Soool0
0`000?ooooooo`0@oooo0013oooo0`000?oooolEoooo00<0003oooooool0]Oooo`<0000Boooo0013
oooo00<0003oooooool0oooooaGoool00`000?ooooooo`2goooo00<0003oooooool04?ooo`00@ooo
o`030000oooooooo0?oooolFoooo00<0003oooooool0]_ooo`030000oooooooo013oool004?oool0
0`000?ooooooo`3ooooo5_ooo`030000oooooooo0;Koool00`000?ooooooo`0@oooo0013oooo00<0
003oooooool0oooooaOoool00`000?ooooooo`2eoooo00<0003oooooool04?ooo`00@oooo`030000
oooooooo0?oooolGoooo00<0003oooooool0]Oooo`030000oooooooo013oool004?oool00`000?oo
ooooo`3ooooo6?ooo`030000oooooooo0;Coool00`000?ooooooo`0@oooo0013oooo00<0003ooooo
ool0oooooaSoool00`000?ooooooo`2doooo00<0003oooooool04?ooo`00@oooo`030000oooooooo
0?oooolIoooo00<0003oooooool0/oooo`030000oooooooo013oool004?oool00`000?ooooooo`3o
oooo6Oooo`030000oooooooo0;?oool00`000?ooooooo`0@oooo000^oooo0`0000;oool200001?oo
o`800008oooo00<0003oooooool0oooooa[oool00`000?ooooooo`2boooo00<0003oooooool04?oo
o`00;oooo`040000oooooooo00000_ooo`040000oooooooo00000_ooo`030000oooooooo00Goool0
0`000?ooooooo`3ooooo6_ooo`030000oooooooo0;;oool00`000?ooooooo`0@oooo000/oooo1@00
0005oooo0000oooooooo000000;oool010000?ooooooo`0000Ooool40000oooooa[oool00`000?oo
ooooo`2^oooo100001;oool002coool010000?ooooooo`0000;oool010000?ooooooo`0000;oool0
10000?ooooooo`0000Ooool00`000?ooooooo`3ooooo7?ooo`030000oooooooo0;3oool00`000?oo
ooooo`0@oooo000]oooo00<0003oool000000_ooo`040000oooooooo00000_ooo`040000oooooooo
00001oooo`030000oooooooo0?oooolLoooo00<0003oooooool0/?ooo`030000oooooooo013oool0
02koool200000oooo`800004oooo0P0000Soool00`000?ooooooo`3ooooo7Oooo`030000oooooooo
0:ooool00`000?ooooooo`0@oooo0013oooo00<0003oooooool0oooooagoool00`000?ooooooo`2_
oooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0?oooolNoooo00<0003oooooool0[_oo
o`030000oooooooo013oool004?oool00`000?ooooooo`3ooooo7_ooo`030000oooooooo0:koool0
0`000?ooooooo`0@oooo0013oooo00<0003oooooool0oooooaooool00`000?ooooooo`2]oooo00<0
003oooooool04?ooo`00@oooo`030000oooooooo0?oooolPoooo00<0003oooooool0[?ooo`030000
oooooooo013oool004?oool00`000?ooooooo`3ooooo8?ooo`030000oooooooo0:coool00`000?oo
ooooo`0@oooo0013oooo00<0003oooooool0ooooob7oool00`000?ooooooo`2[oooo00<0003ooooo
ool04?ooo`00@oooo`030000oooooooo0?oooolQoooo00<0003oooooool0Zoooo`030000oooooooo
013oool004?oool30000ooooob;oool00`000?ooooooo`2Xoooo0`0001;oool004?oool00`000?oo
ooooo`3ooooo8_ooo`030000oooooooo0:[oool00`000?ooooooo`0@oooo0013oooo00<0003ooooo
ool0ooooob?oool00`000?ooooooo`2Yoooo00<0003oooooool04?ooo`00@oooo`030000oooooooo
0?oooolSoooo00<0003oooooool0ZOooo`030000oooooooo013oool004?oool00`000?ooooooo`3o
oooo9?ooo`030000oooooooo0:Soool00`000?ooooooo`0@oooo0013oooo00<0003oooooool0oooo
obGoool00`000?ooooooo`2Woooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0?oooolU
oooo00<0003oooooool0Yoooo`030000oooooooo013oool004?oool00`000?ooooooo`3ooooo9_oo
o`030000oooooooo0:Koool00`000?ooooooo`0@oooo0013oooo00<0003oooooool0ooooobOoool0
0`000?ooooooo`2Uoooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0?oooolWoooo00<0
003oooooool0YOooo`030000oooooooo013oool004?oool00`000?ooooooo`3ooooo:?ooo`030000
oooooooo0:Coool00`000?ooooooo`0@oooo0013oooo00<0003oooooool0ooooobWoool00`000?oo
ooooo`2Soooo00<0003oooooool04?ooo`00@oooo`<0003ooooo:_ooo`030000oooooooo0:3oool3
00004_ooo`00@oooo`030000oooooooo0?oooolZoooo00<0003oooooool0X_ooo`030000oooooooo
013oool004?oool00`000?ooooooo`3ooooo:oooo`030000oooooooo0:7oool00`000?ooooooo`0@
oooo0013oooo00<0003oooooool0ooooobcoool00`000?ooooooo`2Poooo00<0003oooooool04?oo
o`00@oooo`030000oooooooo0?ooool/oooo00<0003oooooool0X?ooo`030000oooooooo013oool0
04?oool00`000?ooooooo`3ooooo;Oooo`030000oooooooo09ooool00`000?ooooooo`0@oooo0013
oooo00<0003oooooool0ooooobkoool00`000?ooooooo`2Noooo00<0003oooooool04?ooo`00@ooo
o`030000oooooooo0?ooool^oooo00<0003oooooool0W_ooo`030000oooooooo013oool004?oool0
0`000?ooooooo`3ooooo;oooo`030000oooooooo09goool00`000?ooooooo`0@oooo0013oooo00<0
003oooooool0oooooc3oool00`000?ooooooo`2Loooo00<0003oooooool04?ooo`007oooo`030000
oooooooo027oool00`000?ooooooo`3ooooo<?ooo`030000oooooooo09coool00`000?ooooooo`0@
oooo000Hoooo00<0003oooooool00oooo`030000oooooooo02;oool00`000?ooooooo`3ooooo<Ooo
o`030000oooooooo09_oool00`000?ooooooo`0@oooo000Hoooo00<0003oooooool00_ooo`030000
oooooooo02?oool30000oooooc;oool00`000?ooooooo`2Hoooo0`0001;oool001Soool200000_oo
o`030000oooooooo02Coool00`000?ooooooo`3ooooo<oooo`030000oooooooo09Woool00`000?oo
ooooo`0@oooo000Joooo1@0002Coool00`000?ooooooo`3ooooo<oooo`030000oooooooo09Woool0
0`000?ooooooo`0@oooo000Joooo00<0003oooooool00_ooo`030000oooooooo027oool00`000?oo
ooooo`3ooooo=?ooo`030000oooooooo09Soool00`000?ooooooo`0@oooo000Ioooo00<0003ooooo
ool00oooo`030000oooooooo027oool00`000?ooooooo`3ooooo=Oooo`030000oooooooo09Ooool0
0`000?ooooooo`0@oooo000Hoooo00<0003oooooool0:?ooo`030000oooooooo0?ooooleoooo00<0
003oooooool0Uoooo`030000oooooooo013oool004?oool00`000?ooooooo`3ooooo=_ooo`030000
oooooooo09Koool00`000?ooooooo`0@oooo0013oooo00<0003oooooool0ooooocOoool00`000?oo
ooooo`2Eoooo00<0003oooooool04?ooo`005?ooo`030000oooooooo0080000Zoooo00<0003ooooo
ool0ooooocOoool00`000?ooooooo`2Eoooo00<0003oooooool04?ooo`004oooo`060000oooooooo
0000oooo0000:_ooo`030000oooooooo0?oooolhoooo00<0003oooooool0U?ooo`030000oooooooo
013oool001?oool00`000?ooo`000002oooo00<0003oooooool04Oooo`<00004oooo0P0000Coool2
00002?ooo`030000oooooooo0?oooolhoooo00<0003oooooool0U?ooo`030000oooooooo013oool0
01Coool01@000?ooooooooooo`00000Coooo00@0003oooooool00002oooo00@0003oooooool00002
oooo00@0003oooooool00007oooo00<0003oooooool0ooooocWoool00`000?ooooooo`2Coooo00<0
003oooooool04?ooo`00;?ooo`040000oooooooo00000_ooo`040000oooooooo00000_ooo`040000
oooooooo00001oooo`@0003ooooo>?ooo`030000oooooooo093oool400004_ooo`00;?ooo`<00003
oooo00@0003oooooool00002oooo00@0003oooooool00007oooo00<0003oooooool0oooooc[oool0
0`000?ooooooo`2Boooo00<0003oooooool04?ooo`00;Oooo`030000oooooooo00;oool010000?oo
ooooo`0000;oool010000?ooooooo`0000Ooool00`000?ooooooo`3ooooo>oooo`030000oooooooo
097oool00`000?ooooooo`0@oooo000]oooo0`0000?oool200001?ooo`800008oooo00<0003ooooo
ool0oooooc_oool00`000?ooooooo`2Aoooo00<0003oooooool04?ooo`00@oooo`030000oooooooo
0?oooolloooo00<0003oooooool0T?ooo`030000oooooooo013oool004?oool00`000?ooooooo`3o
oooo??ooo`030000oooooooo093oool00`000?ooooooo`0@oooo0013oooo00<0003oooooool0oooo
ocgoool00`000?ooooooo`2?oooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0?oooolm
oooo00<0003oooooool0Soooo`030000oooooooo013oool004?oool00`000?ooooooo`3ooooo?_oo
o`030000oooooooo08koool00`000?ooooooo`0@oooo0013oooo00<0003oooooool0ooooockoool0
0`000?ooooooo`2>oooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0?oooolooooo00<0
003oooooool0SOooo`030000oooooooo013oool004?oool00`000?ooooooo`3ooooo?oooo`030000
oooooooo08goool00`000?ooooooo`0@oooo0013oooo0`000?oooom0oooo00<0003oooooool0R_oo
o`<0000Boooo0013oooo00<0003oooooool0oooood3oool00`000?ooooooo`2<oooo00<0003ooooo
ool04?ooo`00@oooo`030000oooooooo0?oooom1oooo00<0003oooooool0Roooo`030000oooooooo
013oool004?oool00`000?ooooooo`3ooooo@Oooo`030000oooooooo08_oool00`000?ooooooo`0@
oooo0013oooo00<0003oooooool0oooood;oool00`000?ooooooo`2:oooo00<0003oooooool04?oo
o`00@oooo`030000oooooooo0?oooom2oooo00<0003oooooool0R_ooo`030000oooooooo013oool0
04?oool00`000?ooooooo`3ooooo@oooo`030000oooooooo08Woool00`000?ooooooo`0@oooo0013
oooo00<0003oooooool0oooood?oool00`000?ooooooo`29oooo00<0003oooooool04?ooo`00@ooo
o`030000oooooooo0?oooom4oooo00<0003oooooool0R?ooo`030000oooooooo013oool004?oool0
0`000?ooooooo`3oooooA?ooo`030000oooooooo08Soool00`000?ooooooo`0@oooo0013oooo00<0
003oooooool0ooooodGoool00`000?ooooooo`27oooo00<0003oooooool04?ooo`00@oooo`030000
oooooooo0?oooom5oooo00<0003oooooool0Qoooo`030000oooooooo013oool004?oool30000oooo
odKoool00`000?ooooooo`24oooo0`0001;oool004?oool00`000?ooooooo`3oooooA_ooo`030000
oooooooo08Koool00`000?ooooooo`0@oooo0013oooo00<0003oooooool0ooooodOoool00`000?oo
ooooo`25oooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0?oooom7oooo00<0003ooooo
ool0QOooo`030000oooooooo013oool004?oool00`000?ooooooo`3oooooB?ooo`030000oooooooo
08Coool00`000?ooooooo`0@oooo0013oooo00<0003oooooool0ooooodSoool00`000?ooooooo`24
oooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0?oooom9oooo00<0003oooooool0Pooo
o`030000oooooooo013oool004?oool00`000?ooooooo`3oooooBOooo`030000oooooooo08?oool0
0`000?ooooooo`0@oooo0013oooo00<0003oooooool0oooood[oool00`000?ooooooo`22oooo00<0
003oooooool04?ooo`00@oooo`030000oooooooo0?oooom:oooo00<0003oooooool0P_ooo`030000
oooooooo013oool004?oool00`000?ooooooo`3oooooBoooo`030000oooooooo087oool00`000?oo
ooooo`0@oooo0013oooo00<0003oooooool0oooood_oool00`000?ooooooo`21oooo00<0003ooooo
ool04?ooo`00@oooo`<0003oooooC?ooo`030000oooooooo07koool300004_ooo`00@oooo`030000
oooooooo0?oooom=oooo00<0003oooooool0Ooooo`030000oooooooo013oool004?oool00`000?oo
ooooo`3oooooCOooo`030000oooooooo07ooool00`000?ooooooo`0@oooo0013oooo00<0003ooooo
ool0ooooodkoool00`000?ooooooo`1noooo00<0003oooooool04?ooo`00@oooo`030000oooooooo
0?oooom>oooo00<0003oooooool0O_ooo`030000oooooooo013oool004?oool00`000?ooooooo`3o
ooooCoooo`030000oooooooo07goool00`000?ooooooo`0@oooo0013oooo00<0003oooooool0oooo
odooool00`000?ooooooo`1moooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0?oooom@
oooo00<0003oooooool0O?ooo`030000oooooooo013oool004?oool00`000?ooooooo`3oooooD?oo
o`030000oooooooo07coool00`000?ooooooo`0@oooo0013oooo00<0003oooooool0oooooe7oool0
0`000?ooooooo`1koooo00<0003oooooool04?ooo`00;Oooo`800004oooo0P0000Coool200002?oo
o`030000oooooooo0?oooomBoooo00<0003oooooool0N_ooo`030000oooooooo013oool002coool0
10000?ooooooo`0000;oool010000?ooooooo`0000;oool010000?ooooooo`0000Ooool00`000?oo
ooooo`3oooooD_ooo`030000oooooooo07[oool00`000?ooooooo`0@oooo000/oooo00@0003ooooo
ool00002oooo00@0003oooooool00002oooo00@0003oooooool00007oooo10000?oooomBoooo00<0
003oooooool0M_ooo`@0000Boooo000]oooo0P0000?oool010000?ooooooo`0000;oool010000?oo
ooooo`0000Ooool00`000?ooooooo`3oooooE?ooo`030000oooooooo07Soool00`000?ooooooo`0@
oooo000/oooo00@0003oooooool00002oooo00@0003oooooool00002oooo00@0003oooooool00007
oooo00<0003oooooool0oooooeCoool00`000?ooooooo`1hoooo00<0003oooooool04?ooo`00;Ooo
o`800004oooo0P0000Coool200002?ooo`030000oooooooo0?oooomEoooo00<0003oooooool0Mooo
o`030000oooooooo013oool004?oool00`000?ooooooo`3oooooE_ooo`030000oooooooo07Koool0
0`000?ooooooo`0@oooo0013oooo00<0003oooooool0oooooeKoool00`000?ooooooo`1foooo00<0
003oooooool04?ooo`00@oooo`030000oooooooo0?oooomGoooo00<0003oooooool0MOooo`030000
oooooooo013oool004?oool00`000?ooooooo`3oooooF?ooo`030000oooooooo07Coool00`000?oo
ooooo`0@oooo0013oooo00<0003oooooool0oooooeSoool00`000?ooooooo`1doooo00<0003ooooo
ool04?ooo`00@oooo`030000oooooooo0?oooomIoooo00<0003oooooool0Loooo`030000oooooooo
013oool004?oool00`000?ooooooo`3oooooF_ooo`030000oooooooo07;oool00`000?ooooooo`0@
oooo0013oooo00<0003oooooool0oooooe_oool00`000?ooooooo`1aoooo00<0003oooooool04?oo
o`00@oooo`<0003oooooFoooo`030000oooooooo06ooool300004_ooo`00@oooo`030000oooooooo
0?oooomLoooo00<0003oooooool0L?ooo`030000oooooooo013oool004?oool00`000?ooooooo`3o
ooooGOooo`030000oooooooo06ooool00`000?ooooooo`0@oooo0013oooo00<0003oooooool0oooo
oekoool00`000?ooooooo`1^oooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0?oooomO
oooo00<0003oooooool0KOooo`030000oooooooo013oool004?oool00`000?ooooooo`3oooooH?oo
o`030000oooooooo06coool00`000?ooooooo`0@oooo0013oooo00<0003oooooool0ooooof3oool0
0`000?ooooooo`1/oooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0?oooomQoooo00<0
003oooooool0Joooo`030000oooooooo013oool004?oool00`000?ooooooo`3oooooH_ooo`030000
oooooooo06[oool00`000?ooooooo`0@oooo0013oooo00<0003oooooool0ooooof?oool00`000?oo
ooooo`1Yoooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0?oooomSoooo00<0003ooooo
ool0JOooo`030000oooooooo013oool004?oool00`000?ooooooo`3oooooI?ooo`030000oooooooo
06Soool00`000?ooooooo`0@oooo0013oooo0`000?oooomToooo00<0003oooooool0I_ooo`<0000B
oooo0013oooo00<0003oooooool0ooooofGoool00`000?ooooooo`1Woooo00<0003oooooool04?oo
o`00@oooo`030000oooooooo0?oooomVoooo00<0003oooooool0I_ooo`030000oooooooo013oool0
04?oool00`000?ooooooo`3oooooI_ooo`030000oooooooo06Koool00`000?ooooooo`0@oooo0013
oooo00<0003oooooool0ooooofOoool00`000?ooooooo`1Uoooo00<0003oooooool04?ooo`00@ooo
o`030000oooooooo0?oooomWoooo00<0003oooooool0IOooo`030000oooooooo013oool004?oool0
0`000?ooooooo`3oooooJ?ooo`030000oooooooo06Coool00`000?ooooooo`0@oooo0013oooo00<0
003oooooool0ooooofWoool00`000?ooooooo`1Soooo00<0003oooooool04?ooo`00@oooo`030000
oooooooo0?oooomYoooo00<0003oooooool0Hoooo`030000oooooooo013oool004?oool00`000?oo
ooooo`3oooooJ_ooo`030000oooooooo06;oool00`000?ooooooo`0@oooo0013oooo00<0003ooooo
ool0ooooof[oool00`000?ooooooo`1Roooo00<0003oooooool04?ooo`00@oooo`030000oooooooo
0?oooom[oooo00<0003oooooool0HOooo`030000oooooooo013oool004?oool30000ooooofcoool0
0`000?ooooooo`1Noooo0`0001;oool004?oool00`000?ooooooo`3oooooK?ooo`030000oooooooo
063oool00`000?ooooooo`0@oooo0013oooo00<0003oooooool0ooooofgoool00`000?ooooooo`1O
oooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0?oooom^oooo00<0003oooooool0G_oo
o`030000oooooooo013oool004?oool00`000?ooooooo`3oooooK_ooo`030000oooooooo05koool0
0`000?ooooooo`0@oooo0013oooo00<0003oooooool0ooooofooool00`000?ooooooo`1Moooo00<0
003oooooool04?ooo`00@oooo`030000oooooooo0?oooom`oooo00<0003oooooool0G?ooo`030000
oooooooo013oool004?oool00`000?ooooooo`3oooooLOooo`030000oooooooo05_oool00`000?oo
ooooo`0@oooo0013oooo00<0003oooooool0ooooog7oool00`000?ooooooo`1Koooo00<0003ooooo
ool04?ooo`00@oooo`030000oooooooo0?oooomboooo00<0003oooooool0F_ooo`030000oooooooo
013oool002Koool500000_ooo`800004oooo0P0000Coool200002?ooo`030000oooooooo0?oooomc
oooo00<0003oooooool0FOooo`030000oooooooo013oool002Soool01@000?ooooooooooo`000002
oooo00@0003oooooool00002oooo00@0003oooooool00002oooo00<0003oooooool01Oooo`030000
oooooooo0?oooomcoooo00<0003oooooool0FOooo`030000oooooooo013oool002Soool01@000?oo
ooooooooo`000002oooo00@0003oooooool00002oooo00@0003oooooool00002oooo00<0003ooooo
ool01Oooo`@0003oooooLoooo`030000oooooooo05Goool400004_ooo`00:?ooo`050000oooooooo
oooo000000;oool010000?ooooooo`0000;oool010000?ooooooo`0000;oool00`000?ooooooo`05
oooo00<0003oooooool0ooooogGoool00`000?ooooooo`1Goooo00<0003oooooool04?ooo`00:?oo
o`050000oooooooooooo000000;oool010000?ooooooo`0000;oool010000?ooooooo`0000;oool0
0`000?ooooooo`05oooo00<0003oooooool0ooooogKoool00`000?ooooooo`1Foooo00<0003ooooo
ool04?ooo`009oooo`800004oooo0P0000Coool200001?ooo`800008oooo00<0003oooooool0oooo
ogOoool00`000?ooooooo`1Eoooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0?oooomh
oooo00<0003oooooool0E?ooo`030000oooooooo013oool004?oool00`000?ooooooo`3oooooNOoo
o`030000oooooooo05?oool00`000?ooooooo`0@oooo0013oooo00<0003oooooool0ooooog[oool0
0`000?ooooooo`1Boooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0?oooomkoooo00<0
003oooooool0DOooo`030000oooooooo013oool004?oool00`000?ooooooo`3oooooO?ooo`030000
oooooooo053oool00`000?ooooooo`0@oooo0013oooo00<0003oooooool0oooooggoool00`000?oo
ooooo`1?oooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0?oooomnoooo0P0004ooool0
0`000?ooooooo`0@oooo0013oooo00<0003oooooool0oooooh3oool00`000?ooooooo`1<oooo00<0
003oooooool04?ooo`00@oooo`<0003oooooPOooo`80001:oooo0`0001;oool004?oool00`000?oo
ooooo`3oooooPoooo`030000oooooooo04Woool00`000?ooooooo`0@oooo0013oooo00<0003ooooo
ool0ooooohCoool20000BOooo`030000oooooooo013oool004?oool00`000?ooooooo`3oooooQ_oo
o`030000oooooooo04Koool00`000?ooooooo`0@oooo0013oooo00<0003oooooool0ooooohOoool2
0000A_ooo`030000oooooooo013oool004?oool00`000?ooooooo`3oooooROooo`030000oooooooo
04?oool00`000?ooooooo`0@oooo0013oooo00<0003oooooool0oooooh[oool20000@oooo`030000
oooooooo013oool004?oool00`000?ooooooo`3oooooS?ooo`030000oooooooo043oool00`000?oo
ooooo`0@oooo0013oooo00<0003oooooool0ooooohgoool20000@?ooo`030000oooooooo013oool0
04?oool00`000?ooooooo`3oooooSoooo`030000oooooooo03goool00`000?ooooooo`0@oooo0013
oooo00<0003oooooool0oooooi3oool00`000?ooooooo`0loooo00<0003oooooool04?ooo`00@ooo
o`030000oooooooo0?oooonAoooo00<0003oooooool0>oooo`030000oooooooo013oool004?oool3
0000oooooi;oool00`000?ooooooo`0hoooo0`0001;oool004?oool00`000?ooooooo`3oooooTooo
o`80000joooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0?oooonEoooo00<0003ooooo
ool0=oooo`030000oooooooo013oool004?oool00`000?ooooooo`3oooooU_ooo`030000oooooooo
02_oool00`000?ooooooo`08oooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0?oooonG
oooo0`0002Soool200002oooo`030000oooooooo013oool004?oool00`000?ooooooo`3oooooV_oo
o`@00007oooo2@0001?oool00`000?ooooooo`0;oooo00<0003oooooool04?ooo`00@oooo`030000
oooooooo0?oooonNoooo1`0000Woool600002oooo`80000>oooo00<0003oooooool04?ooo`00@ooo
o`030000oooooooo0?oooondoooo0`0000Ooool00`000?ooooooo`0>oooo00<0003oooooool04?oo
o`00@oooo`030000oooooooo0?oooongoooo0`0000;oool200004Oooo`030000oooooooo013oool0
04?oool00`000?ooooooo`3ooooo^_ooo`80000Coooo00<0003oooooool04?ooo`00@oooo`030000
oooooooo0?ooooo?oooo00<0003oooooool04?ooo`00@oooo`030000oooooooo0?ooooo?oooo00<0
003oooooool04?ooo`00@oooo`<0003ooooocOooo`<0000Boooo0013oooo00<0003oooooool02?oo
o`030000oooooooo05Koool00`000?ooooooo`1Eoooo00<0003oooooool0E_ooo`030000oooooooo
05Goool00`000?ooooooo`1Foooo00<0003oooooool02?ooo`030000oooooooo013oool004?oool0
0`000?ooooooo`08oooo00<0003oooooool0E_ooo`030000oooooooo05Goool00`000?ooooooo`1F
oooo00<0003oooooool0EOooo`030000oooooooo05Koool00`000?ooooooo`08oooo00<0003ooooo
ool04?ooo`00@oooo`030000oooooooo00Soool00`000?ooooooo`0Coooo00<0003oooooool04ooo
o`030000oooooooo01?oool00`000?ooooooo`0Doooo00<0003oooooool04oooo`030000oooooooo
01?oool00`000?ooooooo`0Coooo00<0003oooooool04oooo`030000oooooooo01?oool00`000?oo
ooooo`0Coooo00<0003oooooool04oooo`030000oooooooo01Coool00`000?ooooooo`0Coooo00<0
003oooooool04oooo`030000oooooooo01?oool00`000?ooooooo`0Coooo00<0003oooooool04ooo
o`030000oooooooo01?oool00`000?ooooooo`0Doooo00<0003oooooool04oooo`030000oooooooo
00Soool00`000?ooooooo`0@oooo0013ooooo`000=<0000Boooo003oooooooooobWoool00?oooooo
oooo:Oooo`00oooooooooolYoooo003oooooooooobWoool00?oooooooooo:Oooo`00oooooooooolY
oooo003oooooooooobWoool00<7oool30000ooooofCoool00<;oool00`000?ooooooo`3oooooHooo
o`00`_ooo`030000oooooooo0?oooomSoooo0032oooo00<0003oooooool0ooooof?oool0087oool5
00001Oooo`<00003oooo0`0000;oool900004?ooo`030000oooo000000<00007oooo100000;oool0
0`000?ooooooo`03oooo1@000003oooo0000000000Coool5000000?oool0000000001?ooo`H00007
oooo1@0000Koool400000_ooo`80000Boooo0P0000Ooool00`000?ooo`00000300004_ooo`030000
oooo000000<00005oooo2@0000Coool800001_ooo`D0000@oooo1P0000Soool5000000?oool00000
00001?ooo`H00006oooo1@000003oooo0000000000;oool300000_ooo`800002oooo0P0000Coool5
00002?ooo`@00007oooo1@0000Koool60000DOooo`00P?ooo`030000oooooooo00?oool00`000?oo
ooooo`03oooo00<0003oooooool00oooo`030000oooooooo00Goool00`000?ooooooo`0Boooo0P00
00Coool00`000?ooooooo`03oooo00<0003oooooool00_ooo`<00004oooo00<0003oooooool00ooo
o`800004oooo00<0003oooooool00oooo`800006oooo00<0003oooooool02?ooo`030000oooooooo
00?oool00`000?ooooooo`02oooo00<0003oooooool00_ooo`<0000Coooo0P0000Ooool200001?oo
o`030000oooooooo00ooool200001?ooo`030000oooooooo00Koool00`000?ooooooo`06oooo00<0
003oooooool01?ooo`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool03ooo
o`030000oooooooo00Soool00`000?ooooooo`03oooo0P0000Koool00`000?ooooooo`07oooo00<0
003oooooool00oooo`800004oooo00D0003oooooooooool000000oooo`030000oooooooo00;oool0
0`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooooooo00;oool200001?ooo`030000
oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool0Doooo`00Ooooo`030000oooooooo
00Goool00`000?ooooooo`02oooo00<0003oooooool00oooo`030000oooooooo00Goool00`000?oo
ooooo`0Boooo00<0003oooooool01?ooo`050000oooooooooooo000000Ooool00`000?ooooooo`02
oooo00<0003oooooool01?ooo`030000oooooooo00;oool00`000?ooooooo`04oooo00<0003ooooo
ool01?ooo`030000oooooooo00Ooool00`000?ooooooo`08oooo00<0003oooooool01Oooo`030000
oooooooo013oool010000?ooooooo`0000Koool00`000?ooooooo`04oooo00<0003oooooool03_oo
o`030000oooooooo00Coool00`000?ooooooo`05oooo00<0003oooooool01oooo`030000oooooooo
00Soool00`000?ooooooo`0Foooo00<0003oooooool02?ooo`030000oooooooo00Coool00`000?oo
ooooo`04oooo00<0003oooooool01oooo`030000oooooooo00Coool00`000?ooooooo`02oooo00D0
003oooooooooool000000oooo`050000oooooooooooo000000goool00`000?ooooooo`07oooo00<0
003oooooool02oooo`030000oooooooo05?oool007koool00`000?ooooooo`0;oooo00<0003ooooo
ool00oooo`030000oooooooo00Goool00`000?ooooooo`0Ioooo00D0003oooooooooool000001ooo
o`030000oooooooo00;oool00`000?ooooooo`04oooo00<0003oooooool00oooo`030000oooooooo
00?oool00`000?ooooooo`04oooo00<0003oooooool01oooo`030000oooooooo00Soool00`000?oo
ooooo`05oooo00<0003oooooool04?ooo`040000oooooooo00003Oooo`030000oooooooo01Goool0
0`000?ooooooo`05oooo00<0003oooooool02?ooo`030000oooooooo00Ooool00`000?ooooooo`0F
oooo00<0003oooooool02Oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003ooooo
ool02?ooo`030000oooooooo00?oool00`000?ooooooo`02oooo00D0003oooooooooool000000ooo
o`050000oooooooooooo000000goool00`000?ooooooo`07oooo00<0003oooooool02oooo`030000
oooooooo05?oool007koool00`000?ooooooo`0;oooo00<0003oooooool00oooo`030000oooooooo
00Goool00`000?ooooooo`06oooo200000[oool00`000?ooooooo`02oooo00<0003oooooool01Ooo
o`030000oooooooo00;oool00`000?ooooooo`04oooo00<0003oooooool01?ooo`H00006oooo00<0
003oooooool01oooo`P00003oooo00<0003oooooool01Oooo`030000oooooooo00ooool00`000?oo
ooooo`02oooo00<0003oooooool02Oooo`030000oooooooo01Koool00`000?ooooooo`05oooo00<0
003oooooool02Oooo`030000oooooooo00Koool800004Oooo`030000oooooooo00[oool600001_oo
o`030000oooooooo00Woool600001?ooo`050000oooooooooooo000000?oool010000?oooooooooo
o`P00006oooo00<0003oooooool01oooo`P00006oooo00<0003oooooool0Doooo`00O_ooo`030000
oooooooo00_oool00`000?ooooooo`03oooo00<0003oooooool01Oooo`030000oooooooo01?oool5
00001Oooo`030000oooooooo00Goool00`000?ooooooo`02oooo00<0003oooooool01?ooo`030000
oooooooo00Woool00`000?ooooooo`04oooo00<0003oooooool01oooo`030000oooooooo00Coool0
1@000?ooooooooooo`000007oooo00<0003oooooool03oooo`030000oooooooo00;oool00`000?oo
ooooo`04oooo1@0001Soool00`000?ooooooo`06oooo00<0003oooooool02_ooo`030000oooooooo
00Goool00`000?ooooooo`04oooo00<0003oooooool03oooo`D0000=oooo00<0003oooooool01?oo
o`030000oooooooo00koool00`000?ooooooo`02oooo00D0003oooooooooool000000oooo`050000
oooooooooooo000000Koool00`000?ooooooo`04oooo00<0003oooooool01oooo`030000oooooooo
00Coool00`000?ooooooo`04oooo00<0003oooooool0Doooo`00O_ooo`030000oooooooo00_oool0
0`000?ooooooo`03oooo00<0003oooooool01Oooo`030000oooooooo01;oool00`000?ooooooo`04
oooo00D0003oooooooooool000001_ooo`800004oooo00<0003oooooool01?ooo`030000oooooooo
00Woool00`000?ooooooo`04oooo0P0000Soool00`000?ooooooo`04oooo00D0003oooooooooool0
00001oooo`030000oooooooo00ooool00`000?ooooooo`02oooo00<0003oooooool00oooo`030000
oooooooo00Coool00`000?ooooooo`0@oooo100000Woool00`000?ooooooo`0;oooo00<0003ooooo
ool01?ooo`030000oooooooo00Coool00`000?ooooooo`0?oooo00<0003oooooool00_ooo`030000
oooooooo00[oool00`000?ooooooo`04oooo0P0000ooool00`000?ooooooo`02oooo00D0003ooooo
ooooool000000oooo`050000oooooooooooo000000Koool00`000?ooooooo`04oooo00<0003ooooo
ool01oooo`030000oooooooo00Coool00`000?ooooooo`04oooo0P0005Coool007koool00`000?oo
ooooo`0;oooo0P0000?oool00`000?ooooooo`06oooo00<0003oooooool04_ooo`030000oooooooo
00?oool200001?ooo`030000oooooooo00;oool00`000?ooo`000004oooo00<0003oooooool01?oo
o`030000oooooooo00?oool00`000?ooooooo`03oooo00<0003oooooool01?ooo`030000oooo0000
00?oool00`000?ooooooo`02oooo00<0003oooooool00_ooo`030000oooooooo00?oool00`000?oo
ooooo`02oooo0`00013oool00`000?ooooooo`04oooo00<0003oooooool00_ooo`030000oooooooo
00?oool200004?ooo`80000=oooo00<0003oooooool01_ooo`030000oooooooo00?oool00`000?oo
ooooo`04oooo00<0003oooooool00_ooo`030000oooooooo013oool00`000?ooooooo`03oooo00<0
003oooooool00oooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oool000000ooo
o`030000oooooooo00;oool00`000?ooooooo`03oooo00<0003oooooool00_ooo`800002oooo0P00
00;oool00`000?ooooooo`02oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?oo
ooooo`08oooo00<0003oooooool00_ooo`030000oooooooo00Goool00`000?ooo`000003oooo00<0
003oooooool0COooo`00O_ooo`030000oooooooo00_oool00`000?ooo`00000200001_ooo`@0000E
oooo1@000003oooo0000oooo00Coool400000_ooo`800002oooo0P0000Goool200001_ooo`D00006
oooo0P0000;oool300001_ooo`@00007oooo100000;oool00`000?ooooooo`0<oooo100000Coool4
00000oooo`D000000oooo`000?ooo`0?oooo00<0003oooooool02Oooo`@00008oooo200000Koool4
00004oooo`030000oooooooo00?oool00`000?ooooooo`04oooo1@0000Koool200000_ooo`<00006
oooo1@0000Coool2000000?oool0000000000_ooo`800006oooo100000Koool800001_ooo`@00007
oooo0P0000;oool30000D?ooo`00Ooooo`030000oooooooo00Goool00`000?ooooooo`02oooo00<0
003oooooool0Koooo`030000oooooooo03;oool00`000?ooooooo`04oooo00<0003oooooool0<ooo
o`030000oooooooo00?oool00`000?ooooooo`10oooo00<0003oooooool0Joooo`00P?ooo`030000
oooooooo00;oool300001?ooo`030000oooooooo06ooool00`000?ooooooo`0coooo00<0003ooooo
ool00_ooo`80000eoooo00<0003oooooool00_ooo`030000oooooooo047oool00`000?ooooooo`1[
oooo0021oooo100000;oool00`000?ooooooo`02oooo00<0003oooooool02oooo`030000oooooooo
067oool00`000?ooooooo`0doooo10000003oooo0000oooo00Koool00`000?ooooooo`0Yoooo1`00
04Coool00`000?ooooooo`1[oooo002;oooo0P0000goool00`000?ooooooo`1Poooo0P0004?oool0
0`000?ooooooo`3Roooo0000\
\>"],
  ImageRangeCache->{{{0, 550.75}, {340, 0}} -> {-1.77268, -146.933, \
0.0225863, 4.16496}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
CellGrouping->Manual,
WindowSize->{1016, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 41, 0, 105, "Title"],

Cell[CellGroupData[{
Cell[1783, 53, 35, 0, 53, "Section"],
Cell[1821, 55, 1462, 26, 188, "Input"],
Cell[3286, 83, 1414, 25, 169, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4737, 113, 35, 0, 53, "Section"],
Cell[4775, 115, 200, 3, 30, "Input"],
Cell[4978, 120, 169, 3, 30, "Input"],
Cell[5150, 125, 1486, 27, 233, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6673, 157, 37, 0, 53, "Section"],

Cell[CellGroupData[{
Cell[6735, 161, 1303, 30, 150, "Input"],
Cell[8041, 193, 41421, 1029, 333, 11090, 650, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[49511, 1228, 36, 0, 53, "Section"],
Cell[49550, 1230, 173, 3, 50, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[49760, 1238, 49, 0, 33, "Section"],
Cell[49812, 1240, 130, 3, 30, "Input"],
Cell[49945, 1245, 124, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[50094, 1252, 1306, 30, 90, "Input"],
Cell[51403, 1284, 62072, 1570, 346, 18713, 1030, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[113512, 2859, 1163, 28, 73, "Input"],
Cell[114678, 2889, 45085, 1036, 349, 9264, 589, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

