(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    148167,       3745]*)
(*NotebookOutlinePosition[    148821,       3768]*)
(*  CellTagsIndexPosition[    148777,       3764]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4.0 in 30 Minutes"
}], "Title"],

Cell[CellGroupData[{

Cell["Basics", "Section"],

Cell["\<\
The first thing you need to know is how to enter expressions. Create a new \
notebook by selecting File | New or pressing Ctrl+N. Enter the following \
text:\
\>", "Text"],

Cell[BoxData[
    \(1 + 1\)], "Input"],

Cell["\<\
Then hit Shift+Enter, or hit the numeric keypad enter key. This evaluates the \
expression you've entered. The kernel starts when you evaluate your first \
expression, so it may take a few seconds. Once the kernel starts and \
evaluates the computation, you should see the result appear in a cell just \
below the one where you entered an expression:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(1 + 1\)], "Input"],

Cell[BoxData[
    \(2\)], "Output"]
}, Open  ]],

Cell["\<\
The blue brackets at the far right of the window show how cells are grouped \
together; this allows you to keep track of which results go with which \
computations, and ultimately to create heirarchies like this tutorial. You \
can double-click to expand or collapse everything in a given bracket. \
Highlight a bracket and hit Shift+Enter or the keypad enter to evaluate it. \
Hit delete to delete that entire bracket. Try expanding, collapsing, \
evaluating, and deleting in your new notebook.\
\>", "Text"],

Cell["\<\
Obviously you're going to want to do more complicated things than add, \
eventually. To take the sin of a number, you can type:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sin[Pi]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "There are three important things to notice about this expression. First, \
the names of all ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions are capitalized. So if you enter"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sin[Pi]\)], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(sin\)\" is similar to \
existing symbol \"\!\(Sin\)\"."\)], "Message"],

Cell[BoxData[
    \(sin[\[Pi]]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "You get a warning, and the result of your expression (the evaluation of \
your brand new \"sin\" function, rather than ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Sin function). Note also that the argument to the Sin function is \
enclosed in square brackets. This is how all arguments to all ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions are made. Thus, the expression"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sin \((Pi)\)\)], "Input"],

Cell[BoxData[
    \(\[Pi]\ Sin\)], "Output"]
}, Open  ]],

Cell["\<\
returns \[Pi] times the Sin function. Note that the output is actually a \
function in this case, not a number. More on outputting functions later. The \
final thing to note is the use of the constant \[Pi], or Pi, which is also \
capitalized. Thus, the expression\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sin[pi]\)], "Input"],

Cell[BoxData[
    \(Sin[pi]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "gives you no error, but \"pi\" is a new variable about which ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " knows absolutely nothing. It might as well be named \"x\"."
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is much more than a glorified calculator, however. It can perform \
symbolic manipulation as well! This expression integrates ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2 + 1\)]],
  " with respect to ",
  StyleBox["x",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Integrate[x^2 + 1, x]\)], "Input"],

Cell[BoxData[
    \(x + x\^3\/3\)], "Output"]
}, Open  ]],

Cell["\<\
Most functions are named exactly what you'd expect, with the notable \
exception of the D function for differentiation:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[x^2 + y^3 + x\ y, x]\)], "Input"],

Cell[BoxData[
    \(2\ x + y\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[x^2 + y^3 + x\ y, y]\)], "Input"],

Cell[BoxData[
    \(x + 3\ y\^2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Note that the expression above uses implicit multiplication of ",
  StyleBox["x",
    FontSlant->"Italic"],
  " and ",
  StyleBox["y",
    FontSlant->"Italic"],
  "; this is accomplished by putting a space between them. Without the space, \
the expression includes a third variable named \"xy\":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[x^2 + y^3 + xy, x]\)], "Input"],

Cell[BoxData[
    \(2\ x\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[x^2 + y^3 + xy, xy]\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Finally, it's important to note that you can give names to expressions by \
storing them in variables. So say we wanted to store the expression ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2 + y\^2\)]],
  "for later computation. We'll call it ",
  StyleBox["z",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(z = x^2 + y^2\)], "Input"],

Cell[BoxData[
    \(x\^2 + y\^2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(z\)], "Input"],

Cell[BoxData[
    \(x\^2 + y\^2\)], "Output"]
}, Open  ]],

Cell["\<\
To clear the value of a variable, just set it equal to \".\", as follows:\
\>", "Text"],

Cell[BoxData[
    \(z =. \)], "Input"],

Cell[TextData[{
  "Note that the value held by ",
  StyleBox["z",
    FontSlant->"Italic"],
  " has, in fact, been erased:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(z\)], "Input"],

Cell[BoxData[
    \(z\)], "Output"]
}, Open  ]],

Cell["\<\
One final thing you might want to do is get numerical values for your \
computations. This is accomplished with the N function:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[Pi]\)], "Input"],

Cell[BoxData[
    \(3.141592653589793`\)], "Output"]
}, Open  ]],

Cell["\<\
A more common way of applying single-argument functions is to use shorthand. \
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Pi // N\)], "Input"],

Cell[BoxData[
    \(3.141592653589793`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(2 // Sqrt\)], "Input"],

Cell[BoxData[
    \(\@2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(2 // Sqrt\) // N\)], "Input"],

Cell[BoxData[
    \(1.4142135623730951`\)], "Output"]
}, Open  ]],

Cell["\<\
This may introduce ambiguity in the order of operations. (For you, not for \
the computer.) The // is generally evaluated last, as a rule of thumb.When in \
doubt, parenthesize.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(1 + 4 // Sqrt\)], "Input"],

Cell[BoxData[
    \(\@5\)], "Output"]
}, Open  ]],

Cell["\<\
With a second argument, you can specifiy the precision of the numerical \
output:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[Pi, 20]\)], "Input"],

Cell[BoxData[
    \(3.141592653589793238462643383279503`20\)], "Output"]
}, Open  ]],

Cell["\<\
Now you know almost everything you need to know in order to do basic \
computations! See the Help Browser (F1) for further details. This is \
extremely useful, and includes examples! Let's move on to lists.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Lists", "Section"],

Cell[TextData[{
  "It's often the case that you want to do computations on lists, and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has an excellent set of tools for working with lists. It's easy to define \
a list. Let's create one called \"a\":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(a = {1, 2, 3, Pi, x, x^2 + 3}\)], "Input"],

Cell[BoxData[
    \({1, 2, 3, \[Pi], x, 3 + x\^2}\)], "Output"]
}, Open  ]],

Cell["\<\
Some useful list functions are demonstrated below; see the Help (F1) for \
further details. Note that if you select one of the function names below and \
then hit F1, you get help on that function. This is true in general, and \
comes in handy for deciphering commands you may encounter.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(First[a]\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Rest[a]\)], "Input"],

Cell[BoxData[
    \({2, 3, \[Pi], x, 3 + x\^2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(a[\([4]\)]\)], "Input"],

Cell[BoxData[
    \(\[Pi]\)], "Output"]
}, Open  ]],

Cell["Drop the first two elements of a:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Drop[a, 2]\)], "Input"],

Cell[BoxData[
    \({3, \[Pi], x, 3 + x\^2}\)], "Output"]
}, Open  ]],

Cell["Or the last two:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Drop[a, \(-2\)]\)], "Input"],

Cell[BoxData[
    \({1, 2, 3, \[Pi]}\)], "Output"]
}, Open  ]],

Cell["\<\
Here's a more complicated, but very useful function that takes a \
Boolean-valued function as its second input:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Select[a, NumberQ]\)], "Input"],

Cell[BoxData[
    \({1, 2, 3}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The NumberQ function returns True (capitalized, remember?) if and only if \
the item it receives as input is a number. The Select function returns a list \
of the elements for which the test function returned true. Pi isn't a number \
from ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s point of view; it's a constant. Be careful of details like this when \
using Pi and E and I as constants."
}], "Text"],

Cell["\<\
Matrices are just lists of lists, but there are some special functions that \
apply to them:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(b = {{1, 2}, {4, 3}}\)], "Input"],

Cell[BoxData[
    \({{1, 2}, {4, 3}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(b[\([1]\)]\)[\([2]\)]\)], "Input"],

Cell[BoxData[
    \(2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(b[\([1, 2]\)]\)], "Input"],

Cell[BoxData[
    \(2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(b[\([2, 1]\)]\)], "Input"],

Cell[BoxData[
    \(4\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[b]\)], "Input"],

Cell[BoxData[
    \({{1, 4}, {2, 3}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Det[b]\)], "Input"],

Cell[BoxData[
    \(\(-5\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Inverse[b]\)], "Input"],

Cell[BoxData[
    \({{\(-\(3\/5\)\), 2\/5}, {4\/5, \(-\(1\/5\)\)}}\)], "Output"]
}, Open  ]],

Cell["Matrix multiplication is performed using the \".\" operator:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(b . Inverse[b]\)], "Input"],

Cell[BoxData[
    \({{1, 0}, {0, 1}}\)], "Output"]
}, Open  ]],

Cell["\<\
To generate a list or table, you may want to use the Table function, which \
evaluates its first argument for the ranges specified as its later arguments. \
For example:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[i + j, {i, 1, 3}, {j, 0, 3}]\)], "Input"],

Cell[BoxData[
    \({{1, 2, 3, 4}, {2, 3, 4, 5}, {3, 4, 5, 6}}\)], "Output"]
}, Open  ]],

Cell["You can also generate a table of lists, of course:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[{x, Sin[x]}, {x, 0, 2  Pi, Pi/6}]\)], "Input"],

Cell[BoxData[
    \({{0, 0}, {\[Pi]\/6, 1\/2}, {\[Pi]\/3, \@3\/2}, {\[Pi]\/2, 
        1}, {\(2\ \[Pi]\)\/3, \@3\/2}, {\(5\ \[Pi]\)\/6, 1\/2}, {\[Pi], 
        0}, {\(7\ \[Pi]\)\/6, \(-\(1\/2\)\)}, {\(4\ \[Pi]\)\/3, \(-\(\@3\/2\)\
\)}, {\(3\ \[Pi]\)\/2, \(-1\)}, {\(5\ \[Pi]\)\/3, \(-\(\@3\/2\)\)}, {\(11\ \
\[Pi]\)\/6, \(-\(1\/2\)\)}, {2\ \[Pi], 0}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The last Pi/6 tells Table to go from 0 to 2Pi in steps of this size. F1 \
for details. Note that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " leaves expressions such as ",
  Cell[BoxData[
      \(TraditionalForm\`\@3\/2\)]],
  "in exact form, rather than evaluating them numerically."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Advanced Lists and Functions", "Section"],

Cell["\<\
This section describes more advanced commands and shorthand for working with \
lists. Most of the commands have long and short forms, in order to save \
typing. We'll mention the long forms briefly and then settle in with the \
shorthand.\
\>", "Text"],

Cell["\<\
The Map function applies a function to each element of a list:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[Sin, {0, Pi, Pi/2}]\)], "Input"],

Cell[BoxData[
    \({0, 0, 1}\)], "Output"]
}, Open  ]],

Cell["Its shorthand form is function/@list:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sin /@ {0, Pi, Pi/2}\)], "Input"],

Cell[BoxData[
    \({0, 0, 1}\)], "Output"]
}, Open  ]],

Cell["\<\
The Apply function essentially passes a list as arguments to a function with \
multiple arguments:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Apply[Plus, {1, 2}]\)], "Input"],

Cell[BoxData[
    \(3\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plus @@ {1, 2, 3, 4}\)], "Input"],

Cell[BoxData[
    \(10\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This is all well and good for built-in functions, but you may need to \
define your own. Fortunately, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " accounts for that. You can define a function as follows:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(newPlus = Function[#1 + #2]\)], "Input"],

Cell[BoxData[
    \(#1 + #2 &\)], "Output"]
}, Open  ]],

Cell["\<\
The Function command returns a function specified by its argument. The \
arguments to the actual function are given by # (for a single-argument \
function) or #1, #2, etc. Thus, the function newPlus is now defined to take \
two arguments (#1 and #2) and return their sum:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(newPlus[1, 2]\)], "Input"],

Cell[BoxData[
    \(3\)], "Output"]
}, Open  ]],

Cell["The shorthand for this is as follows:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(newPlus = \((#1 + #2)\) &\)], "Input"],

Cell[BoxData[
    \(#1 + #2 &\)], "Output"]
}, Open  ]],

Cell["\<\
Now we're ready to do heavy-duty list manipulation. Let's define a function \
without even giving it a name, then map it onto a list. Looks complicated? \
Break it down.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\((#^2 + 1)\) &\) /@ {1, 2, 3, 4, 5}\)], "Input"],

Cell[BoxData[
    \({2, 5, 10, 17, 26}\)], "Output"]
}, Open  ]],

Cell["See Help on Function for further details.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Plotting Commands", "Section"],

Cell["\<\
There are commands for plotting functions, lists, and 3D information.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[Sin[x], {x, 0, 10}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.309015 0.294306 [
[.21429 .29651 -3 -9 ]
[.21429 .29651 3 0 ]
[.40476 .29651 -3 -9 ]
[.40476 .29651 3 0 ]
[.59524 .29651 -3 -9 ]
[.59524 .29651 3 0 ]
[.78571 .29651 -3 -9 ]
[.78571 .29651 3 0 ]
[.97619 .29651 -6 -9 ]
[.97619 .29651 6 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30901 m
.21429 .31526 L
s
[(2)] .21429 .29651 0 1 Mshowa
.40476 .30901 m
.40476 .31526 L
s
[(4)] .40476 .29651 0 1 Mshowa
.59524 .30901 m
.59524 .31526 L
s
[(6)] .59524 .29651 0 1 Mshowa
.78571 .30901 m
.78571 .31526 L
s
[(8)] .78571 .29651 0 1 Mshowa
.97619 .30901 m
.97619 .31526 L
s
[(10)] .97619 .29651 0 1 Mshowa
.125 Mabswid
.07143 .30901 m
.07143 .31276 L
s
.11905 .30901 m
.11905 .31276 L
s
.16667 .30901 m
.16667 .31276 L
s
.2619 .30901 m
.2619 .31276 L
s
.30952 .30901 m
.30952 .31276 L
s
.35714 .30901 m
.35714 .31276 L
s
.45238 .30901 m
.45238 .31276 L
s
.5 .30901 m
.5 .31276 L
s
.54762 .30901 m
.54762 .31276 L
s
.64286 .30901 m
.64286 .31276 L
s
.69048 .30901 m
.69048 .31276 L
s
.7381 .30901 m
.7381 .31276 L
s
.83333 .30901 m
.83333 .31276 L
s
.88095 .30901 m
.88095 .31276 L
s
.92857 .30901 m
.92857 .31276 L
s
.25 Mabswid
0 .30901 m
1 .30901 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .19129 m
.02756 .19129 L
s
.02381 .22072 m
.02756 .22072 L
s
.02381 .25015 m
.02756 .25015 L
s
.02381 .27958 m
.02756 .27958 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .42516 L
.08255 .47925 L
.10458 .52975 L
.11448 .54875 L
.12507 .56621 L
.13499 .5797 L
.14415 .58954 L
.14901 .59372 L
.15437 .59746 L
.15975 .6003 L
.1627 .60146 L
.16546 .6023 L
.1667 .60259 L
.16805 .60286 L
.16934 .60305 L
.17052 .60319 L
.1717 .60327 L
.17277 .60331 L
.174 .60332 L
.17516 .60327 L
.17643 .60317 L
.17707 .6031 L
.17777 .60301 L
.18017 .60258 L
.18153 .60225 L
.18298 .60184 L
.1856 .60091 L
.19088 .59838 L
.19577 .59525 L
.20684 .58538 L
.21659 .57358 L
.22696 .55801 L
.26471 .47813 L
.30491 .3646 L
.3436 .24588 L
.38474 .13133 L
.40527 .08527 L
.41527 .06645 L
.42436 .05167 L
.4332 .03954 L
.44279 .02902 L
.44806 .02443 L
.45291 .02098 L
.45756 .01838 L
.46247 .01637 L
.465 .01565 L
.46625 .01537 L
.4674 .01515 L
.46853 .01498 L
Mistroke
.46956 .01486 L
.4707 .01477 L
.47191 .01472 L
.47322 .01472 L
.47442 .01476 L
.47574 .01487 L
.4764 .01494 L
.47713 .01504 L
.47836 .01525 L
.47968 .01552 L
.48205 .01615 L
.48441 .01696 L
.48697 .01805 L
.49163 .02056 L
.50036 .02711 L
.50978 .03685 L
.52017 .05066 L
.54119 .08778 L
.58145 .18687 L
.62019 .30277 L
.66138 .42668 L
.68195 .48175 L
.70106 .52578 L
.71952 .56007 L
.72977 .57512 L
.73922 .58626 L
.74949 .59527 L
.75489 .59869 L
.75765 .60007 L
.7606 .60129 L
.7632 .60212 L
.76557 .60269 L
.76671 .6029 L
.76795 .60308 L
.76913 .6032 L
.77021 .60328 L
.77147 .60332 L
.77264 .60331 L
.77393 .60325 L
.77466 .60319 L
.77533 .60312 L
.77659 .60295 L
.77798 .6027 L
.78077 .60202 L
.7833 .60118 L
.78604 .60004 L
.79103 .59735 L
.80035 .5902 L
.81125 .57845 L
.8213 .56447 L
Mistroke
.84004 .53097 L
.86067 .48425 L
.90097 .37167 L
.93977 .25263 L
.97619 .14891 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`006goo00<007ooOol0ogoo0goo000KOol0
0`00Oomoo`3oOol3Ool001=oo`D000=oo`03001oogoo0?moo`=oo`005Goo00<007ooOol00goo00<0
07ooOol0ogoo0goo000EOol00`00Oomoo`03Ool2001bOol7002:Ool000eoo`@000Aoo`03001oogoo
00=oo`03001oogoo06moo`8000Moo`8008Qoo`005Goo00<007ooOol00goo00<007ooOol0KWoo00<0
07ooOol02Goo0P00QWoo000DOol20005Ool00`00Oomoo`1]Ool00`00Oomoo`0<Ool00`00Oomoo`23
Ool001]oo`03001oogoo06aoo`03001oogoo00ioo`03001oogoo089oo`006goo00<007ooOol0Jgoo
00<007ooOol03goo00<007ooOol0PWoo000KOol00`00Oomoo`1ZOol00`00Oomoo`0AOol00`00Oomo
o`21Ool001]oo`03001oogoo06Uoo`03001oogoo01=oo`03001oogoo081oo`006goo0P00JWoo00<0
07ooOol057oo00<007ooOol0Ogoo000KOol00`00Oomoo`1XOol00`00Oomoo`0FOol00`00Oomoo`1n
Ool001]oo`03001oogoo06Moo`03001oogoo01Qoo`03001oogoo07eoo`006goo00<007ooOol0Igoo
00<007ooOol067oo00<007ooOol0OGoo000KOol00`00Oomoo`1VOol00`00Oomoo`0JOol00`00Oomo
o`1lOol001]oo`03001oogoo06Ioo`03001oogoo01Yoo`03001oogoo07aoo`006goo00<007ooOol0
IGoo00<007ooOol077oo00<007ooOol0Ngoo000KOol2001UOol00`00Oomoo`0MOol00`00Oomoo`1k
Ool001]oo`03001oogoo06Aoo`03001oogoo01ioo`03001oogoo07Yoo`006goo00<007ooOol0Hgoo
00<007ooOol07goo00<007ooOol0NWoo000KOol00`00Oomoo`1SOol00`00Oomoo`0POol00`00Oomo
o`1iOol001]oo`03001oogoo069oo`03001oogoo025oo`03001oogoo07Uoo`006goo00<007ooOol0
HWoo00<007ooOol08Goo00<007ooOol0NGoo000KOol00`00Oomoo`1QOol00`00Oomoo`0SOol00`00
Oomoo`1hOol001]oo`03001oogoo065oo`03001oogoo02=oo`03001oogoo07Qoo`006goo0P00HGoo
00<007ooOol09Goo00<007ooOol0Mgoo000KOol00`00Oomoo`1POol00`00Oomoo`0UOol00`00Oomo
o`1gOol001]oo`03001oogoo061oo`03001oogoo02Eoo`03001oogoo07Moo`006goo00<007ooOol0
Ggoo00<007ooOol09goo00<007ooOol0MWoo000KOol00`00Oomoo`1OOol00`00Oomoo`0WOol00`00
Oomoo`1fOol001]oo`03001oogoo05ioo`03001oogoo02Uoo`03001oogoo07Eoo`006goo00<007oo
Ool0GWoo00<007ooOol0:Goo00<007ooOol0MGoo000KOol00`00Oomoo`1MOol00`00Oomoo`0ZOol0
0`00Oomoo`1eOol001]oo`8005ioo`03001oogoo02]oo`03001oogoo07Aoo`006goo00<007ooOol0
GGoo00<007ooOol0:goo00<007ooOol0M7oo000KOol00`00Oomoo`1LOol00`00Oomoo`0]Ool00`00
Oomoo`1cOol001]oo`03001oogoo05aoo`03001oogoo02eoo`03001oogoo07=oo`006goo00<007oo
Ool0G7oo00<007ooOol0;Woo00<007ooOol0JWoo00<007ooOol01Goo000KOol00`00Oomoo`1KOol0
0`00Oomoo`0_Ool00`00Oomoo`1ZOol00`00Oomoo`05Ool000Qoo`8000Aoo`8000Aoo`8000Eoo`03
001oogoo05]oo`03001oogoo02moo`03001oogoo06Uoo`03001oogoo00Ioo`001goo00@007ooOol0
00Qoo`04001oogoo0004Ool00`00Oomoo`1JOol00`00Oomoo`0aOol00`00Oomoo`1XOol00`00Oomo
o`06Ool000Moo`04001oogoo000;Ool00`00Oomoo`02Ool2001KOol00`00Oomoo`0aOol00`00Oomo
o`1XOol00`00Oomoo`06Ool00003Ool000000080009oo`04001oogoo0009Ool20005Ool00`00Oomo
o`1JOol00`00Oomoo`0bOol00`00Oomoo`1VOol00`00Oomoo`07Ool000Moo`04001oogoo0009Ool0
0`00Oomoo`04Ool00`00Oomoo`1IOol00`00Oomoo`0cOol00`00Oomoo`1VOol00`00Oomoo`07Ool0
00Qoo`8000Yoo`<000Aoo`03001oogoo05Uoo`03001oogoo03=oo`03001oogoo06Ioo`03001oogoo
00Moo`006goo00<007ooOol0FGoo00<007ooOol0=7oo00<007ooOol0I7oo00<007ooOol027oo000K
Ool00`00Oomoo`1HOol00`00Oomoo`0eOol00`00Oomoo`1TOol00`00Oomoo`08Ool001]oo`03001o
ogoo05Qoo`03001oogoo03Ioo`03001oogoo069oo`03001oogoo00Uoo`006goo00<007ooOol0F7oo
00<007ooOol0=Woo00<007ooOol0HWoo00<007ooOol02Goo000KOol2001HOol00`00Oomoo`0gOol0
0`00Oomoo`1ROol00`00Oomoo`09Ool001]oo`03001oogoo05Moo`03001oogoo03Qoo`03001oogoo
061oo`03001oogoo00Yoo`006goo00<007ooOol0EWoo00<007ooOol0>Goo00<007ooOol0H7oo00<0
07ooOol02Woo000KOol00`00Oomoo`1FOol00`00Oomoo`0iOol00`00Oomoo`1POol00`00Oomoo`0:
Ool001]oo`03001oogoo05Ioo`03001oogoo03Yoo`03001oogoo05ioo`03001oogoo00]oo`006goo
00<007ooOol0EGoo00<007ooOol0>goo00<007ooOol0GWoo00<007ooOol02goo000KOol00`00Oomo
o`1EOol00`00Oomoo`0kOol00`00Oomoo`1NOol00`00Oomoo`0;Ool001]oo`03001oogoo05Eoo`03
001oogoo03aoo`03001oogoo05aoo`03001oogoo00aoo`006goo0P00EGoo00<007ooOol0?Goo00<0
07ooOol0G7oo00<007ooOol037oo000KOol00`00Oomoo`1DOol00`00Oomoo`0mOol00`00Oomoo`1L
Ool00`00Oomoo`0<Ool001]oo`03001oogoo05=oo`03001oogoo03moo`03001oogoo05Yoo`03001o
ogoo00eoo`006goo00<007ooOol0Dgoo00<007ooOol0?goo00<007ooOol0FWoo00<007ooOol03Goo
000KOol00`00Oomoo`1COol00`00Oomoo`0oOol00`00Oomoo`1IOol00`00Oomoo`0>Ool001]oo`03
001oogoo059oo`03001oogoo045oo`03001oogoo05Qoo`03001oogoo00ioo`006goo00<007ooOol0
DWoo00<007ooOol0@Goo00<007ooOol0F7oo00<007ooOol03Woo000KOol2001COol00`00Oomoo`11
Ool00`00Oomoo`1GOol00`00Oomoo`0?Ool001]oo`03001oogoo055oo`03001oogoo04=oo`03001o
ogoo05Ioo`03001oogoo00moo`006goo00<007ooOol0DGoo00<007ooOol0@goo00<007ooOol0EWoo
00<007ooOol03goo000KOol00`00Oomoo`1AOol00`00Oomoo`13Ool00`00Oomoo`1EOol00`00Oomo
o`0@Ool001]oo`03001oogoo051oo`03001oogoo04Eoo`03001oogoo05Aoo`03001oogoo011oo`00
6goo00<007ooOol0;Goo10007goo00<007ooOol03goo0`00;Woo0`000Woo00<007ooOol0:goo0P00
9goo00<007ooOol00goo1@000Woo0P0017oo000KOol00`00Oomoo`0]Ool00`00Oomoo`0POol00`00
Oomoo`0@Ool00`00Oomoo`0]Ool01P00Oomoo`00Ool002aoo`04001oogoo000UOol00`00Oomoo`06
Ool01@00Oomoogoo00000Woo00<007ooOol00Goo000KOol00`00Oomoo`0^Ool00`00Oomoo`0OOol0
0`00Oomoo`0=Ool5000^Ool01000Oomoo`000Woo00<007ooOol0:Goo00@007ooOol002Eoo`03001o
ogoo00Ioo`05001oogooOol00002Ool00`00Oomoo`01Ool001]oo`80031oo`03001oogoo01eoo`03
001oogoo00ioo`04001oogoo000_Ool30003Ool00`00Oomoo`0ZOol2000VOol00`00Oomoo`06Ool0
1@00Oomoogoo00000Woo00<007ooOol00Goo000KOol00`00Oomoo`0]Ool01000Oomoo`007Woo00<0
07ooOol03goo00<007oo0000<7oo00<007ooOol00Woo00<007ooOol0:Goo00@007ooOol002Eoo`03
001oogoo00Ioo`05001oogooOol00002Ool00`00Oomoo`01Ool001]oo`03001oogoo02ioo`8001mo
o`03001oogoo011oo`80031oo`<000=oo`03001oogoo02Uoo`8002Eoo`03001oogoo00Ioo`8000Ao
o`8000Aoo`006goo00<007ooOol0CWoo00<007ooOol0BGoo00<007ooOol0D7oo00<007ooOol04Woo
000KOol00`00Oomoo`1>Ool00`00Oomoo`19Ool00`00Oomoo`1@Ool00`00Oomoo`0BOol001]oo`03
001oogoo04ioo`03001oogoo04Yoo`03001oogoo04ioo`03001oogoo01=oo`006goo00<007ooOol0
CGoo00<007ooOol0Bgoo00<007ooOol0CWoo00<007ooOol04goo000KOol00`00Oomoo`1=Ool00`00
Oomoo`1;Ool00`00Oomoo`1>Ool00`00Oomoo`0COol001Aoool000d000006goo00<007ooOol02Goo
00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Woo
00@007ooOol000Qoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yo
o`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Yo
o`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Moo`03001oo`0000ao
o`03001oogoo00Eoo`006goo0P00<7oo00<007ooOol06Woo00<007ooOol04goo00<007ooOol0<7oo
00<007ooOol017oo00<007ooOol0:7oo00<007ooOol08Goo00<007ooOol037oo00<007ooOol01Goo
000KOol2001=Ool00`00Oomoo`1>Ool00`00Oomoo`1:Ool00`00Oomoo`0EOol001]oo`8004aoo`03
001oogoo04moo`03001oogoo04Yoo`03001oogoo01Eoo`006goo00<007oo0000Bgoo00<007ooOol0
Cgoo00<007ooOol0BWoo00<007ooOol05Goo000KOol00`00Ool0001;Ool00`00Oomoo`1@Ool00`00
Oomoo`18Ool00`00Oomoo`0FOol001]oo`03001oo`0004]oo`03001oogoo051oo`03001oogoo04Qo
o`03001oogoo01Ioo`006goo0P0000=oo`00Ool0B7oo00<007ooOol0DGoo00<007ooOol0B7oo00<0
07ooOol05Woo000KOol01000Oomoo`00BGoo00<007ooOol0DWoo00<007ooOol0Agoo00<007ooOol0
5Woo000KOol01000Oomoo`00BGoo00<007ooOol0DWoo00<007ooOol0AWoo00<007ooOol05goo000K
Ool01@00Oomoogoo0000Agoo00<007ooOol0Dgoo00<007ooOol0AWoo00<007ooOol05goo000KOol0
1@00Oomoogoo0000Agoo00<007ooOol0E7oo00<007ooOol0AGoo00<007ooOol05goo000KOol01@00
Oomoogoo0000Agoo00<007ooOol0E7oo00<007ooOol0A7oo00<007ooOol067oo000KOol00`00Oomo
o`02Ool00`00Oomoo`13Ool00`00Oomoo`1EOol00`00Oomoo`14Ool00`00Oomoo`0HOol001]oo`03
001oogoo009oo`03001oogoo04=oo`03001oogoo05Ioo`03001oogoo04=oo`03001oogoo01Qoo`00
6goo0P000goo00<007ooOol0@goo00<007ooOol0EWoo00<007ooOol0@Woo00<007ooOol06Goo000K
Ool00`00Oomoo`02Ool00`00Oomoo`12Ool00`00Oomoo`1GOol00`00Oomoo`12Ool00`00Oomoo`0I
Ool001]oo`03001oogoo00=oo`03001oogoo045oo`03001oogoo05Qoo`03001oogoo045oo`03001o
ogoo01Uoo`006goo00<007ooOol00goo00<007ooOol0@Goo00<007ooOol0F7oo00<007ooOol0@7oo
00<007ooOol06Woo000KOol00`00Oomoo`03Ool00`00Oomoo`10Ool00`00Oomoo`1IOol00`00Oomo
o`10Ool00`00Oomoo`0JOol001]oo`03001oogoo00Aoo`03001oogoo03moo`03001oogoo05Yoo`03
001oogoo03moo`03001oogoo01Yoo`006goo00<007ooOol017oo00<007ooOol0?Woo00<007ooOol0
Fgoo00<007ooOol0?Woo00<007ooOol06goo000KOol00`00Oomoo`04Ool00`00Oomoo`0nOol00`00
Oomoo`1KOol00`00Oomoo`0nOol00`00Oomoo`0KOol001]oo`8000Ioo`03001oogoo03eoo`03001o
ogoo05aoo`03001oogoo03aoo`03001oogoo01aoo`006goo00<007ooOol01Goo00<007ooOol0?7oo
00<007ooOol0GGoo00<007ooOol0?7oo00<007ooOol077oo000KOol00`00Oomoo`05Ool00`00Oomo
o`0lOol00`00Oomoo`1MOol00`00Oomoo`0lOol00`00Oomoo`0LOol001]oo`03001oogoo00Ioo`03
001oogoo03]oo`03001oogoo05ioo`03001oogoo03Yoo`03001oogoo01eoo`006goo00<007ooOol0
1Woo00<007ooOol0>Woo00<007ooOol0Ggoo00<007ooOol0>Woo00<007ooOol07Goo000KOol00`00
Oomoo`06Ool00`00Oomoo`0jOol00`00Oomoo`1OOol00`00Oomoo`0jOol00`00Oomoo`0MOol001]o
o`03001oogoo00Moo`03001oogoo03Uoo`03001oogoo061oo`03001oogoo03Qoo`03001oogoo01io
o`006goo0P0027oo00<007ooOol0>7oo00<007ooOol0HGoo00<007ooOol0>7oo00<007ooOol07Woo
000KOol00`00Oomoo`07Ool00`00Oomoo`0hOol00`00Oomoo`1QOol00`00Oomoo`0hOol00`00Oomo
o`0NOol001]oo`03001oogoo00Qoo`03001oogoo03Ioo`03001oogoo06=oo`03001oogoo03Ioo`03
001oogoo01moo`006goo00<007ooOol027oo00<007ooOol0=Woo00<007ooOol0Hgoo00<007ooOol0
=Woo00<007ooOol07goo000KOol00`00Oomoo`08Ool00`00Oomoo`0fOol00`00Oomoo`1TOol00`00
Oomoo`0dOol00`00Oomoo`0POol001]oo`03001oogoo00Uoo`03001oogoo03Aoo`03001oogoo06Eo
o`03001oogoo03Aoo`03001oogoo021oo`0027oo0P0017oo0P0017oo0P001Goo00<007ooOol02Goo
00<007ooOol0=7oo00<007ooOol0IGoo00<007ooOol0=7oo00<007ooOol087oo0007Ool01000Oomo
o`0027oo00@007ooOol000Aoo`03001oogoo00Yoo`03001oogoo03=oo`03001oogoo06Ioo`03001o
ogoo039oo`03001oogoo025oo`001goo00@007ooOol000]oo`03001oogoo009oo`8000]oo`03001o
ogoo039oo`03001oogoo06Moo`03001oogoo039oo`03001oogoo025oo`001goo00@007ooOol000Uo
o`8000Eoo`03001oogoo00Yoo`03001oogoo039oo`03001oogoo06Qoo`03001oogoo035oo`03001o
ogoo025oo`001goo00@007ooOol000Uoo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo031o
o`03001oogoo06Uoo`03001oogoo031oo`03001oogoo029oo`0027oo0P002Woo0`0017oo00<007oo
Ool02goo00<007ooOol0<7oo00<007ooOol0JGoo00<007ooOol0<7oo00<007ooOol08Woo000KOol0
0`00Oomoo`0;Ool00`00Oomoo`0`Ool00`00Oomoo`1ZOol00`00Oomoo`0^Ool00`00Oomoo`0SOol0
01]oo`03001oogoo00aoo`03001oogoo02ioo`03001oogoo06]oo`03001oogoo02ioo`03001oogoo
02=oo`006goo00<007ooOol037oo00<007ooOol0;Woo00<007ooOol0K7oo00<007ooOol0;Goo00<0
07ooOol08goo000KOol00`00Oomoo`0<Ool00`00Oomoo`0^Ool00`00Oomoo`1/Ool00`00Oomoo`0/
Ool00`00Oomoo`0TOol001]oo`8000ioo`03001oogoo02aoo`03001oogoo06eoo`03001oogoo02ao
o`03001oogoo02Aoo`006goo00<007ooOol03Goo00<007ooOol0;7oo00<007ooOol0KWoo00<007oo
Ool0:goo00<007ooOol097oo000KOol00`00Oomoo`0>Ool00`00Oomoo`0ZOol00`00Oomoo`1_Ool0
0`00Oomoo`0ZOol00`00Oomoo`0UOol001]oo`03001oogoo00ioo`03001oogoo02Yoo`03001oogoo
071oo`03001oogoo02Uoo`03001oogoo02Eoo`006goo00<007ooOol03goo00<007ooOol0:7oo00<0
07ooOol0LGoo00<007ooOol0:7oo00<007ooOol09Woo000KOol00`00Oomoo`0?Ool00`00Oomoo`0X
Ool00`00Oomoo`1bOol00`00Oomoo`0WOol00`00Oomoo`0VOol001]oo`03001oogoo00moo`03001o
ogoo02Moo`03001oogoo07=oo`03001oogoo02Moo`03001oogoo02Ioo`006goo00<007ooOol047oo
00<007ooOol09Woo00<007ooOol0Lgoo00<007ooOol09Woo00<007ooOol09goo000KOol2000AOol0
0`00Oomoo`0UOol00`00Oomoo`1eOol00`00Oomoo`0UOol00`00Oomoo`0WOol001]oo`03001oogoo
015oo`03001oogoo02Aoo`03001oogoo07Eoo`03001oogoo02Aoo`03001oogoo02Qoo`006goo00<0
07ooOol04Goo00<007ooOol08goo00<007ooOol0Mgoo00<007ooOol08goo00<007ooOol0:7oo000K
Ool00`00Oomoo`0BOol00`00Oomoo`0ROol00`00Oomoo`1gOol00`00Oomoo`0ROol00`00Oomoo`0Y
Ool001]oo`03001oogoo019oo`03001oogoo025oo`03001oogoo07Uoo`03001oogoo025oo`03001o
ogoo02Uoo`006goo00<007ooOol04goo00<007ooOol087oo00<007ooOol0NGoo00<007ooOol087oo
00<007ooOol0:Woo000KOol00`00Oomoo`0COol00`00Oomoo`0OOol00`00Oomoo`1kOol00`00Oomo
o`0OOol00`00Oomoo`0ZOol001]oo`03001oogoo01Aoo`03001oogoo01ioo`03001oogoo07]oo`03
001oogoo01ioo`03001oogoo02]oo`006goo0P005Goo00<007ooOol07Goo00<007ooOol0OGoo00<0
07ooOol07Goo00<007ooOol0:goo000KOol00`00Oomoo`0EOol00`00Oomoo`0LOol00`00Oomoo`1m
Ool00`00Oomoo`0LOol00`00Oomoo`0/Ool001]oo`03001oogoo01Ioo`03001oogoo01Yoo`03001o
ogoo07moo`03001oogoo01]oo`03001oogoo02aoo`006goo00<007ooOol05goo00<007ooOol06Goo
00<007ooOol0Ogoo00<007ooOol06Woo00<007ooOol0;Goo000KOol00`00Oomoo`0GOol00`00Oomo
o`0HOol00`00Oomoo`21Ool00`00Oomoo`0IOol00`00Oomoo`0]Ool001]oo`03001oogoo01Qoo`03
001oogoo01Moo`03001oogoo089oo`03001oogoo01Moo`03001oogoo02ioo`006goo00<007ooOol0
6Goo00<007ooOol05Goo00<007ooOol0Q7oo00<007ooOol05Goo00<007ooOol0;goo000KOol2000J
Ool00`00Oomoo`0DOol00`00Oomoo`25Ool00`00Oomoo`0EOol00`00Oomoo`0_Ool001]oo`03001o
ogoo01Yoo`03001oogoo01=oo`03001oogoo08Ioo`03001oogoo01=oo`03001oogoo031oo`006goo
00<007ooOol06Woo00<007ooOol04Woo00<007ooOol0R7oo00<007ooOol04Goo00<007ooOol0<Goo
000KOol00`00Oomoo`0KOol00`00Oomoo`0AOol00`00Oomoo`28Ool00`00Oomoo`0@Ool00`00Oomo
o`0bOol001]oo`03001oogoo01aoo`03001oogoo00moo`03001oogoo08Yoo`03001oogoo00ioo`03
001oogoo03=oo`006goo00<007ooOol07Goo00<007ooOol037oo0P00SWoo0P003Goo00<007ooOol0
=7oo000COol50003Ool00`00Oomoo`0NOol2000:Ool2002BOol00`00Oomoo`09Ool00`00Oomoo`0e
Ool001Eoo`03001oogoo00=oo`03001oogoo021oo`03001oogoo00Ioo`03001oogoo09=oo`8000Mo
o`8003Qoo`005Goo00<007ooOol00goo0P008Woo2000V7oo1`00>Woo000EOol00`00Oomoo`03Ool0
0`00Oomoo`3oOol3Ool001Eoo`03001oogoo00=oo`03001oogoo0?moo`=oo`0057oo0P001Goo00<0
07ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.07864, -1.13005, \
0.0394728, 0.0127735}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Easy enough. You can also plot lists using the ListPlot command:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(a = {5, 4, 3, 2, 1}\)], "Input"],

Cell[BoxData[
    \({5, 4, 3, 2, 1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[a]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214286 0.238095 -0.132436 0.147151 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.7381 .00222 -3 -9 ]
[.7381 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .16187 -6 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .45617 -6 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(2)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(3)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(4)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(5)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16187 m
.03006 .16187 L
s
[(2)] .01131 .16187 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(3)] .01131 .30902 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(4)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(5)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .60332 Mdot
.2619 .45617 Mdot
.5 .30902 Mdot
.7381 .16187 Mdot
.97619 .01472 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo001>Ool4
000mOol20010Ool3000mOol2000=Ool004ioo`03001oogoo03eoo`04001oogoo0010Ool00`00Oomo
o`0kOol01000Oomoo`0037oo001?Ool00`00Oomoo`0nOol00`00Oomoo`0lOol5000oOol00`00Oomo
o`0:Ool0051oo`03001oogoo03ioo`03001oogoo03]oo`04001oogoo000nOol2000=Ool004ioo`04
001oogoo000lOol01000Oomoo`00?Woo00<007oo0000?Woo00<007ooOol037oo001?Ool2000nOol2
0010Ool2000nOol3000<Ool00?moob5oo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3o
Ool?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo0009Oooo000A0007Ool0
00moo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Uoo`8000eoo`003goo00<007ooOol0?Woo00<007ooOol0?Goo00<007ooOol0?Woo00<007ooOol0
?Woo00<007ooOol02goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo
00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo
0P00ogoo47oo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007oo
Ool0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007oo
Ool0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`800?mooa1oo`003goo00<007ooOol0ogoo
3goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo
3goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo
3goo000?Ool2003oOol@Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?
Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?
Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo0P00ogoo47oo000?Ool00`00
Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00
Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`001goo100017oo00<007ooOol0ogoo3goo0007
Ool00`00Oomoo`05Ool00`00Oomoo`3oOol?Ool000Qoo`03001oogoo00Aoo`<00;moo`8004eoo`00
2Goo00<007ooOol00goo00<007ooOol0_goo0P00CGoo0007Ool01000Oomoo`0017oo00<007ooOol0
ogoo3goo0008Ool20005Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<0
07ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo0P00
ogoo47oo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0
ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0
ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`800?mooa1oo`003goo00<007ooOol0ogoo3goo
000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo
000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo
000?Ool2003oOol@Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool0
0`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool0
0`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo0P00ogoo47oo000?Ool00`00Oomo
o`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomo
o`3oOol?Ool000moo`03001oogoo0?moo`moo`0027oo0P001Goo00<007ooOol0ogoo3goo0007Ool0
1000Oomoo`0017oo00<007ooOol0ogoo3goo0009Ool00`00Oomoo`03Ool3001nOol2002>Ool000Yo
o`03001oogoo009oo`03001oogoo07ioo`8008ioo`001goo00@007ooOol000Aoo`03001oogoo0?mo
o`moo`0027oo0P001Goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001o
ogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`800?mo
oa1oo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?mo
o`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?mo
o`moo`003goo00<007ooOol0ogoo3goo000?Ool2003oOol@Ool000moo`03001oogoo0?moo`moo`00
3goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`00
3goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`00
3goo0P00ogoo47oo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<0
07ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<0
07ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`800?mooa1oo`003goo00<007ooOol0
ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0
ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000Uoo`<000=oo`03001oogoo0?moo`moo`002Woo00<0
07ooOol00Woo00<007ooOol0ogoo3goo0007Ool50003Ool3000mOol2003?Ool000Moo`04001oogoo
0004Ool00`00Oomoo`0mOol2003?Ool000Qoo`03001oo`0000Aoo`03001oogoo0?moo`moo`002Goo
0P0017oo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`mo
o`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`800?mooa1oo`003goo
00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo
00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo
00<007ooOol0ogoo3goo000?Ool2003oOol@Ool000moo`03001oogoo0?moo`moo`003goo00<007oo
Ool0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007oo
Ool0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo0P00ogoo
47oo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo
3goo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo
3goo000?Ool00`00Oomoo`3oOol?Ool000moo`800?mooa1oo`003goo00<007ooOol0ogoo3goo000?
Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?
Ool00`00Oomoo`3oOol?Ool000Qoo`8000Eoo`03001oogoo0?moo`moo`001goo00@007ooOol000Ao
o`03001oogoo0?moo`moo`002Woo00@007ooOomoo`@00?moo`moo`0027oo0P0017oo0P00ogoo4Goo
0008Ool00`00Oomoo`04Ool00`00Oomoo`3oOol?Ool000Qoo`<000Aoo`03001oogoo0?moo`moo`00
3goo00<007ooOol0ogoo3goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.760744, 0.690121, \
0.0154472, 0.024994}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The graphics can be resized using the mouse if they're too small. Here the \
list ",
  StyleBox["a",
    FontSlant->"Italic"],
  " has been plotted using the index of each element as an ",
  StyleBox["x",
    FontSlant->"Italic"],
  "-coordinate. Alternately, we could do"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(a = Table[{x, Sin[x]}, {x, 0, 2  Pi, Pi/12}]\)], "Input"],

Cell[BoxData[
    \({{0, 0}, {\[Pi]\/12, \(\(-1\) + \@3\)\/\(2\ \@2\)}, {\[Pi]\/6, 
        1\/2}, {\[Pi]\/4, 
        1\/\@2}, {\[Pi]\/3, \@3\/2}, {\(5\ \[Pi]\)\/12, \(1 + \@3\)\/\(2\ \@2\
\)}, {\[Pi]\/2, 
        1}, {\(7\ \[Pi]\)\/12, \(1 + \@3\)\/\(2\ \@2\)}, {\(2\ \[Pi]\)\/3, \
\@3\/2}, {\(3\ \[Pi]\)\/4, 1\/\@2}, {\(5\ \[Pi]\)\/6, 
        1\/2}, {\(11\ \[Pi]\)\/12, \(\(-1\) + \@3\)\/\(2\ \@2\)}, {\[Pi], 
        0}, {\(13\ \[Pi]\)\/12, \(-\(\(\(-1\) + \@3\)\/\(2\ \@2\)\)\)}, {\(7\ \
\[Pi]\)\/6, \(-\(1\/2\)\)}, {\(5\ \[Pi]\)\/4, \(-\(1\/\@2\)\)}, {\(4\ \[Pi]\)\
\/3, \(-\(\@3\/2\)\)}, {\(17\ \[Pi]\)\/12, \(-\(\(1 + \@3\)\/\(2\ \@2\)\)\)}, \
{\(3\ \[Pi]\)\/2, \(-1\)}, {\(19\ \[Pi]\)\/12, \(-\(\(1 + \@3\)\/\(2\ \@2\)\)\
\)}, {\(5\ \[Pi]\)\/3, \(-\(\@3\/2\)\)}, {\(7\ \[Pi]\)\/4, \(-\(1\/\@2\)\)}, \
{\(11\ \[Pi]\)\/6, \(-\(1\/2\)\)}, {\(23\ \[Pi]\)\/12, \(-\(\(\(-1\) + \
\@3\)\/\(2\ \@2\)\)\)}, {2\ \[Pi], 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[a]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309017 0.294302 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01472 -12 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75137 .30902 m
.75137 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01472 m
.03006 .01472 L
s
[(-1)] .01131 .01472 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .30902 Mdot
.06349 .38519 Mdot
.10317 .45617 Mdot
.14286 .51712 Mdot
.18254 .56389 Mdot
.22222 .59329 Mdot
.2619 .60332 Mdot
.30159 .59329 Mdot
.34127 .56389 Mdot
.38095 .51712 Mdot
.42063 .45617 Mdot
.46032 .38519 Mdot
.5 .30902 Mdot
.53968 .23285 Mdot
.57937 .16187 Mdot
.61905 .10091 Mdot
.65873 .05414 Mdot
.69841 .02474 Mdot
.7381 .01472 Mdot
.77778 .02474 Mdot
.81746 .05414 Mdot
.85714 .10091 Mdot
.89683 .16187 Mdot
.93651 .23285 Mdot
.97619 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`006goo00<007ooOol0ogoo0goo000KOol0
0`00Oomoo`3oOol3Ool001=oo`D000=oo`03001oogoo0?moo`=oo`005Goo00<007ooOol00goo00<0
07ooOol0^Woo0P00AWoo000EOol00`00Oomoo`03Ool2002kOol20016Ool000eoo`@000Aoo`03001o
ogoo00=oo`03001oogoo0?moo`=oo`005Goo00<007ooOol00goo00<007ooOol0/7oo0P004goo0P00
>goo000DOol20005Ool00`00Oomoo`2`Ool2000COol2000kOol001]oo`03001oogoo0?moo`=oo`00
6goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`00
6goo0P00ogoo17oo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0:Eoo`8002Qoo`80035o
o`006goo00<007ooOol0YGoo0P00:7oo0P00<Goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001o
ogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol2003oOol4Ool001]oo`03001oogoo0?mo
o`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?mo
o`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo09]o
o`8003eoo`8002Ioo`006goo0P00W7oo0P00?Goo0P009Woo000KOol00`00Oomoo`3oOol3Ool001]o
o`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]o
o`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]o
o`800?moo`Aoo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001o
ogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool000Qoo`8000Ao
o`8000Aoo`8000Eoo`03001oogoo0?moo`=oo`001goo00@007ooOol000Qoo`04001oogoo0004Ool0
0`00Oomoo`2@Ool2001BOol2000LOol000Moo`04001oogoo000;Ool00`00Oomoo`02Ool2002AOol2
001BOol2000LOol00003Ool000000080009oo`04001oogoo0009Ool20005Ool00`00Oomoo`3oOol3
Ool000Moo`04001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3oOol3Ool000Qoo`8000Yoo`<0
00Aoo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool0
01]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol2003oOol4Ool001]oo`03
001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03
001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03
001oogoo0?moo`=oo`006goo0P00ogoo17oo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo
08Eoo`8006Qoo`80015oo`006goo00<007ooOol0QGoo0P00J7oo0P004Goo000KOol00`00Oomoo`3o
Ool3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol2003oOol4Ool0
01]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool0
01]oo`03001oogoo0?moo`=oo`006goo00<007ooOol08goo1@008goo10009Woo0P009goo0`0097oo
0P009Woo0`004Woo000KOol00`00Oomoo`0UOol00`00Oomoo`0SOol00`00Oomoo`0VOol01000Oomo
o`009goo00<007ooOol08Woo00@007ooOol002Eoo`04001oogoo000AOol001]oo`03001oogoo02Eo
o`03001oogoo02Aoo`03001oogoo02Moo`03001oogoo02=oo`D002Ioo`03001oogoo02=oo`04001o
ogoo000AOol001]oo`8002Ioo`03001oogoo02Eoo`03001oogoo02Moo`03001oogoo029oo`04001o
ogoo000UOol2000VOol3000BOol001]oo`03001oogoo02Eoo`03001oogoo02=oo`04001oogoo000U
Ool01000Oomoo`009Goo00<007oo00009Goo00<007ooOol09Woo00<007ooOol04Goo000KOol00`00
Oomoo`0TOol2000VOol2000WOol2000WOol2000UOol3000VOol3000AOol001]oo`03001oogoo0?mo
o`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?mo
o`=oo`006goo00<007ooOol0ogoo0goo000DOooo000=000001Yoo`8000Moo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo009oo`800003Ool007oo00Io
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Io
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo0080
00=oo`40005oo`5oo`006goo00<007ooOol09Goo00<007ooOol09Goo00<007ooOol09Woo00<007oo
Ool09Goo00<007ooOol09Goo00<007ooOol09Woo00<007ooOol047oo000KOol00`00Oomoo`3oOol3
Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3
Ool001]oo`03001oogoo0?moo`=oo`006goo0P00ogoo17oo000KOol00`00Oomoo`3oOol3Ool001]o
o`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]o
o`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]o
o`800?moo`Aoo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001o
ogoo0?moo`=oo`006goo00<007ooOol01goo0P00Igoo0P00T7oo000KOol00`00Oomoo`07Ool2001W
Ool2002@Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol2003oOol4
Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3
Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3
Ool001]oo`800?moo`Aoo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]o
o`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool000Qo
o`8000Aoo`8000Aoo`8000Eoo`03001oogoo0?moo`=oo`001goo00@007ooOol000Qoo`04001oogoo
0004Ool00`00Oomoo`3oOol3Ool000Moo`04001oogoo000;Ool00`00Oomoo`02Ool2000BOol2001C
Ool2002JOol000Moo`04001oogoo0009Ool20005Ool00`00Oomoo`0AOol2001COol2002JOol000Mo
o`04001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3oOol3Ool000Qoo`8000Yoo`<000Aoo`03
001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03
001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol2003oOol4Ool001]oo`03001oogoo
0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo
0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo
0?moo`=oo`006goo0P007Goo0P00?Goo0P00YGoo000KOol00`00Oomoo`0LOol2000mOol2002UOol0
01]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool0
01]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool0
01]oo`800?moo`Aoo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03
001oogoo0?moo`=oo`006goo00<007ooOol09Woo0P00:Goo0P00[goo000KOol00`00Oomoo`0VOol2
000YOol2002_Ool001]oo`03001oogoo0?moo`=oo`006goo0P00ogoo17oo000KOol00`00Oomoo`3o
Ool3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3o
Ool3Ool001]oo`03001oogoo035oo`8001=oo`800;Yoo`004goo1@000goo00<007ooOol0<Goo0P00
4goo0P00^Woo000EOol00`00Oomoo`03Ool00`00Oomoo`3oOol3Ool001Eoo`03001oogoo00=oo`80
03eoo`800<Aoo`005Goo00<007ooOol00goo00<007ooOol0?7oo0P00a7oo000EOol00`00Oomoo`03
Ool00`00Oomoo`3oOol3Ool001Aoo`8000Eoo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo
0goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.677733, -1.13006, \
0.0248015, 0.0127737}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Note that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " evaluates the exact expressions in the list numerically in order to plot \
them, but the list remains unchanged."
}], "Text"],

Cell["\<\
The commands displayed here all have plotting options (see help examples for \
details) and 3D versions. For example:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[x^2 + y^2, {x, \(-5\), 5}, {y, \(-5\), 5}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-016 1.04977 -0.0679587 1.04977 [
[.08608 .22315 -12 -8.87306 ]
[.08608 .22315 0 .12694 ]
[.20731 .17545 -11.6738 -9 ]
[.20731 .17545 .32622 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.46808 .07289 -5.33651 -9 ]
[.46808 .07289 .66349 0 ]
[.60856 .01769 -5.08632 -9 ]
[.60856 .01769 .91368 0 ]
[.73498 .04732 0 -6.2105 ]
[.73498 .04732 12 2.7895 ]
[.79846 .14452 0 -6.11593 ]
[.79846 .14452 12 2.88407 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.90976 .31495 0 -5.95504 ]
[.90976 .31495 6 3.04496 ]
[.95881 .39008 0 -5.88604 ]
[.95881 .39008 6 3.11396 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01048 .35054 -12 -2.81462 ]
[.01048 .35054 0 6.18538 ]
[-0.00392 .44084 -12 -2.89148 ]
[-0.00392 .44084 0 6.10852 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09549 .2323 m
.1002 .23687 L
s
[(-4)] .08608 .22315 1 .97179 Mshowa
.21633 .18498 m
.22084 .18975 L
s
[(-2)] .20731 .17545 .94563 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.47614 .08324 m
.48017 .08842 L
s
[(2)] .46808 .07289 .77884 1 Mshowa
.61605 .02846 m
.6198 .03385 L
s
[(4)] .60856 .01769 .69544 1 Mshowa
.125 Mabswid
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.18558 .19702 m
.18832 .19985 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.51046 .06981 m
.51284 .07294 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.06616 .24378 m
.06901 .2465 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.72272 .05198 m
.71658 .05431 L
s
[(-4)] .73498 .04732 -1 .38011 Mshowa
.78611 .14895 m
.77994 .15117 L
s
[(-2)] .79846 .14452 -1 .3591 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.89727 .31899 m
.89103 .32101 L
s
[(2)] .90976 .31495 -1 .32334 Mshowa
.94627 .39394 m
.94 .39587 L
s
[(4)] .95881 .39008 -1 .30801 Mshowa
.125 Mabswid
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.7708 .12553 m
.7671 .12688 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.9099 .3383 m
.90615 .3395 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.70593 .0263 m
.70226 .02771 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02277 .34593 m
.02892 .34363 L
s
[(20)] .01048 .35054 1 -0.37453 Mshowa
.00843 .43642 m
.01461 .43421 L
s
[(40)] -0.00392 .44084 1 -0.35745 Mshowa
.125 Mabswid
.03301 .2813 m
.03669 .27988 L
s
.02965 .30255 m
.03332 .30114 L
s
.02623 .32409 m
.02991 .3227 L
s
.01926 .36808 m
.02295 .36671 L
s
.0157 .39054 m
.0194 .38919 L
s
.01209 .41332 m
.01579 .41198 L
s
.00472 .45986 m
.00843 .45855 L
s
.00095 .48363 m
.00467 .48234 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.744 .635 .738 r
.37583 .7584 .39806 .80578 .43765 .76727 .41565 .71971 Metetra
.733 .63 .744 r
.41565 .71971 .43765 .76727 .47712 .73308 .45533 .68531 Metetra
.719 .624 .75 r
.45533 .68531 .47712 .73308 .51664 .7031 .49503 .65508 Metetra
.705 .617 .756 r
.49503 .65508 .51664 .7031 .55633 .67724 .53487 .62893 Metetra
.689 .61 .762 r
.53487 .62893 .55633 .67724 .59635 .65545 .57502 .60681 Metetra
.672 .601 .768 r
.57502 .60681 .59635 .65545 .63684 .63769 .61562 .58868 Metetra
.652 .592 .774 r
.61562 .58868 .63684 .63769 .67796 .62396 .65683 .57455 Metetra
.632 .581 .779 r
.65683 .57455 .67796 .62396 .71989 .6143 .69882 .56444 Metetra
.609 .569 .784 r
.69882 .56444 .71989 .6143 .76278 .60878 .74176 .55841 Metetra
.585 .556 .788 r
.74176 .55841 .76278 .60878 .80685 .60747 .78585 .55656 Metetra
.559 .542 .792 r
.78585 .55656 .80685 .60747 .85228 .61053 .8313 .55901 Metetra
.532 .526 .794 r
.8313 .55901 .85228 .61053 .89932 .61812 .87832 .56594 Metetra
.503 .51 .796 r
.87832 .56594 .89932 .61812 .9482 .63045 .92718 .57756 Metetra
.473 .492 .797 r
.92718 .57756 .9482 .63045 .99922 .6478 .97816 .59413 Metetra
.753 .65 .747 r
.35316 .7148 .37583 .7584 .41565 .71971 .39326 .67588 Metetra
.741 .646 .754 r
.39326 .67588 .41565 .71971 .45533 .68531 .43319 .64122 Metetra
.727 .64 .761 r
.43319 .64122 .45533 .68531 .49503 .65508 .47311 .61071 Metetra
.712 .634 .768 r
.47311 .61071 .49503 .65508 .53487 .62893 .51316 .58425 Metetra
.696 .626 .775 r
.51316 .58425 .53487 .62893 .57502 .60681 .55349 .56179 Metetra
.677 .618 .782 r
.55349 .56179 .57502 .60681 .61562 .58868 .59425 .54329 Metetra
.657 .608 .788 r
.59425 .54329 .61562 .58868 .65683 .57455 .63559 .52875 Metetra
.634 .597 .795 r
.63559 .52875 .65683 .57455 .69882 .56444 .6777 .5182 Metetra
.61 .585 .8 r
.6777 .5182 .69882 .56444 .74176 .55841 .72075 .51169 Metetra
.584 .571 .805 r
.72075 .51169 .74176 .55841 .78585 .55656 .76492 .50932 Metetra
.555 .556 .809 r
.76492 .50932 .78585 .55656 .8313 .55901 .81043 .51121 Metetra
.525 .539 .812 r
.81043 .51121 .8313 .55901 .87832 .56594 .85751 .51753 Metetra
.493 .52 .814 r
.85751 .51753 .87832 .56594 .92718 .57756 .90641 .52849 Metetra
.46 .501 .814 r
.90641 .52849 .92718 .57756 .97816 .59413 .95742 .54435 Metetra
.763 .667 .757 r
.32993 .6749 .35316 .7148 .39326 .67588 .37037 .6357 Metetra
.75 .663 .765 r
.37037 .6357 .39326 .67588 .43319 .64122 .41061 .60074 Metetra
.736 .658 .773 r
.41061 .60074 .43319 .64122 .47311 .61071 .45081 .56991 Metetra
.72 .652 .781 r
.45081 .56991 .47311 .61071 .51316 .58425 .49111 .54311 Metetra
.703 .645 .789 r
.49111 .54311 .51316 .58425 .55349 .56179 .53167 .52029 Metetra
.683 .637 .797 r
.53167 .52029 .55349 .56179 .59425 .54329 .57264 .50141 Metetra
.661 .627 .805 r
.57264 .50141 .59425 .54329 .63559 .52875 .61418 .48646 Metetra
.637 .616 .812 r
.61418 .48646 .63559 .52875 .6777 .5182 .65646 .47548 Metetra
.61 .603 .818 r
.65646 .47548 .6777 .5182 .72075 .51169 .69966 .46851 Metetra
.582 .588 .824 r
.69966 .46851 .72075 .51169 .76492 .50932 .74397 .46564 Metetra
.55 .571 .828 r
.74397 .46564 .76492 .50932 .81043 .51121 .78961 .46701 Metetra
.517 .553 .832 r
.78961 .46701 .81043 .51121 .85751 .51753 .83681 .47277 Metetra
.481 .533 .833 r
.83681 .47277 .85751 .51753 .90641 .52849 .88582 .48314 Metetra
.444 .511 .833 r
.88582 .48314 .90641 .52849 .95742 .54435 .93694 .49837 Metetra
.773 .686 .768 r
.30606 .63865 .32993 .6749 .37037 .6357 .34689 .5991 Metetra
.76 .683 .777 r
.34689 .5991 .37037 .6357 .41061 .60074 .38749 .56379 Metetra
.746 .678 .786 r
.38749 .56379 .41061 .60074 .45081 .56991 .42803 .53261 Metetra
.729 .673 .795 r
.42803 .53261 .45081 .56991 .49111 .54311 .46864 .50544 Metetra
.711 .666 .805 r
.46864 .50544 .49111 .54311 .53167 .52029 .50948 .48224 Metetra
.69 .658 .814 r
.50948 .48224 .53167 .52029 .57264 .50141 .55071 .46297 Metetra
.666 .648 .823 r
.55071 .46297 .57264 .50141 .61418 .48646 .59249 .44762 Metetra
.64 .637 .831 r
.59249 .44762 .61418 .48646 .65646 .47548 .635 .4362 Metetra
.611 .623 .839 r
.635 .4362 .65646 .47548 .69966 .46851 .67841 .42879 Metetra
.579 .607 .845 r
.67841 .42879 .69966 .46851 .74397 .46564 .72293 .42546 Metetra
.544 .589 .85 r
.72293 .42546 .74397 .46564 .78961 .46701 .76876 .42633 Metetra
.506 .569 .853 r
.76876 .42633 .78961 .46701 .83681 .47277 .81614 .43158 Metetra
.466 .547 .855 r
.81614 .43158 .83681 .47277 .88582 .48314 .86533 .44141 Metetra
.424 .522 .854 r
.86533 .44141 .88582 .48314 .93694 .49837 .91662 .45608 Metetra
.784 .707 .779 r
.28144 .606 .30606 .63865 .34689 .5991 .32272 .56605 Metetra
.771 .704 .789 r
.32272 .56605 .34689 .5991 .38749 .56379 .36374 .53034 Metetra
.756 .701 .8 r
.36374 .53034 .38749 .56379 .42803 .53261 .40466 .49876 Metetra
.739 .696 .811 r
.40466 .49876 .42803 .53261 .46864 .50544 .44564 .4712 Metetra
.719 .69 .822 r
.44564 .4712 .46864 .50544 .50948 .48224 .48682 .44761 Metetra
.696 .682 .832 r
.48682 .44761 .50948 .48224 .55071 .46297 .52837 .42793 Metetra
.671 .672 .843 r
.52837 .42793 .55071 .46297 .59249 .44762 .57045 .41216 Metetra
.642 .661 .853 r
.57045 .41216 .59249 .44762 .635 .4362 .61324 .40032 Metetra
.61 .646 .861 r
.61324 .40032 .635 .4362 .67841 .42879 .65692 .39248 Metetra
.574 .63 .869 r
.65692 .39248 .67841 .42879 .72293 .42546 .7017 .3887 Metetra
.535 .61 .874 r
.7017 .3887 .72293 .42546 .76876 .42633 .74778 .38912 Metetra
.493 .587 .877 r
.74778 .38912 .76876 .42633 .81614 .43158 .79542 .39391 Metetra
.448 .562 .878 r
.79542 .39391 .81614 .43158 .86533 .44141 .84486 .40326 Metetra
.4 .535 .876 r
.84486 .40326 .86533 .44141 .91662 .45608 .8964 .41744 Metetra
.795 .73 .791 r
.25594 .57695 .28144 .606 .32272 .56605 .29774 .53653 Metetra
.782 .728 .803 r
.29774 .53653 .32272 .56605 .36374 .53034 .33924 .50038 Metetra
.766 .726 .815 r
.33924 .50038 .36374 .53034 .40466 .49876 .38061 .46836 Metetra
.748 .722 .827 r
.38061 .46836 .40466 .49876 .44564 .4712 .42201 .44037 Metetra
.728 .717 .84 r
.42201 .44037 .44564 .4712 .48682 .44761 .46358 .41635 Metetra
.703 .709 .853 r
.46358 .41635 .48682 .44761 .52837 .42793 .50551 .39625 Metetra
.676 .7 .865 r
.50551 .39625 .52837 .42793 .57045 .41216 .54795 .38006 Metetra
.644 .688 .876 r
.54795 .38006 .57045 .41216 .61324 .40032 .59108 .36781 Metetra
.608 .673 .886 r
.59108 .36781 .61324 .40032 .65692 .39248 .6351 .35954 Metetra
.568 .655 .894 r
.6351 .35954 .65692 .39248 .7017 .3887 .6802 .35535 Metetra
.524 .633 .9 r
.6802 .35535 .7017 .3887 .74778 .38912 .7266 .35535 Metetra
.476 .608 .903 r
.7266 .35535 .74778 .38912 .79542 .39391 .77455 .35971 Metetra
.424 .579 .903 r
.77455 .35971 .79542 .39391 .84486 .40326 .82431 .36864 Metetra
.37 .547 .898 r
.82431 .36864 .84486 .40326 .8964 .41744 .87619 .38239 Metetra
.807 .755 .804 r
.22944 .55152 .25594 .57695 .29774 .53653 .27182 .51057 Metetra
.794 .754 .817 r
.27182 .51057 .29774 .53653 .33924 .50038 .31387 .47392 Metetra
.778 .753 .831 r
.31387 .47392 .33924 .50038 .38061 .46836 .35575 .44141 Metetra
.759 .75 .845 r
.35575 .44141 .38061 .46836 .42201 .44037 .39763 .41296 Metetra
.736 .746 .86 r
.39763 .41296 .42201 .44037 .46358 .41635 .43967 .38848 Metetra
.71 .74 .874 r
.43967 .38848 .46358 .41635 .50551 .39625 .48203 .36794 Metetra
.68 .731 .889 r
.48203 .36794 .50551 .39625 .54795 .38006 .52489 .35133 Metetra
.645 .718 .902 r
.52489 .35133 .54795 .38006 .59108 .36781 .56842 .33866 Metetra
.604 .702 .913 r
.56842 .33866 .59108 .36781 .6351 .35954 .61283 .32998 Metetra
.559 .683 .922 r
.61283 .32998 .6351 .35954 .6802 .35535 .65832 .32539 Metetra
.508 .658 .928 r
.65832 .32539 .6802 .35535 .7266 .35535 .70511 .325 Metetra
.453 .629 .929 r
.70511 .325 .7266 .35535 .77455 .35971 .75344 .32898 Metetra
.394 .596 .927 r
.75344 .32898 .77455 .35971 .82431 .36864 .8036 .33755 Metetra
.331 .559 .919 r
.8036 .33755 .82431 .36864 .87619 .38239 .8559 .35095 Metetra
.819 .781 .817 r
.20179 .52976 .22944 .55152 .27182 .51057 .24483 .48821 Metetra
.805 .783 .832 r
.24483 .48821 .27182 .51057 .31387 .47392 .28749 .45099 Metetra
.789 .783 .847 r
.28749 .45099 .31387 .47392 .35575 .44141 .32996 .41796 Metetra
.769 .782 .864 r
.32996 .41796 .35575 .44141 .39763 .41296 .37238 .389 Metetra
.745 .779 .881 r
.37238 .389 .39763 .41296 .43967 .38848 .41494 .36404 Metetra
.716 .773 .897 r
.41494 .36404 .43967 .38848 .48203 .36794 .4578 .34304 Metetra
.682 .764 .913 r
.4578 .34304 .48203 .36794 .52489 .35133 .50115 .32599 Metetra
.643 .752 .928 r
.50115 .32599 .52489 .35133 .56842 .33866 .54515 .3129 Metetra
.597 .735 .94 r
.54515 .3129 .56842 .33866 .61283 .32998 .59002 .30383 Metetra
.545 .713 .95 r
.59002 .30383 .61283 .32998 .65832 .32539 .63596 .29886 Metetra
.487 .685 .954 r
.63596 .29886 .65832 .32539 .70511 .325 .6832 .29811 Metetra
.423 .651 .954 r
.6832 .29811 .70511 .325 .75344 .32898 .73201 .30176 Metetra
.354 .612 .948 r
.73201 .30176 .75344 .32898 .8036 .33755 .78264 .31001 Metetra
.283 .569 .935 r
.78264 .31001 .8036 .33755 .8559 .35095 .83544 .32315 Metetra
.831 .81 .83 r
.17284 .51175 .20179 .52976 .24483 .48821 .2166 .46953 Metetra
.817 .813 .846 r
.2166 .46953 .24483 .48821 .28749 .45099 .25996 .43168 Metetra
.799 .815 .864 r
.25996 .43168 .28749 .45099 .32996 .41796 .30308 .39805 Metetra
.778 .815 .883 r
.30308 .39805 .32996 .41796 .37238 .389 .34613 .36854 Metetra
.752 .814 .901 r
.34613 .36854 .37238 .389 .41494 .36404 .38928 .34307 Metetra
.72 .809 .92 r
.38928 .34307 .41494 .36404 .4578 .34304 .43271 .32159 Metetra
.682 .801 .938 r
.43271 .32159 .4578 .34304 .50115 .32599 .4766 .30409 Metetra
.637 .788 .954 r
.4766 .30409 .50115 .32599 .54515 .3129 .52114 .29058 Metetra
.585 .769 .967 r
.52114 .29058 .54515 .3129 .59002 .30383 .56654 .28112 Metetra
.524 .743 .975 r
.56654 .28112 .59002 .30383 .63596 .29886 .613 .2758 Metetra
.456 .711 .977 r
.613 .2758 .63596 .29886 .6832 .29811 .66078 .27473 Metetra
.382 .671 .973 r
.66078 .27473 .6832 .29811 .73201 .30176 .71012 .27809 Metetra
.303 .625 .96 r
.71012 .27809 .73201 .30176 .78264 .31001 .76132 .2861 Metetra
.222 .573 .941 r
.76132 .2861 .78264 .31001 .83544 .32315 .8147 .29903 Metetra
.843 .84 .842 r
.14238 .49761 .17284 .51175 .2166 .46953 .18697 .45463 Metetra
.828 .845 .86 r
.18697 .45463 .2166 .46953 .25996 .43168 .2311 .41608 Metetra
.809 .849 .88 r
.2311 .41608 .25996 .43168 .30308 .39805 .27495 .3818 Metetra
.785 .851 .9 r
.27495 .3818 .30308 .39805 .34613 .36854 .31869 .3517 Metetra
.756 .851 .921 r
.31869 .3517 .34613 .36854 .38928 .34307 .36251 .32568 Metetra
.721 .847 .942 r
.36251 .32568 .38928 .34307 .43271 .32159 .40658 .30369 Metetra
.678 .839 .961 r
.40658 .30369 .43271 .32159 .4766 .30409 .4511 .28573 Metetra
.626 .824 .977 r
.4511 .28573 .4766 .30409 .52114 .29058 .49625 .2718 Metetra
.564 .802 .988 r
.49625 .2718 .52114 .29058 .56654 .28112 .54225 .26196 Metetra
.494 .772 .994 r
.54225 .26196 .56654 .28112 .613 .2758 .58932 .2563 Metetra
.415 .732 .991 r
.58932 .2563 .613 .2758 .66078 .27473 .63771 .25495 Metetra
.329 .684 .979 r
.63771 .25495 .66078 .27473 .71012 .27809 .68768 .25807 Metetra
.239 .628 .958 r
.68768 .25807 .71012 .27809 .76132 .2861 .73953 .2659 Metetra
.148 .567 .929 r
.73953 .2659 .76132 .2861 .8147 .29903 .79359 .27871 Metetra
.853 .871 .853 r
.11023 .48749 .14238 .49761 .18697 .45463 .15573 .44366 Metetra
.836 .878 .873 r
.15573 .44366 .18697 .45463 .2311 .41608 .20073 .40433 Metetra
.816 .884 .894 r
.20073 .40433 .2311 .41608 .27495 .3818 .24539 .36935 Metetra
.789 .887 .916 r
.24539 .36935 .27495 .3818 .31869 .3517 .28991 .3386 Metetra
.757 .888 .938 r
.28991 .3386 .31869 .3517 .36251 .32568 .33448 .31199 Metetra
.716 .884 .959 r
.33448 .31199 .36251 .32568 .40658 .30369 .37927 .28947 Metetra
.665 .875 .977 r
.37927 .28947 .40658 .30369 .4511 .28573 .42448 .27103 Metetra
.605 .857 .991 r
.42448 .27103 .4511 .28573 .49625 .2718 .47033 .25668 Metetra
.533 .83 .999 r
.47033 .25668 .49625 .2718 .54225 .26196 .51701 .24647 Metetra
.45 .792 .998 r
.51701 .24647 .54225 .26196 .58932 .2563 .56476 .2405 Metetra
.358 .744 .987 r
.56476 .2405 .58932 .2563 .63771 .25495 .61384 .23889 Metetra
.261 .685 .965 r
.61384 .23889 .63771 .25495 .68768 .25807 .66453 .24183 Metetra
.161 .619 .933 r
.66453 .24183 .68768 .25807 .73953 .2659 .71712 .24955 Metetra
.063 .548 .893 r
.71712 .24955 .73953 .2659 .79359 .27871 .77198 .26233 Metetra
.86 .902 .862 r
.07613 .48161 .11023 .48749 .15573 .44366 .12266 .43682 Metetra
.842 .911 .883 r
.12266 .43682 .15573 .44366 .20073 .40433 .16861 .39663 Metetra
.818 .918 .904 r
.16861 .39663 .20073 .40433 .24539 .36935 .21418 .36087 Metetra
.788 .922 .926 r
.21418 .36087 .24539 .36935 .28991 .3386 .25958 .32941 Metetra
.75 .923 .948 r
.25958 .32941 .28991 .3386 .33448 .31199 .30497 .30217 Metetra
.702 .918 .967 r
.30497 .30217 .33448 .31199 .37927 .28947 .35057 .27909 Metetra
.643 .905 .983 r
.35057 .27909 .37927 .28947 .42448 .27103 .39657 .26015 Metetra
.571 .881 .992 r
.39657 .26015 .42448 .27103 .47033 .25668 .44319 .24537 Metetra
.486 .846 .992 r
.44319 .24537 .47033 .25668 .51701 .24647 .49064 .23481 Metetra
.39 .798 .981 r
.49064 .23481 .51701 .24647 .56476 .2405 .53917 .22855 Metetra
.287 .738 .958 r
.53917 .22855 .56476 .2405 .61384 .23889 .58903 .22673 Metetra
.179 .668 .923 r
.58903 .22673 .61384 .23889 .66453 .24183 .64053 .22955 Metetra
.073 .591 .879 r
.64053 .22955 .66453 .24183 .71712 .24955 .69397 .23723 Metetra
0 .512 .829 r
.69397 .23723 .71712 .24955 .77198 .26233 .74972 .25009 Metetra
.864 .932 .867 r
.03981 .48021 .07613 .48161 .12266 .43682 .08747 .43437 Metetra
.843 .941 .888 r
.08747 .43437 .12266 .43682 .16861 .39663 .13449 .39321 Metetra
.815 .949 .909 r
.13449 .39321 .16861 .39663 .21418 .36087 .18109 .35659 Metetra
.779 .953 .929 r
.18109 .35659 .21418 .36087 .25958 .32941 .22744 .32436 Metetra
.734 .951 .948 r
.22744 .32436 .25958 .32941 .30497 .30217 .27377 .29644 Metetra
.676 .942 .963 r
.27377 .29644 .30497 .30217 .35057 .27909 .32027 .27276 Metetra
.606 .923 .972 r
.32027 .27276 .35057 .27909 .39657 .26015 .36715 .25331 Metetra
.521 .89 .971 r
.36715 .25331 .39657 .26015 .44319 .24537 .41463 .2381 Metetra
.423 .844 .96 r
.41463 .2381 .44319 .24537 .49064 .23481 .46294 .22719 Metetra
.316 .784 .935 r
.46294 .22719 .49064 .23481 .53917 .22855 .51234 .22068 Metetra
.203 .711 .898 r
.51234 .22068 .53917 .22855 .58903 .22673 .56309 .2187 Metetra
.09 .63 .851 r
.56309 .2187 .58903 .22673 .64053 .22955 .61549 .22146 Metetra
0 .546 .798 r
.61549 .22146 .64053 .22955 .69397 .23723 .66989 .22919 Metetra
0 .463 .742 r
.66989 .22919 .69397 .23723 .74972 .25009 .72666 .24224 Metetra
.862 .959 .867 r
.00095 .48363 .03981 .48021 .08747 .43437 .04987 .43659 Metetra
.837 .968 .886 r
.04987 .43659 .08747 .43437 .13449 .39321 .09809 .39438 Metetra
.803 .974 .904 r
.09809 .39438 .13449 .39321 .18109 .35659 .14581 .3568 Metetra
.76 .975 .921 r
.14581 .3568 .18109 .35659 .22744 .32436 .19325 .32374 Metetra
.705 .968 .934 r
.19325 .32374 .22744 .32436 .27377 .29644 .24061 .29508 Metetra
.636 .952 .94 r
.24061 .29508 .27377 .29644 .32027 .27276 .28811 .27077 Metetra
.553 .922 .938 r
.28811 .27077 .32027 .27276 .36715 .25331 .33597 .25079 Metetra
.456 .878 .925 r
.33597 .25079 .36715 .25331 .41463 .2381 .38441 .23514 Metetra
.347 .819 .899 r
.38441 .23514 .41463 .2381 .46294 .22719 .43369 .2239 Metetra
.231 .746 .86 r
.43369 .2239 .46294 .22719 .51234 .22068 .48405 .21717 Metetra
.114 .663 .811 r
.48405 .21717 .51234 .22068 .56309 .2187 .53579 .21508 Metetra
.002 .576 .755 r
.53579 .21508 .56309 .2187 .61549 .22146 .58923 .21785 Metetra
.102 0 0 r
.58923 .21785 .61549 .22146 .66989 .22919 .6447 .22575 Metetra
.194 0 0 r
.6447 .22575 .66989 .22919 .72666 .24224 .70262 .2391 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09549 .2323 m
.1002 .23687 L
s
[(-4)] .08608 .22315 1 .97179 Mshowa
.21633 .18498 m
.22084 .18975 L
s
[(-2)] .20731 .17545 .94563 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.47614 .08324 m
.48017 .08842 L
s
[(2)] .46808 .07289 .77884 1 Mshowa
.61605 .02846 m
.6198 .03385 L
s
[(4)] .60856 .01769 .69544 1 Mshowa
.125 Mabswid
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.18558 .19702 m
.18832 .19985 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.51046 .06981 m
.51284 .07294 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.06616 .24378 m
.06901 .2465 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jA000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo002aOol3001/Ool00;9oo`03001oogoo06]oo`00[goo1@00K7oo002_
Ool01000Oomoo`005Goo0P00EWoo002`Ool00`00Ool0000COol200000goo0000001EOol00;5oo`80
011oo`<000=oo`8005Eoo`00`Goo0P001Woo00<007oo0000E7oo002nOol30008Ool01000Oomoo`00
Dgoo002lOol20002Ool00`00Oomoo`06Ool01000Oomoo`00Dgoo002iOol3000=Ool01@00Oomoogoo
0000DWoo002fOol3000@Ool00`00Oomoo`02Ool00`00Oomoo`1?Ool00;Aoo`8001=oo`04001oogoo
Ool2001AOol00;5oo`<0009oo`03001oogoo015oo`03001oogoo009oo`03001oogoo00eoo`<003io
o`00[goo0P006Goo00<007ooOol00goo00<007ooOol03Goo00<007ooOol0?Goo002/Ool3000KOol0
0`00Oomoo`03Ool00`00Oomoo`0:Ool5000nOol008Qoo`@001ioo`<001eoo`03001oogoo00Aoo`03
001oogoo00=oo`@0009oo`04001oogoo000oOol008Qoo`03001oogoo01aoo`<0009oo`03001oogoo
01]oo`03001oogoo00Aoo`03001oogoo00Yoo`03001oo`0003moo`00RGoo00<007ooOol06Goo0P00
8goo00<007ooOol01Goo0P002goo0P00?goo002:Ool00`00Oomoo`0EOol3000UOol00`00Oomoo`04
Ool00`00Ool0001<Ool008Qoo`04001oogoo000DOol4000VOol00`00Oomoo`06Ool00`00Oomoo`1:
Ool008Uoo`80019oo`<002Yoo`03001oogoo00Moo`03001oogoo04Uoo`00VWoo0`00;Goo00<007oo
Ool027oo00<007ooOol0B7oo002HOol2000`Ool00`00Oomoo`08Ool00`00Oomoo`18Ool009Eoo`<0
0003Ool007oo02moo`03001oogoo00Uoo`03001oogoo04Moo`00Tgoo0P00=Goo00<007ooOol02Woo
00<007ooOol0AWoo002@Ool3000gOol00`00Oomoo`09Ool20018Ool008ioo`8003Yoo`03001oogoo
00]oo`03001oogoo04Eoo`00Rgoo0`000Woo00<007ooOol0=goo00<007ooOol037oo00<007ooOol0
A7oo0029Ool2000oOol00`00Oomoo`0<Ool00`00Oomoo`14Ool008Ioo`<0049oo`03001oogoo00ao
o`03001oogoo04=oo`00IGoo0P007Goo0`00A7oo00<007ooOol03Goo00<007ooOol0@Woo001TOol0
1000Oomoo`006Goo0`00Agoo00<007ooOol037oo0P00A7oo001TOol01000Oomoo`005Woo0`00BWoo
00<007ooOol03Woo00<007ooOol0@Goo001TOol01000Oomoo`0057oo0P00CGoo00<007ooOol03goo
00<007ooOol0@7oo001TOol01000Oomoo`004Goo0`0000=oo`00Ool0C7oo00<007ooOol03goo00<0
07ooOol0@7oo001UOol2000@Ool2001BOol00`00Oomoo`0@Ool00`00Oomoo`0oOol007Aoo`<005Ao
o`03001oogoo015oo`03001oogoo03ioo`00LWoo0P00Egoo00<007ooOol04Goo00<007ooOol0?Woo
001_Ool30002Ool00`00Oomoo`1DOol00`00Oomoo`0AOol2000oOol006eoo`8005aoo`03001oogoo
019oo`03001oogoo00]oo`@002ioo`00JWoo0`00GWoo00<007ooOol04goo00<007ooOol02Woo00<0
07ooOol0;goo001XOol20002Ool00`00Oomoo`1LOol00`00Oomoo`0DOol00`00Oomoo`0:Ool00`00
Oomoo`0^Ool006Eoo`<000Aoo`03001oogoo05aoo`03001oogoo01Aoo`03001oogoo00=oo`@000Ao
o`03001oogoo02eoo`00@Goo10007Woo0P00IWoo00<007ooOol05Goo00<007ooOol027oo00@007oo
Ool002ioo`00@Goo00<007ooOol077oo0`00J7oo00<007ooOol05Goo0P002Woo0P00;goo0012Ool0
0`00Oomoo`0HOol30002Ool00`00Oomoo`1WOol00`00Oomoo`0COol00`00Ool0000kOol003]oo`@0
00Aoo`03001oogoo01Eoo`8006moo`03001oogoo01Ioo`03001oogoo03Qoo`00@Goo00@007ooOol0
01=oo`<0075oo`03001oogoo01Moo`03001oogoo03Moo`00@Woo0P004Woo0P000Woo00<007ooOol0
Kgoo00<007ooOol05goo00<007ooOol0=goo001COol3001fOol00`00Oomoo`0HOol00`00Oomoo`0f
Ool0055oo`8007Uoo`03001oogoo01Uoo`03001oogoo03Eoo`00CWoo1000NWoo00<007ooOol067oo
0P00=goo001<Ool2001nOol00`00Oomoo`0JOol00`00Oomoo`0dOol004Uoo`<0081oo`03001oogoo
01]oo`03001oogoo03=oo`00Agoo0P00Pgoo00<007ooOol06goo00<007ooOol0<goo0014Ool30002
Ool00`00Oomoo`20Ool00`00Oomoo`0LOol00`00Oomoo`0bOol0045oo`<008Qoo`03001oogoo01eo
o`03001oogoo035oo`008Goo0`006goo0P00Rgoo00<007ooOol077oo0P00<goo000ROol00`00Oomo
o`0GOol300000goo001oo`2:Ool00`00Oomoo`0NOol00`00Oomoo`0`Ool001moo`D001Ioo`80091o
o`03001oogoo01moo`03001oogoo02moo`006Goo10000Woo00@007ooOol001Aoo`<0099oo`03001o
ogoo01moo`03001oogoo02moo`0087oo00<007oo00004Woo0P0000=oo`00Ool0TWoo00<007ooOol0
87oo00<007ooOol0;Woo000QOol2000?Ool3001SOol?000VOol00`00Oomoo`0POol00`00Oomoo`0]
Ool0031oo`8005aoo`X0008>V@062YT>V@jI3YT:V@jI4P006goo00<007ooOol07goo0P0027oo0P00
9Goo000]Ool4001FOol7000011kk6_XNna[j3P0000TJg1KK6]`Ffa[L5]/Jg1KK6]`0100000<:NPZJ
00002P004goo00<007ooOol08Goo00<007ooOol017oo00@007ooOol002Aoo`00:goo0P00E7oo4@00
2BLM100000HJg1KK5]`Fg1[L5]/25]`?00000`Yj00000008000<Ool00`00Oomoo`0QOol00`00Oomo
o`04Ool01000Oomoo`0097oo000XOol3001BOol4000012/k:e`[>b]L100000@cGCMN<edgGP<00003
9adW72LM008W7@059a`W7BLM9adW70039ad:000022;m8_hRoBKn8_dRoR;m9_h200001A:L5[dBW1Jm
4Y`04@001Woo00<007ooOol08Woo00<007ooOol00goo00@007ooOol002Aoo`009Goo0`00DGoo1000
12/l100000/gGS=M=ehcGSMN<edgGS=N=ehcGCMN008000DW7@H00005<cl_?Rln;chc?`0200028_h0
1B;m8_hRoR;n8_d00b;n00<RoB;n8_h00P0000/F_AJl5[dB_1Jm5[`F_A:l5[dF_1Jm00d0009oo`03
001oogoo02=oo`03001oogoo009oo`04001oogoo000TOol002=oo`8000=oo`03001oogoo04Yoo``0
000?<edgGS=M=ehcGCMN<edgGS=M=ehcGCMN<edgGS=M00L0000=;chc?bln<cl_?S<o;chc?bln<cl_
?S<o;ch00P0000dRoR;m9_hRoB;n8_dVoR;m8_hRoBKn8_dRoP0200002a:L5[dBW1Jm4Y`F_A:L5[dB
W1Jm4Y`00P0000H:F`IK2U`6F`YK1U/7000TOol20004Ool2000UOol0021oo`<004moo`<00006>gdg
O3]m=g`kOCMl0P000d>N00<oWP0000000P0000DgGS=N=ehcGCMN00H00005>ehoGc]O?elkGP020000
1C<o;ch_?Rln<cl00bln00Dc?bln;ch_?S<o028000H6F`L001moo`03001oo`0002]oo`007Woo0P00
CWoo100000HkOCMl>gdgO3]m=g`300002Smn@ihoOT>N?gi3WSmn@ihoOT>N1@0000doGc]N?elkGSmO
>ehoGc]N?elkGSmO>ehoG`0200001Bln<cl_?S<o;ch01P0000@k?cLO>clg7`80000<;_lZoRko:_h^
ob[n;_lZoRko:_h^ob[n0P0000hR_Qjm8[hN_R:n7[dR_Qjn8[hN_B:n7[h0019l1@0000H6F`000000
007i0QX5000OOol00`00Oomoo`0XOol001]oo`<00003Ool007oo04Yoo`<00007=g`kOCMl>gdgO3]m
=g`00`000T>N00DoWT>N@ii3WSnN00=3WP<0000CAgm7OP00000oGc]N?elkGcmO>ehoGc]O?elkGSmO
>eloGc]N?el01P0000`g7cLo=alk?cLO=clg7c/o=alg?cLO>cl200003B[n;_lZoR[o:_h^ob[n:_lZ
oRko:_hZo`0000`N_P80008BO@P000040QX26@8J0QT4000LOol00`00Oomoo`0XOol001Uoo`8004eo
o`H00005>gdgO3]m=g`kO@0200002Cmn@ihoOT>N?gi3WSmn@ihoOP0400001d^OAgi;WdMnBim7OT^O
00800009>ehoGc]N?elkGSmO>ehoGc]N00@000=3G`80000?=alk?cLO>clg7c/o=alk?cLO>clg7c/o
=alk?cLO0080000;;_lZoRko:_h^ob[n;_lZoRko:_h^o`0200002ajm8[hN_R:n7[dR_Qjn8[hN_B:n
7[h00`0000DBO19m4W`FOA9l00H000050QX1n@8J0OT26P03000JOol00`00Oomoo`0WOol001Moo`80
04aoo`<00006@ke7_DNmAke3_DNm20000T>N00<oWT>N@ih00`000TMo00E7OTMoAgm7OdMn00=7O`03
Agi7OdMo00800003?elkGcmO00@000U3G`80000<>clg7cLo=alk?cLO=clg7c/o=alg?cLO6`000Qjn
00<0019m4Wd0119m00<0019m4Wd01`0000<26P8I0QX00P006Goo00<007ooOol09Woo000GOol20019
Ool300002D>mAke3_DNm@ke7_D>mAke3_@0200001TnnBki?_T^nCki;_PD0000@Agi;WdMnBim7OT^O
Agi;WdMnBim7OT^OAgi;WdMnBil5000?@el2000013LO>clg7c/o1P00014k7SlO>aho7`00=_lbgSKo
<]hfoc;N=_lbgSKo<]hfoc;N00800003:[lV_RZo00`0000<4W`FOA9l000BO1Im4W`000Hk1S`6>`Hl
1`005goo0P009goo000GOol00`00Ool00016Ool200001D>mAke7_DNm@kd00dNm00A3_@00000000=;
_P05Cki;_T^nBki?_P0200000dnNDim?WP0300001DMnAgm7OdMoAgh00dMo00=7OP0000000P000d]o
00=;OP0000003T=O1P002clO00<003;o<_h00c;o00DboS;o<_lboc;n00<bo`<0000::[hV_RZn9[hZ
_RJn:[hV_RZn00027Wh700002Q9m000000Hl1S/6?0Hk1S`6>`Hl0`005goo00<007ooOol09Goo000?
Ool20006Ool01000Oomoo`00@Woo0`0000Q7_D>mAke3_DNm@ke7_D>m0`0000U;_TnnBki?_T^nCki;
_TnnBkh00P0000QCWdnNDim?WU>OCiiCWdnN0P0000=;WdMnBil0100000Y;GTmoBei?Od]NCgm;GTmo
Bei?O`8000Q3G`@00003Aci7?dLn0080000G?alk7SlO>aho7c/N?alk7SlO>aho7c/N?al003Ko<]hf
oc;N=_lbgSKo<]hfo`0300003CKo000Z_bJn:[lV_RZo9[hZ_bJn:[lV_RZo008000076WdNOQYm7Wh0
01in6Wd01@0000T6>`Hl1S/6?0Hk1S`6>`Hl00005goo00<007ooOol097oo000>Ool01000Oomoo`00
17oo00<007ooOol00Woo00<007ooOol0?Goo1@0000I3_DNmAke7_D>mAkd20003Bkh01DnnBki;_T^n
Ckh00T^n0P0000a?WU>NCiiCWdnNDii?WU>OCiiCWTnNDil300000d]oBgi;O`02Bgl01D]nBgm;Od]o
Bgh00d]o00=;OT]oBgl00P000T=O100000Y7?dLnAcm7?TLoAci7?dLnAcl000do7`03000boc;n00<b
o`<00003<_lboS;o008bo`80000<9[hZ_RJn:[hV_RZn9[hZ_RJn:[hV_P000Qin00DJOAin000NOQYm
00<NOPD000051S`6>`Hl1S/6?002000EOol00`00Oomoo`0TOol000ioo`04001oogoo0004Ool00`00
Oomoo`03Ool00`00Oomoo`0jOol200001DnmDme?_E?MCkd01`0000U;_TnnBki?_T^nCki;_TnnBkh0
0P0000aCWdnNDim?WU>OCiiCWdnNDim?WU>OCih200004eMoDgh00000Cgm;GTmoBei?Od]NCgm;GTmo
Bei?Od]NCgm;GTmo00@0000NAci7?dLnAcm7?TLoAci7?dLnAcm7?TLoAci7?`00?alk7SlO>aho7c/N
?alk7SlO>aho7c/N?al003Ko0`0000<foc;N=_l03P0001@V_RZo9[hZ_bJn000JOAin6WdNOP007WhJ
OAin6WdNOP004Ud>?19M100000@6>`Hl1S/001Eoo`03001oogoo02=oo`003Woo00@007ooOol000Ao
o`03001oogoo00Aoo`03001oogoo03Moo`8000Q?g@8000=G_P03Dkh000000080009;_P0>Ckh00000
CiiCWdnNDii?WU>OCiiCWTnNDim?WP<000ICOP800005Bgi;Od]oBgm;OP03Bgl00d]n000000020000
4dmNCci?GP00Acm7?TLoAci7?dLnAcm7?TLoAci7?dLnAcm7?TLo008000Ho7`d00009>]hfgS[N=]hj
gSKN>]hfgP0000D^_PT000056WdNOP007WhJO@037Wh01@004SdB?A8m3S`00Q8m1@005Goo00<007oo
Ool08Woo000>Ool01000Oomoo`0017oo0P001Woo0P00=Goo0P0000Q?_E?MCkeCgDnmDme?_E?M0P00
00YC_EONDkeGgU>mEmiC_EONDkeGgP@00009CiiCWdnNDim?WU>OCiiCWdnN00<0000;DgiGOe=nEgmC
OUMoDgiGOe=nEgmCOP0200000dmoBei?O`04000024lnCem??TmOCci?GdlnCel200003DLnAcm7?TLo
Aci7?dLnAcm7?TLoAci7?dLn00P0000T@_h000000012oSkn@_l003[O=]hjgcKN>]lfgS[O=]hjgcKN
>]lfgS[O=]h002jN;[h^WS:o;Yh^_RjN<[l^WRjn;Yh0029m1@0000hJOAin6WdNOP004Ud>?19M3S`B
G@hl4Ud>?19M0P004goo0P0097oo000?Ool20005Ool00`00Oomoo`07Ool00`00Oomoo`0`Ool20008
Cmd200000eNnDkiG_P02Ekh01U>nEkiG_UNnDkiG_P8000=G_P@00003Dim?WU>N008000mCOP@0000G
Cei??TmNCci?GTlnCei??TmNCci?GTlnCei??P00Aci7?dLnAcm7?TLoAci7?`040002Bah00dLN0012
oP02@_h20007@_h04000>]hfgS[N=]hjgSKN>]hfgS[N=]hjgSKN>]hfgP002bjn00H002In9WhRO@00
9Wh400000ain000B?@024Sd01@hl4SdB?A8m3S`00Q8m00<007ooOol04Woo00<007ooOol08Goo000F
Ool00`00Oomoo`08Ool00`00Oomoo`0]Ool2000024nmDme?_E?MCkeCgDnmDmd200002e>mEmiC_EON
DkeGgU>mEmiC_EONDkd00P0000UK_UNNFkiGWE^nEiiK_UNMFkh00`0000mGOe=nEgmCOUMoDgiGOe=n
EgmCOUMoDgiGOe=nEgl00P0001MCGEMN000004lnCem??TmOCci?GdlnCem??TmOCci?GdlnCem??P00
Aci7?dLn00@00008Bai77T/NAae;7TLNBai77@<0000:?_i2ockn@_hnoT;o?_i2oSkn@_l200008SKN
>]lfgS[O=]hjgcKN>]lfgS[O=]hjg`00<[l^WRjn;Yhb_bjN;[h^WS:o;Yh^_RjN000ROBIn8Wd0029m
9WhROBIn1@0000PBG@hl4Ud>?19M3S`BG@hl0P004goo00<007ooOol087oo000EOol00`00Oomoo`0:
Ool00`00Oomoo`0ZOol20008Cmd20003Ekh01E>nEkiG_UNnDkh00eNn0P0000=G_U^nEkh00UNn00EK
_UNnEkiG_U^n00800004FgiKWP00000:Dgh300000eMNDeiGGP02Eeh03e=N001??TmNCci?GTlnCei?
?TmNCci?GTlnCei??P0500001DLNBai;7T/NAah00d/N00I77P00000004LN000=@_h03P00=]hjgSKN
>]hfgS[N=]hjgSKN>]hfgS[N000;;[h01P009WhVORIn8Wd0008VOP068WdVORIn9Wh001YM1@0000<B
?@hl4Sd00Q8m00<007ooOol047oo00<007ooOol087oo000EOol00`00Oomoo`0;Ool00`00Oomoo`0X
Ool=00002E>mEmiC_EONDkeGgU>mEmiC_@0200002U^nEieK_UNNFkiGWE^nEiiK_UNM0P0000IKWUMm
FiiKOE^NEgd200001UMoDgiGOe=nEgmCOP80000CEeiCGEMNDeeGGU=MEeiCGEMNDed004lnCem??TmO
Cci?GdlnCel0100000]?7E<nCad004LNBai77D/NAai;7TLM00<0000nAae;7TLNBai77@00?_i2oSkn
@_lnoT;n?_i2ockn@_hnoT;o?_h003KN>]lfgS[O=]hjgcKN>]lfgS[O=]hjg`00<[l^WRjn;Yhb_bjN
;[h^WS:o;Yh^_P009WhROBIn000VOR9m9WhROBIn8WdVOP006UdJ?AYM6SdJG@D000034Ud007oo015o
o`03001oogoo01moo`005Goo00<007ooOol037oo00<007ooOol09Goo0P0000QGgE_MEmeKgEOMFmeG
gE_M0P000e_M100000=G_U>nEkh00P000eNn00EK_UNnEkiG_U^n009G_P80000:FgeKWU]nFiiKOE^N
FgiKWU]mFih20002Dgh200001E=NEeiGGUMNDeh00eMN00ECGUMNEeiGGU=N00800003Cei??P0000<0
0009Cai?7E<NCae?7TlMDai?7@00009;7P05Aah0000000177P03Bah01TLNBai;7T/NAah000M2oQX0
00D^_P05000VORIn9Wh000039Wh03R9m9WhVORIn000JGAXm6UdJ?AYM6SdJGAXm6Ud3000BOol00`00
Oomoo`0NOol001Eoo`8000ioo`03001oogoo02=oo`09001KgEOLFmeGgE_MEmaKgEOM00800009GmiK
_EoNFkeOgU^mGmiK_EoN00<0000IFkiGWU^nEieK_UNNFkiGWE^nEiiK_P00FiiKOE^NEgeKWU]mFiiG
OE^NFgeKWUMmFih00`00011GGU=MEeiCGEMNDeeGGU=MEeiCGEMNDeeGGU=MEeiCG@<0000=CaeC?TlM
Dci?7E<nCaeC?TlMDci?7E<nCad00`0000]77D/NAai;7TLMBai77T/NAae;7TLN00T0000J@]e6gT;M
A]i2gDKN@]d003Zm?[hj_Cjn>[dn_SZm?[hj_Cjn>[dn_P00=YhbWCJN<YdfWP/0000D9WhROBIn8WdV
OR9m9Wh001YM6SdJGAXm6UdJ?AYM6SdJGAXm6Ud0011oo`8000Moo`@001Eoo`005Goo00<007ooOol0
3Woo00<007ooOol087oo0P0000]KgEOMFmeGgE_MEmeKgEOM001KgEoM00=Kg@05GmeKgE_MFmeOg@02
0002Gkd300001U^nEkiG_UNnFkiG_P80000<FiiKOE^NFgiKWU]mFiiKOU^NFgeKWU]n0P000U]M0P00
0eMN00ECGUMNEeiGGU=N00=GGP04DeiGGP000002Ecd02`00Dai?7DlNCaeC7TlMCai?7E<NCad00`00
00E?7DlN001;7TLN00=;7P03Aai;7P0000<000=:o@030012gDKN00=2g@05A]i2gD;M@]e6gP03@]d0
6P00>[dn_SZm?[hj_Cjn>[dn_SZm?[hj_Cjn000fWS:M=YhbWCJN<YdfWS:M=YhbWCJN0002:Wd70002
9Wh030006UdJ?AYM6SdJGAXm6UdJ?AYM6Sd0019oo`03001oogoo00Aoo`03001oogoo01Ioo`005Goo
00<007ooOol03goo00<007ooOol07Woo00T005OMFmeGg5_MEmeKgEOLFmd00P0000UK_EoNFkeOgU^m
GmiK_EoNFkd00P0000MO_U^mGkiO_EnnFkeO_P02000045NMFkh00000EgeKWU]mFiiGOE^NFgeKWUMm
FiiKOE^N0P000e]M00eKGU]MFed005MNDeeGGU=MEeiCGEMNDeeGGP03000035LmDceG?E<mEcd005<n
CaeC?TlMDci?7@<00009CaeC?TlMDci?7E<n001;7TLM00@000Q:o@0`0012gDKN@]e6gT;MA]i2gDKN
@]e6gT;MA]i2g@00>[dn_SZm?[hj_Cjn>[dn_SZm?[hj_Cjn000fWS:M=YhbWCJN<YdfWS:M=YhbWCJN
000^ORYm000ZOBin:Wd^ORYm1@0000XJ?AYM6SdJGAXm6UdJ?AYM6Sd0015oo`03001oogoo00Eoo`03
001oogoo01Eoo`005Goo00<007ooOol047oo00<007ooOol06goo0P0000UGgE_MEmeKgEOMFmeGgE_M
00000U_M00EOgE_MFmeKgEoM009Kg@8000]O_@<0000;FgiKWU]mFiiKOU^NFgeKWU]nFiiKO@020009
Fed01@00EeiGGUMNDeh00UMN0P002ELm0P0000a?7DlN000004lMCai?7E<NCae?7TlMDah4000<B_d0
1000@]e2gDKN0d;M00E6gT;M@]e2gDKN0092g@0K000n_SZm?[hj_Cjn>[dn_SZm?[hj_Cjn>[d003:M
=YhbWCJN<YdfWS:M=YhbWCJN<YdfWP00008ZO@03000ZOBYm00HZO@D000076UdJ?AYM6SdJGAXm0000
4Goo00<007ooOol01Goo00<007ooOol057oo000DOol00`00Oomoo`0BOol00`00Oomoo`0IOol02@00
FmeGgE_MEmaKgEOMFmeGg00200005UoNFkeOgU^mGmiK_EoNFkeOgP00GkiO_EnnFkeO_UnmGkiK_Enn
GkeO_U^m0P0000=OWEmm00000P0000IGOE^NFgeKWUMmFih200000e]MFeiKG@02Fed01E]NFeeKGE]M
Feh00U]M0P00011CGEMN000005<mEceC?ELmDceG?E<mEceC?ELmDceG?@<00006Dci?7E<nCaeC?TlM
100000ABoDklD_d000e:o@0h0016gT;MA]i2gDKN@]e6gT;MA]i2gDKN@]e6gP00?[hj_Cjn>[dn_SZm
?[hj_Cjn>[dn_SZm000bWCJN<YdfWS:M=YhbWCJN<YdfWS:M000ZOBin:Wd002Ym;WhZOBin:Wd^ORYm
;Wh0029M8SdRG@<000056UdJ?AYM6Sd0000AOol00`00Oomoo`02Ool01000Oomoo`005Goo000DOol0
0`00Oomoo`0COol00`00Oomoo`0FOol200001e_MEmeKgEOMFmeGgE_M008000=Kg@06GmeKgE_MFmeO
gE_M0P002enm0P001enM0P0000AKWU]n000000mKG@<000]G?@<0009G?@03001?7DlN00@00009C_eB
oDklD_e>oE;mC_aBo@0000e:o@040012gD;MA]h3@]d01DKN@]e2gD;MA]h00T;M01X003jn>[dn_SZm
?[hj_Cjn>[dn_SZm?[hj_@00<YdfWS:M=YhbWCJN<YdfWS:M=YhbW@000RYm00<002Ym:Wd01RYm00<0
028m8Sd0128m1@0047oo0P001Goo0P005Woo000DOol2000EOol00`00Oomoo`0DOol>00001EoNFkeO
gU^mGmh00P0000]K_EnnGkeO_U^mGkiO_EnnFkeO_Unm0080000;HieOOEnMGgeSWEmmGieOOF>MGgeO
W@020003Fed01E]NFeeKGE]MFeh00e]M00AKGU]MFeeKG@80000;FceK?000DceG?E<mEceC?ELmDceG
?@0300001ELmDceG?E<mEcd00`0000iBoDklD_e>o5;mC_aBoDklD_e>o5;mC_aBo@003D[m00/004KN
@]e6gT;MA]i2gDKN@]e6gT;M01L0000K<YdfWS:M=YhbW@00:Wd^OP00;WhZOBin:Wd^ORYm;WhZO@00
8S`RGB8m8UdR?29M8SdRGB8l0080015oo`03001oogoo01Yoo`0057oo00<007ooOol05Goo0P004Woo
0P0000=Og5oMGm`00UoL00IOgEoL000006?MHm`3Hmd6000;Gkd00`00GieOW@0:Gid200000emL0000
000;Fed20003Fc`00e/mFc`00004Ecd30006Ecd20002Ea`03`00C_aBoDkmD_e>o5;mC_eBoDklD_e>
oE;mC_`0000=B_d01@00@]e2gD;MA]h01P0000M6_4JmA[a6_@00?YdnW003?Yd01CjL?YdnWCjM?Y`0
0SjM00H003Il=WdfOCYm=W`:0008:Wd00`008SdR?@088Sd00`00Oomoo`0?Ool00`00Oomoo`0IOol0
01Aoo`03001oogoo01Moo`03001oogoo00ioo`0C001SoEoLHoeOg6?mGmaSoEoL001O_6?MHkaSgEnl
HmeS_6?MGk`00P0000=S_F>l00000P0000IK_EnnGkeO_U^mGkh200004emmHieOOEnMGgeSWEmmGieO
OF>MGgeOW@00HgeOG5mmGeaSO@00009KG@06FeiKGE]MFeeKGU]M0P0000QK?E/lFceK?5/mFcaK?E/l
100000IG?E<mEceC?ELmDcd3000055;lEaaBo5LMD_`004klD_e>o5;mC_aBoDklD_e>o5;mC_aBoDkl
000:B_d700009TJm@[a6_DJlA[e2_4JmA[a6_D:l000nW4:M?Ya2WCjL@YdnW4:M?Ya2WCjL@Yd003ZM
=W`jWCIl>YdfO3ZM=W`jWCIl>YdfO000;U`500004BYm;WhZOBin:Wd0028l8UdR?B9M8S`RGB8m8UdR
?29M000047oo00<007ooOol06Goo000DOol00`00Oomoo`0HOol00`00Oomoo`0;Ool20002Gm`01EoM
GmaOg5oLGmd00P000V?M00ESg6?MHmeSgF?L009Sg@03001S_6>m009S_@03HkaS_F>m0080009O_@80
00aOW@800005GeeOG5mLGeaOG@02Ge`00`00FeeKG@03Fed200000e/lFceK?002Fc`00e/mFcaK?003
00000e/l001G?@04Ecd20009Ea`03`00C_aBoDkmD_e>o5;mC_eBoDklD_e>oE;mC_`00003B_d60004
B]`03`00A[a6_DJlA[e6_4JmA[a6_DJlA[e6_4JmA[`00002?Yd01CjL?YdnWCjM?Y`00cjM00DnW3jM
000jOCIl008fO@0>>WdfO3Im=WdjOCIl=Wd0039M;U`002iM<Ud^G0@00003:Wd0028m00XR?@03001o
ogoo00ioo`03001oogoo01Qoo`004goo00<007ooOol06Woo00<007ooOol02Goo01<005oLHoeOg6?m
GmaSoEoLHod006?MGkaSgF>lHmeO_6?MHkaSg@0200002V>lHkeS_6NmHkaS_F>lIkeS_6>m0`0001MO
WEmmHieOOEnMGgeSWEmmGieOOF>MGgd005mLHgeOG5mmGeaSOEmLGgeOG6=m0080000;Fed00000FceK
?5/mFcaK?E/lFceK?002000025/mFcaK?E/lFcd005LmDcd2000065LLD_aG7E;lEaaBo5LMD_aG75;l
Ead005;mC_aBoDklD_e>o5;mC_aBoDklD_e>o0D0000lB[a>gDZlC]a:_4kMB[a>g4ZlC]e:_000@[a6
_DJlA[e2_4JmA[a6_D:lA[e6_4Jm@[`003jL@YdnW4:M?Ya2WCjL@YdnW4:M?Ya2W@00>YdfO3ZM=W`j
WCIl>YdfO3ZM=W`jW@00<Ud^G000;U`bGBiL<Ud^G39M1@0000TRGB8m8UdR?29M8SdRGB8l000047oo
0P006Goo000COol2000LOol00`00Oomoo`07Ool01@00GmaOg5oLGmd00eoL00=Og@00Hmd00V?M00US
g6?MHmeSgF?LHmd006>mHk`00f>m00IS_6>mHkeS_F>lHkd20002Hi`20008Gid200000emLGeeOG002
Ge`01EmMGeaOG5mLGed00emL00D005/lFcaK?5/m00=K?0<00003FcaK?E/l009K?003FceK?0000080
00iG7008001BoDklD_e>oE;mC_aBo@@0009Bg003C]`004[L00a:g00>0016_4JmA[a6_DJlA[e6_4Jm
A[a6_DJlA[d000<nW@05?Y`nWCjM?YdnW003?Yd01CjL000fOCYm=W`00SIm01DjOCIl=WdfOCYm=W`f
O@00<Ud^G000;UdbGBiL<Ud^GC9M;U`bG@00:Sd01@00128m00<007ooOol03Woo00<007ooOol05goo
000COol00`00Oomoo`0LOol00`00Oomoo`04Ool200001eoLHoeOg6?mGmaSoEoL0080000LHmeO_6?M
HkaSgEnlHmeS_6?M001W_F>lHkeS_6NmHkaS_F>lIkeS_6>m001WWF=lHieSO6NMHg`200004f>MGgeO
WEmmHid005mmGeaSOEmLGgeOG6=mGeaOOEmLHgeOG5mm00800005Gc/005/lFceK?003000025/lFceK
?5/mFcaK?E/lFcd200005ELKFa`005LLD_aG7E;lEaaBo5LMD_aG75;lEaeBo5LLD_aG7@00D_e>o004
0000Ce;LC]]Bg4kKD]a>fe;LC]/004ZlC]a:_4kMB[a>g4ZlC]e:_4kLB[a>gDZl0012_4JmA[a6_D:l
A[e6_4Jm@[a6_DJlA[d004:M?Ya2WCjL@YdnW4:M?Ya2WCjL@YdnW000=W`jWCIl>YdfO3ZM=W`jWCIl
>YdfO000;U`bGBiL000^G39M;U`bGBiL<Ud^G0009S`Z?BHl:SdV?2Xm00@000038S`007oo00moo`03
001oogoo01Ioo`0017oo10000goo0P001Woo00<007ooOol07Goo00<007ooOol00Woo00<005oMGm`0
0UoL00IOgEoLGmaOg000Hm`3Hmd01F?LHmeSgF?MHm`00P0000=S_F>lHkd00V>m00ES_6>mHkeS_F>l
008000USW0800003Gid00000009OG005GeeOG5mLGeaOG@03Ge`015mMGe`0000015ll0`0000=K?5/m
Fc`00U/l00AK?E/lFcaK?08000=K7003Fa]K700000iG70<00005C]aBg5;LD]a>g003D]`01DkLD]aB
g5;L00003D[L00l004JmA[a6_DJlA[e6_4JmA[a6_DJlA[e6_4Jm00000cjM00DnW3jM?YdnWCjL00<n
W@05?Y`003Im>WdfO002=Wd073Ym=W`fOCIm>WdfO000;UdbG@00<Ud^GC9M;U`bGBiM<Ud^G0009S`Z
?BHl:S`V?2Xm9S`Z?2Hl0`0047oo00<007ooOol05Goo0004Ool00`00Oomoo`03Ool01000Oomoo`00
1Goo00<007ooOol07Woo00/007oo000006?mGmaSoEoLHoeOg6?m0080000`HkaSgEnlHmeS_6?MGkaS
gF>l001S_6NmHkaS_F>lIkeS_6>mHkaW_F>l001SO6NMHgaSWF=lIieSO6>MHgaWWF=lHieSO000GeaO
OEmLHgeOG5mmGeaSOEmLGgeOG6=m0P0000=O>ellGc/00`0000YO>`00001K?E/lFceK?5/mFcaK?@80
000DFa]K75LKFaaK6e/LEa]K7000EaaBo5LMD_aG75;lEaeBo5LLD_aG7@80001ND]]Fo000D]a>fe;L
C]]Bg4kKD]a>fe;LC]]Bg4kKD]`004kMB[a>g4ZlC]e:_4kLB[a>gDZlC]a:_4kM0016_D:lA[e6_4Jm
@[a6_DJlA[e2_4JmA[`003jL@YdnW4:M?Ya2WCjL@YdnW4:M?Ya2W@00>YdfO3ZM=W`jWCIl>YdfO3ZM
=W`jWCIl000^G39M000bGBiL<Ud^G39M;U`bGBiL000V?2Xm9S`Z?BHl:SdV?2Xm9S`Z?BHl000?Ool0
0`00Oomoo`0EOol000Eoo`03001oogoo009oo`04001oogoo0005Ool00`00Oomoo`0OOol>00000f?M
HmaSg@02Hmd20002Hkd01F>lHkeS_F>mHk`00f>m0P0036>L0P0000ASG000001OG@=OG006GeeOG5mL
GeaOG@000Ull0`001Ull00D005/lFcaK?E/l00800003FaaK6e/L009K7007Fa]K75/LFaaK6e/L0000
25LL0P000UKk00IFo5KkE_/005;LC]`3D]`01DkLD]aBg5;LC]`00e;L00<004[LB]`02d[L00L004Jm
A[a6_DJlA[e6_00J00007SYm=W`fOCIm>Wd0039M;UdbG@00<Ud^GC9M;U`bGBiM<Ud002Xl9S`Z?BHl
:S`V?2Xm9S`Z?2Hl:Sd000moo`8001Ioo`001Woo00D007ooOomoo`00009oo`03001oogoo009oo`03
001oogoo01ioo`80000>Hm]Wo6?LIoaSffOlHmaWo000ImaW_6OLIkaWg0L0000MIkeS_6>mHkaW_F>l
HkeS_6Nm001SWF=lIieSO6>MHgaWWF=lHieSO6NMHgaSW@00HgaSFf=lHe]SO00200001EmLHgeOG5mm
Ge`01@0000aO>ellGc]O?5lkGcaO>ellGc]O?000Fcd2000055LKFaaK6e/LEa]K75/KFaaG6e/LFa]K
75LKFa`005LLD_aG7E;lEa`200008E;KE_aBfeKlD]]Fo5;KE_`005;LC]]Bg4kKD]a>fe;LC]]Bg4kK
D]a>fe;L001>gDZlC]a:_4kMB[a>g4ZlC]e:_00900006TJKBYa6VdJLAY]:W4JK000nNd:L?W]2W3ik
@Y`nNd:L?W]2W3ik@Y`003il>U`jO3YK?W`:00005BiL<Ud^G39M;U`bGBiL<Ud002Xm9S`Z?BHl:SdV
?2Xm9S`Z?BHl:Sd0000@Ool00`00Oomoo`0COol000Aoo`04001oogoo0002Ool01000Oomoo`0017oo
00<007ooOol07Goo00D006OLImaWg6?L00=Wg00=Hm`00000ImaW_6OLIkaWg6NlImaW_6OL00000fNl
100000=S_6>mHkd00P0036>L0P0026=L0P0000=OG00000000P003Ull00D005/LFaaK75/K00=K7005
Fa]K75/LFaaK6`03Fa`00e/KFa`00002Ea`200001EKlE_]FneKkE_`00eKk00IFo5KkE_/005;LC]`3
D]`01DkLD]aBg5;LC]`00U;L00<004[LB]`00T[L1P0001i:^djkB[]:^`00AYa6VdJLAY]6W4JKAYa6
VdJLAY]6W000@Ya2O4:L@Wa2W49l@Ya2O4:L@Wa2W49l000<>W`00`00=U`bG0060000439M;Ud002Hl
:S`V?2Xm9S`Z?2Hl:SdV?2Xl9S`Z?@003goo00<007ooOol04goo0005Ool20004Ool20005Ool2000M
Ool04`00IoaSffOlHmaWo6?KIoaSg000IkaWg6NlImaW_6OLIkaWg6Nl00800008IkaWVf^lIiaW_6NK
JkaWW0@0000IHieSO6NMHgaSWF=lIieSO6>MHgaWWF=l001SFf=lHe]SO6=KHgaSFf=lHe]SO6=KHg`0
0P0000mO>ellGc]O?5lkGcaO>ellGc]O?5lkGcaO>ellGc/00P00019O6`00FaaK6e/LEa]K75/KFaaG
6e/LFa]K75LKFaaK6e/LEa/300006U;KE_aBfeKlD]]Fo5;KE_aBfeKlD]]Fo5;K001>fe;LC]]Bg4kK
D]a>fe;LC]]Bg4kKD]`50000>DjlB[]>_4ZkC[a:^djlB[]>_4Zk0016VdJLAY]:W4JKAYa6VdZLAY]6
W4JKBY`004:L?W]2W3ik@Y`nNd:L?W]2W3ik@Y`nN`00>U/nO3YL>W`jFcil>U`jO3YK?W`jG000<U/f
G39L000bFcIL<U`fG00500002bXm9S`Z?BHl:SdV?2Xm9S`Z?BHl000047oo00<007ooOol04Woo000B
Ool00`00Oomoo`0JOol20003Im`046?LImaWg6OLHm`006NlImaW_6OLIkaWg6NlImaW_0002fNl00<0
06MkIi`00P0026>L0P002V=L0`0000=S>`0000003Ell00<005lKGa/00UlK00D005/LFaaK75/K00=K
7006Fa]K75/LFaaK6e/L0P0000AFne[k001Fo0=Fn`05E_aFneKkE_]Fo003E_/00eKlE_/00002D]`0
1DkLD]aBg5;LC]`0100000=B^djk00000dZk00E>^dZkB[]:^djk00=:^`0LC[]:^`00AY]6W4JKAYa6
VdJLAY]6W4JKAYa6VdJL0012W49l@Ya2O4:L@Wa2W49l@Ya2O4:L000<>W`03000<U`fG39L000bG3IL
<U`fG39L=U`bG0D000089S`Z?2Hl:SdV?2Xl9S`0011oo`03001oogoo015oo`004Woo00<007ooOol0
6Goo00T006?LIoaSffOlHmaWo6?KIo`00P0001AW_6OLIkaWg6NlImaW_6OLIk`006NLIkaWVf^lIiaW
_6NKJkaWW6Nl0P0000EWNfNLIg]WW6Mk0080000?IieSO6>MHgaWW@00HgaSFf=lHe]SO6=KHgaSFf=l
00@0000@Gc]S?6<kHcaO>`00Gc]O?5lkGcaO>ellGc]O?5lkGc`200004E/KGa]K6elLFa]O6`00FaaK
6e/LEa]K75/KFaaG6e/LFa/00P0001MJneKkF_]FnU[k001Fo5;KE_aBfeKlD]]Fo5;KE_aBfeKlD]]F
o5;K001>fe;L00@0001;C[]B^djkD[]>^e:kC[/004ZkC[a:^djlB[]>_4ZkC[a:^djlB[]>_4Zk0016
VdJLAY]:W4JKAYa6VdZLAY]6W4JK000nNd:L?W]2W3ik@Y`nNd:L?W]2W3ik@Y`003Yl>U/nO3YL>W`j
Fcil>U`jO3YK?W`003IL<U/fG000=U`bFcIL<U`fG39K=U`002hl:S/^?2Xk00@00005:SdV?2Xm9S`0
000>Ool30008Ool30007Ool0019oo`03001oogoo01Moo`800005HmaWg6OLImaSg003Im`03000ImaW
_6OLIkaWg6NlImaW_6OLIk`000YW_00:001WW6MkIiaWNfNLIg]WW6MkIi`200000f>L00000007He`3
0002He`00`00Hc]S>`05Hc/00`00GcaO?005Gc`20009Ga/01@00FaaK75/LFa/00e/L0P000U[k00QF
ne[kF_]JneKk001FneKl0eKk00EFo5KkE_]FneKl00=Fn`0AE_`00000001B^djkD[]>^e:kC[]B^djk
D[]>^e:k001>^`03B[/01DjkB[]:^dZkC[/00dZk01]>^`00AYa6VdJLAY]6W4JKAYa6VdJLAY]6W4JK
0012O4:L@Wa2W49l@Ya2O4:L@Wa2W49l000033Yl00l003IL<U`fG000=U`bG3IL<U`fG39L=U`002hl
;S/00bhl00<^>bhl0000100047oo00<007ooOol01goo00<007ooOol01Woo000BOol00`00Oomoo`0F
Ool0;@00IoaSg6OlHm]Wo6?LIoaSffOl001Wg6NlImaW_6OLIkaWg6NlImaW_000IiaW_6NKJkaWW6Nl
Ii][_6NLIk`006NLIg]WW6MkIiaWNfNLIg]WW6MkIiaWN`0200001F=lHe]SO6=KHg`00`0000=SO6=K
Hg`00P0000UO>f<lHc]S?5lkHcaS>f<lGc/00P0001IO?5lkGcaO>`00Fa]O75/KGa]K6elLFa]O6e/K
GaaK6elK001K75/KFaaG6`80000FF_]FnU[kE_]JneKjF_]Fne[kE_X005;KE_aBfeKlD]]Fo5;KE_aB
feKlD]/20000FUKKD[X004jkD[]>^e:kC[]B^djkD[]>^e:kC[]B^`00C[a:^djlB[]>_4ZkC[a:^djl
B[]>_4ZkC[`004ZLAY]6W4JKBYa6VdJLAY]:W4JKAYa6V`00?W]2W3ik@Y`nNd:L?W]2W3ik@Y`nN`00
>U`jO3YK?W`jG3Yl>U/nO3YL>W`jF`00<U`fG39K=U`003IL<U/fG39L=U`bF`00:S/^?2Xk;S`Z>bhl
:S/^?2Xk;S`Z>`80011oo`03001oogoo00=oo`D000Moo`004Goo00<007ooOol05Woo00<006OLHm`0
0fOL00=Sg6OLIm`00P0000UWg6NlImaW_6OLIkaWg6NlIm`00P002VNl00`006NLIg]WW6MkIiaWNfNL
Ig]WW6MkIi`20002Ie/50005He`00`00Hc]S>`0;Hc/01000Gc`000003UlK00D005/L000005Kk00=J
n`05E_]Jne[kF_]Fn`03F_/015Kk001FneKl0eKk00=Fo5Kk00000P0001ABfUKKE]]Ff`00D[]>^e:k
C[]B^djkD[]>^e:kC[]B^djkD[/004jk0dZk00E>^dZkB[]:^djk00=:^`0JC[/004JLAY]6W4JKAYa6
VdJLAY]6W4JKAY`004:L@Wa2W49l@Ya2O4:L@Wa2W49l@Y`000`jO00=000bG3IL<U`fG000=U`bG3IL
<U`fG39L00000Rhl00D^>bhl;S`^?2hk00<^?003;S/^?00000moo`03001oogoo00=oo`04001oogoo
0008Ool0015oo`8001Eoo`80000_IoaSg6OlHm]Wo6?LIoaSf`00IkaWg6NlImaW_6OLIkaWg6NlIm`0
06^lIiaW_6NKJkaWW6NlIi][_6NLIk`006NLIg]WW6MkIiaWNfNLIg]WW6MkIi`006MlIe]WN`050000
9V=lHe]SO6=KHg`006<lGc]S?6<kHcaO>f<lHc]S?5lkHcaS>f<lGc]S?000Ga]K6elLFa]O6e/KGaaK
6elKFa]O75/KGa]K6elLFa/200005E[kE_]JneKjF_]Fne[kE_YJneKkF_]FnU[kE_]JneKj001BfeKl
D]]Fo0020000:U:jE]]B^UKKD[YFfe:jE]/005:kC[]B^djkD[]>^e:kC[]B^djkD[]>^e:k001>_4Zk
C[a:^djlB[]>_4ZkC[a:^djlB[/004JKBYa6VdJLAY]:W1T0000O>W`jFcil>U`jO000=U`bG3IL<U/0
039L=U`bFcIL<U`fG39K000Z>bhl:S/^?2Xk;S`Z>bhl:S/^?2Xk000047oo00<007ooOol00goo00<0
07oo000027oo000AOol00`00Oomoo`0COol@00001VOLIkaWg6NlIm`000YW_080000<IiaWNfNLIg]W
W6MkIiaWNfNLIg]WW0000VMK0P001FMK0P0000=SG00000003V<k0P0000=S6`00Ga/035lK0P0000=J
nUkk00000e[k00EFne[kF_]JneKk00=Jn`05E_]Jne[kF_/00002E_/20003E]/01E;JE]]FfeKKD]X0
0eKK010005:kC[]B^djkD[]>^e:kC[]B^djkD[]>^`00B[]>^`=:^`05C[]:^dZkB[]>^`090007AW/0
0`00@W]2N`09@W/00`00?U/nF`03?U/900002SIL<U`0039L=U`bG3IL<U`fG0000bhl00D^>bhl;S`^
?2hk00<^?003;S/007oo00ioo`8000Eoo`8000Qoo`004Goo00<007ooOol04Woo014006OKJmaWff_L
Im][g6OKJmaWf`00Jk][_6NkJka[^f^l00L0000DIkaWVf^lIiaW_6NKJkaWW000Ig]WW6MkIiaWNfNL
Ig]WW6MkIiaWN`D0000YHe]WO6MKIg]SFfMlIe]WNf=K001S>f<lGc]S?6<kHcaO>f<lHc]S?5lkHcaS
>f<lGc/005lJHa]O6V<K001O6e/KGaaK6elKFa]O75/KGa]K6`02000055kkF_YNne[jG_/005[kE_]J
neKjF_]Fne[kE_YJneKkF_]FnU[kE_/300007e:jE]]B^UKKD[YFfe:jE]]B^UKKD[YFfe:j001>^e:k
C[]B^djkD[]>^e:kC[]B^djkD[]>^`00B[]>_4Zk00H0000BCY]:VTjKBYX004IjBY]6NTZKAWY:VdIj
BY]6NTZKAWX0049j0d9k00E2NT9k@W]2Nd9j0092N`0?000jFciK>U/nFcYK?U/jFciK>U/nFcYK?U/0
03Xk00D0000B=U`bFcIL<U`fG000;S`Z>bhl:S/^?2Xk;S`Z>bhl:S/^?0003Woo00<007oo00003goo
000AOol00`00Oomoo`0AOol00`00Jm][f`07Jm/01@00Jk][^f^kJk`00f^k00A[_6^kJk/000=[V`@0
00=W_00<001WNfNLIg]WW6MkIiaWNfNLIg]WW6Mk0`002VMK0P0000=S>P00Hc/02f<k0P0000MO6V<K
Ga]S6elJHa/00007Ga/200002E[jG_]JnUkkF_YNne[jG_/00003F_/01EKkF_]Jne[kE_/00e[k0P00
00=FfU[J00000eKK00EBfUKKE]]Ffe;J00=Ff`0?D]YFfeKK001>^e:kC[]B^djkD[]>^e:kC[]B^djk
00D0000;BYY>VdZJCY]:VTjKBYY>VdZJCY/0000<AW/00`00@W]2N`09@W/00`00?U/nF`09?U/00`00
=S/f>`02=S/00`00=S/0000300000c9L000^>`03;S`01Bhk;S`^?2hl;S/00bhl00<007ooOol03Woo
00<007ooOol037oo000AOol00`00Oomoo`0@Ool07P00Im][g6OKJmaWff_LIm][g6OK001[^f^lIk][
_6^kJkaW^f^lJk][_000Jka[Vf^lIi][_6^KJkaWV`@00008IiaWNfNLIg]WW6MkIiaWN`<0000[He]W
O6MKIg]SFfMlIe]WNf=KIgaWFfMk001W>f<jIc]S>P00Hc]S?5lkHcaS>f<lGc]S?6<kHc`006<KGaYS
6elJHa]O6V<KGaYS6`00Ga]K6elLFa/00P0001ANne[jG_]JnUkkF_YNne[jG_]JnUkk001JneKkF_]F
nU[kE_]JneKj0P0001]JfeKJF]]FfU[K001Ffe:jE]]B^UKKD[YFfe:jE]]B^UKKD[YFfe:j001>^e:k
C[]B^djkD[/0100001m>VU:kCYX004ZJCY]:VTjKBYY>VdZJCY]:VTjKBYY>V`00BY]6NTZKAWY:VdIj
BY]6NTZKAWY:V`00@W]2NP03@W/07D9j@W]2Nd9k@WY2N`00?U/jFciK>U/nFcYK?U/jFciK>U/nFcYK
000f>cXk=S/j>`00>S/f>cXk=S/0100000/^?2Xk;S`Z>bhl:S/^?2Xk;S`Z>`00011oo`03001oogoo
00aoo`0047oo00<007ooOol047oo00<006_KJm/01f_K00D006^kJk][^f^l00=[^`04Jka[^`00000:
Ji/00`00Jg][N`0300000fNLIg/00004000<Ie/01`00Ic]S>VLkHc]W>f<j008000IS>`80000=Ha]O
6V<KGa]S6elJHa]O6f<KGaYS6`00Ga/00P0000mJnUkkF_YNne[jG_]JnUkkF_YNne[jG_]JnUkk0000
0e[k00AFne[k000000=FfP06F]YFfUKJE]X005;J0eKK00EBfUKKE]]Ffe;J00=Ff`05D]YFf`00D[]>
^`0400005E:JCYYBVTjJDYY>VU:J001>VdZJCY]:VTjKBYY>VdZJCY]:VTjKBYX0000<AW/00`00@W]2
N`09@W/00`00?U/nF`09?U/00`00=S/f>`03=S/00`00=S/f>`04=S/500001Bhk;S`^?2hl;S/00Rhl
00<007ooOol03Woo00<007ooOol02goo000@Ool2000@Ool02@00Im][g6OKJmaWff_LIm][g0020000
6f^kJkaW^f^lJk][_6NkJka[^`00Ii][_6^KJkaWVf^lJi][_6NKJka[V`00IgY[NfMkJg]WNP030000
3fMkIi`006MkHe]WO6MKIg]SFfMlIe]WNf=KIgaWF`020000<VLkHcYW>f<jIc]S>VLkHcYW>`00HcaO
>f<lHc/005lJHa]O6V<KGaYS6elJHa]O6V<KGaYS6elJHa/005kkF_YNne[jG_]JnUkkF_YNne[jG_]J
nUkkF_YNne[jG_/005[kE_/2000065[KE]YJfeKJF]]FfU[KE]YJfeKJ001B^UKKD[YFfe:jE]]B^UKK
D[YFfe:jE]]B^P<0000YCYYB^djJD[]>VU:kCYYB^djJD[]>VU:k001>VdZJCY]:VTjKBYY>VdZJCY]:
VTjKBYX004IjBY]6NTZKAWY:VdIjBY]6NTZKAWY:V`00@W]2NP03@W/08d9j@W]2Nd9k@WY2N`00?U/j
FciK>U/nFcYK?U/jFciK>U/nF`00>S/f>cXk=S/j>`00>S/f>cXk=S/j>`00<Q/^6c8K;Q/00`0000DZ
>bhl:S/^?000011oo`8000aoo`0047oo00<007ooOol03Goo0P0026_K00<006^lJk/00V^k00M[_6^k
Jk][^f^lJk/0000:Ji/20003Jg/30003Jg/3000;Ie/03`00Hc]W>f<jIc]S>fLkHcYW>f<kIc]S>VLk
001S>`0200003ElKHa]O6V<KGa]S6elJHa]O6f<KGaYS6elK0080000CG_X005kkF_YNne[jG_]JnUkk
F_YNne[jG_]JnUkkF_YNne[jG_/00P0000=FfU[JE]X00UKJ00EJfUKJE]YFfU[J00=FfP03001BfUKK
009Ff`05D]YFfeKKE]]BfP030002D[X06`00DYY>VU:JCYYBVTjJDYY>VU:JCYYBVTjJ001:VTjKBYY>
VdZJCY]:VTjKBYY>VdZJCY/0000<AW/00`00@W]2N`09@W/00`00?U/nF`0:?U/00`00=S/f>`02=S/0
0`00=S/f>`04=S/00`00<Q/b6`04<Q/400000bhl001oo`0?Ool00`00Oomoo`0:Ool0011oo`03001o
ogoo00aoo`0T001[g6OKJmaWff_LIm][g6OKJm`006^lJk][_6NkJka[^f^lIk][_6^k001WVf^lJi][
_6NKJka[Vf^lIi][_000Jg]WNV]k0P0000UWNV]kIg][NfMjJg/006]KIeX00P0003YWNf=KIgaWFfMk
He]WO6MK001S>VLkHcYW>f<jIc]S>VLkHcYW>f<jIc]S>VLk001S6elJHa]O6V<KGaYS6elJHa]O6V<K
GaYS6elJ001NnV;jG_YRnP00G_]JnUkkF_YNne[jG_]JnUkkF_YNne[jG_]JnP80000FG]X005[KE]YJ
feKJF]]FfU[KE]YJfeKJF]]FfU[KE]X005:jE]]B^UKKD[X30000;U:iE[YB^UJjD[T004jJD[]>VU:k
CYYB^djJD[]>VU:kCYYB^djJ001:VTjKBYY>VdZJCY]:VTjKBYY>VdZJCY/004ZKAWY:VdIjBY]6NTZK
AWY:VdIjBY]6NP000T9k00E2NT9k@W]2Nd9j00=2N`0T@WX003YK?U/jFciK>U/nFcYK?U/jFciK>U/0
03Hk>S/f>cXk=S/003Hk>S/f>cXk=S/002hK<Q/^6c8K;Q/b6bhK<Q/^6c8K0P004Goo00<007ooOol0
2Goo000@Ool00`00Oomoo`0;Ool00`00Jm][f`07Jm/00`00Jka[^`02Jk/01f^lJk][^f^kJka[^`00
00Y[V`03001[N`00008000M[N`06001WFfMJJe]WFVMK0P0016MK0P0000eS>fLkHcYW>f<kIc]S>VLk
Hc]W>f<jIc]S>`0200003f<J001S6elJHa]O6f<KGaYS6elKHa]O6V<KGa/00006G_X03000G_]JnUkk
F_YNne[jG_]JnUkkF_YNn`8000=JfP05001FfUKJE]YJfP03E]X01E[JE]YFfUKJF]X00UKJ00<005KK
D]X00`000e:j025F^U:jD[YB^UJjD[X004jJDYY>VU:JCYYBVTjJDYY>VU:JCYYBVTjJ001:VTjKBYY>
VdZJCY]:VTjKBYY>VdZJ000034Ik00<0049k@W/02D9k00<003iK?U/02SiK00<003Hk=S/00cHk00<0
03Hk=S/00cHk00<0038K<Q/02C8K00<007ooOol03goo00<007ooOol027oo000@Ool00`00Oomoo`0:
Ool05000JmaWff_LIm][g6OKJmaWff_L001[_6^kJkaW^f^lJk][_6NkJk`200002VNKJka[Vf^lIi][
_6^KJkaWVf^l0`00019[NfMkJg]WNV]kIg][NfMjJg/006]KIeY[FfMJJe]WFV]KIeX200004FMl001W
>f<jIc]S>VLkHcYW>f<jIc]S>VLkHcYW>f<j00000f<J00]W6P00Ha]O6V<KGaYS6elJHa]O6V<K0080
000AG_YRnUkjH_YNnV;jG_YRnP00G_]JnUkkF_YNne[jG_]JnP0200005EkJF]YNfU[IG]YJfP00E]YJ
feKJF]]FfU[KE]YJfeKJF]]FfU[KE]YJf`020000;U:iE[YB^UJjD[UF^U:jE[YB^EJjD[YF^P00D[]>
VU:kCYYB^djJD[]>VU:kCYYB^djJD[/004jKBYY>VdZJCY]:VTjKBYY>VdZJCY]:VP00AWY:VdIjBY]6
NTZK6@0001hnFcYK?U/jFciK000j>cHk>S/f>cXk=S/003Hk>S/f>cXk=S/002hK<Q/^6c8K;Q/b6bhK
<Q/^6c8K000AOol00`00Oomoo`08Ool0011oo`03001oogoo00Uoo`03001[ff_K00M[f`03001[_6^k
009[^`06Jka[^f^kJk][_0002F^K0`002f]k01`006MKIeY[FfMJIe]WFV]KIeYWFfMJJe/006LkHc]W
>f<jIc]S>fLkHcYW>f<kIc]S>VLkHc/000IS6P800007GaYS6elKHa]O6V<K00002Ukj00T005[jG_]J
nUkkF_YNne[j00002E[J00D005KJE]YFfU[J00=FfP04F]YFfUKJE]X200000eJj001F^P03D[X01EJj
D[YB^U:jE[X00e:j01UF^P00DYY>VU:JCYYBVTjJDYY>VU:JCYYBVTjJDYX004jKBYY>VdZJCY]:VTjK
BYY>V`0900001dYjAWY:NTIjBWY6NP0000=2FP05AUY2FT9J@UY6FP03@UX00dIJ000n>P04?SX90003
=S/00`00=S/f>`03=S/00`00<Q/b6`09<Q/00`00Oomoo`0>Ool20009Ool000moo`<000Uoo`05001[
g6OKJmaWf`0:00003F^lJk][_6NkJk`006^lIi][_6^KJkaWVf^l00D0000:Jg]WNV]kIg][NfMjJg]W
Nf]kIgX200006F]KIeY[FfMJJe]WFV]KIeY[FfMJJe/006Lj001W>f<jIc]S>VLkHcYW>f<jIc]S>VLk
008000=S6P0MIaYS6V<JHaYW6V<J001O6V<KGaYS6`00H_YNnV;jG_YRnUkjH_YNnV;jG_YRnUkj001J
nUkkF_YNn`02000055[IG]YJfUkJF]UNfU[JG]YJfEkJ001JfeKJF]]FfU[KE]YJfeKJF]/200008eJi
F[YF^@00D[YF^U:iE[YB^UJjD[UF^U:jE[YB^EJjD[YF^P00D[]>VU:kCYYB^djJD[]>VU:kCYYB^djJ
001:VTjKBYX01P0002]>NTYiCWX004YjAUY:NTIJBWY6FTYjAUY:NTIJBWY6FP00@UY6Fd9JAUY2FTIK
@UY6FT9JAU]2FP00?SY2Fchj?U/n>T9K?SXnFchj@U/n>SiK000j>`0500004CXk=S/j>cHk>S/0038K
;Q/b6bhK<Q/^6c8K;Q/b6bhK000037oo100000=oo`00Ool027oo000?Ool00`00Oomoo`08Ool60000
1f_KKm][fVoK001_^f^j00=_^`L000=[V`<0009[V`03001[Nf]k00U[N`0>001WFVMKIeY[FfMJIe]W
FV]KIeYWFfMJJe/000=W>P0;001W>f<kIc]S>VLkHc]W>f<jIc/0000<HaX01000GaX000003Ukj00@0
05[j000000eJfP03001JfUKJ009FfP0=F]YFfP00001F^UJiE[YF^EJjE[T005:jE[X00e:j00EF^U:j
D[YB^UJj00=B^P0<001>VU:JCYYBVTjJDYY>VU:JCYYBVTjJ1@0001Q:NTijBWY>NTYjCWY:NTijBWX0
04IjBWY6NTYjAWY:NTIjBWY6NTYjAWY:NP00AUX3@UX01DIJ@UY2FT9JAUX00d9J00<003hj?SX02Chj
00<003Xj>SX013Xj100000<f>`00<Q/02S8K00<007ooOol01Woo0`001Goo00<007ooOol01goo0003
Ool30002Ool20005Ool00`00Oomoo`07Ool06000Km][fVoKJmY_ff_JKm][fVoK001_^f^jKk][^Vnk
JkY_^f^jKk/006nKJiY_V`@0000MJi][_6NK001WNf]kIgY[NfMkJg]WNV]kIg][NfMj001WFV]KIeY[
FfMJJe]WFV]KIeY[FfMJJe/00002IcX00f/jIcYW>P02000026<jIc]S>VLkHcYW>`00IaX3HaX01FLJ
HaYS6V<JIaX00f<J02UW6V<J001NnV;jG_YRnUkjH_YNnV;jG_YRnUkjH_YNnV;jG_YRnUkj001JfUkJ
F]UNfU[JG]YJfEkJF]YNfU[IG]YJfUkJF]UNfP00F]]FfU[K0080000NE[UJ^UJiF[YF^EZjE[UJ^P00
E[YB^UJjD[UF^U:jE[YB^EJjD[YF^U:iE[YB^P00CYYB^djJD[]>VU:k100003m>NE:JCWT004YiCWY:
NDijBWU>NTYiCWY:NDijBWT004IJBWY6FTYjAUY:NTIJBWY6FTYjAUY:NP00AUY2FTIK@UY6FT9JAU]2
FTIJ@UY6F`00?U/n>T9K?SXnFchj@U/n>SiK?SY2Fchj000f>SXk>SXj>cHj>S/003Xk=SX0100000/b
6bhK<Q/^6c8K;Q/b6bhK<Q/^6`0000Aoo`<000Qoo`03001oogoo00Moo`0017oo00@007ooOol0009o
o`03001oogoo009oo`03001oogoo00Ioo`0=001_ff_KKm][fVoKJm]_ff_JKm/006nkJkX00fnk00I[
^VnkKk]_^`00Ki/3000016nKJiY_Vf^J10002V]k00h006MJIe]WFV]KIeYWFfMJJe]WFVMKIeY[F`00
26Lj00@006<kIc]S>P8000iS6P03001Rn@0000iNnP800003G]T005[J00iJfP0@001FfP00001F^UJi
E[YF^EJjE[UF^UJiE[YF^EJj0002D[X01EJjD[YB^U:jE[X00e:j00IF^U:jD[X005:JCYX400008djJ
CYUBVTjICYY>VE:J001>NTYjCWY:NTijBWY>NTYjCWY:NTij001:NTIjBWY6NTYjAWY:NTIjBWY6NTYj
AWX0049JAUX00d9J00E6FT9J@UY2FTIJ0092FP03000n>Shj00Tn>P03000j>SXj00@j>P03000j>SXj
008j>P03000f6P0000<000Hb6`D000aoo`03001oogoo00Ioo`0000=oo`0000000`0000Eoo`00Oomo
o`0000Aoo`03001oogoo00Eoo`0D001_ff_JKm][fVoKJmY_ff_JKm/006nkJkY_^f^jKk][^VnkJkY_
^`<0000;Ki][VVnKJiY_Vf^JKi][VP00JgY_N`0300004V]kIgY[NfMkJg]WNP00IeY[FfMJJe]WFV]K
IeY[FfMJJe]WFP80009W>P05JcYW>VLjIcY[>P03IcX01@00HcX006<JIaX00f<J00EW6V<JHaYS6VLJ
00=S6P14IaX00000G_URnV;i001NnV;jG_YRnUkjH_YNnV;jG_YRnUkjH_X005kJG]UNfU[I001JfUkJ
F]UNfU[JG]YJfEkJF]YNfU[IG]YJfUkJF]T005JiF[YF^EZjE[UJ^UJiF[YF^EZjE[UJ^UJiF[X005Jj
D[YF^U:iE[YB^UJjD[UF^U:jE[YB^@<0001?CWUBVTiiDYY>NE:JCWUBVTiiDYY>NE:J001>NTYiCWY:
NDijBWU>NTYiCWY:NDij001:NTIJBWY6FTYjAUY:NTIJBWY6FTYjAUX0049JAUY2FTIK@UY6FT9JAU]2
FTIJ@UX003hj?U/n>T9K?SXnFchj@U/n>SiK?SY2F`00>S/f>SXk>SXj>cHj000j>SXk=SXj>`00=Q/b
6SHK<QX00`0000D^6c8K;Q/b6`0000moo`03001oogoo00Ioo`0000Eoo`00Oomoo`00009oo`04001o
ogoo0004Ool00`00Oomoo`04Ool03@00Km][ffoKJmY_ff_KKm][fVoK001_^f^j00=_^`03JkY_^fnk
00<0000:JiY_Vf^JKi][VVnKJiY_Vf^J0006JgX30002Jg/03@00IeYWFfMJJe]WFVMKIeY[FfMJIe]W
FP0000eW>P03001S6V<J00aS6P08001RnV;iH_YRnF;jH_T000UNnP800007G]YNfEkIG]UNfUkI0000
35[J0P00011J^@00E[UF^UJiE[YF^EJjE[UF^UJiE[YF^EJjE[T000=B^P06E[YB^U:jD[YF^U:j0`00
0U:I02L005:JCYU>VTjIDYY>VDjJCYUBVTjICYY>V@00BWY>NTYjCWY:NTijBWY>NTYjCWY:NP00AWY:
NTIjBWY6NTYjAWY:NTIjBWY6NTYj00000T9J00E6FT9J@UY2FTIJ00=2FP03AUY2FP0000/n>P03000j
>SXj00Dj>P0<000j>SXj>SX0038J=QXb6SHJ<QXf6S8J1@003goo00<007ooOol01Woo0002Ool00`00
Ool00002Ool01000Oomoo`000goo00<007ooOol017oo00T006oKJmY_ff_JKm][fVoKJmX00P0000I_
^f^jKk][^VnkJkX400005FnKJiY_Vf^JKi][VVnKJiY_Vf^J001[NVmkJgY_Nf]jKg][NVmkJgY_N`03
00002f]KIeY[FfMJJe]WFV]KIeY[FfMJ00000fLj00E[>VLjIcYW>V/j00=W>P04JcYW>P00HaT20002
HaX01FLJHaYS6V<JIaX00f<J015W6P00H_YNnF;jH_URnUkiH_YRn@00G_YRnUkjH_YNnV;j0080000C
F]UNfUkIG]YJfEkJG]UNfU[I001JfUkJF]UNfU[JG]YJfEkJF]X00P0001QJ^UZiF[X005ZjE[UJ^UJi
F[YF^EZjE[UJ^UJiF[YF^EZjE[T005:iE[YB^UJjD[T30000G5:IEYYBVEJJDYT004iiDYY>NE:JCWUB
VTiiDYY>NE:JCWUBVTii001:NDijBWU>NTYiCWY:NDijBWU>NTYi0016FTYjAUY:NTIJBWY6FTYjAUY:
NTIJBWX004IK@UY6FT9JAU]2FTIJ@UY6Fd9JAUX0049K?SXnFchj@U/n>SiK?SY2Fchj?U/n>P00>SXj
>cHj>S/j>SXk000j>cXj>S/f>P00<QXf6c8J=Q/b6SHK<QXf6c8J=Q/2000>Ool00`00Oomoo`06Ool0
00=oo`8000=oo`8000Aoo`8000Aoo`0:001_ff_KKm][fVoKJm]_ff_J0002Kk/00f^jKk]_^`030000
3Vnk000006nKJiY_Vf^JKi][VVnKJiY_Vf^J000;JgX00`00JeY[FP02000026MJIe]WFV]KIeYWFfMJ
000=IcX01P00IaUW6VLIIaX000US6P0<001RnV;iH_YRnF;jH_URnV;iH_YRn@0015kj00@005kIG]UN
fP=Nf@06G]YNfEkIG]UNfP001e[J0P001UZi014005JjE[UF^UJiE[YF^EJjE[UF^UJiE[YF^EJj001F
^U:j00<000UBV@0W001>VE:JCYU>VTjIDYY>VDjJCYUBVTjICYX004ijBWY>NTYjCWY:NTijBWY>NTYj
CWX004YjAWY:NTIjBWY6NTYjAWY:NTIjBWY6NP0000=2FP05AUY2FT9J@UY6FP03@UX00dIJ000n>P0:
?SX00`00>SXj>P05>SX04@00>SXj>SXj000f6S8J=QXb6SHJ<QXf6S8J=QXb6SHJ00003Woo00<007oo
Ool01Woo000>Ool00`00Oomoo`02Ool03@00Km][fVoKJmY_ff_JKm][fP00JkY_^f^j00<0000LJkY_
^f^j001[VVnKJiY_Vf^JKi][VVnKJiY_Vf^J001[NVmkJgY_Nf]jKg][NVmkJgY_Nf]j0002JeX00fMI
JeY[FP0200001F]KIeY[FfMJ00000fLj00E[>VLjIcYW>V/j00=W>P0:JcYW>P00HaUW6V<IIaYS6FLJ
0002HaX056LJHaYS6V<JIaX006;jG_URnV;iH_YNnF;jH_URnUkiH_YRn@00G_X200004UkJF]UNfUkI
G]YJfEkJG]UNfU[IG]YNfEkJ001NfU[JG]YJf@80000FF[YJ^EZjF[UJ^UZiF[YJ^EZj001J^UJiF[YF
^EZjE[UJ^UJiF[YF^EZjE[T30000IE:IEYYBVEJJDYUFVU:IEYYBVEJJDYUFVP00DYY>NE:JCWUBVTii
DYY>NE:JCWUBVTiiDYX004ijBWU>NTYiCWY:NDijBWU>NTYiCWX004YjAUY:NTIJBWY6FTYjAUY:NTIJ
BWY6FP00@UY6Fd9JAUY2FTIK@UY6FT9JAU]2FP00?SY2Fchj?U/n>T9K?SXnFchj@U/n>SiK000j>cXj
>S/f>SXk>SXj>`00>S/j>SXk000f6c8J=Q/b6SHK<QXf6c8J=Q/b6SHK00003Goo00<007ooOol01Woo
000>Ool03`00Oomoogoo001_ff_KKm][fVoKJm]_ff_J001_^`030002Kk/046^jKk]_^`00JiY_Vf^J
Ki][VVnKJiY_Vf^JKi][VP002f]j00<006]JJeX01V]J0P0000=WFP00IcX036Lj00T006LIIaYW6FLJ
IaUW6VLIIaX00P000f<J0P0000mRnV;iH_YRnF;jH_URnV;iH_YRnF;jH_URnV;i00000ekI00ENfUkI
G]UNfEkJ00=Nf@07G]YNfEkIG]UNfP00F]X00P002eZi00/005JiE[YF^EJjE[UF^UJiE[YF^EJj0080
009FV@03001BVE:I00]BV@0P001>VTjIDYY>VDjJCYUBVTjICYY>VE:JCYT004YjCWY:NTijBWY>NTYj
CWY:NTijBWX004IjBWY6NTYjAWY:NQL000Pn>P03000j>SXj00Hj>P0@000j>SXj000b6SHJ<QXf6S8J
=QXb6SHJ<QXf6S8J000=Ool00`00Oomoo`06Ool000ioo`0<001oogoo001_ff_JKm][fVoKJmY_ff_J
0`00021[^VnkJkY_^f^jKk][^P00JiY_Vf^JKi][VVnKJiY_Vf^JKi][VP00JgY_Nf]jKg][NVmkJgY_
Nf]jKg][NP000V]J00EWFF]JJeY[FVMI00=[FP03IeT006Lj009W>P05JcYW>VLjIcY[>P03IcX0BV/j
000006<IIaYS6FLJHaUW6V<IIaYS6FLJHaT006<J001RnF;jG_URnV;iH_YNnF;jH_URnUkiH_YRnF;j
G_T005kI001JfEkJG]UNfU[IG]YNfEkJF]UNfUkIG]YJfEkJG]UNfP00F[YJ^EZjF[UJ^UZiF[YJ^EZj
F[UJ^UZiF[YJ^@00E[UJ^UJiF[YF^EZjE[T20004EYT08P00DYUFVU:IEYYBVEJJDYUFVU:IEYYBVEJJ
DYUFVP00DYY>NE:JCWUBVTiiDYY>NE:JCWUBVTii001:NDijBWU>NTYi300001M:FTIIBUY6FDYJAUU:
FP00AUY2>DIJ@SU6FT8iAUY2>DIJ@SU6FT8i000n>D8j00H0000L?SY2Fchj000f>SXk>SXj>cHj>S/j
>P00=SXj>`00=Q/b6SHK<QXf6c8J=Q/b6SHK<QXf6c8J000=Ool00`00Oomoo`05Ool000ioo`0:001o
o`00Km][ffoKJmY_ff_KKm/20002Kk/01F^jKk]_^fnkJkX00Vnk00d006^JKi][VVnKJiY_Vf^JKi][
VVnKJiX0000;JgX00`00JeY[FP09JeX01000IcT000002FLj01h006LJIaUW6VLIIaYW6FLJIaUW6VLI
IaYW6FLJIaT006;iH_YRnF;jH_URnV;iH_YRnF;jH_URnV;iH_X2000015kIH]T005kJ0ekI00ENfUkI
G]UNfEkJ00=Nf@06G]YNf@00001Nf@003UZi00D005JiE[YF^EJj008000MFV@03001BVE:I00]BV@0<
001>VDjJCYUBVTjICYY>VE:JCYU>VTjI1`0002U:FDiiBUU>NDYICWU:F@00AUU:FDIIBUU6FDYIAUU:
FDIIBUU6F@00@SU6FT8iAUU2>DIJ@SU6FD8iAUY2>DII0012>Shi@SXn>D8j?SU2>Shi00H000Hj>P0@
000j>SXj000f6S8J=QXb6SHJ<QXf6S8J=QXb6SHJ000=Ool00`00Oomoo`05Ool000eoo`08001oo`00
Km][fVoKJmY_f`@0000RJkY_^f^jKk][^VnkJkY_^f^j001[VVnKJiY_Vf^JKi][VVnKJiY_Vf^J001[
NVmkJgY_Nf]jKg][NVmkJgY_Nf]j0002JeX01FMIJeY[FV]JIeT00f]J00IWF@00IcU[>VLiJcX20000
0fLjJcYW>P02IcX0B6/j001W6V<IIaYS6FLJHaUW6V<IIaYS6FLJHaUW6V<I001Rn@00G_URnV;iH_YN
nF;jH_URnUkiH_YRnF;j001RnEkIH_UNfF;i001NfU[IG]YNfEkJF]UNfUkIG]YJfEkJG]T005ZhG]UJ
^@00F[UJ^UZiF[YJ^EZjF[UJ^UZiF[YJ^EZjF[UJ^P00F[YF^@8000UFV@0F001FVU:IEYYBVEJJDYUF
VU:IEYYBVEJJDYUFVU:I001>NE:JCWUBVTiiDYX40000=TiiDWT004ijBUU>NDYICWY:FDiiBUU>NTYI
CWT004YJAUU:FTIIBUY6FDYJAUU:FTIIBUY6F@00@SU6FT8iAUY2>DIJ@SU6FT8iAUY2>DIJ0012>Shi
@SXn>D8j?SU2>Shi@SXn>@00>QTn6P@0000C=SXj>cXj000f>P00<QXf6c8J=Q/b6SHK<QXf6c8J=Q/b
6SHK000037oo00<007ooOol01Goo000=Ool200000foKJm]_f`0B00002V^JKi][VVnKJiY_Vf^JKi][
VP002f]j00<006]JJeX02F]J00T006LiJcYW>F/jIcU[>VLi000016Lj00h006LJIaUW6VLIIaYW6FLJ
IaUW6VLIIaYW6FLJ0P000f;i01D006;iH_YRnF;jH_URnV;iH_YRnF;j001RfEkIH]UNfF;IG]URf@00
G]X00ekI00ENfUkIG]UNfEkJ00800006G[UNfEZiG]UN^@003UZi0P0035JI00<005:IDYT02e:I00<0
05:JCYT010000Tii03YBNDiiCWU>N@00BUU>NDYICWU:FDiiBUU>NDYICWU:FDii001:FDIIBUU6FDYI
AUU:FDIIBUU6FDYI0016FD8iAUY2>DII@SU6FT8iAUU2>DIJ@ST003hi@SXn>D8j?SU2>Shi@SXn>D8j
?ST003XJ?QXj6@8j6PD0000>>SX0038J=QXb6SHJ<QXf6S8J=QXb6SHJ<QX000aoo`03001oogoo00Eo
o`003Goo1@004Woo1@00011[VVnKJiX006]jKg][NVmkJgY_Nf]jKg][NVmkJgX0009[FP05IeU[FV]J
JeYWF@03JeX02fMI001W>F/jIcU[>VLiJcYW>F/jIcT00P0004I[>P00IaYS6FLJHaUW6V<IIaYS6FLJ
HaUW6V<IIaX006LJH_UW6F;iIaYRn@00G_URnV;iH_YNnF;jH_URnP00H_UNfF;iG]URnEkIH_UNf@00
G]UNfU[IG]YNfEkJF]UNfP00G]UJ^5kIF[UNfEZhG]T005ZjF[UJ^UZiF[YJ^EZjF[UJ^UZiF[YJ^@80
0003F[T005JI00]FV@0>001BVEJJDYUFVU:IEYYBVEJJDYUFVU:IEYYBV@<00016CWQBNDiiDWU>N59i
CWUBNDihDWU>N@00BUU>NTYICWU:FDijBUU>NDYICWY:F@00AUU:FTIIBUY6FDYJAUU:FTIIBUY6FDYJ
0016FT8iAUY2>DIJ@SU6FT8iAUY2>DIJ@ST003hi@SXn>D8j?SU2>Shi@SXn>D8j000n6SXI?QXj6ChJ
>QTn6SXI?QX400002c8J=Q/b6SHK<QXf6c8J=Q/b6SHK000037oo00<007ooOol01Goo000=Ool2000J
Ool4000:JgX00`00JeY[FP08JeX2000076LiJcYW>F/jIcU[>VLiJcYW>F/jIcU[>P00IaYW6FLJIaUW
6VLIIaYW6FLJIaUW6VLIIaX006Ki0f;i01UVnF;iH_URn@00H_URnV;iH_YRnF;j001RfEkIH]UNfF;I
G]URfEkIH]UNf@00G]UNfP03G]T200002UkIG[UNfEZiG]UN^EkIF[UNf@002UZi00D005ZIF[UJV@00
00eFV@03001BVE:I00QBV@80009BN@03001BNDii009>N@05DWU>NDiiCWUBN@02CWT0<`00CWU:FDii
BUU>NDYICWU:FDiiBUU>NDYI0016FDYIAUU:FDIIBUU6FDYIAUU:FDII0012>DII@SU6FT8iAUU2>DIJ
@SU6FD8iAUX0048j?SU2>Shi@SXn>D8j?SU2>Shi@SX00002>QX02ChJ>QTj6SXJ?QXj6CXJ000n6P05
000023HJ<QXf6S8J=QXb6SHJ000;Ool00`00Oomoo`05Ool000ioo`03001oogoo01aoo`<00007Kg][
NVmkJgY_Nf]j00000V]J00EWFF]JJeY[FVMI00=[FP0[001[>VLiJcYW>F/jIcU[>VLiJcYW>F/jIcU[
>P00IaT006LJHaUW6V<IIaYS6FLJHaUW6V<IIaX006LJH_UW6F;iIaYRnFLIH_UW6V;i001NnF;jH_T0
0P0002ERnEkIH_UNfF;iG]URnEkIH_UNfF;iG]T005kIG]YJf@00F[UNfEZhG]UJ^EkIF[QNfEZiG]UJ
^5kI001J^UZiF[YJ^EZjF[UJ^P0200001UJHF[UFV5ZiEYP000aFV@08001FVU:IEYYBVEJJDYUFVP<0
001=EWUBN59iDWP004iiDWU>N59iCWUBNDihDWU>NE9iCWQBN@00CWU:FDijBUU>NDYICWY:FDiiBUU>
NP00BUY6FDYJAUU:FTIIBUY6FDYJAUU:FTII0012>DIJ@SU6FT8iAUY2>DIJ@SU6FT8iAUX0048j?SU2
>Shi@SXn>D8j?SU2>Shi000j6ChJ>QTn6SXI?QXj6ChJ>QTn6P02000013Gi>QXenCHJ0`0000Df6c8J
=Q/b6P0000aoo`03001oogoo00Aoo`003goo0P007goo0`000V]j00<006]JJeX026]J00l006/jIcU[
>VLiJcYW>F/jIcU[>VLiJcYW>F/j00000fLI00`006LJIaUW6VLIIaYW6FLJIaUW6P00I_T3H_T01FKi
H_URnF;iI_T00f;i01<006;i001NfF;IG]URfEkIH]UNfF;IG]URfEkIH]UNfF;I001Nf@0200003UZi
G]UN^EkIF[UNfEjiG]UJ^EkIG[UNfEZi0005F[T2000025ZiFYUJ^EZIF[UJVEZi000=EYT00`00DYUB
V@02DYT20008DWT00`00CWUBN@03CWT0>U9iCWU>NDiiDWU>N@00BUU>NDYICWU:FDiiBUU>NDYICWU:
FDii001:FDIIBUU6FDYIAUU:FDIIBUU6FDYI0016FT8iAUU2>DIJ@SU6FD8iAUY2>DII@ST003hi@SXn
>D8j?SU2>Shi@SXn>D8j?ST003XI0SXJ00Ln6SXI>QXj6ShJ>QTj6P0200001SGi=QXenSHJ=OTf6P@0
0003<QX007oo00Yoo`03001oogoo00Aoo`004Goo00<007ooOol07goo0`0000=[FVMIJeX00V]J01=W
FF]JJeY[FP00JcYW>F/jIcU[>VLiJcYW>F/jIcU[>VLiJcX00002IaT00f/JIaUW6@0200001F<IIaYS
6FLJHaT00P00041W6V;iIaURnFLJH_UW6F;iIaYRnFLIH_UW6V;i001NfF;iG]URnEkIH_UNfF;iG]UR
nEkIH_UNfF;iG]URn@00G]UJ^EkIF[QNfEZiG]UJ^5kIF[UNfEZhG]UJ^EkIF[P005ZiF[YJ^@00EYQJ
^EJHF[UFV5ZiEYQJ^EJHF[T000aFV@03001BVEJJ0080001CDWQBNE9hEWUBN59iDWQFNE9hDWT0059i
CWUBNDihDWU>NE9iCWQBNDiiDWU>N000BUU>NDYICWY:FDiiBUU>NTYICWU:F@00AUU:FTIIBUY6FDYJ
AUU:FTIIBUY6FDYJ0016FT8iAUY2>DIJ@SU6FT8iAUY2>DIJ@ST003hi@SXn>D8j?SU2>Shi@SXn>D8j
000n6SXI?QXj6ChJ>QTn6SXI?QXj6@0200002SHJ=OTj6SGi=QXenCXJ=OTf6SGi0P002goo00<007oo
Ool017oo000BOol00`00Oomoo`0QOol30005JeX03`00JcYW>F/jIcU[>VLiJcYW>F/jIcU[>VLiJcX0
0008IaT01`00IaUW6VLI001RnFKi00=Rn@05I_URnF;iH_UVn@03H_T04VKiH_T006;I001NfF;IG]UR
fEkIH]UNfF;IG]URfEkIH]UNf@80000CG]T005kIG[UNfEZiG]UN^EkIF[UNfEjiG]UJ^EkIG[UNf@00
F[T00P0000aJVEZiFYUJ^EZIF[UJVEZiFYUJ^EZI000<EYT3000=DWT01000CWU>NE9i0dii03YBNDii
CWU>NE9i001>NDYICWU:FDiiBUU>NDYICWU:FDiiBUT004IIBUU6FDYIAUU:FDIIBUU6FDYIAUT0048i
AUY2>DII@SU6FT8iAUU2>DIJ@SU6F@00@SXn>D8j?SU2>Shi@SXn>D8j?ST003XJ?QXj6@8j6P06?QXj
6CXJ>QXn6SXI0P0000`f6SGi=QXenSHJ=OTf6SGj=QXenCHJ000:Ool00`00Oomoo`04Ool001=oo`03
001oogoo02=oo`80009[FP0=001[>VLiJcYW>F/jIcU[>VLiJcYW>F/jIcT00P000VLI00E[6VLIIaUW
6F/J00=W6@0A001S6@00H_UW6V;iIaURnFLJH_UW6F;iIaYRnFLIH_UW6P020000=6;HH_URf000G]UR
nEkIH_UNfF;iG]URnEkIH_UNf@00G[QRfEjhG]T005kIF[UNfEZhG]UJ^EkIF[QNfEZiG]UJ^5kIF[UN
f@00F[UFV5ZiEYQJ^EJHF[UFV5ZiEYQJ^EJHF[UFV0002EJI0P0006MFVE9h001BN59iDWQFNE9hDWUB
N5IiDWQBNE9hEWUBN000CWQBNDiiDWU>N59iCWUBNDihDWU>NE9i001>NTYICWU:FDijBUU>NDYICWY:
FDii001:FTIIBUY6FDYJAUU:FTIIBUY6FDYJAUT0048iAUY2>DIJ@SU6FT8iAUY2>DIJ@SU6FP00@SXn
>D8j?SU2>Shi@SXn>D8j?ST003XI?QXj6ChJ>QTn6SXI?QXj6ChJ>QT003Gi=QXenCXJ=OTf6SGi>QXe
nCHJ=OT0000:Ool00`00Oomoo`04Ool001Aoo`8002Eoo`80000=JcYW>F/jIcU[>VLiJcYW>F/jIcU[
>VLi00003FLI00<006;iI_T00f;i00EVnF;iH_URnFKi00=Rn@0VI_T006;iH]URnF;HH_T006;IG]UR
fEkIH]UNfF;IG]URfEkI001Nf5kIG]QNfEkH001J^EkIG[UNfEZiG]UN^EkIF[UNfEjiG]UJ^@80000@
F[T005ZiFYUJ^EZIF[UJVEZiFYUJ^EZIF[UJVEZi0007EYT200001EJHEYUFV5JI00003U9i00D004ii
CWU>NE9i00=>N@0>DWU>NDiiCWT004YICWU:FDiiBUU>NDYICWU:FB000008@SXn>D8j?SU2>Shi@SX0
008j6P06?QXj6CXJ>QXn6SXI0SXJ00ln6P00000enSHJ=OTf6SGj=QXenCHJ=OXf6SGi00002Goo00<0
07ooOol017oo000FOol00`00Oomoo`0TOol200002VLiJcYW>F/jIcU[>VLiJcYW>@000fLI00E[6VLI
IaUW6F/J00=W6@0QJaYW6@00H_P006;iIaURnFLJH_UW6F;iIaYRnFLIH_UW6P00H_URf6;iH]QRnF;H
H_T006;iG]URnEkIH_UNfF;i0080000WG[QRfEjhG]UN^6;IG[P005ZhG]UJ^EkIF[QNfEZiG]UJ^5kI
F[T005ZhG[UJ^000EYQJ^EJHF[UFV5ZiEYQJ^EJHF[UFV5ZiEYQJ^@0000AFV@80000UEYUBN5JIDWQF
VE9hEYT005IiDWQBNE9hEWUBN59iDWQFNE9hDWUBN5Ii001BNDihDWU>NE9iCWQBNDiiDWU>N59iCWT0
04YICWX01P00021:F4iIBUP004HhBUU6>4YIASQ:FDHhBUU6>4YIASP0048hASU2>DHi@SQ6>D8iASU2
>4Hi@SU6>@00@STn6D8i1P0001/n>D8j000n6SXI?QXj6ChJ>QTn6SXI?QXj6ChJ000j6SGi=QXenCXJ
=OTf6SGi>QXenCHJ00002Goo00<007ooOol017oo000GOol00`00Oomoo`0UOol200001f/jIcU[>VLi
JcYW>@0000eW6@07001VnFKiI_P006;iI_T00f;i02UVnF;iH_URnFKi001RnF;IH_URf6;iH]URnF;H
H_T006;IG]URfEkIH]T005kIG]QNfEkHG]UNf5kIG]QNfEkH001J^EkIG[UNfEZiG]UN^EkI00800003
F[QJ^EZh009J^00?001JVEZiFYUJ^EZIF[UJVEZiFYUJ^EZIF[UJV@00009FV@80000:EYQFVEJHEYUF
V5JIEYQFVEJH000>DWT00`00DWU>N@02CWT01U9iCWU>NDiiDWU>N@@0000GCUU:F4iIBUQ>FDYHCUU:
F4iIBUP004HiBUU:>DYIASU:FDXiBUU6>DYIBST0000<AST00`00@QU26@06@QT500000cXJ?QXj6@02
>QX04ShJ>QTj6SXJ?QX003HJ=OXf6SGi=QXenSHJ=OTf6SGj=QX000Uoo`03001oogoo00=oo`0067oo
00<007ooOol09Woo00H006/jIcU[>VLi0003IaT01F/JIaUW6FLIJaX00fLI03A[6VLI001Rn6LIH_QW
6F;h001RnFLIH_UW6V;iIaURnFLJ001RnF;HH_URf6;iH]QRnF;HH_URf6;i001RnEkIH_T005kIG[QR
fEjhG]UN^6;IG[QNfEjhH]UN^000F[QNfEZiG]UJ^080000FG[UJ^5jiF[QN^EZhG[T005ZiEYQJ^EJH
F[UFV5ZiEYQJ^EJHF[UFV5ZiEYP200008EJIDWQFVE9hEYUBN5JIDWQFVE9hEYUBN000DWQFNE9hDWUB
N5IiDWQBNE9hEWUBN59iDWP004iiDWU>N59iCWUBN@040000=DiH001:F4iIBUQ>FDYHCUU:F4iIBUQ>
FDYHCUT004YIASQ:FDHhBUU6>4YIASQ:FDHhBUT004Hi@SQ6>D8iASU2>4Hi@SU6>D8hASU2>@00?QQ2
>ChI@STn648i?QU2>ChH@ST003hI>QT01@0000Dj6ChJ>QTn6SXI0080000;>QXenCHJ=OTj6SGi=QXe
nCXJ=OT00009Ool00`00Oomoo`03Ool001Uoo`8002Moo`800003IcT006LI00aW6@04001VnFKiI_P3
I_T016Kh001RnFKi0f;i0P0000iRnF;IH_URf6;iH]URnF;HH_URfF;iH]P005kI0P0001=NfEkHG]UN
f5kIG]QNfEkHG]UNf5kIG]QNf@00G]UJ^EkIG[T00003F[P01EZiF[QJ^5ZhF[T00UZh00`005ZiFYUJ
^EZIF[UJVEZiFYUJ^EZIF[T200003eJH001FV5JIEYQFVEJHEYUFV5JIEYQFVEJHEYT0000>DWT00`00
CWT00003000084iICUQ>F4iHCUU>F000BUQ>FDYHCUU:F4iIBUQ>FDYHCUU:F4iI001:FDHiBUU:>DYI
ASU:FDXiBUU6>DYI000<AST00`00@QU26@08@QT00`00?QTn6@04?QT40002>QX03@00=OTf6SGj=QXe
nCHJ=OXf6SGi=QXenP0000Qoo`03001oogoo00=oo`006goo00<007ooOol09Woo00D006LIIaUW6F/J
00=W6@05JaYW6FLIIaU[6P020000<6;hIaURn6LIH_QW6F;hIaURn000H_UW6F;i001Rf6;iH]QRnF;H
H_URf6;iH]QRnF;HH_URf6;iH]P005jhG]UN^6;IG[QNfEjhH]UN^5kIG[QRfEjhG]UN^6;I001Nf@80
000EF[QN^EZhG[UJ^5jiF[QN^EZhG[UJ^5ji001J^EJHF[UFV5ZiEYQJ^EJH0080000NFYUFV5ZH001F
VE9hEYUBN5JIDWQFVE9hEYUBN5JIDWQFV@00DWUBN5IiDWQBNE9hEWUBN59iDWQFNE9h0`0004I>F59I
CUQBFDiHDUU>F59ICUQBF@00CUU:F4iIBUQ>FDYHCUU:F4iIBUQ>FDYH0016>4YIASQ:FDHhBUU6>4YI
ASQ:FDHh0012>DHi@SQ6>D8iASU2>4Hi@SU6>D8hAST0048i?QQ2>ChI@STn648i?QU2>ChH000j6ChI
>QTn6CXI?QTj6ChI>QTn6@@0000;=OTj6SGi=QXenCXJ=OTf6SGi>QX00008Ool00`00Oomoo`03Ool0
01aoo`03001oogoo02Ioo`03001W6FLI00QW6@05001VnFKiI_UVn003I_T0;6KhI_UVnFKiI_P006;i
001Rf6;iH]URnF;HH_URfF;iH]QRnF;IH_URf6;iH]T005kH001Nf5kIG]QNfEkHG]UNf5kIG]QNfEkH
G]UNf5kIG]QNf@00F[T3F[P01EZiF[QJ^5ZhF[T00eZh00UJ^EZh001JVEZiFYUJ^EZIF[T00P0000=F
V5ZHEYP00UJH00mJV000EYUFV5JIEYQFVEJHEYUFV5JIEYQFVEJH00002E9i0`0000=BN000CUP00TiH
00E>FDiHCUQ>F4iI00=>F00KCUT004iIBUQ>FDYHCUU:F4iIBUQ>FDYHCUU:F000BSU:FDHiBUU:>DYI
ASU:FDXiBUU6>@0000]6>@0300126D8I00U26@03000n6ChI00Tn6@03000in@0000<00008=QXenCHJ
=OXf6SGi=QX000Moo`03001oogoo00=oo`007Goo00<007ooOol09Woo00D006LIIaUW6F/J00=W6@18
JaX006LIH_QW6F;hIaURn6LIH_QW6F;hIaURn6LIH_P006;HH_URf6;iH]QRnF;HH_URf6;iH]QRnF;H
H_URf000G]QRf000H]UN^5kIG[QRfEjhG]UN^6;IG[QNfEjhH]UN^5kI001N^@00G[UJ^5jiF[QN^EZh
G[UJ^5jiF[QN^EZhG[UJ^000EYQJ^EJH0P0001aJV5JHFYUFV5ZHEYQJVEJH001BN5JIDWQFVE9hEYUB
N5JIDWQFVE9hEYUBN000DWQBNE9hEWUBN0<0001DDUQBN59HDWUBF000CUQBFDiHDUU>F59ICUQBFDiH
DUU>F000BUQ>FDYHCUU:F4iIBUQ>FDYHCUU:F4iI001:FDHhBUU6>4YIASQ:FDHhBUU6>4YI0016>D8i
ASU2>4Hi@SU6>D8hASU2>DHi@SP003hI@STn648i?QU2>ChH@STn6D8i000n6CXI?QTj6ChI>QTn6CXI
?QTj6ChI>QT003Gi000enCWi0`0000Dj6SGi=QXen@0000Moo`03001oogoo00=oo`007Woo00<007oo
Ool09Woo0P001FLI00D006KiI_UVnFKh00=Vn@05I_QVnFKiI_UVn002I_T04P00H]P006;IH_URf6;i
H]URnF;HH_URfF;iH]QRnF;I001Nf0=Rf00=001NfEkHG]UNf5kIG]QNfEkHG]UNf5kIG]P00P000Ujh
00<005ZhF[T00eZh00EJ^EZhF[QJ^5Zi00=J^003F[T005Zi008000=FV005FYQFV5JHEYQJV003EYP0
3P00EYQFVEJHEYUFV5JIEYQFVEJHEYUFV5JI0002DWT30008DWP00`00CUU>F002CUP01DiICUQ>F4iH
CUT00diH01X004YHCUU:F4iIBUQ>FDYHCUU:F4iIBUQ>F@00BUU:>DYIASU:FDXiBUU6>DYIBSU:F@00
2dHi00<0048I@QT02D8I00<003hI?QT02ChI00D003Wi000inCGi00<in@@00003=OT007oo00Eoo`03
001oogoo00=oo`007goo0P00:7oo06D006LIIaU[6P00IaURn6LIH_QW6F;hIaURn6LIH_QW6F;hIaUR
n000H]QVnF;H001Rf6;iH]QRnF;HH_URf6;iH]QRnF;H001Nf6;HG]QRfEkHH]P006;IG[QNfEjhH]UN
^5kIG[QRfEjh001J^5jiF[QN^5Zh001J^5jiF[QN^EZhG[UJ^5jiF[QN^EZhG[UJ^5ji001JVEJHFYQF
V5ZIEYQJV5JHFYUFV5ZHEYQJV@00EYUBN5JIDWQFVE9hEYUBN5JIDWQFVE9h00<0001QDUQBN59HDWUB
F59hDUQBNE9HDWQBF59i001BFDiHDUU>F59ICUQBFDiHDUU>F59I001>FDYHCUU:F4iIBUQ>FDYHCUU:
F4iIBUP004HhBUU6>4YIASQ:FDHhBUU6>4YIASP0048hASU2>DHi@SQ6>D8iASU2>4Hi@ST003hH@STn
6D8i?QQ2>ChI@STn648i?QT003XI?QTj6ChI>QTn6CXI?QTj6ChI>QTn6@00>OT003Wi=OTinCGi>OTe
nCWi=OT00P001goo00<007ooOol00Woo000QOol00`00Oomoo`0VOol00`00IaT00003I_T01FKhI_UV
nFKiI_P00fKi019Vn6KiI_T006;HH_QRf6KhH]P006;IH_URf6;iH]URnF;HH_T200001EkHH]QRf6;H
G]P00f;H00X005kIG]QNfEkHG]UNf5kIG]P000IN^004001J^5ZhF[T3F[P01UZiF[QJ^5ZhF[UJ^080
0005FYP005JHEYQJV003EYP01EZHEYQFV5JHFYP00UJH00X005JIEYQFVEJHEYUFV5JIEYQFV@80009F
N003001BN59h00YBN003001>F4iI00=>F005CUU>F4iHCUQ>F@02CUP06P00CUU:F4iIBUQ>FDYHCUU:
F4iIBUQ>FDYH0016>DYIBSU:FDHiBUU:>DYIASU:FDXi000;AST00`00@QU26@09@QT00`00?QTn6@09
?QT01P00=OTin@00>OTen@<in@04=OTinCWi0007Ool00`00Oomoo`02Ool0029oo`03001oogoo02Io
o`17001W6F;hIaURn6LIH_QW6F;hIaURn6LIH_QW6F;h001Rf6KiH]QVnF;HI_URf000H]QRnF;HH_UR
f6;i001RfEkHH]QNf6;IG]QRf5kHH]UNf000G[QRfEjhG]UN^6;IG[P005ZhG[UJ^5jhF[QN^EZhG[P0
05jiF[QN^EZhG[UJ^5jiF[QN^EZh001JU`02FYP05P00EYQJVEJHFYQFV5ZIEYQJV5JHFYUFV5ZHEYP0
059hEYUBN5JIDWQFVE9h0P0006UFN59hEWQBN000DUQBNE9HDWQBF59iDUQBN59HDWUBF59h001BFDiH
DUU>F59ICUQBFDiHDUU>F59ICUP004YHCUU:F4iIBUQ>FDYHCUU:F4iIBUQ>F@00BUU6>4YIASQ:FDHh
BUU6>4YIASQ:F@00ASU2>4Hi@SU6>D8hASU2>DHi@SQ6>@00@STn648i?QU2>ChH@STn6D8i?QQ2>@00
?QTj6ChI>QTn6CXI?QTj6ChI>QTn6CXI000enCWi000inCGi>OTenCWi=OTinCGi00001Woo00<007oo
Ool00Woo000SOol00`00Oomoo`0VOol00`00I_UVn003I_T01FKhI_UVnFKiI_P00VKi018006;HH_QR
f6KhH]QRn6;HI_P006;iH]URnF;HH_T006;HG]P3H]P01EkHH]QRf6;HG]P00V;H00L005kHG]UNf5kI
G]P0000:G[P01000F[QJ^5Zi0eZh00=J^@0000001EZH00D005JHEYQFV5ZH00=FV00;FYQFV5JHEYQJ
V5JH001FV5JIEYQFV@0200001E9hEWQFN5IhDWP00UIh00<0059hDWP02U9h00@004iHCUQ>F@=>F00P
CUU>F4iHCUQ>FDiH001:F4iIBUQ>FDYHCUU:F4iIBUQ>FDYHCUT004YIASU:FDXiBUU6>DYIBSU:FDHi
BUT000]6>@0300126D8I00U26@03000n6ChI00Tn6@04000inCGi0002>OT01cGi>OTinCWi=OTin@00
00Ioo`03001oogoo009oo`0097oo0P009goo02`006LIH_QW6F;hIaURn6LIH_QW6F;h001Rf6KiH]QV
nF;HI_URf6KiH]QVn@00H_URf6;i001RfEkHH]QNf6;IG]QRf5kHH]UNf6;HG]QRfEkH001N^6;I0P00
015J^5jiF[QN^5ZhG[UJ^5jhF[QN^EZh001J^5jiF[QN^EZh00800003FYQJUeZH009JV00CFYMJV000
FYQFV5ZIEYQJV5JHFYUFV5ZHEYQJVEJHFYP005JIDWP00P0002eFN59hEWQBN5IhDWQFN59hEWP0059h
DUQBNE9HDWQBF59iDUQBN59HDWUBF000CUQBFDiHDUU>F59ICUQBFDiHDUU>F59I001>FDYHCUU:F4iI
BUQ>FDYHCUT07`000292>ChI@STn648i?QU2>ChH000j6ChI>QTn6CXI?QTj6ChI>QTn6CXI?QT003Wi
=OT003Gi>OTenCWi=OTinCGi>OT000Eoo`03001oogoo009oo`009Woo00<007ooOol09Goo0P0000EV
n6KiI_UVnFKh009Vn@0B001Rf6;hH]QVn6;HH_QRf6KhH]QRn6;HI_P006;i001Rf5kH0f;H00ENf6;H
H]QRf5kH00=Rf005G]QRf000G]T0000>G[P01@00F[QJ^5Zh00002UZH00<005ZHEYP00UJH00EJV5JH
EYQFV5ZH00=FV003FYP00000009FN005DWQFN5IhEWQBN003EWP00e9hEWP0000;DWP00`00CUU>F002
CUP01DiICUQ>F4iHCUT00diH00A>F@00CUU:F0H0009:>003CSP004Xh009:>005ASQ:>4XhBSQ6>003
BSP03@00ASQ664HhAQQ6>4HHASQ664HhAQQ6>00000926003@QT0000000@000=26@03000n6ChI00Tn
6@05000inCWi=OT00002>OT01SGi>OTinCWi=OT000Eoo`03001oogoo009oo`009goo00<007ooOol0
9Woo03T006;hIaURn6LIH_P006;HI_URf6KiH]QVnF;HI_URf6KiH]QVnF;HI_T006;IG]QRf5kHH]UN
f6;HG]QRfEkHH]QNf6;IG]QRf5kHH]T005jhF[QN^EZhG[QJ^5jiF[QN^5ZhG[UJ^5jhF[QN^@00G[T0
0P000UZH00EJUeZHFYQJV5ZG00=JV00=FYL005JHFYQFV5ZIEYQJV5JHFYUFV5ZHEYP00P0002IJN000
EWQBN5IhDWQFN59hEWQBN5IhDWQFN59h001BF59hDUQBNE9HDWQBF59iDUQBN59HDWT0059ICUQBFDiH
DUU>F59ICUQBFDiH1@0002]:>4iHBSQ>F4XhCUQ:>4iHBSQ>F000BSU6>4XhASQ:>DHhBSQ6>4XiASQ:
>000ASU664Hi@QQ6>DHHASU264HiAQQ6>@00@QU2648I@QQ26D8H@QU2600600005chI>QTn6CXI?QTj
6ChI>QTn6CXI000enCWi000inCGi>OTenCWi=OTinCGi000017oo00<007ooOol00Woo000XOol00`00
Oomoo`0VOol05P00I_QVnFKi001Rf6;hH]QVn6;HH_QRf6KhH]QRn6;HI_QRf6;h001Rf0000f;H00EN
f6;HH]QRf5kH00=Rf007G]QRf6;HH]P005jh00003ejh00<005ZHFYP035ZH00<005JHFYP00eJH00=J
V5JHEYP00P000eIh00<0059hEWP00UIh00EBN5IhEWQFN59h00=FN003DWP0059h00YBN003001>F4iI
00=>F003CUT000000080009>F003001>>4Xh009:>005CSQ:>4XhBSQ>>003BSP00`00ASQ:>002BSP0
1DHhBSQ:>4XhASP00TXh00d004HHASQ664HhAQQ6>4HHASQ664HhAQP00003@QP01D8I@QQ2648H@QT0
0d8H00<003gh?QP01@001ChI00D003Wi>OTin@0000<in@05=OTinCWi>OT00005Ool00`00Oomoo`01
Ool002Uoo`8002Moo`0B001Rn000H]QVnF;HI_URf6KiH]QVnF;HI_URf6KiH]QVn@000f;H00d006;I
G]QRf5kHH]UNf6;HG]QRfEkHH]QNf00200005V:hG[L005ZhG[QJ^5jiF[QN^5ZhG[UJ^5jhF[QN^EZh
G[P005jH001JV5ZG0eZH00EJUeZHFYQJV5ZG00=JV007001JVEJHFYQFV5ZIEYP00P00029JN5IgFWQF
MeYhEWL0059hEWQBN5IhDWQFN59hEWQBN5IhDWQFN000DWUBF59hDUQBNE9HDWQBF59iDUQBN59H001>
F0@00003CUQ>Ee9H009>F00jCUMBF000CUQ:>4iHBSQ>F4XhCUQ:>4iHBSQ>F4Xh0016>4XiASQ:>4Hh
BSU6>4XhASQ:>DHh001264HiAQQ6>D8HASU664Hi@QQ6>DHH0012648I@QQ26D8H@QU2648I@QQ26D8H
000mn3hI?OPn6Cgh?QT400003SXI?QT003Wi=OTin@00>OTenCWi=OTinCGi0005Ool00`00Oomoo`01
Ool002]oo`03001oogoo02Eoo`0@001Rf6;hH]QVn6;HH_QRf6KhH]QRn6;HI_QRf6;h0004H]P00`00
G]QRf002H]P01EkHH]QRf6;HG]P00V;H00<005jhG[P00ejh00<005jhG[P02Ejh0P0000=NV5ZG0000
3UZH00@005JHEYQJV08000QFN003001FN59h00=FN005DWQFN5IhEWQBN003EWP00`00DWQBN008DWP3
000;CUP00`00BSQ>>003BSP01DhhBSQ:>4XhCSP00TXh00<004XhASP00dXh01A6>4XhBSQ:>4HhBSP0
04HhAQQ6>4HHASQ664HhAQQ6>4HHASP0048I0d8H00E26D8H@QQ2648I0092600;000n6Cgh?QPmn3hI
?OPn63gh?QTmn0040003>OT01@00>OTinCWi=OT00SWi00<007ooOol00Woo00<007ooOol00Goo000/
Ool00`00Oomoo`0UOol03P00H]QVnF;HI_URf6KiH]QVnF;HI_URf6Ki0003H]P09V;GH]QRf000G]QR
fEkHH]QNf6;IG]QRf5kH001N]f:hG[MR^5jgH[P005jiF[QN^5ZhG[UJ^5jhF[QN^EZh001JUejHFYMN
V5ZG0002FYP01EZGFYQJV5ZHFYL00eZH00EJUeZHFYP005JH0080000OFWQFMeYhEWMJN5IgFWQFMeYh
EWMJN000EWQBN5IhDWQFN59hEWQBN5IhDWQFN59h001BF59iDUQBN59HDWT0100000A>E`00CUMBF09>
F006CUMBF4iHCUQ>Ee9H0TiH041>E`00BSQ>F4XhCUQ:>4iHBSQ>F4XhCUQ:>4iH001:>4HhBSU6>4Xh
ASQ:>DHhBSQ6>4Xi0016>D8HASU664Hi@QQ6>DHHASU264Hi00126D8H@QU2648I@QQ26D8H@QU2648I
000n6Cgh?QTmn3hI?OPn6Cgh?QTmn3hI000in@@00007=OTinCGi>OTenCWi000017oo00<007ooOol0
0Goo000]Ool00`00Oomoo`0UOol03000H]QRn6;HI_QRf6;hH]QVn6;HH_P000QRf003001Nf6;H009R
f004G]QRf6;H0008G[P00`00G[QN^006G[P02000FYQNV5ZGGYQJV5jH000>FYP00`00EWQFN00;EWP0
1000EWQFN59h0eIh00EBN5IhEWQFN59h009FN003001BN00000<000IBF003001>F4iH00Y>F004001:
>4XhCSP3BSP01dhhBSQ:>4XhCSQ:>000009:>005ASQ:>4XhBSQ6>003BSP044Hh001664HhAQQ6>4HH
ASQ664HhAQQ6>4HH0012648I0d8H01M26D8H@QQ2648I@QP003gh?QTmn3hH?OPn6Cgh?QPmn3hI?OPn
6000>OTin3Wi00<000<in@03=OTin@0000=oo`03001oogoo005oo`00;Woo0P009Woo00X006;HI_UR
f6KiH]QVnF;HI_T000=Rf005H]MRf6;HH]QRe`02H]P08P00G]QRfEkHH]QNf000G[MR^5jgH[QN]f:h
G[MR^5jgH[P005jiF[QN^5ZhG[UJ^000FYMNV5ZGGYQJUejHFYMNV0000eZH00EJUeZHFYQJV5ZG00=J
V080000KEWL005IgFWQFMeYhEWMJN5IgFWQFMeYhEWMJN5Ig001BN5IhDWQFN59hEWQBN5IhDWQFN59h
00<0000>CUMBF4iGDUQ>Ee9HCUMBF4iGDUP004iHCUMBF09>F006CUMBF4iHCUQ>Ee9H0TiH04<004iH
BSQ>F4XhCUQ:>4iHBSQ>F4XhCUP004XiASQ:>4HhBSU6>4XhASQ:>DHhBSP004HiAQQ6>D8HASU664Hi
@QQ6>DHHAST0048I@QQ26D8H@QU2648I@QQ26D8H@QT003hI?OPn6Cgh?QTmn3hI?OPn6Cgh?QTmn000
>OPinCWh?OTin003000013Gi>OTen@000goo00<007ooOol00Goo000`Ool00`00Oomoo`0TOol02000
H]QRn6;HI_QRf6;h000;H]P01000H]QNf6;H0P002ejh00<005jhG[P00ejh00/005ZHGYQJUejHFYQN
V5ZGGYQJV00000YJV005001JV5YgFYP0000=EWP01@00EWQFN5IhDWP00eIh00IBN5Ih0000059G000<
DUP00`00CUQ>F00:CUP01@00BSQ:>4XhCSP00dXh00I>>4XhBSQ:>4hh0003BSP01DHhBSQ:>4XhASP0
0dXh00d004HhAQQ6>4HHASQ664HhAQQ6>4HHASP00002@QP01D8I@QQ2648H@QT00d8H01I26@00?QPm
n3hI?OPn63gh?QTmn3hH?OPn6@00>OTin3Wi>OPinCWh000in0<00005=OT007ooOol00003Ool0035o
o`03001oogoo02=oo`07001VnF;HI_URf6Ki00000f;H00ERef;HH]QRf6;G00=Rf00FH]MRf000H]P0
06:hG[MR^5jgH[QN]f:hG[MR^5jgH[QN]f:hG[L005ZhG[T200003EZGGYQJUejHFYMNV5ZGGYQJUejH
FYL005ZG00=JV003FYMJV5ZH0080000JFYQFMeZHEWMJV000FWQFMeYhEWMJN5IgFWQFMeYhEWMJN5Ig
FWP005IhDWQFN59hEWQBN080000AEWQBEeIhDUL004iGDUQ>Ee9HCUMBF4iGDUQ>Ee9HCUL00002CUP0
1TiGDUQ>F4iHCUMBF09>F01;CUMBF4iH001:>4iHBSQ>F4XhCUQ:>4iHBSQ>F4Xh0016>4XiASQ:>4Hh
BSU6>4XhASQ:>DHh001264HiAQQ6>D8HASU664Hi@QQ6>DHH0012648I@QQ26D8H@QU2648I@QQ26D8H
000mn3hI?OPn6Cgh?QTmn3hI?OPn6Cgh?QT003gi>OPinCWh?OT003Wi>OPmnCWh008000=oo`40005o
o`5oo`00<Woo00<007ooOol08goo00D006KhH]QRn00000mRf003001N^5jh00eN^00A001N^000GYQJ
V5jHFYMNV5ZHGYQJUejHFYQNV5ZGGYP00005FYP2000025YgFYQJMeZHFWMJV5Yg000=EWP00`00DWQF
N002EWP200001e9GEUQBEeIHDUMFF00000aBF003001>F4iH00Y>F003001>>4Xh009:>005CSQ:>4Xh
BSQ>>003BSP00`00ASQ:>002BSP01DHhBSQ:>4XhASP00TXh00d004HHASQ664HhAQQ6>4HHASQ664Hh
AQP00003@QP01D8I@QQ2648H@QT00d8H01T003gh?QPmn3hI?OPn63gh?QTmn3hH?OP003Wh>OTin3Wi
>OPin@00>OTin3Wi>OP00003Ool10001Ool1Ool003=oo`8002Aoo`03001Vn@0000=Rf005H]MRf6;H
H]QRe`03H]P0AF;GH]QRf6;H001R^000H[QN]f:hG[MR^5jgH[QN]f:hG[MR^5jgH[QN]f:h001NV5ZG
GYQJUejHFYMNV5ZGGYQJUejHFYMNV5ZGGYP005ZHFYMJV000FYQFMeZHEWMJV5IgFYQFMeZHEWL005Ig
FWQFMeYhEWMJN5IgFWQFMeYhEWMJN5Ig001BN00200005eIhDUMFN59GEWQBEeIhDUMFN000DUQ>Ee9H
CUMBF4iGDUQ>Ee9HCUMBF000DUP00TiH00I>Ee9HCUQ>F4iGDUP2CUP0C4iGDUP004iHBSQ>F4XhCUQ:
>4iHBSQ>F4XhCUP004XhASQ:>DHhBSQ6>4XiASQ:>4HhBST004Hi@QQ6>DHHASU264HiAQQ6>D8HAST0
048I@QQ26D8H@QU2648I@QQ26D8H@QT003hI?OPn6Cgh?QTmn3hI?OPn6Cgh?QT003Wi>OPmnCWh>OTi
n3gi000inCWh?OTin0000Woo0@000Goo0Goo000eOol00`00Oomoo`0ROol00`00H]QRf00=H]P01000
H[QN]`003Ujh01<005jG001NV5ZGGYQJV5jHFYMNV5ZHGYQJUejHFYQNV5ZG001JV002000035ZHFWMJ
V5YgFYQJMeZHFWMJV5YgFYP000eFN080000<DUMFF59GEUQBEeIHDUMFF59GEUQBE`00359H00<004iH
CUP02TiH00<004XhCSP00dXh00E>>4XhBSQ:>4hh009:>003001:>4Hh00=:>00DASQ:>4XhBSQ6>4Xh
0016>4HHASQ664HhAQQ6>4HHASQ664Hh00126@=2600P@QU2648H@QQ26D8H000mn3hI?OPn63gh?QTm
n3hH?OPn6Cgh?QP003Wi>OPinCWh>OTin000>OPinCWh>OT0009oo`40005oo`5oo`00=Woo00<007oo
Ool08Woo00<006;HH]L00f;H00ERef;HH]QRf6;G00=Rf00A001R^5jgH[QN]`00G[MR^5jgH[QN]f:h
G[MR^5jgH[QN]`020000;5jhFYL005ZGGYQJUejHFYMNV5ZGGYQJUejHFYMNV5ZGGYQJU`00EWMJV5Ig
FYQFMeZHEWMJV5IgFYQFMeZHEWMJV000FWQFMeYhEWMJN5IgFWQFMeYhEWL30000759GEWQBEeIhDUMF
N59GEWQBEeIhDUMFN59G001>Ee9HCUMBF4iGDUQ>Ee9HCUMBF4iG001>Ee9H0TiH00I>Ee9HCUQ>F4iG
DUP2CUP01diG001:>4iHBSQ>F4Xh0240000R@QQ26D8H@QU2648I@QQ26D8H000mn3hI?OPn6Cgh?QTm
n3hI?OPn6Cgh000in3Wi>OPmnCWh>OTin000>OPinCWh0002Ool10001Ool1Ool003Moo`03001oogoo
025oo`03001Rf6;H00YRf007001R^5jgH[QR]f:h00002Ujh01@005jGGYMNUejHGYL005ZHGYQJUejH
FYQNV5ZGGYQJV5jHFYMNV5ZH0P0000mJV5YgFYQJMeZHFWMJV5YgFYQJMeZHFWMJV5Yg000025Ih0P00
015FMeIhEWL0059GEUQBEeIHDUMFF59GEUQBEeIHDUMFF00000aBF003001>F4iH00Q>F0P0025oo`@0
000Q@QU2648H@QQ26@00?QPmn3hI?OPn63gh?QTmn3hH?OPn6@00>OTin3Wi>OPinCWh>OTin000>OPi
nCWh001oo`00009oo`00>7oo00<007ooOol08Goo00@006;HH]QRe`=Rf003H]MRf6;H0080000SH[QN
]f:hG[MR^5jgH[P006:hG[MR^5jgH[QN]f:hG[L005jGG[QJUejhGYMN^000GYQJUejHFYMNV5ZGGYQJ
UejHFYMNV00200005eYgGYP005ZHEWMJV5IgFYQFMeZHEWMJV5IgFYQFMeZHEWL005IgFWQFMeYhEWL0
0P0002=FN5IgEWQFMeIh001FN59GEWQBEeIhDUMFN59GEWQBEeIhDUL004iGDUQ>Ee9HCUMBF4iGDUQ>
Ee9HCUMBF000CUQ>Ee9H009>F003CUL00000008002eoo`@0000K@QQ26@00?QTmn3hI?OPn6Cgh?QTm
n3hI?OPn6@00?OTin3Wi>OPmnCWh>OTin000>OPin@00009oo`40005oo`00>Goo0P008Woo00<006;H
H]P01F;H00`006:gH[QN]f:hH[MR^5jgH[QR]f:h0006G[P01@00GYMNUejGGYP00ejG00aNV000GYQJ
V5jHFYMNV5ZHGYQJUejH0004FYL04000FWMJV5YgFYQJMeZHFWMJV5YgFYQJMeZHFWMJV0000eIh0P00
0eIg01=FN5IgEWMFMeIh001FF59GEUQBEeIHDUMFF59GEUQBEeIHDUL0000<DUP00`00CUP00003000e
Ool500005Sgh?QTmn3hH?OPn6Cgh?QPmn000>OPinCWh>OTin3Wi>OPin@00>OTin0000Woo0@000Goo
000kOol00`00Oomoo`0OOol01@00H]QRf6;HH]L00V;H03/005jgH[QN]f:hG[MR^5jgH[QN]f:hG[L0
05jgH[QN]f:hG[L005jGG[QJUejhGYMN^5ZGG[QNU`00FYMNV5ZGGYQJUejHFYMNV000GYQJMejHFWMN
V5Yg001FMeZHEWMJV5IgFYQFMeZHEWMJV5IgFYQFMeZH00<0000SEWQFMeIhEWMFN5IgEWQFMeIhEWL0
059GEWQBEeIhDUMFN59GEWQBEeIhDUMFN000DUQ>Ee9HCUMBF4iGDUQ>Ee9HCUMBF003000nOol40000
5ChI?OPn6Cgh?QT003Wi>OPmnCWh>OTin3gi>OPin@00?OTin000Ool00001Ool003aoo`03001oogoo
01moo`03001Rf6;H009Rf00?001R]f:hG[MR^6:gH[QN]f:hH[MR^5jgH[QR]`00009N^08000=NU`05
GYQNUejGGYMNV003GYL02000FYMNV5ZHGYQJUejH0007FYL04P00FYQJMeZHFWMJV5YgFYQJMeZHFWMJ
V5YgFYQJM`00EWMFN0=FM`05EWQFMeIgEWMFN003EWL03P00DUMFF59GEUQBEeIHDUMFF59GEUQBEeIH
0007DUP30015Ool400004Cgh?QP003Wi>OPinCWh>OTin3Wi>OPin@00>OT007oo00000Goo000mOol0
0`00Oomoo`0OOol0?P00H]QRf000G[MR^5jgH[QN]f:hG[MR^5jgH[QN]f:hG[MR^000H[P005jhGYMN
^5ZGG[QNUejhFYMN^5jGG[QJUejh001NV5ZGGYQJUejH001NV5YgGYQJMejHFWMNV5YgGYP005ZHEWMJ
V5IgFYQFMeZHEWMJV5IgFYP3000085IhEWMFN5IgEWQFMeIhEWMFN5IgEWQFMeIh001FN59GEWQBEeIh
DUMFN59GEWQBEeIhDUL004iGDUQ>Ee9HCUL2001<Ool400002CWi>OPmnCWh>OTin3gi>OPin@020001
Ool10001Ool003ioo`8001moo`0E001Rf000H[MR^5jgH[QR]f:hG[MR^6:gH[QN]f:hH[MR^5jgH[P0
05jH00=NU`05GYQNUejGGYMNV003GYL01UjHGYMNU`00GYQJU`8000YJU`0@001JMeZHFWMJV5YgFYQJ
MeZHFWMJV000FWMFMeYg0002EWL01EIhEWMFMeIgEWP00eIg019FN5Ig001BEeIHDUMFF59GEUQBEeIH
DUMFF59GEUQBE`00DUP3001BOol3000023Wi>OPinCWh>OTin000>OP20001Ool0041oo`03001oogoo
01eoo`1J001N]f:hG[MR^5jgH[QN]f:hG[MR^5jgH[QN]f:hG[MR^000H[P005jhFYMN^5jGG[QJUejh
GYMN^5ZGG[QNUejhFYL005ZG001JMejHFWMNV5YgGYQJMejHFWMNV5YgGYQJM`00EWMJV5IgFYQFMeZH
EWMJV000FWMFMeYhEWL005IgEWQFMeIhEWMFN5IgEWQFMeIhEWMFN5Ig001BEeIhDUMFN59GEWQBEeIh
DUMFN59G0`00F7oo0`0000@inCWh?OTin0<0005oo`00@Goo00<007ooOol07Goo01D005jgH[QR]f:h
G[MR^6:gH[QN]f:hH[MR^5jgH[P006:gGYL005jGGYP00ejG00ENV5jGGYMNUejH00=NU`03GYQNU`00
00iJU`07001JV5YgFYQJMeZHFWL00P0000MJMeIgFWMFMeYgEWL00003EWL01EIhEWMFMeIgEWP00eIg
00]FN000EUQBEeIHDUMFF59GEUQBEeIH008005ioo`800005>OPinCWh001oo`010000049oo`03001o
ogoo01aoo`1E001R^5jgH[QN]f:hG[MR^5jgH[QN]f:hG[MR^000H[QNUf:gGYL005jGG[QJUejhGYMN
^5ZGG[QNUejhFYMN^5jG001JU`00FWMNV5YgGYQJMejHFWMNV5YgGYQJMejHFWMNV000FYQFMeZHEWL0
05IgFWMFMeYhEWMJMeIgFWP005IhEWMFN5IgEWQFMeIhEWMFN5IgEWQFMeIh001FN59GEWQBEeIhDUL0
0P00HWoo0`000CWh0@000@000013Ool2000MOol04`00H[QN]f:hH[MR^5jgH[QR]f:hG[MR^000H[MN
UejgGYMR]`00009NU`05GYQNUejGGYMNV003GYL00ejH00000002GYL00`00FYMJU`0<FYL04@00FWMJ
V5Yg001FMeYgEWMJMeIgFWMFMeYgEWMJM`00EWP00eIg00EFN5IgEWMFMeIh00=FM`05001BEeIHDUMF
F002001WOol3000004Eoo`03001oogoo01]oo`0a001R^5jgH[QN]f:hG[MR^5jgH[P006:hGYMR]ejG
H[QNUf:g001N^5jGG[QJUejhGYMN^5ZGG[P005jGFYMNV5ZGGYL005jHFWMNV5YgGYQJMejHFWMNV5Yg
GYQJMejHFWL00`0001]FMeYgEWMJN5IgFWMFMeYhEWMJMeIg001FMeIhEWMFN5IgEWQFMeIhEWMFN5Ig
EWQFM`00DUL00P00JWoo0P000016Ool00`00Oomoo`0KOol04P00H[QN]f:hH[MR^5jgH[P006:gGYMN
]ejGH[MNUejgGYL000=NU`06GYQNUejGGYMNV0000ejG00AJUejGGYL000iJU`0?001JMeIgFWMFMeYg
EWMJMeIgFWMFMeYgEWMJM`00009FM`05EWQFMeIgEWMFN003EWL00eIhEWMFM`02001XOol40002Ool0
04Moo`03001oogoo01Yoo`0^001N]f:hG[MR^5jgH[P006:hGYMR]ejGH[QNUf:gGYMR^5jG001JUejh
GYMN^5ZGG[P005jGFYMNV5ZGGYMJUejHFYL005YgGYQJMejHFWMNV5YgGYQJMejHFWL300006EIgFWMF
MeYhEWMJMeIgFWQFMeYgEWMJN5IgFWL005IhEWMFN5IgEWQFMeIhEWMFN5Ig008006Ioo`@000Ioo`00
B7oo0P006goo01<006:gH[QN]f:h001R]ejGG[MNUf:gGYMN]ejGH[MNUejg001NV003GYL00ejH001N
U`02GYL01eZGGYMNUejGFYMNU`0000YJU`0C001JMeYgFWL005IgFWMFMeYgEWMJMeIgFWMFMeYgEWMJ
MeIg00000eIg00EFN5IgEWMFMeIh008006Aoo`@000Yoo`00BWoo00<007ooOol06Goo01@005jgH[P0
06:hGYMR]ejGH[QNUf:gGYMR^5jGH[MNUf:h001N^5ZG0P0001INUeZGGYQJUejGFYMNV5ZGGYMJUejH
001NV5YgGYQJMejHFWMNV5Yg001JMP=JM`0E001JN5IgFWMFMeYhEWMJMeIgFWQFMeYgEWMJN5Ig001F
MeIhEWMFN5Ig0080069oo`@000ioo`00Bgoo00<007ooOol067oo01D006:h001R]ejGG[MNUf:gGYMN
]ejGH[MNUejgGYMR]ejG001NU`00FYL00ejG00EJUejGGYMNUeZG00=NU`03FYL005ZG00EJU`8000IJ
M`0@001JMeIgFWMFMeYgEWMJMeIgFWMFMeYgEWMJM`00EWP2EWL2001POol4000BOol004aoo`03001o
ogoo01Qoo`0Y001R^5jGH[MNUf:hGYMR]ejGH[QNUf:gGYMR^5jGH[MNU`00FYMNUeZGGYQJUejGFYMN
V5ZGGYMJUejHFYMNUeZG001JMejHFWMNV000FWMJMP03FWL04UYfFWMJM`00EWMJN5IgFWMFMeYhEWMJ
MeIgFWQFMeYgEWMJN0<005moo`<001Ioo`00CGoo0P006Goo018005jgGYMR]ejGG[MNUf:gGYMN]ejG
H[MNUejgGYL005jG0002GYL01EZGGYMNUejGFYL00ejG00EJUejGGYMNU`0000=JU`03001JMeYg00QJ
M`0?001FMeYgEWMJMeIgFWMFMeYgEWMJMeIgFWMFM`0005eoo`@001Uoo`00Cgoo00<007ooOol05Woo
00l005jGH[QNUf:gGYMR^5jGH[MNUf:hGYMR]ejG00000UjG010005jHFYMNUeZGGYQJUejGFYMNV5ZG
GYMJUejHFYMNU`<00003FWMJMUYg009JM`0BFWIJMeYgFWMJMUYg001JMeIgFWQFMeYgEWMJN5IgFWMF
MeYh0P00FWoo10007Goo001@Ool00`00Oomoo`0FOol03@00GYMN]ejGH[MNUejgGYMR]ejGG[MNU`00
00ANU`05001NUejGGYMJU`03GYL01EZGGYMNUejGFYL00UjG00<005YgFWL035Yg00/005YgEWMJMeIg
FWMFMeYgEWMJM`0005Qoo`@0025oo`00DGoo00<007ooOol05Goo00`006:gGYMR^5jGH[MNUf:hGYMR
]ejG0002GYL04EjFGYMNU`00FYMNV5ZGGYMJUejHFYMNUeZGGYQJUejGFYL00P0000=JMeYfFWL00UYg
00EJMUYgFWMJMeYf00=JM`09FWH005IgFWMFMeYhEWMJMeIg008005Eoo`@002Eoo`00DWoo00<007oo
Ool05Goo00X006:gGYMN]ejGH[MNUejgGYL000MNU`03001JUejG009NU`06FYMNUejGGYMJUejG0P00
0UYg00<005YgFWL035Yg00D005IgFWMFMeYg008005=oo`@002Uoo`00Dgoo0P005Goo00T005jGH[MN
Uf:hGYMR]ejG00000UjG01INUUjGGYMNUejFGYL005jGFYMNV5ZGGYMJUejHFYMNU`00GYMJMUjGFWH0
009JM`05FWIJMeYgFWMJMP03FWL02EYfFWMJMeYg001JN5IgFWL0001BOol3000]Ool005Eoo`03001o
ogoo01=oo`07001NUf:gGYMN]ejG00002UjG00<005jGFYL00ejG00AJUejG001NM`=JM`03GWMJM`00
00iJM`<004moo`@0031oo`00EWoo00<007ooOol04Woo00H006:hGYMR]ejG0002GYL01EjFGYMNUejG
GYH00ejG015NUP00FYMNUeZGGYQJUejG001NUeYfGYMJMUjGFWINU`0000=JM`05FWIJMeYgFWMJMP03
FWL015YfFWMJM`00CGoo1000=7oo001GOol00`00Oomoo`0BOol01000G[MNU`003EjG00L005jGGYMJ
UejG001NM`03FWL01UigFWMJMeYgGWL000]JM`8004Yoo`@003Qoo`00F7oo0P004Woo00<005jG0000
0UjG00ENUUjGGYMNUejF00=NU`07GYINUejGGYL005jHFYL00P0000aNUeYfGYMJMUjGFWINUeYfGYMJ
MP00FWH3FWL01eYfFWMJMeYgFWIJM`0004Qoo`@003aoo`00FWoo00<007ooOol047oo00<005jGGYL0
3UjG0P0000=JMeigFWL00UYg00ENMeYgFWMJMeig00=JM`03001JMeYg00IJM`03001oogoo04=oo`@0
041oo`00Fgoo00<007ooOol047oo00<005jFGYL00UjG00ENUUjGGYMNUejF00=NU`0EGYINUejG001J
MUjGFWINUeYfGYMJMUjGFWINUeYfGYMJMUjG001JMeYf00=JM`03FWH0000004=oo`<004Aoo`00G7oo
00<007ooOol03goo00<005jGGYL035jG0P0000ENMeYgFWMJMeig00=JM`05GWMJMeYgFWMNM`02FWL0
0`00FWMJM`02FWL00`00Oomoo`0oOol40017Ool005eoo`80011oo`03001NUejF00=NU`05GYINUejG
GYMNUP02GYL04`00FWINU`00GYMJMUjGFWINUeYfGYMJMUjGFWINUeYfGYMJMP00009JM`03FWH007oo
03eoo`@004]oo`00Ggoo00<007ooOol03Goo00<005jGGYL02EjG00L005ifGYMNMP00FWMNM`03FWL0
1EigFWMJMeYgGWL00eYg00=NMeYg00000P00>goo1000Cgoo001POol00`00Oomoo`0=Ool01000GYMN
UejF0ejG01UNUUjGGYL005YfGYMJMUjGFWH005YfGYMJMUjGFWINUeYfGYMJMUjGFWINUeYfGYL0000i
Ool4001COol0065oo`03001oogoo00eoo`03001NUejG00ENU`08001NMUjGGWINUeifGYL0009JM`05
GWMJMeYgFWMNM`03FWL015igFWMJM`00=Woo1000Egoo001ROol2000=Ool01@00GYMNUejGGYH00ejG
01<005jGFWINUeYfGYMJMUjG001NUeYfGYMJMUjGFWINUeYfGYMJMP02000cOol4001KOol006Aoo`03
001oogoo00]oo`03001NUejG00=NU`0:001NUeifGYMNMUjGGWINUeif0003FWL01eigFWMJMeYgGWMJ
M`00039oo`<005moo`00IGoo00<007ooOol02Woo00<005jFGYL00UjG01@005jGFWINUeYfGYMJMUjG
FWINUeYf001JMUjGFWINUeYfGYMJMP00;goo1000HWoo001VOol00`00Oomoo`0:Ool04@00GYMNU`00
GYMNMUjGGWINUeifGYMNMUjGGWINU`00GWL00eYg00=NMeYg0000;7oo1000IWoo001WOol2000:Ool0
5P00GYL005jGFWINUeYfGYMJMUjGFWINUeYfGYMJMUjG001NUeYfGYMJMP00:Goo1000JWoo001YOol0
0`00Oomoo`08Ool04P00GYMNMUjGGWINUeifGYMNMUjGGWINUeifGYMNMP00FWMNM`8002Ioo`@006io
o`00JWoo00<007ooOol01goo010005YfGYMJMUjGFWINUeYfGYMJMUjGFWINUeYfGYMJMP8002Aoo`@0
079oo`00Jgoo00<007ooOol01goo010005ifGYMNMUjGGWINUeifGYMNMUjGGWINUeifGYL0029oo`<0
07Ioo`00K7oo00<007ooOol01Woo00l005jGFWINUeYfGYMJMUjGFWINUeYfGYMJMUjG00007goo1000
NGoo001]Ool20007Ool03@00GYMNMUjGGWINUeifGYMNMUjGGWINU`0001aoo`@007eoo`00Kgoo00<0
07ooOol017oo00`005YfGYMJMUjGFWINUeYfGYMJMUjG000IOol40021Ool0071oo`03001oogoo00Ao
o`0:001NMUjGGWINUeifGYMNMUjG000FOol40025Ool0075oo`03001oogoo00=oo`09001NUeYfGYMJ
MUjGFWINU`0001=oo`@008Uoo`00LWoo0P0017oo00P005jGGWINUeifGYMNMP0047oo0`00SGoo001d
Ool02`00Oomoogoo001JMUjGFWINUeYf00003Goo1000T7oo001eOol02@00Oomoogoo001NMUjGGWH0
000:Ool4002DOol007Ioo`07001oogoo001NUeYf00001goo1000V7oo001gOol200000goo00000004
Ool4002LOol007Uoo`800003Ool0000000800:1oo`00NWoo0P00Y7oo003oOolQOol00?moob5oo`00
ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.563, 0}} -> {-0.0454698, 0.0394782, \
0.00347758, 0.00347758}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Previous Commands", "Section"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has a built-in history feature. Note that each expression you enter has \
In[#] and Out[#] next to the input and output. You can recall previous \
outputs using the % command. For example:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(1 + 1\)], "Input"],

Cell[BoxData[
    \(2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% + 2\)], "Input"],

Cell[BoxData[
    \(4\)], "Output"]
}, Open  ]],

Cell["This command displays the third item in the history:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(%3\)], "Input"],

Cell[BoxData[
    \(x\^2 + y\^2\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Making Things Pretty", "Section"],

Cell["\<\
There are some functions that only affect the display of a variable. Useful \
ones include MatrixForm and TableForm, for example:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(a = {{1, 2}, {4, 3}}\)], "Input"],

Cell[BoxData[
    \({{1, 2}, {4, 3}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(a // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "2"},
            {"4", "3"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[a]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "2"},
          {"4", "3"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
One other thing you may want to do is suppress output in certain cases. To do \
this, add a semicolon to the end of the line:\
\>", "Text"],

Cell[BoxData[
    \(\(a = {1, 2, 3, 4};\)\)], "Input"],

Cell[TextData[{
  "Note that there is no output, but you can still access the result, both \
through the variable ",
  StyleBox["a",
    FontSlant->"Italic"],
  ", and through the history:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(%\)], "Input"],

Cell[BoxData[
    \({1, 2, 3, 4}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(a\)], "Input"],

Cell[BoxData[
    \({1, 2, 3, 4}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " also includes a way of inputting mathematical expressions in standard \
form. Ctrl+2 creates a graphical square root, for example:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\@2\)], "Input"],

Cell[BoxData[
    \(\@2\)], "Output"]
}, Open  ]],

Cell["\<\
Hit Ctrl+Space to escape from a graphical template. Try to enter the \
following expression on your own, in a new notebook:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\@2 + 1\)], "Input"],

Cell[BoxData[
    \(1 + \@2\)], "Output"]
}, Open  ]],

Cell["\<\
Ctrl+6 creates an exponent, and Ctrl+/ creates a fraction. In the fraction, \
Tab moves to the next box.\
\>", "Text"],

Cell[BoxData[
    \(\(x\^2 + y\^2\)\/2\)], "Input"],

Cell["\<\
Again, try to enter this expression on your own. I used the key sequence \
Ctrl+/ x Ctrl+6 2 Ctrl+Space + y Ctrl+6 2 Ctrl+Space Tab 2 Ctrl+Space Enter. \
Seem like more work than it's worth? Wait until you have to debug an \
expression like\
\>", "Text"],

Cell[BoxData[
    \(\(\(rawdata[\([i, 2]\)]\ rawdata[\([i, 7]\)]\)\/rawdata[\([i, 4]\)] - \
\(blankdata[\([i, 2]\)]\ blankdata[\([i, 5]\)]\)\/blankdata[\([i, \
4]\)]\)\/\(rawdata[\([i, 5]\)]\/rawdata[\([i, 4]\)] - \
PMTflare\/PMTflarePickOff\)\)], "Input"],

Cell["\<\
and you'll gain new appreciation for the benefits of graphical input! The \
alternative is:\
\>", "Text"],

Cell[BoxData[
    \(\((rawdata[\([i, 2]\)] rawdata[\([i, 7]\)]/rawdata[\([i, 4]\)] - 
          blankdata[\([i, 2]\)] 
            blankdata[\([i, 5]\)]/
              blankdata[\([i, 4]\)])\)/\((rawdata[\([i, 5]\)]/
            rawdata[\([i, 4]\)] - PMTflare/PMTflarePickOff)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Further Reading", "Section"],

Cell["\<\
The Help files can teach you how to do pretty much anything in relatively \
short order. Just hit F1, and search the Master Index (click that button) to \
get everything from discrete tools to graphical directives to plotting \
options. \
\>", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 951}},
WindowSize->{1143, 663},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 103, 4, 105, "Title"],

Cell[CellGroupData[{
Cell[1867, 59, 25, 0, 53, "Section"],
Cell[1895, 61, 181, 4, 33, "Text"],
Cell[2079, 67, 38, 1, 30, "Input"],
Cell[2120, 70, 374, 6, 52, "Text"],

Cell[CellGroupData[{
Cell[2519, 80, 38, 1, 30, "Input"],
Cell[2560, 83, 35, 1, 29, "Output"]
}, Open  ]],
Cell[2610, 87, 519, 8, 71, "Text"],
Cell[3132, 97, 151, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[3308, 104, 40, 1, 30, "Input"],
Cell[3351, 107, 35, 1, 29, "Output"]
}, Open  ]],
Cell[3401, 111, 225, 6, 33, "Text"],

Cell[CellGroupData[{
Cell[3651, 121, 40, 1, 30, "Input"],
Cell[3694, 124, 179, 3, 24, "Message"],
Cell[3876, 129, 44, 1, 29, "Output"]
}, Open  ]],
Cell[3935, 133, 441, 10, 52, "Text"],

Cell[CellGroupData[{
Cell[4401, 147, 45, 1, 30, "Input"],
Cell[4449, 150, 44, 1, 29, "Output"]
}, Open  ]],
Cell[4508, 154, 288, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[4821, 163, 40, 1, 30, "Input"],
Cell[4864, 166, 41, 1, 29, "Output"]
}, Open  ]],
Cell[4920, 170, 210, 5, 33, "Text"],
Cell[5133, 177, 338, 11, 33, "Text"],

Cell[CellGroupData[{
Cell[5496, 192, 54, 1, 30, "Input"],
Cell[5553, 195, 45, 1, 45, "Output"]
}, Open  ]],
Cell[5613, 199, 143, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[5781, 206, 55, 1, 30, "Input"],
Cell[5839, 209, 42, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5918, 215, 55, 1, 30, "Input"],
Cell[5976, 218, 45, 1, 29, "Output"]
}, Open  ]],
Cell[6036, 222, 327, 9, 33, "Text"],

Cell[CellGroupData[{
Cell[6388, 235, 53, 1, 30, "Input"],
Cell[6444, 238, 38, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6519, 244, 54, 1, 30, "Input"],
Cell[6576, 247, 35, 1, 29, "Output"]
}, Open  ]],
Cell[6626, 251, 326, 9, 33, "Text"],

Cell[CellGroupData[{
Cell[6977, 264, 46, 1, 30, "Input"],
Cell[7026, 267, 45, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7108, 273, 34, 1, 30, "Input"],
Cell[7145, 276, 45, 1, 29, "Output"]
}, Open  ]],
Cell[7205, 280, 97, 2, 33, "Text"],
Cell[7305, 284, 38, 1, 30, "Input"],
Cell[7346, 287, 135, 5, 33, "Text"],

Cell[CellGroupData[{
Cell[7506, 296, 34, 1, 30, "Input"],
Cell[7543, 299, 35, 1, 29, "Output"]
}, Open  ]],
Cell[7593, 303, 151, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[7769, 310, 38, 1, 30, "Input"],
Cell[7810, 313, 52, 1, 29, "Output"]
}, Open  ]],
Cell[7877, 317, 103, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[8005, 324, 40, 1, 30, "Input"],
Cell[8048, 327, 52, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8137, 333, 42, 1, 30, "Input"],
Cell[8182, 336, 37, 1, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8256, 342, 51, 1, 30, "Input"],
Cell[8310, 345, 53, 1, 29, "Output"]
}, Open  ]],
Cell[8378, 349, 201, 4, 33, "Text"],

Cell[CellGroupData[{
Cell[8604, 357, 46, 1, 30, "Input"],
Cell[8653, 360, 37, 1, 30, "Output"]
}, Open  ]],
Cell[8705, 364, 105, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[8835, 371, 42, 1, 30, "Input"],
Cell[8880, 374, 72, 1, 29, "Output"]
}, Open  ]],
Cell[8967, 378, 230, 4, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9234, 387, 24, 0, 53, "Section"],
Cell[9261, 389, 272, 6, 33, "Text"],

Cell[CellGroupData[{
Cell[9558, 399, 62, 1, 30, "Input"],
Cell[9623, 402, 63, 1, 29, "Output"]
}, Open  ]],
Cell[9701, 406, 311, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[10037, 415, 41, 1, 30, "Input"],
Cell[10081, 418, 35, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10153, 424, 40, 1, 30, "Input"],
Cell[10196, 427, 60, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10293, 433, 43, 1, 30, "Input"],
Cell[10339, 436, 39, 1, 29, "Output"]
}, Open  ]],
Cell[10393, 440, 49, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[10467, 444, 43, 1, 30, "Input"],
Cell[10513, 447, 57, 1, 29, "Output"]
}, Open  ]],
Cell[10585, 451, 32, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[10642, 455, 48, 1, 30, "Input"],
Cell[10693, 458, 50, 1, 29, "Output"]
}, Open  ]],
Cell[10758, 462, 135, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[10918, 469, 51, 1, 30, "Input"],
Cell[10972, 472, 43, 1, 29, "Output"]
}, Open  ]],
Cell[11030, 476, 438, 9, 52, "Text"],
Cell[11471, 487, 116, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[11612, 494, 53, 1, 30, "Input"],
Cell[11668, 497, 50, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11755, 503, 56, 1, 30, "Input"],
Cell[11814, 506, 35, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11886, 512, 46, 1, 30, "Input"],
Cell[11935, 515, 35, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12007, 521, 46, 1, 30, "Input"],
Cell[12056, 524, 35, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12128, 530, 45, 1, 30, "Input"],
Cell[12176, 533, 50, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12263, 539, 39, 1, 30, "Input"],
Cell[12305, 542, 40, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12382, 548, 43, 1, 30, "Input"],
Cell[12428, 551, 80, 1, 42, "Output"]
}, Open  ]],
Cell[12523, 555, 76, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[12624, 559, 47, 1, 30, "Input"],
Cell[12674, 562, 50, 1, 29, "Output"]
}, Open  ]],
Cell[12739, 566, 193, 4, 33, "Text"],

Cell[CellGroupData[{
Cell[12957, 574, 67, 1, 30, "Input"],
Cell[13027, 577, 76, 1, 29, "Output"]
}, Open  ]],
Cell[13118, 581, 66, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[13209, 585, 72, 1, 30, "Input"],
Cell[13284, 588, 364, 5, 47, "Output"]
}, Open  ]],
Cell[13663, 596, 329, 9, 43, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[14029, 610, 47, 0, 33, "Section"],
Cell[14079, 612, 262, 5, 52, "Text"],
Cell[14344, 619, 86, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[14455, 625, 56, 1, 30, "Input"],
Cell[14514, 628, 43, 1, 29, "Output"]
}, Open  ]],
Cell[14572, 632, 53, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[14650, 636, 53, 1, 30, "Input"],
Cell[14706, 639, 43, 1, 29, "Output"]
}, Open  ]],
Cell[14764, 643, 122, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[14911, 650, 52, 1, 30, "Input"],
Cell[14966, 653, 35, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15038, 659, 53, 1, 30, "Input"],
Cell[15094, 662, 36, 1, 29, "Output"]
}, Open  ]],
Cell[15145, 666, 249, 6, 33, "Text"],

Cell[CellGroupData[{
Cell[15419, 676, 60, 1, 30, "Input"],
Cell[15482, 679, 43, 1, 29, "Output"]
}, Open  ]],
Cell[15540, 683, 295, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[15860, 692, 46, 1, 30, "Input"],
Cell[15909, 695, 35, 1, 29, "Output"]
}, Open  ]],
Cell[15959, 699, 53, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[16037, 703, 58, 1, 30, "Input"],
Cell[16098, 706, 43, 1, 29, "Output"]
}, Open  ]],
Cell[16156, 710, 193, 4, 33, "Text"],

Cell[CellGroupData[{
Cell[16374, 718, 71, 1, 30, "Input"],
Cell[16448, 721, 52, 1, 29, "Output"]
}, Open  ]],
Cell[16515, 725, 57, 0, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[16609, 730, 36, 0, 33, "Section"],
Cell[16648, 732, 93, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[16766, 738, 57, 1, 30, "Input"],
Cell[16826, 741, 17862, 475, 186, 4466, 305, "GraphicsData", "PostScript", \
"Graphics"],
Cell[34691, 1218, 130, 3, 29, "Output"]
}, Open  ]],
Cell[34836, 1224, 88, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[34949, 1230, 52, 1, 30, "Input"],
Cell[35004, 1233, 49, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35090, 1239, 44, 1, 30, "Input"],
Cell[35137, 1242, 8546, 275, 186, 2769, 199, "GraphicsData", "PostScript", \
"Graphics"],
Cell[43686, 1519, 130, 3, 29, "Output"]
}, Open  ]],
Cell[43831, 1525, 303, 9, 33, "Text"],

Cell[CellGroupData[{
Cell[44159, 1538, 77, 1, 30, "Input"],
Cell[44239, 1541, 936, 14, 141, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45212, 1560, 44, 1, 30, "Input"],
Cell[45259, 1563, 10291, 346, 186, 3739, 261, "GraphicsData", "PostScript", \
"Graphics"],
Cell[55553, 1911, 130, 3, 29, "Output"]
}, Open  ]],
Cell[55698, 1917, 213, 6, 33, "Text"],
Cell[55914, 1925, 141, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[56080, 1932, 82, 1, 30, "Input"],
Cell[56165, 1935, 87361, 1599, 242, 20844, 773, "GraphicsData", "PostScript", \
"Graphics"],
Cell[143529, 3536, 137, 3, 29, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[143715, 3545, 36, 0, 33, "Section"],
Cell[143754, 3547, 273, 6, 33, "Text"],

Cell[CellGroupData[{
Cell[144052, 3557, 38, 1, 30, "Input"],
Cell[144093, 3560, 35, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[144165, 3566, 38, 1, 30, "Input"],
Cell[144206, 3569, 35, 1, 29, "Output"]
}, Open  ]],
Cell[144256, 3573, 68, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[144349, 3577, 35, 1, 30, "Input"],
Cell[144387, 3580, 45, 1, 29, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[144481, 3587, 39, 0, 33, "Section"],
Cell[144523, 3589, 153, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[144701, 3596, 53, 1, 30, "Input"],
Cell[144757, 3599, 50, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[144844, 3605, 48, 1, 30, "Input"],
Cell[144895, 3608, 189, 6, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[145121, 3619, 45, 1, 30, "Input"],
Cell[145169, 3622, 245, 9, 55, "Output"]
}, Open  ]],
Cell[145429, 3634, 149, 3, 33, "Text"],
Cell[145581, 3639, 54, 1, 30, "Input"],
Cell[145638, 3642, 201, 6, 33, "Text"],

Cell[CellGroupData[{
Cell[145864, 3652, 34, 1, 30, "Input"],
Cell[145901, 3655, 46, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[145984, 3661, 34, 1, 30, "Input"],
Cell[146021, 3664, 46, 1, 29, "Output"]
}, Open  ]],
Cell[146082, 3668, 215, 5, 33, "Text"],

Cell[CellGroupData[{
Cell[146322, 3677, 36, 1, 32, "Input"],
Cell[146361, 3680, 37, 1, 30, "Output"]
}, Open  ]],
Cell[146413, 3684, 147, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[146585, 3691, 40, 1, 32, "Input"],
Cell[146628, 3694, 41, 1, 30, "Output"]
}, Open  ]],
Cell[146684, 3698, 128, 3, 33, "Text"],
Cell[146815, 3703, 51, 1, 45, "Input"],
Cell[146869, 3706, 264, 5, 52, "Text"],
Cell[147136, 3713, 256, 4, 65, "Input"],
Cell[147395, 3719, 115, 3, 33, "Text"],
Cell[147513, 3724, 291, 5, 50, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[147841, 3734, 34, 0, 33, "Section"],
Cell[147878, 3736, 261, 5, 52, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

